@@ -3,27 +3,27 @@
     <name>GuideGrid</name>
     <message>
         <source>Recording Once</source>
-        <translation>Gravar una sola vegada</translation>
+        <translation type="obsolete">Gravar una sola vegada</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Gravar en la franja horària</translation>
+        <translation type="obsolete">Gravar en la franja horària</translation>
     </message>
     <message>
         <source>Channel Recording</source>
-        <translation>Gravar en aquest canal</translation>
+        <translation type="obsolete">Gravar en aquest canal</translation>
     </message>
     <message>
         <source>All Recording</source>
-        <translation>Gravar sempre</translation>
+        <translation type="obsolete">Gravar sempre</translation>
     </message>
     <message>
         <source>Not Recording</source>
-        <translation>No gravar</translation>
+        <translation type="obsolete">No gravar</translation>
     </message>
     <message>
         <source>Weekly Recording</source>
-        <translation>Gravar setmanalment</translation>
+        <translation type="obsolete">Gravar setmanalment</translation>
     </message>
 </context>
 <context>
@@ -162,8 +162,8 @@
 <context>
     <name>MythContext</name>
     <message>
-        <source>Connection to the master backend server timed out.  You probably should modify the Mater Server setting in the setup program and set the proper IP address there.</source>
-        <translation>La connexió amb el backend ha fallat. Probablement hauries de comprovar que tens d&apos;adreça IP correcta a la configuració.</translation>
+        <source>Connection to the master backend server timed out.  You probably should modify the Master Server setting in the setup program and set the proper IP address there.</source>
+        <translation type="obsolete">La connexió amb el backend ha fallat. Probablement hauries de comprovar que tens d&apos;adreça IP correcta a la configuració.</translation>
     </message>
     <message>
         <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
@@ -350,6 +350,10 @@
         <source>Cancel</source>
         <translation>Cancel·lar</translation>
     </message>
+    <message>
+        <source>Yes; allow re-recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProgFinder</name>
@@ -402,31 +406,62 @@
     <name>ProgLister</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Gravar només aquest programa</translation>
+        <translation type="obsolete">Gravar només aquest programa</translation>
     </message>
     <message>
         <source>Recording every day when shown in this timeslot</source>
-        <translation>Gravar cada dia quan s&apos;emeti en aquesta hora</translation>
+        <translation type="obsolete">Gravar cada dia quan s&apos;emeti en aquesta hora</translation>
     </message>
     <message>
         <source>Recording every week when shown in this timeslot</source>
-        <translation>Gravar setmanalment quan s&apos;emeti en aquesta hora</translation>
+        <translation type="obsolete">Gravar setmanalment quan s&apos;emeti en aquesta hora</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Gravar quan aparegui en aquest canal</translation>
+        <translation type="obsolete">Gravar quan aparegui en aquest canal</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Gravar sempre que aparegui</translation>
+        <translation type="obsolete">Gravar sempre que aparegui</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>No gravar aquest programa</translation>
+        <translation type="obsolete">No gravar aquest programa</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>Error!</translation>
+        <translation type="obsolete">Error!</translation>
+    </message>
+</context>
+<context>
+    <name>ProgramRecPriority</name>
+    <message>
+        <source>Recording just this showing</source>
+        <translation type="unfinished">Gravar només aquest programa</translation>
+    </message>
+    <message>
+        <source>Recording every week</source>
+        <translation type="unfinished">Gravar cada setmana</translation>
+    </message>
+    <message>
+        <source>Recording when shown in this timeslot</source>
+        <translation type="unfinished">Gravar en aquesta hora</translation>
+    </message>
+    <message>
+        <source>Recording when shown on this channel</source>
+        <translation type="unfinished">Gravar quan aparegui en aquest canal</translation>
+    </message>
+    <message>
+        <source>Recording all showings</source>
+        <translation type="unfinished">Gravar sempre que aparegui</translation>
+    </message>
+    <message>
+        <source>Not recording this showing</source>
+        <translation type="unfinished">No gravar aquest programa</translation>
+    </message>
+    <message>
+        <source>Error!</source>
+        <translation type="unfinished">Error!</translation>
     </message>
 </context>
 <context>
@@ -441,7 +476,7 @@
     </message>
     <message>
         <source>Yes, Exit and shutdown the computer</source>
-        <translation>Si, sortir i apagar l&apos;ordinador</translation>
+        <translation type="obsolete">Si, sortir i apagar l&apos;ordinador</translation>
     </message>
     <message>
         <source>Do you really want to exit MythTV?</source>
@@ -563,29 +598,53 @@
         <source>Schedule</source>
         <translation>Programació</translation>
     </message>
+    <message>
+        <source>Do not record this proram</source>
+        <translation type="obsolete">No gravar aquest programa</translation>
+    </message>
+    <message>
+        <source>Record only this showing</source>
+        <translation>Grava aquest programa només aquesta vegada</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every day</source>
+        <translation>Grava aquest programa in aquesta hora cada dia</translation>
+    </message>
+    <message>
+        <source>Record at any time on this channel</source>
+        <translation>Grava aquest programa sempre que el trobi en aquest canal</translation>
+    </message>
+    <message>
+        <source>Record at any time on any channel</source>
+        <translation>Grava aquest programa sempre que el trobi</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every week</source>
+        <translation>Grava aquest programa en aquesta hora cada setmana</translation>
+    </message>
     <message>
         <source>Do not record this program</source>
         <translation>No gravar aquest programa</translation>
     </message>
     <message>
         <source>Record only this showing of the program</source>
-        <translation>Grava aquest programa només aquesta vegada</translation>
+        <translation type="obsolete">Grava aquest programa només aquesta vegada</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every day</source>
-        <translation>Grava aquest programa in aquesta hora cada dia</translation>
+        <translation type="obsolete">Grava aquest programa in aquesta hora cada dia</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown on this channel</source>
-        <translation>Grava aquest programa sempre que el trobi en aquest canal</translation>
+        <translation type="obsolete">Grava aquest programa sempre que el trobi en aquest canal</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown anywhere</source>
-        <translation>Grava aquest programa sempre que el trobi</translation>
+        <translation type="obsolete">Grava aquest programa sempre que el trobi</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every week</source>
-        <translation>Grava aquest programa en aquesta hora cada setmana</translation>
+        <translation type="obsolete">Grava aquest programa en aquesta hora cada setmana</translation>
     </message>
     <message>
         <source>Profile</source>
@@ -597,14 +656,14 @@
     </message>
     <message>
         <source>Rank</source>
-        <translation>Rànquing</translation>
+        <translation type="obsolete">Rànquing</translation>
     </message>
     <message>
-        <source>Allow recording even if duplicate episode</source>
+        <source>Record duplicates</source>
         <translation>Permetre gravar encara que estigui duplicat</translation>
     </message>
     <message>
-        <source>Allow recordings to be Auto-Expired</source>
+        <source>Auto Expire</source>
         <translation>Permetre que les gravacions auto-expirin</translation>
     </message>
     <message>
@@ -645,7 +704,7 @@
     </message>
     <message>
         <source>Not Currently Suppressed</source>
-        <translation>Sense suprimir</translation>
+        <translation type="obsolete">Sense suprimir</translation>
     </message>
     <message>
         <source>Not Recording</source>
@@ -653,15 +712,15 @@
     </message>
     <message>
         <source>Recording Once</source>
-        <translation>Gravar una sola vegada</translation>
+        <translation type="obsolete">Gravar una sola vegada</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Gravar en la franja horària</translation>
+        <translation type="obsolete">Gravar en la franja horària</translation>
     </message>
     <message>
         <source>Weekslot Recording</source>
-        <translation>Gravació setmanal</translation>
+        <translation type="obsolete">Gravació setmanal</translation>
     </message>
     <message>
         <source>Channel Recording</source>
@@ -801,7 +860,7 @@
     </message>
     <message>
         <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
-        <translation>Saltar-se els anuncis trobats a la detecció automàtica o amb el programa mythcommflag.</translation>
+        <translation type="obsolete">Saltar-se els anuncis trobats a la detecció automàtica o amb el programa mythcommflag.</translation>
     </message>
     <message>
         <source>Automatically Flag Commercials</source>
@@ -1427,62 +1486,6 @@
         <source>Time Blocks (30 mins) to Display</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Rankings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use program rankings to resolve conflicts.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rankings First.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use rankings to resolve conflicts before using traditional conflict resolution.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recording types will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guide starts at channel</source>
         <translation type="unfinished"></translation>
@@ -1599,10 +1602,6 @@
         <source>Program Guide</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Ranking Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screen settings</source>
         <translation type="unfinished"></translation>
@@ -1847,36 +1846,365 @@
         <source>PVR-350 Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Filters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced Filter configuration, format:
+[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>small</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>big</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default: TV, small: monitor, big:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change channels immediately without select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General playback (part 2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial: %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pre-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Post-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify, but do not skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UDP Notify Port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip blank frames after commercials</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Recording on cardid: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not Recording: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Override</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previously Recorded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Currently Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other Showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too Many Recordings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Record List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lower Rec Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reason Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>W</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daily Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly Recording</source>
+        <translation type="unfinished">Gravar setmanalment</translation>
+    </message>
+    <message>
+        <source>Conflicting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Will Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Won&apos;t Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t record it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never record this episode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record it anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this choice and use it automatically in the future</source>
+        <translation type="unfinished">Recordar aquesta opció i utilitzarla automàticament en el futur</translation>
+    </message>
+    <message>
+        <source>Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable AC3 to SPDIF passthrough</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIP Video Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of PIP Video window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reverse direction in fast forward/rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Recording Priorities</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use program recording priorities to resolve conflicts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording Priorities First.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recording types will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Recording Priorities Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, Exit and Shutdown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RankPrograms</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Gravar només aquest programa</translation>
+        <translation type="obsolete">Gravar només aquest programa</translation>
     </message>
     <message>
         <source>Recording every week</source>
-        <translation>Gravar cada setmana</translation>
+        <translation type="obsolete">Gravar cada setmana</translation>
     </message>
     <message>
         <source>Recording when shown in this timeslot</source>
-        <translation>Gravar en aquesta hora</translation>
+        <translation type="obsolete">Gravar en aquesta hora</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Gravar quan aparegui en aquest canal</translation>
+        <translation type="obsolete">Gravar quan aparegui en aquest canal</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Gravar sempre que aparegui</translation>
+        <translation type="obsolete">Gravar sempre que aparegui</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>No gravar aquest programa</translation>
+        <translation type="obsolete">No gravar aquest programa</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>Error!</translation>
+        <translation type="obsolete">Error!</translation>
     </message>
 </context>
 <context>
@@ -1898,7 +2226,7 @@
     <name>Scheduler</name>
     <message>
         <source>the maximum number of episodes have already been recorded.</source>
-        <translation>s&apos;ha assolit el màxim nombre d&apos;episodis a gravar.</translation>
+        <translation type="obsolete">s&apos;ha assolit el màxim nombre d&apos;episodis a gravar.</translation>
     </message>
 </context>
 <context>
@@ -2136,7 +2464,7 @@
     </message>
     <message>
         <source>4:3 Zoom</source>
-        <translation>Zoom 4:3</translation>
+        <translation type="unfinished">Zoom 4:3</translation>
     </message>
     <message>
         <source>Brightness (REC) %1 %</source>
@@ -2154,36 +2482,80 @@
         <source>Hue (REC) %1 %</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Program Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip to Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Auto Expire</source>
+        <translation type="unfinished">No auto-expira</translation>
+    </message>
+    <message>
+        <source>Auto Expire</source>
+        <translation type="unfinished">Auto-expira</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancel·lar</translation>
+    </message>
+    <message>
+        <source>Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16:9 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewScheduled</name>
     <message>
         <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
-        <translation>La gravació d&apos;aquest programa ha estat desactivada perquè estava en conflicte amb una altra gravació programada. Vol tornar-la a reactivar?</translation>
+        <translation type="obsolete">La gravació d&apos;aquest programa ha estat desactivada perquè estava en conflicte amb una altra gravació programada. Vol tornar-la a reactivar?</translation>
     </message>
     <message>
         <source>Yes, I want to record it.</source>
-        <translation>Si, vull gravar-ho.</translation>
+        <translation type="obsolete">Si, vull gravar-ho.</translation>
     </message>
     <message>
         <source>No, leave it disabled.</source>
-        <translation>No, mantenir desactivat.</translation>
+        <translation type="obsolete">No, mantenir desactivat.</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
-        <translation>Aquesta gravació ha estat suprimida perquè ja ha estat gravada anteriorment.</translation>
+        <translation type="obsolete">Aquesta gravació ha estat suprimida perquè ja ha estat gravada anteriorment.</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
-        <translation>Les següents gravacions programades estan en conflicte. Quina vol mantenir?</translation>
+        <translation type="obsolete">Les següents gravacions programades estan en conflicte. Quina vol mantenir?</translation>
     </message>
     <message>
         <source>Remember this choice and use it automatically in the future</source>
-        <translation>Recordar aquesta opció i utilitzarla automàticament en el futur</translation>
+        <translation type="obsolete">Recordar aquesta opció i utilitzarla automàticament en el futur</translation>
     </message>
     <message>
         <source>Time Conflict</source>
@@ -2195,11 +2567,19 @@
     </message>
     <message>
         <source>Unsuppress recording</source>
-        <translation>Dessuprimir gravació</translation>
+        <translation type="obsolete">Dessuprimir gravació</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because: </source>
-        <translation>Aquesta gravació ha estat suspesa per la següent raó: </translation>
+        <translation type="obsolete">Aquesta gravació ha estat suspesa per la següent raó: </translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Important</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
