@@ -3,27 +3,27 @@
     <name>GuideGrid</name>
     <message>
         <source>Recording Once</source>
-        <translation>Grabar una vez</translation>
+        <translation type="obsolete">Grabar una vez</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Grabar en esta franja horaria</translation>
+        <translation type="obsolete">Grabar en esta franja horaria</translation>
     </message>
     <message>
         <source>Channel Recording</source>
-        <translation>Grabar en el canal</translation>
+        <translation type="obsolete">Grabar en el canal</translation>
     </message>
     <message>
         <source>All Recording</source>
-        <translation>Grabar en todas partes</translation>
+        <translation type="obsolete">Grabar en todas partes</translation>
     </message>
     <message>
         <source>Not Recording</source>
-        <translation>No grabar</translation>
+        <translation type="obsolete">No grabar</translation>
     </message>
     <message>
         <source>Weekly Recording</source>
-        <translation>Grabación semanal</translation>
+        <translation type="obsolete">Grabación semanal</translation>
     </message>
 </context>
 <context>
@@ -162,8 +162,8 @@
 <context>
     <name>MythContext</name>
     <message>
-        <source>Connection to the master backend server timed out.  You probably should modify the Mater Server setting in the setup program and set the proper IP address there.</source>
-        <translation>Tiempo de espera agotado para conectar con el backend. Probablemente debes de configurar correctamente la dirección IP.</translation>
+        <source>Connection to the master backend server timed out.  You probably should modify the Master Server setting in the setup program and set the proper IP address there.</source>
+        <translation type="obsolete">Tiempo de espera agotado para conectar con el backend. Probablemente debes de configurar correctamente la dirección IP.</translation>
     </message>
     <message>
         <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
@@ -298,6 +298,10 @@
         <source>Cancel</source>
         <translation>Cancelar</translation>
     </message>
+    <message>
+        <source>Yes; allow re-recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProgFinder</name>
@@ -350,31 +354,62 @@
     <name>ProgLister</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Graba el programa solamente esta vez</translation>
+        <translation type="obsolete">Graba el programa solamente esta vez</translation>
     </message>
     <message>
         <source>Recording every day when shown in this timeslot</source>
-        <translation>Graba el programa cada dia en esta franja</translation>
+        <translation type="obsolete">Graba el programa cada dia en esta franja</translation>
     </message>
     <message>
         <source>Recording every week when shown in this timeslot</source>
-        <translation>Graba el programa cada semana en esta franja</translation>
+        <translation type="obsolete">Graba el programa cada semana en esta franja</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Grabarlo cuando aparezca en este canal</translation>
+        <translation type="obsolete">Grabarlo cuando aparezca en este canal</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Grabarlo siempre que aparezca</translation>
+        <translation type="obsolete">Grabarlo siempre que aparezca</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>No grabar este programa</translation>
+        <translation type="obsolete">No grabar este programa</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>¡ Error !</translation>
+        <translation type="obsolete">¡ Error !</translation>
+    </message>
+</context>
+<context>
+    <name>ProgramRecPriority</name>
+    <message>
+        <source>Recording just this showing</source>
+        <translation type="unfinished">Graba el programa solamente esta vez</translation>
+    </message>
+    <message>
+        <source>Recording every week</source>
+        <translation type="unfinished">Grabar cada semana</translation>
+    </message>
+    <message>
+        <source>Recording when shown in this timeslot</source>
+        <translation type="unfinished">Grabarlo cuando aparezca a esta hora</translation>
+    </message>
+    <message>
+        <source>Recording when shown on this channel</source>
+        <translation type="unfinished">Grabarlo cuando aparezca en este canal</translation>
+    </message>
+    <message>
+        <source>Recording all showings</source>
+        <translation type="unfinished">Grabarlo siempre que aparezca</translation>
+    </message>
+    <message>
+        <source>Not recording this showing</source>
+        <translation type="unfinished">No grabar este programa</translation>
+    </message>
+    <message>
+        <source>Error!</source>
+        <translation type="unfinished">¡ Error !</translation>
     </message>
 </context>
 <context>
@@ -389,7 +424,7 @@
     </message>
     <message>
         <source>Yes, Exit and shutdown the computer</source>
-        <translation>Si, salir ahora y apagar el equipo</translation>
+        <translation type="obsolete">Si, salir ahora y apagar el equipo</translation>
     </message>
     <message>
         <source>Do you really want to exit MythTV?</source>
@@ -511,29 +546,53 @@
         <source>Schedule</source>
         <translation>Parrilla</translation>
     </message>
+    <message>
+        <source>Do not record this proram</source>
+        <translation type="obsolete">No grabar este programa</translation>
+    </message>
+    <message>
+        <source>Record only this showing</source>
+        <translation>Graba este programa solamente esta vez</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every day</source>
+        <translation>Grabar este programa a esta hora cada dia</translation>
+    </message>
+    <message>
+        <source>Record at any time on this channel</source>
+        <translation>Grabar este programa siempre que aparezca en este canal</translation>
+    </message>
+    <message>
+        <source>Record at any time on any channel</source>
+        <translation>Grabar este programa en cualquier siempre que aparezca</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every week</source>
+        <translation>Grabar este programa a esta hora cada semana</translation>
+    </message>
     <message>
         <source>Do not record this program</source>
         <translation>No grabar este programa</translation>
     </message>
     <message>
         <source>Record only this showing of the program</source>
-        <translation>Graba este programa solamente esta vez</translation>
+        <translation type="obsolete">Graba este programa solamente esta vez</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every day</source>
-        <translation>Grabar este programa a esta hora cada dia</translation>
+        <translation type="obsolete">Grabar este programa a esta hora cada dia</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown on this channel</source>
-        <translation>Grabar este programa siempre que aparezca en este canal</translation>
+        <translation type="obsolete">Grabar este programa siempre que aparezca en este canal</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown anywhere</source>
-        <translation>Grabar este programa en cualquier siempre que aparezca</translation>
+        <translation type="obsolete">Grabar este programa en cualquier siempre que aparezca</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every week</source>
-        <translation>Grabar este programa a esta hora cada semana</translation>
+        <translation type="obsolete">Grabar este programa a esta hora cada semana</translation>
     </message>
     <message>
         <source>Profile</source>
@@ -545,14 +604,14 @@
     </message>
     <message>
         <source>Rank</source>
-        <translation>Ránking</translation>
+        <translation type="obsolete">Ránking</translation>
     </message>
     <message>
-        <source>Allow recording even if duplicate episode</source>
+        <source>Record duplicates</source>
         <translation>Grabar aunque se trate de episodios duplicados</translation>
     </message>
     <message>
-        <source>Allow recordings to be Auto-Expired</source>
+        <source>Auto Expire</source>
         <translation>Permitir que las grabaciones autoexpiren</translation>
     </message>
     <message>
@@ -593,7 +652,7 @@
     </message>
     <message>
         <source>Not Currently Suppressed</source>
-        <translation>Sin suprimir</translation>
+        <translation type="obsolete">Sin suprimir</translation>
     </message>
     <message>
         <source>Not Recording</source>
@@ -601,15 +660,15 @@
     </message>
     <message>
         <source>Recording Once</source>
-        <translation>Grabar una vez</translation>
+        <translation type="obsolete">Grabar una vez</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Grabar en esta franja horaria</translation>
+        <translation type="obsolete">Grabar en esta franja horaria</translation>
     </message>
     <message>
         <source>Weekslot Recording</source>
-        <translation>Grabar semanalmente</translation>
+        <translation type="obsolete">Grabar semanalmente</translation>
     </message>
     <message>
         <source>Channel Recording</source>
@@ -749,7 +808,7 @@
     </message>
     <message>
         <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
-        <translation>Saltarse automáticamente los anuncios cuando fueron detectados por el proceso automático de detección o el programa mythcommflag.</translation>
+        <translation type="obsolete">Saltarse automáticamente los anuncios cuando fueron detectados por el proceso automático de detección o el programa mythcommflag.</translation>
     </message>
     <message>
         <source>Automatically Flag Commercials</source>
@@ -1375,62 +1434,6 @@
         <source>Time Blocks (30 mins) to Display</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Rankings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use program rankings to resolve conflicts.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rankings First.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use rankings to resolve conflicts before using traditional conflict resolution.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recording types will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guide starts at channel</source>
         <translation type="unfinished"></translation>
@@ -1547,10 +1550,6 @@
         <source>Program Guide</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Ranking Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screen settings</source>
         <translation type="unfinished"></translation>
@@ -1795,36 +1794,365 @@
         <source>PVR-350 Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Filters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced Filter configuration, format:
+[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>small</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>big</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default: TV, small: monitor, big:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change channels immediately without select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General playback (part 2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial: %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pre-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Post-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify, but do not skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UDP Notify Port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip blank frames after commercials</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Recording on cardid: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not Recording: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Override</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previously Recorded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Currently Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other Showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too Many Recordings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Record List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lower Rec Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reason Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>W</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daily Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly Recording</source>
+        <translation type="unfinished">Grabación semanal</translation>
+    </message>
+    <message>
+        <source>Conflicting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Will Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Won&apos;t Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t record it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never record this episode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record it anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this choice and use it automatically in the future</source>
+        <translation type="unfinished">Recordar esta opción y usarla automáticamente en el futuro</translation>
+    </message>
+    <message>
+        <source>Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable AC3 to SPDIF passthrough</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIP Video Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of PIP Video window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reverse direction in fast forward/rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Recording Priorities</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use program recording priorities to resolve conflicts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording Priorities First.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recording types will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Recording Priorities Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, Exit and Shutdown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RankPrograms</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Graba el programa solamente esta vez</translation>
+        <translation type="obsolete">Graba el programa solamente esta vez</translation>
     </message>
     <message>
         <source>Recording every week</source>
-        <translation>Grabar cada semana</translation>
+        <translation type="obsolete">Grabar cada semana</translation>
     </message>
     <message>
         <source>Recording when shown in this timeslot</source>
-        <translation>Grabarlo cuando aparezca a esta hora</translation>
+        <translation type="obsolete">Grabarlo cuando aparezca a esta hora</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Grabarlo cuando aparezca en este canal</translation>
+        <translation type="obsolete">Grabarlo cuando aparezca en este canal</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Grabarlo siempre que aparezca</translation>
+        <translation type="obsolete">Grabarlo siempre que aparezca</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>No grabar este programa</translation>
+        <translation type="obsolete">No grabar este programa</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>¡ Error !</translation>
+        <translation type="obsolete">¡ Error !</translation>
     </message>
 </context>
 <context>
@@ -1846,7 +2174,7 @@
     <name>Scheduler</name>
     <message>
         <source>the maximum number of episodes have already been recorded.</source>
-        <translation>se alcanzó el número máximo de episodios a grabar.</translation>
+        <translation type="obsolete">se alcanzó el número máximo de episodios a grabar.</translation>
     </message>
 </context>
 <context>
@@ -2084,7 +2412,7 @@
     </message>
     <message>
         <source>4:3 Zoom</source>
-        <translation>Zoom 4:3</translation>
+        <translation type="unfinished">Zoom 4:3</translation>
     </message>
     <message>
         <source>Brightness (REC) %1 %</source>
@@ -2102,36 +2430,80 @@
         <source>Hue (REC) %1 %</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Program Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip to Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Auto Expire</source>
+        <translation type="unfinished">No autoexpirar</translation>
+    </message>
+    <message>
+        <source>Auto Expire</source>
+        <translation type="unfinished">Autoexpirar</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16:9 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewScheduled</name>
     <message>
         <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
-        <translation>La grabación de este programa ha sido desactivada porque estaba en conflicto con otra grabación. ¿Desea volver a activar esta grabación?</translation>
+        <translation type="obsolete">La grabación de este programa ha sido desactivada porque estaba en conflicto con otra grabación. ¿Desea volver a activar esta grabación?</translation>
     </message>
     <message>
         <source>Yes, I want to record it.</source>
-        <translation>Si, quiero grabarlo.</translation>
+        <translation type="obsolete">Si, quiero grabarlo.</translation>
     </message>
     <message>
         <source>No, leave it disabled.</source>
-        <translation>No, mantener desactivada.</translation>
+        <translation type="obsolete">No, mantener desactivada.</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
-        <translation>Esta grabación fué cancelada porque ya se grabó anteriormente.</translation>
+        <translation type="obsolete">Esta grabación fué cancelada porque ya se grabó anteriormente.</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
-        <translation>Estas grabaciones programadas estan en conflicto entre sí. ¿Cuál quiere mantener?</translation>
+        <translation type="obsolete">Estas grabaciones programadas estan en conflicto entre sí. ¿Cuál quiere mantener?</translation>
     </message>
     <message>
         <source>Remember this choice and use it automatically in the future</source>
-        <translation>Recordar esta opción y usarla automáticamente en el futuro</translation>
+        <translation type="obsolete">Recordar esta opción y usarla automáticamente en el futuro</translation>
     </message>
     <message>
         <source>Time Conflict</source>
@@ -2143,11 +2515,19 @@
     </message>
     <message>
         <source>Unsuppress recording</source>
-        <translation>Desuprimir grabación</translation>
+        <translation type="obsolete">Desuprimir grabación</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because: </source>
-        <translation>Esta grabación se suspendió por la siguiente causa:</translation>
+        <translation type="obsolete">Esta grabación se suspendió por la siguiente causa:</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Important</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
