@@ -3,27 +3,27 @@
     <name>GuideGrid</name>
     <message>
         <source>Recording Once</source>
-        <translation>Enregistrement simple</translation>
+        <translation type="obsolete">Enregistrement simple</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Enregistrement de créneau horaire</translation>
+        <translation type="obsolete">Enregistrement de créneau horaire</translation>
     </message>
     <message>
         <source>Channel Recording</source>
-        <translation>Enregistrement de station</translation>
+        <translation type="obsolete">Enregistrement de station</translation>
     </message>
     <message>
         <source>All Recording</source>
-        <translation>Toujours enregistré</translation>
+        <translation type="obsolete">Toujours enregistré</translation>
     </message>
     <message>
         <source>Not Recording</source>
-        <translation>Pas enregistré</translation>
+        <translation type="obsolete">Pas enregistré</translation>
     </message>
     <message>
         <source>Weekly Recording</source>
-        <translation>Enregistrement Hebdomadaire</translation>
+        <translation type="obsolete">Enregistrement Hebdomadaire</translation>
     </message>
 </context>
 <context>
@@ -162,8 +162,8 @@
 <context>
     <name>MythContext</name>
     <message>
-        <source>Connection to the master backend server timed out.  You probably should modify the Mater Server setting in the setup program and set the proper IP address there.</source>
-        <translation>La connection au serveur maître est impossible. Veuillez modifier l&apos;ajustement Master Server dans le programme de setup et y mettre le bon IP.</translation>
+        <source>Connection to the master backend server timed out.  You probably should modify the Master Server setting in the setup program and set the proper IP address there.</source>
+        <translation type="obsolete">La connection au serveur maître est impossible. Veuillez modifier l&apos;ajustement Master Server dans le programme de setup et y mettre le bon IP.</translation>
     </message>
     <message>
         <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
@@ -291,6 +291,10 @@
         <source>Cancel</source>
         <translation>Annuler</translation>
     </message>
+    <message>
+        <source>Yes; allow re-recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProgFinder</name>
@@ -343,31 +347,62 @@
     <name>ProgLister</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Enregistrer seulement cet épisode</translation>
+        <translation type="obsolete">Enregistrer seulement cet épisode</translation>
     </message>
     <message>
         <source>Recording every day when shown in this timeslot</source>
-        <translation>Enregistrer chaque jour à cette heure</translation>
+        <translation type="obsolete">Enregistrer chaque jour à cette heure</translation>
     </message>
     <message>
         <source>Recording every week when shown in this timeslot</source>
-        <translation>Enregistrer chaque semaine à cette heure</translation>
+        <translation type="obsolete">Enregistrer chaque semaine à cette heure</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Enregistré sur cette station</translation>
+        <translation type="obsolete">Enregistré sur cette station</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Toujours enregistré</translation>
+        <translation type="obsolete">Toujours enregistré</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>Ne pas enregistrer cette instance</translation>
+        <translation type="obsolete">Ne pas enregistrer cette instance</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>Erreur!</translation>
+        <translation type="obsolete">Erreur!</translation>
+    </message>
+</context>
+<context>
+    <name>ProgramRecPriority</name>
+    <message>
+        <source>Recording just this showing</source>
+        <translation type="unfinished">Enregistrer seulement cet épisode</translation>
+    </message>
+    <message>
+        <source>Recording every week</source>
+        <translation type="unfinished">Enregistré chaque semaine</translation>
+    </message>
+    <message>
+        <source>Recording when shown in this timeslot</source>
+        <translation type="unfinished">Enregistré à ce créneau horaire</translation>
+    </message>
+    <message>
+        <source>Recording when shown on this channel</source>
+        <translation type="unfinished">Enregistré sur cette station</translation>
+    </message>
+    <message>
+        <source>Recording all showings</source>
+        <translation type="unfinished">Toujours enregistré</translation>
+    </message>
+    <message>
+        <source>Not recording this showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Error!</source>
+        <translation type="unfinished">Erreur!</translation>
     </message>
 </context>
 <context>
@@ -386,7 +421,7 @@
     </message>
     <message>
         <source>Yes, Exit and shutdown the computer</source>
-        <translation>Oui, quitter et éteindre l&apos;ordinateur</translation>
+        <translation type="obsolete">Oui, quitter et éteindre l&apos;ordinateur</translation>
     </message>
     <message>
         <source>cut point</source>
@@ -504,29 +539,53 @@
         <source>Schedule</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Do not record this proram</source>
+        <translation type="obsolete">Ne pas enregistrer ce programme</translation>
+    </message>
+    <message>
+        <source>Record only this showing</source>
+        <translation>Enregistrer seulement cette instance du programme</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every day</source>
+        <translation>Enregistrer ce programme chaque jour à ce créneau horaire</translation>
+    </message>
+    <message>
+        <source>Record at any time on this channel</source>
+        <translation>Enregistrer ce programme à chaque apparition sur cette station</translation>
+    </message>
+    <message>
+        <source>Record at any time on any channel</source>
+        <translation>Enregistrer ce programme à chaque apparition</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every week</source>
+        <translation>Enregistrer ce programme chaque semaine à ce créneau horaire</translation>
+    </message>
     <message>
         <source>Do not record this program</source>
         <translation>Ne pas enregistrer ce programme</translation>
     </message>
     <message>
         <source>Record only this showing of the program</source>
-        <translation>Enregistrer seulement cette instance du programme</translation>
+        <translation type="obsolete">Enregistrer seulement cette instance du programme</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every day</source>
-        <translation>Enregistrer ce programme chaque jour à ce créneau horaire</translation>
+        <translation type="obsolete">Enregistrer ce programme chaque jour à ce créneau horaire</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown on this channel</source>
-        <translation>Enregistrer ce programme à chaque apparition sur cette station</translation>
+        <translation type="obsolete">Enregistrer ce programme à chaque apparition sur cette station</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown anywhere</source>
-        <translation>Enregistrer ce programme à chaque apparition</translation>
+        <translation type="obsolete">Enregistrer ce programme à chaque apparition</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every week</source>
-        <translation>Enregistrer ce programme chaque semaine à ce créneau horaire</translation>
+        <translation type="obsolete">Enregistrer ce programme chaque semaine à ce créneau horaire</translation>
     </message>
     <message>
         <source>Profile</source>
@@ -538,14 +597,14 @@
     </message>
     <message>
         <source>Rank</source>
-        <translation>Rang</translation>
+        <translation type="obsolete">Rang</translation>
     </message>
     <message>
-        <source>Allow recording even if duplicate episode</source>
-        <translation>Enregistrer même si copie en double</translation>
+        <source>Allow recording even if duplicate episodE</source>
+        <translation type="obsolete">Enregistrer même si copie en double</translation>
     </message>
     <message>
-        <source>Allow recordings to be Auto-Expired</source>
+        <source>Auto Expire</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -584,25 +643,17 @@
         <source>Skip %1 seconds</source>
         <translation>Sauter %1 secondes</translation>
     </message>
-    <message>
-        <source>Not Currently Suppressed</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Not Recording</source>
         <translation>Pas enregistré</translation>
     </message>
     <message>
         <source>Recording Once</source>
-        <translation>Enregistré une fois</translation>
+        <translation type="obsolete">Enregistré une fois</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Pas enregistré</translation>
-    </message>
-    <message>
-        <source>Weekslot Recording</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Pas enregistré</translation>
     </message>
     <message>
         <source>Channel Recording</source>
@@ -740,10 +791,6 @@
         <source>Automatically Skip Commercials</source>
         <translation>Automatiquement sauter les commerciaux</translation>
     </message>
-    <message>
-        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Automatically Flag Commercials</source>
         <translation>Automatiquement identifier les commerciaux</translation>
@@ -1328,62 +1375,6 @@
         <source>Time Blocks (30 mins) to Display</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Rankings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use program rankings to resolve conflicts.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rankings First.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use rankings to resolve conflicts before using traditional conflict resolution.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recording types will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guide starts at channel</source>
         <translation type="unfinished"></translation>
@@ -1500,10 +1491,6 @@
         <source>Program Guide</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Ranking Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screen settings</source>
         <translation type="unfinished"></translation>
@@ -1748,36 +1735,369 @@
         <source>PVR-350 Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Filters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced Filter configuration, format:
+[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>small</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>big</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default: TV, small: monitor, big:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change channels immediately without select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General playback (part 2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial: %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record duplicates</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pre-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Post-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify, but do not skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UDP Notify Port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip blank frames after commercials</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Recording on cardid: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not Recording: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Override</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previously Recorded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Currently Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other Showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too Many Recordings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Record List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lower Rec Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reason Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>W</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daily Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly Recording</source>
+        <translation type="unfinished">Enregistrement Hebdomadaire</translation>
+    </message>
+    <message>
+        <source>Conflicting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Will Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Won&apos;t Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t record it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never record this episode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record it anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this choice and use it automatically in the future</source>
+        <translation type="unfinished">Conserver ce choix et l&apos;utiliser automatiquement dans le futur</translation>
+    </message>
+    <message>
+        <source>Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable AC3 to SPDIF passthrough</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIP Video Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of PIP Video window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reverse direction in fast forward/rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Recording Priorities</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use program recording priorities to resolve conflicts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording Priorities First.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recording types will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Recording Priorities Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, Exit and Shutdown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RankPrograms</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Enregistrer seulement cet épisode</translation>
+        <translation type="obsolete">Enregistrer seulement cet épisode</translation>
     </message>
     <message>
         <source>Recording every week</source>
-        <translation>Enregistré chaque semaine</translation>
+        <translation type="obsolete">Enregistré chaque semaine</translation>
     </message>
     <message>
         <source>Recording when shown in this timeslot</source>
-        <translation>Enregistré à ce créneau horaire</translation>
+        <translation type="obsolete">Enregistré à ce créneau horaire</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Enregistré sur cette station</translation>
+        <translation type="obsolete">Enregistré sur cette station</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Toujours enregistré</translation>
+        <translation type="obsolete">Toujours enregistré</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>Pas enregistré</translation>
+        <translation type="obsolete">Pas enregistré</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>Erreur!</translation>
+        <translation type="obsolete">Erreur!</translation>
     </message>
 </context>
 <context>
@@ -1795,13 +2115,6 @@
         <translation>Lister tous les prochains épisodes.</translation>
     </message>
 </context>
-<context>
-    <name>Scheduler</name>
-    <message>
-        <source>the maximum number of episodes have already been recorded.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>SetRecTimeDialog</name>
     <message>
@@ -2037,7 +2350,7 @@
     </message>
     <message>
         <source>4:3 Zoom</source>
-        <translation>Zoom 4:3</translation>
+        <translation type="unfinished">Zoom 4:3</translation>
     </message>
     <message>
         <source>Brightness (REC) %1 %</source>
@@ -2055,6 +2368,50 @@
         <source>Hue (REC) %1 %</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Program Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip to Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Annuler</translation>
+    </message>
+    <message>
+        <source>Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16:9 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewScheduled</name>
@@ -2068,39 +2425,47 @@
     </message>
     <message>
         <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
-        <translation>Cet programme a été désactivé car il était en conflict avec un autre programme. Réactiver ce programme?</translation>
+        <translation type="obsolete">Cet programme a été désactivé car il était en conflict avec un autre programme. Réactiver ce programme?</translation>
     </message>
     <message>
         <source>Yes, I want to record it.</source>
-        <translation>Oui, l&apos;enregistrer</translation>
+        <translation type="obsolete">Oui, l&apos;enregistrer</translation>
     </message>
     <message>
         <source>No, leave it disabled.</source>
-        <translation>Non, le garder désactivé.</translation>
+        <translation type="obsolete">Non, le garder désactivé.</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
-        <translation>Ce programme a été désactivé car il a déjà été enregistré auparavant.</translation>
+        <translation type="obsolete">Ce programme a été désactivé car il a déjà été enregistré auparavant.</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>Unsuppress recording</source>
-        <translation>Réactiver l&apos;enregistrement</translation>
+        <translation type="obsolete">Réactiver l&apos;enregistrement</translation>
     </message>
     <message>
         <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
-        <translation>Les programmes suivants sont en conflit entre eux. Lequel voulez-vous enregistrer?</translation>
+        <translation type="obsolete">Les programmes suivants sont en conflit entre eux. Lequel voulez-vous enregistrer?</translation>
     </message>
     <message>
         <source>Remember this choice and use it automatically in the future</source>
-        <translation>Conserver ce choix et l&apos;utiliser automatiquement dans le futur</translation>
+        <translation type="obsolete">Conserver ce choix et l&apos;utiliser automatiquement dans le futur</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because: </source>
-        <translation>L&apos;enregistrement de se programme a été désactivé parce que:</translation>
+        <translation type="obsolete">L&apos;enregistrement de se programme a été désactivé parce que:</translation>
+    </message>
+    <message>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Important</source>
+        <translation type="unfinished"></translation>
     </message>
 </context>
 </TS>
