@@ -3,27 +3,23 @@
     <name>GuideGrid</name>
     <message>
         <source>Recording Once</source>
-        <translation>Registrazione singolo evento</translation>
+        <translation type="obsolete">Registrazione singolo evento</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Registrazione a fascia oraria</translation>
+        <translation type="obsolete">Registrazione a fascia oraria</translation>
     </message>
     <message>
         <source>Channel Recording</source>
-        <translation>Reg. automatica sul canale</translation>
+        <translation type="obsolete">Reg. automatica sul canale</translation>
     </message>
     <message>
         <source>All Recording</source>
-        <translation>Reg. aut. su tutti i canali</translation>
+        <translation type="obsolete">Reg. aut. su tutti i canali</translation>
     </message>
     <message>
         <source>Not Recording</source>
-        <translation>Nessuna registrazione</translation>
-    </message>
-    <message>
-        <source>Weekly Recording</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Nessuna registrazione</translation>
     </message>
 </context>
 <context>
@@ -201,10 +197,6 @@
 </context>
 <context>
     <name>MythContext</name>
-    <message>
-        <source>Connection to the master backend server timed out.  You probably should modify the Mater Server setting in the setup program and set the proper IP address there.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
         <translation type="unfinished"></translation>
@@ -331,6 +323,10 @@
         <source>Cancel</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Yes; allow re-recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProgFinder</name>
@@ -381,17 +377,40 @@
 </context>
 <context>
     <name>ProgLister</name>
+    <message>
+        <source>Recording just this showing</source>
+        <translation type="obsolete">Registrazione singolo evento</translation>
+    </message>
+    <message>
+        <source>Recording when shown on this channel</source>
+        <translation type="obsolete">Registrazione automatica su questo canale</translation>
+    </message>
+    <message>
+        <source>Recording all showings</source>
+        <translation type="obsolete">Registrazione automatica su tutti i canali</translation>
+    </message>
+    <message>
+        <source>Not recording this showing</source>
+        <translation type="obsolete">Nessuna registrazione</translation>
+    </message>
+    <message>
+        <source>Error!</source>
+        <translation type="obsolete">Errore!</translation>
+    </message>
+</context>
+<context>
+    <name>ProgramRecPriority</name>
     <message>
         <source>Recording just this showing</source>
         <translation type="unfinished">Registrazione singolo evento</translation>
     </message>
     <message>
-        <source>Recording every day when shown in this timeslot</source>
+        <source>Recording every week</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Recording every week when shown in this timeslot</source>
-        <translation type="unfinished"></translation>
+        <source>Recording when shown in this timeslot</source>
+        <translation type="unfinished">Registrazione in questa fascia oraria</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
@@ -426,7 +445,7 @@
     </message>
     <message>
         <source>Yes, Exit and shutdown the computer</source>
-        <translation>Si, esci e spengi il computer</translation>
+        <translation type="obsolete">Si, esci e spengi il computer</translation>
     </message>
     <message>
         <source>cut point</source>
@@ -532,29 +551,49 @@
         <source>Schedule</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Record only this showing</source>
+        <translation type="unfinished">Registra questo programma una volta sola</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every day</source>
+        <translation type="unfinished">Registra sempre questo canale in questo orario</translation>
+    </message>
+    <message>
+        <source>Record at any time on this channel</source>
+        <translation type="unfinished">Registra sempre questo programma, su questo canale</translation>
+    </message>
+    <message>
+        <source>Record at any time on any channel</source>
+        <translation type="unfinished">Registra sempre questo programma, su qualsiasi canale</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every week</source>
+        <translation type="unfinished">Registra tutte le settimane questo programma in questo orario</translation>
+    </message>
     <message>
         <source>Do not record this program</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Record only this showing of the program</source>
-        <translation type="unfinished">Registra questo programma una volta sola</translation>
+        <translation type="obsolete">Registra questo programma una volta sola</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every day</source>
-        <translation type="unfinished">Registra sempre questo canale in questo orario</translation>
+        <translation type="obsolete">Registra sempre questo canale in questo orario</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown on this channel</source>
-        <translation type="unfinished">Registra sempre questo programma, su questo canale</translation>
+        <translation type="obsolete">Registra sempre questo programma, su questo canale</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown anywhere</source>
-        <translation type="unfinished">Registra sempre questo programma, su qualsiasi canale</translation>
+        <translation type="obsolete">Registra sempre questo programma, su qualsiasi canale</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every week</source>
-        <translation type="unfinished">Registra tutte le settimane questo programma in questo orario</translation>
+        <translation type="obsolete">Registra tutte le settimane questo programma in questo orario</translation>
     </message>
     <message>
         <source>Profile</source>
@@ -565,15 +604,11 @@
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Rank</source>
+        <source>Record duplicates</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Allow recording even if duplicate episode</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Allow recordings to be Auto-Expired</source>
+        <source>Auto Expire</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -612,25 +647,17 @@
         <source>Skip %1 seconds</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Not Currently Suppressed</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Not Recording</source>
         <translation type="unfinished">Nessuna registrazione</translation>
     </message>
     <message>
         <source>Recording Once</source>
-        <translation type="unfinished">Registrazione singolo evento</translation>
+        <translation type="obsolete">Registrazione singolo evento</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation type="unfinished">Registrazione a fascia oraria</translation>
-    </message>
-    <message>
-        <source>Weekslot Recording</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Registrazione a fascia oraria</translation>
     </message>
     <message>
         <source>Channel Recording</source>
@@ -768,10 +795,6 @@
         <source>Automatically Skip Commercials</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Automatically Flag Commercials</source>
         <translation type="unfinished"></translation>
@@ -1356,62 +1379,6 @@
         <source>Time Blocks (30 mins) to Display</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Rankings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use program rankings to resolve conflicts.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rankings First.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use rankings to resolve conflicts before using traditional conflict resolution.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recording types will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guide starts at channel</source>
         <translation type="unfinished"></translation>
@@ -1528,10 +1495,6 @@
         <source>Program Guide</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Ranking Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screen settings</source>
         <translation type="unfinished"></translation>
@@ -1776,36 +1739,361 @@
         <source>PVR-350 Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Filters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced Filter configuration, format:
+[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>small</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>big</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default: TV, small: monitor, big:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change channels immediately without select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General playback (part 2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial: %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pre-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Post-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify, but do not skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UDP Notify Port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip blank frames after commercials</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Recording on cardid: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not Recording: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Override</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previously Recorded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Currently Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other Showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too Many Recordings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Record List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lower Rec Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reason Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>W</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daily Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Conflicting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Will Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Won&apos;t Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t record it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never record this episode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record it anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this choice and use it automatically in the future</source>
+        <translation type="unfinished">Usa questa scelta automaticamente in futuro</translation>
+    </message>
+    <message>
+        <source>Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable AC3 to SPDIF passthrough</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIP Video Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of PIP Video window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reverse direction in fast forward/rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Recording Priorities</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use program recording priorities to resolve conflicts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording Priorities First.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recording types will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Recording Priorities Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, Exit and Shutdown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RankPrograms</name>
     <message>
         <source>Recording just this showing</source>
-        <translation type="unfinished">Registrazione singolo evento</translation>
-    </message>
-    <message>
-        <source>Recording every week</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Registrazione singolo evento</translation>
     </message>
     <message>
         <source>Recording when shown in this timeslot</source>
-        <translation type="unfinished">Registrazione in questa fascia oraria</translation>
+        <translation type="obsolete">Registrazione in questa fascia oraria</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation type="unfinished">Registrazione automatica su questo canale</translation>
+        <translation type="obsolete">Registrazione automatica su questo canale</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation type="unfinished">Registrazione automatica su tutti i canali</translation>
+        <translation type="obsolete">Registrazione automatica su tutti i canali</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation type="unfinished">Nessuna registrazione</translation>
+        <translation type="obsolete">Nessuna registrazione</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation type="unfinished">Errore!</translation>
+        <translation type="obsolete">Errore!</translation>
     </message>
 </context>
 <context>
@@ -1823,13 +2111,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>Scheduler</name>
-    <message>
-        <source>the maximum number of episodes have already been recorded.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>SetRecTimeDialog</name>
     <message>
@@ -2035,10 +2316,6 @@
         <source>Do not edit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>4:3 Zoom</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Brightness (REC) %1 %</source>
         <translation type="unfinished"></translation>
@@ -2055,36 +2332,84 @@
         <source>Hue (REC) %1 %</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Program Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip to Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16:9 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4:3 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewScheduled</name>
     <message>
         <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
-        <translation>La registrazione di questo programma e&apos; stata disattivata perche&apos; in conflitto con altre. Vuoi riattivare la registrazione?</translation>
+        <translation type="obsolete">La registrazione di questo programma e&apos; stata disattivata perche&apos; in conflitto con altre. Vuoi riattivare la registrazione?</translation>
     </message>
     <message>
         <source>Yes, I want to record it.</source>
-        <translation>Si, voglio riattivare la registrazione.</translation>
+        <translation type="obsolete">Si, voglio riattivare la registrazione.</translation>
     </message>
     <message>
         <source>No, leave it disabled.</source>
-        <translation>No, non voglio riattivare la registrazione.</translation>
+        <translation type="obsolete">No, non voglio riattivare la registrazione.</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
-        <translation>La registrazione di questo programma e&apos; stata disattivata perche&apos; il programma e&apos; gia&apos;; stato registrato in passato.</translation>
+        <translation type="obsolete">La registrazione di questo programma e&apos; stata disattivata perche&apos; il programma e&apos; gia&apos;; stato registrato in passato.</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
-        <translation>Le seguenti registrazioni programmate sono in conflitto tra loro. Quale vuoi registrare?</translation>
+        <translation type="obsolete">Le seguenti registrazioni programmate sono in conflitto tra loro. Quale vuoi registrare?</translation>
     </message>
     <message>
         <source>Remember this choice and use it automatically in the future</source>
-        <translation>Usa questa scelta automaticamente in futuro</translation>
+        <translation type="obsolete">Usa questa scelta automaticamente in futuro</translation>
     </message>
     <message>
         <source>Time Conflict</source>
@@ -2095,11 +2420,11 @@
         <translation>Nessun conflitto</translation>
     </message>
     <message>
-        <source>Unsuppress recording</source>
+        <source>All</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Recording this program has been suppressed because: </source>
+        <source>Important</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
