@@ -3,27 +3,27 @@
     <name>GuideGrid</name>
     <message>
         <source>Recording Once</source>
-        <translation>Eenmalig Opnemen</translation>
+        <translation type="obsolete">Eenmalig Opnemen</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Opnemen per Tijdsblok</translation>
+        <translation type="obsolete">Opnemen per Tijdsblok</translation>
     </message>
     <message>
         <source>Channel Recording</source>
-        <translation>Opnemen per Kanaal</translation>
+        <translation type="obsolete">Opnemen per Kanaal</translation>
     </message>
     <message>
         <source>All Recording</source>
-        <translation>Alles Opnemen</translation>
+        <translation type="obsolete">Alles Opnemen</translation>
     </message>
     <message>
         <source>Not Recording</source>
-        <translation>Niet Opnemen</translation>
+        <translation type="obsolete">Niet Opnemen</translation>
     </message>
     <message>
         <source>Weekly Recording</source>
-        <translation>Wekelijks Opnemen</translation>
+        <translation type="obsolete">Wekelijks Opnemen</translation>
     </message>
 </context>
 <context>
@@ -161,10 +161,6 @@
 </context>
 <context>
     <name>MythContext</name>
-    <message>
-        <source>Connection to the master backend server timed out.  You probably should modify the Mater Server setting in the setup program and set the proper IP address there.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
         <translation type="unfinished"></translation>
@@ -298,6 +294,10 @@
         <source>Cancel</source>
         <translation type="unfinished">Annuleer</translation>
     </message>
+    <message>
+        <source>Yes; allow re-recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProgFinder</name>
@@ -350,15 +350,46 @@
     <name>ProgLister</name>
     <message>
         <source>Recording just this showing</source>
-        <translation type="unfinished">Neem enkel deze vertoning op</translation>
+        <translation type="obsolete">Neem enkel deze vertoning op</translation>
     </message>
     <message>
         <source>Recording every day when shown in this timeslot</source>
-        <translation type="unfinished">Dagelijkse vertoningen opnemen in dit tijdsblok</translation>
+        <translation type="obsolete">Dagelijkse vertoningen opnemen in dit tijdsblok</translation>
     </message>
     <message>
         <source>Recording every week when shown in this timeslot</source>
-        <translation type="unfinished">Wekelijkse vertoningen opnemen in dit tijdsblok</translation>
+        <translation type="obsolete">Wekelijkse vertoningen opnemen in dit tijdsblok</translation>
+    </message>
+    <message>
+        <source>Recording when shown on this channel</source>
+        <translation type="obsolete">Neem enkel vertoningen op dit kanaal op</translation>
+    </message>
+    <message>
+        <source>Recording all showings</source>
+        <translation type="obsolete">Neem alle vertoningen op</translation>
+    </message>
+    <message>
+        <source>Not recording this showing</source>
+        <translation type="obsolete">Neem deze vertoning niet op</translation>
+    </message>
+    <message>
+        <source>Error!</source>
+        <translation type="obsolete">Fout!</translation>
+    </message>
+</context>
+<context>
+    <name>ProgramRecPriority</name>
+    <message>
+        <source>Recording just this showing</source>
+        <translation type="unfinished">Neem enkel deze vertoning op</translation>
+    </message>
+    <message>
+        <source>Recording every week</source>
+        <translation type="unfinished">Neem wekelijks op</translation>
+    </message>
+    <message>
+        <source>Recording when shown in this timeslot</source>
+        <translation type="unfinished">Neem enkel vertoningen op in dit tijdsblok</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
@@ -393,7 +424,7 @@
     </message>
     <message>
         <source>Yes, Exit and shutdown the computer</source>
-        <translation>Ja, sluit nu af en zet de computer uit</translation>
+        <translation type="obsolete">Ja, sluit nu af en zet de computer uit</translation>
     </message>
     <message>
         <source>cut point</source>
@@ -511,29 +542,53 @@
         <source>Schedule</source>
         <translation>Plannen</translation>
     </message>
+    <message>
+        <source>Do not record this proram</source>
+        <translation type="obsolete">Dit programma niet opnemen</translation>
+    </message>
+    <message>
+        <source>Record only this showing</source>
+        <translation>Enkel deze vertoning van het programma opnemen</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every day</source>
+        <translation>Dit programma dagelijks in dit tijdsblok opnemen</translation>
+    </message>
+    <message>
+        <source>Record at any time on this channel</source>
+        <translation>Dit programma altijd op dit kanaal opnemen</translation>
+    </message>
+    <message>
+        <source>Record at any time on any channel</source>
+        <translation>Dit programma altijd en op alle kanalen opnemen</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every week</source>
+        <translation>Dit programma wekelijks in dit tijdsblok opnemen</translation>
+    </message>
     <message>
         <source>Do not record this program</source>
         <translation>Dit programma niet opnemen</translation>
     </message>
     <message>
         <source>Record only this showing of the program</source>
-        <translation>Enkel deze vertoning van het programma opnemen</translation>
+        <translation type="obsolete">Enkel deze vertoning van het programma opnemen</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every day</source>
-        <translation>Dit programma dagelijks in dit tijdsblok opnemen</translation>
+        <translation type="obsolete">Dit programma dagelijks in dit tijdsblok opnemen</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown on this channel</source>
-        <translation>Dit programma altijd op dit kanaal opnemen</translation>
+        <translation type="obsolete">Dit programma altijd op dit kanaal opnemen</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown anywhere</source>
-        <translation>Dit programma altijd en op alle kanalen opnemen</translation>
+        <translation type="obsolete">Dit programma altijd en op alle kanalen opnemen</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every week</source>
-        <translation>Dit programma wekelijks in dit tijdsblok opnemen</translation>
+        <translation type="obsolete">Dit programma wekelijks in dit tijdsblok opnemen</translation>
     </message>
     <message>
         <source>Profile</source>
@@ -545,14 +600,14 @@
     </message>
     <message>
         <source>Rank</source>
-        <translation>Rang</translation>
+        <translation type="obsolete">Rang</translation>
     </message>
     <message>
-        <source>Allow recording even if duplicate episode</source>
+        <source>Record duplicates</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
-        <source>Allow recordings to be Auto-Expired</source>
+        <source>Auto Expire</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
@@ -591,25 +646,17 @@
         <source>Skip %1 seconds</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Not Currently Suppressed</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Not Recording</source>
         <translation type="unfinished">Niet Opnemen</translation>
     </message>
     <message>
         <source>Recording Once</source>
-        <translation type="unfinished">Eenmalig Opnemen</translation>
+        <translation type="obsolete">Eenmalig Opnemen</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation type="unfinished">Opnemen per Tijdsblok</translation>
-    </message>
-    <message>
-        <source>Weekslot Recording</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Opnemen per Tijdsblok</translation>
     </message>
     <message>
         <source>Channel Recording</source>
@@ -747,10 +794,6 @@
         <source>Automatically Skip Commercials</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Automatically Flag Commercials</source>
         <translation type="unfinished"></translation>
@@ -1335,62 +1378,6 @@
         <source>Time Blocks (30 mins) to Display</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Rankings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use program rankings to resolve conflicts.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rankings First.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use rankings to resolve conflicts before using traditional conflict resolution.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recording types will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guide starts at channel</source>
         <translation type="unfinished"></translation>
@@ -1507,10 +1494,6 @@
         <source>Program Guide</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Ranking Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screen settings</source>
         <translation type="unfinished"></translation>
@@ -1755,36 +1738,365 @@
         <source>PVR-350 Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Filters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced Filter configuration, format:
+[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>small</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>big</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default: TV, small: monitor, big:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change channels immediately without select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General playback (part 2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial: %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pre-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Post-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify, but do not skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UDP Notify Port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip blank frames after commercials</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">OK</translation>
+    </message>
+    <message>
+        <source>Recording on cardid: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not Recording: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Override</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previously Recorded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Currently Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other Showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too Many Recordings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Record List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lower Rec Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reason Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>W</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daily Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly Recording</source>
+        <translation type="unfinished">Wekelijks Opnemen</translation>
+    </message>
+    <message>
+        <source>Conflicting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Will Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Won&apos;t Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t record it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never record this episode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record it anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this choice and use it automatically in the future</source>
+        <translation type="unfinished">Onthou deze keuze en gebruik ze later automatisch</translation>
+    </message>
+    <message>
+        <source>Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable AC3 to SPDIF passthrough</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIP Video Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of PIP Video window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reverse direction in fast forward/rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Recording Priorities</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use program recording priorities to resolve conflicts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording Priorities First.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recording types will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Recording Priorities Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, Exit and Shutdown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RankPrograms</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Neem enkel deze vertoning op</translation>
+        <translation type="obsolete">Neem enkel deze vertoning op</translation>
     </message>
     <message>
         <source>Recording every week</source>
-        <translation>Neem wekelijks op</translation>
+        <translation type="obsolete">Neem wekelijks op</translation>
     </message>
     <message>
         <source>Recording when shown in this timeslot</source>
-        <translation>Neem enkel vertoningen op in dit tijdsblok</translation>
+        <translation type="obsolete">Neem enkel vertoningen op in dit tijdsblok</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Neem enkel vertoningen op dit kanaal op</translation>
+        <translation type="obsolete">Neem enkel vertoningen op dit kanaal op</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Neem alle vertoningen op</translation>
+        <translation type="obsolete">Neem alle vertoningen op</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>Neem deze vertoning niet op</translation>
+        <translation type="obsolete">Neem deze vertoning niet op</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>Fout!</translation>
+        <translation type="obsolete">Fout!</translation>
     </message>
 </context>
 <context>
@@ -1806,13 +2118,6 @@
         <translation type="unfinished"></translation>
     </message>
 </context>
-<context>
-    <name>Scheduler</name>
-    <message>
-        <source>the maximum number of episodes have already been recorded.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>SetRecTimeDialog</name>
     <message>
@@ -2050,10 +2355,6 @@
         <source>Do not edit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>4:3 Zoom</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Brightness (REC) %1 %</source>
         <translation type="unfinished"></translation>
@@ -2070,6 +2371,54 @@
         <source>Hue (REC) %1 %</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Program Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip to Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Annuleer</translation>
+    </message>
+    <message>
+        <source>Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16:9 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4:3 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewScheduled</name>
@@ -2083,38 +2432,42 @@
     </message>
     <message>
         <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
-        <translation>Opname van dit programma is gedesactiveerd omdat het in conflict is met een andere opname. Wilt U deze opname heractiveren?</translation>
+        <translation type="obsolete">Opname van dit programma is gedesactiveerd omdat het in conflict is met een andere opname. Wilt U deze opname heractiveren?</translation>
     </message>
     <message>
         <source>Yes, I want to record it.</source>
-        <translation>Ja, ik wil het opnemen.</translation>
+        <translation type="obsolete">Ja, ik wil het opnemen.</translation>
     </message>
     <message>
         <source>No, leave it disabled.</source>
-        <translation>Nee, laat het gedesactiveerd.</translation>
+        <translation type="obsolete">Nee, laat het gedesactiveerd.</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
-        <translation>Opname van dit programma is uitgeschakeld, omdat het vroeger al is opgenomen.</translation>
+        <translation type="obsolete">Opname van dit programma is uitgeschakeld, omdat het vroeger al is opgenomen.</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>OK</translation>
+        <translation type="obsolete">OK</translation>
     </message>
     <message>
         <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
-        <translation>De volgende opnames zijn in conflict. Welk programma wenst U op te nemen?</translation>
+        <translation type="obsolete">De volgende opnames zijn in conflict. Welk programma wenst U op te nemen?</translation>
     </message>
     <message>
         <source>Remember this choice and use it automatically in the future</source>
-        <translation>Onthou deze keuze en gebruik ze later automatisch</translation>
+        <translation type="obsolete">Onthou deze keuze en gebruik ze later automatisch</translation>
     </message>
     <message>
         <source>Unsuppress recording</source>
-        <translation>Heractiveer opname</translation>
+        <translation type="obsolete">Heractiveer opname</translation>
     </message>
     <message>
-        <source>Recording this program has been suppressed because: </source>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Important</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
