@@ -3,27 +3,27 @@
     <name>GuideGrid</name>
     <message>
         <source>Recording Once</source>
-        <translation>Gravar uma Vez</translation>
+        <translation type="obsolete">Gravar uma Vez</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation>Gravar a esta Hora</translation>
+        <translation type="obsolete">Gravar a esta Hora</translation>
     </message>
     <message>
         <source>Channel Recording</source>
-        <translation>Gravar neste Canal</translation>
+        <translation type="obsolete">Gravar neste Canal</translation>
     </message>
     <message>
         <source>All Recording</source>
-        <translation>Gravar em Todos os Canais</translation>
+        <translation type="obsolete">Gravar em Todos os Canais</translation>
     </message>
     <message>
         <source>Not Recording</source>
-        <translation>Não Gravar</translation>
+        <translation type="obsolete">Não Gravar</translation>
     </message>
     <message>
         <source>Weekly Recording</source>
-        <translation>Gravação Semanal</translation>
+        <translation type="obsolete">Gravação Semanal</translation>
     </message>
 </context>
 <context>
@@ -161,10 +161,6 @@
 </context>
 <context>
     <name>MythContext</name>
-    <message>
-        <source>Connection to the master backend server timed out.  You probably should modify the Mater Server setting in the setup program and set the proper IP address there.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Could not connect to the master backend server -- is it running?  Is the IP address set for it in the setup program correct?</source>
         <translation type="unfinished"></translation>
@@ -335,7 +331,7 @@
     </message>
     <message>
         <source>Auto Expire</source>
-        <translation type="unfinished"></translation>
+        <translation type="unfinished">Permitir que a gravação seja apagada automaticamente</translation>
     </message>
     <message>
         <source>Delete</source>
@@ -345,6 +341,10 @@
         <source>Cancel</source>
         <translation type="unfinished">Cancelar</translation>
     </message>
+    <message>
+        <source>Yes; allow re-recording</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ProgFinder</name>
@@ -397,15 +397,46 @@
     <name>ProgLister</name>
     <message>
         <source>Recording just this showing</source>
-        <translation type="unfinished">Gravar apenas este programa</translation>
+        <translation type="obsolete">Gravar apenas este programa</translation>
     </message>
     <message>
         <source>Recording every day when shown in this timeslot</source>
-        <translation type="unfinished">Gravar todos os dias quando der neste período de tempo</translation>
+        <translation type="obsolete">Gravar todos os dias quando der neste período de tempo</translation>
     </message>
     <message>
         <source>Recording every week when shown in this timeslot</source>
-        <translation type="unfinished">Gravar todos as semanas quando der neste período de tempo</translation>
+        <translation type="obsolete">Gravar todos as semanas quando der neste período de tempo</translation>
+    </message>
+    <message>
+        <source>Recording when shown on this channel</source>
+        <translation type="obsolete">Gravar quando der neste canal</translation>
+    </message>
+    <message>
+        <source>Recording all showings</source>
+        <translation type="obsolete">Gravar sempre que que der este programa</translation>
+    </message>
+    <message>
+        <source>Not recording this showing</source>
+        <translation type="obsolete">Não gravar este programa</translation>
+    </message>
+    <message>
+        <source>Error!</source>
+        <translation type="obsolete">Erro!</translation>
+    </message>
+</context>
+<context>
+    <name>ProgramRecPriority</name>
+    <message>
+        <source>Recording just this showing</source>
+        <translation type="unfinished">Gravar apenas este programa</translation>
+    </message>
+    <message>
+        <source>Recording every week</source>
+        <translation type="unfinished">Gravar todas as semanas</translation>
+    </message>
+    <message>
+        <source>Recording when shown in this timeslot</source>
+        <translation type="unfinished"></translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
@@ -436,7 +467,7 @@
     </message>
     <message>
         <source>Yes, Exit and shutdown the computer</source>
-        <translation>Sim, sair e desligar o computador</translation>
+        <translation type="obsolete">Sim, sair e desligar o computador</translation>
     </message>
     <message>
         <source>Do you really want to exit MythTV?</source>
@@ -558,29 +589,53 @@
         <source>Schedule</source>
         <translation>Programação</translation>
     </message>
+    <message>
+        <source>Do not record this proram</source>
+        <translation type="obsolete">Não gravar este programa</translation>
+    </message>
+    <message>
+        <source>Record only this showing</source>
+        <translation>Gravar este programa apenas esta vez</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every day</source>
+        <translation>Gravar este programa neste período de tempo todos os dias</translation>
+    </message>
+    <message>
+        <source>Record at any time on this channel</source>
+        <translation>Gravar este programa sempre que apareça neste canal</translation>
+    </message>
+    <message>
+        <source>Record at any time on any channel</source>
+        <translation>Gravar este programa sempre que esteja programado</translation>
+    </message>
+    <message>
+        <source>Record in this timeslot every week</source>
+        <translation>Gravar este programa neste período de tempo todas as semanas</translation>
+    </message>
     <message>
         <source>Do not record this program</source>
         <translation>Não gravar este programa</translation>
     </message>
     <message>
         <source>Record only this showing of the program</source>
-        <translation>Gravar este programa apenas esta vez</translation>
+        <translation type="obsolete">Gravar este programa apenas esta vez</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every day</source>
-        <translation>Gravar este programa neste período de tempo todos os dias</translation>
+        <translation type="obsolete">Gravar este programa neste período de tempo todos os dias</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown on this channel</source>
-        <translation>Gravar este programa sempre que apareça neste canal</translation>
+        <translation type="obsolete">Gravar este programa sempre que apareça neste canal</translation>
     </message>
     <message>
         <source>Record this program whenever it&apos;s shown anywhere</source>
-        <translation>Gravar este programa sempre que esteja programado</translation>
+        <translation type="obsolete">Gravar este programa sempre que esteja programado</translation>
     </message>
     <message>
         <source>Record this program in this timeslot every week</source>
-        <translation>Gravar este programa neste período de tempo todas as semanas</translation>
+        <translation type="obsolete">Gravar este programa neste período de tempo todas as semanas</translation>
     </message>
     <message>
         <source>Profile</source>
@@ -592,14 +647,14 @@
     </message>
     <message>
         <source>Rank</source>
-        <translation>Preferência</translation>
+        <translation type="obsolete">Preferência</translation>
     </message>
     <message>
-        <source>Allow recording even if duplicate episode</source>
+        <source>Record duplicates</source>
         <translation>Permitir gravação mesmo que seja um episódio duplicado</translation>
     </message>
     <message>
-        <source>Allow recordings to be Auto-Expired</source>
+        <source>Auto Expire</source>
         <translation>Permitir que a gravação seja apagada automaticamente</translation>
     </message>
     <message>
@@ -726,10 +781,6 @@
         <source>Automatically Skip Commercials</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Automatically Flag Commercials</source>
         <translation type="unfinished"></translation>
@@ -890,25 +941,17 @@
         <source>Pre-scaling theme images</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Not Currently Suppressed</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Not Recording</source>
         <translation type="unfinished">Não Gravar</translation>
     </message>
     <message>
         <source>Recording Once</source>
-        <translation type="unfinished">Gravar uma Vez</translation>
+        <translation type="obsolete">Gravar uma Vez</translation>
     </message>
     <message>
         <source>Timeslot Recording</source>
-        <translation type="unfinished">Gravar a esta Hora</translation>
-    </message>
-    <message>
-        <source>Weekslot Recording</source>
-        <translation type="unfinished"></translation>
+        <translation type="obsolete">Gravar a esta Hora</translation>
     </message>
     <message>
         <source>Channel Recording</source>
@@ -1426,62 +1469,6 @@
         <source>Time Blocks (30 mins) to Display</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>Use Rankings</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use program rankings to resolve conflicts.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Rankings First.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Use rankings to resolve conflicts before using traditional conflict resolution.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Single Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Weekslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Timeslot Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>Channel Recordings will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recordings Rank</source>
-        <translation type="unfinished"></translation>
-    </message>
-    <message>
-        <source>All Recording types will receive this additional ranking value.</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Guide starts at channel</source>
         <translation type="unfinished"></translation>
@@ -1598,10 +1585,6 @@
         <source>Program Guide</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>General Ranking Settings</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Screen settings</source>
         <translation type="unfinished"></translation>
@@ -1846,36 +1829,365 @@
         <source>PVR-350 Settings</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Custom Filters</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Advanced Filter configuration, format:
+[[&lt;filter&gt;=&lt;options&gt;,]...]</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Font size</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>small</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>big</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>default: TV, small: monitor, big:</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Change channels immediately without select</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When a complete channel number is entered MythTV will switch to that channel immediately without requiring you to hit the select button.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General playback (part 2)</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Commercial: %1 seconds</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Pre-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Post-Roll Minutes</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Notify, but do not skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically Skip</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Automatically skip commercial breaks that have been flagged during Automatic Commercial Flagging or by the mythcommflag program, or just notify that a commercial has been detected.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>UDP Notify Port</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If this is set to a port number, MythTV will listen during playback for connections from the &apos;mythtvosd&apos; or &apos;mythudprelay&apos; for events.  See the README in contrib/mythnotify/ for more details.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If deleted</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Always</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Skip blank frames after commercials</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>When using Blank Frame Detection and Auto-Flagging, flag blank frames following commercial breaks as part of the the commercial break.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>OK</source>
+        <translation type="unfinished">Ok</translation>
+    </message>
+    <message>
+        <source>Recording on cardid: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Not Recording: </source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Override</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Previously Recorded</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Currently Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Other Showing</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Too Many Recordings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Record List</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Lower Rec Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Manual Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Conflict</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Overlap</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reason Unknown</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Repeat</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>R</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>T</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>W</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>C</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>A</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source></source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Daily Recording</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekly Recording</source>
+        <translation type="unfinished">Gravação Semanal</translation>
+    </message>
+    <message>
+        <source>Conflicting</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Will Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Won&apos;t Record</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t record it</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Never record this episode</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Record it anyway</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>The following scheduled recordings conflict with each other.  Which would you like to record?</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Remember this choice and use it automatically in the future</source>
+        <translation type="unfinished">Recordar esta opción y usarla automáticamente en el futuro</translation>
+    </message>
+    <message>
+        <source>Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable AC3 to SPDIF passthrough</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Enable sending AC3 sound directly to your sound card&apos;s SPDIF output, on sources which contain AC3 soundtracks (usually digital TV).  Requires that the audio output device be set to something suitable.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>PIP Video Location</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Left</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Top Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Bottom Right</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Location of PIP Video window.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Reverse direction in fast forward/rewind</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>If set, pressing the sticky rewind key in fast forward mode will switch to rewind mode, and vice versa.  If not set, doing so will decrease the speed in the current direction or switch to play mode if the speed can&apos;t be decreased further..</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use Recording Priorities</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use program recording priorities to resolve conflicts.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Recording Priorities First.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Use recording priorities to resolve conflicts before using traditional conflict resolution.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Single Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Weekslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Timeslot Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Channel Recordings will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recordings Priority</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>All Recording types will receive this additional recording priority value.</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>General Recording Priorities Settings</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Yes, Exit and Shutdown</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>RankPrograms</name>
     <message>
         <source>Recording just this showing</source>
-        <translation>Gravar apenas este programa</translation>
+        <translation type="obsolete">Gravar apenas este programa</translation>
     </message>
     <message>
         <source>Recording every week</source>
-        <translation>Gravar todas as semanas</translation>
+        <translation type="obsolete">Gravar todas as semanas</translation>
     </message>
     <message>
         <source>Recording when shown in this timeslot</source>
-        <translation>Gravar quando der neste período de tempo</translation>
+        <translation type="obsolete">Gravar quando der neste período de tempo</translation>
     </message>
     <message>
         <source>Recording when shown on this channel</source>
-        <translation>Gravar quando der neste canal</translation>
+        <translation type="obsolete">Gravar quando der neste canal</translation>
     </message>
     <message>
         <source>Recording all showings</source>
-        <translation>Gravar sempre que que der este programa</translation>
+        <translation type="obsolete">Gravar sempre que que der este programa</translation>
     </message>
     <message>
         <source>Not recording this showing</source>
-        <translation>Não gravar este programa</translation>
+        <translation type="obsolete">Não gravar este programa</translation>
     </message>
     <message>
         <source>Error!</source>
-        <translation>Erro!</translation>
+        <translation type="obsolete">Erro!</translation>
     </message>
 </context>
 <context>
@@ -1893,13 +2205,6 @@
         <translation>Ver a lista de todos os próximos episódios e horários.</translation>
     </message>
 </context>
-<context>
-    <name>Scheduler</name>
-    <message>
-        <source>the maximum number of episodes have already been recorded.</source>
-        <translation type="unfinished"></translation>
-    </message>
-</context>
 <context>
     <name>SetRecTimeDialog</name>
     <message>
@@ -2133,10 +2438,6 @@
         <source>Do not edit</source>
         <translation type="unfinished"></translation>
     </message>
-    <message>
-        <source>4:3 Zoom</source>
-        <translation type="unfinished"></translation>
-    </message>
     <message>
         <source>Brightness (REC) %1 %</source>
         <translation type="unfinished"></translation>
@@ -2153,36 +2454,84 @@
         <source>Hue (REC) %1 %</source>
         <translation type="unfinished"></translation>
     </message>
+    <message>
+        <source>Program Menu</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Set Commercial Auto-Skip to Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Don&apos;t Auto Expire</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto Expire</source>
+        <translation type="unfinished">Permitir que a gravação seja apagada automaticamente</translation>
+    </message>
+    <message>
+        <source>Cancel</source>
+        <translation type="unfinished">Cancelar</translation>
+    </message>
+    <message>
+        <source>Auto-Skip OFF</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip ON</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Auto-Skip Notify</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>16:9 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>4:3 Zoom</source>
+        <translation type="unfinished"></translation>
+    </message>
 </context>
 <context>
     <name>ViewScheduled</name>
     <message>
         <source>Recording this program has been deactivated because it conflicts with another scheduled recording.  Do you want to re-enable this recording?</source>
-        <translation>A gravação deste programa foi desactivada pois está em conflito com outra gravação. Deseja reabilitar esta gravação?</translation>
+        <translation type="obsolete">A gravação deste programa foi desactivada pois está em conflito com outra gravação. Deseja reabilitar esta gravação?</translation>
     </message>
     <message>
         <source>Yes, I want to record it.</source>
-        <translation>Sim, quero gravar.</translation>
+        <translation type="obsolete">Sim, quero gravar.</translation>
     </message>
     <message>
         <source>No, leave it disabled.</source>
-        <translation>Não, deixar desabilitada.</translation>
+        <translation type="obsolete">Não, deixar desabilitada.</translation>
     </message>
     <message>
         <source>Recording this program has been suppressed because it has already been recorded in the past.</source>
-        <translation type="unfinished">Esta grabación fué cancelada porque ya se grabó anteriormente.</translation>
+        <translation type="obsolete">Esta grabación fué cancelada porque ya se grabó anteriormente.</translation>
     </message>
     <message>
         <source>OK</source>
-        <translation>Ok</translation>
+        <translation type="obsolete">Ok</translation>
     </message>
     <message>
         <source>The follow scheduled recordings conflict with each other.  Which would you like to record?</source>
-        <translation type="unfinished">Estas grabaciones programadas estan en conflicto entre sí. ¿Cuál quiere mantener?</translation>
+        <translation type="obsolete">Estas grabaciones programadas estan en conflicto entre sí. ¿Cuál quiere mantener?</translation>
     </message>
     <message>
         <source>Remember this choice and use it automatically in the future</source>
-        <translation type="unfinished">Recordar esta opción y usarla automáticamente en el futuro</translation>
+        <translation type="obsolete">Recordar esta opción y usarla automáticamente en el futuro</translation>
     </message>
     <message>
         <source>Time Conflict</source>
@@ -2194,10 +2543,14 @@
     </message>
     <message>
         <source>Unsuppress recording</source>
-        <translation type="unfinished">Desuprimir grabación</translation>
+        <translation type="obsolete">Desuprimir grabación</translation>
     </message>
     <message>
-        <source>Recording this program has been suppressed because: </source>
+        <source>All</source>
+        <translation type="unfinished"></translation>
+    </message>
+    <message>
+        <source>Important</source>
         <translation type="unfinished"></translation>
     </message>
 </context>
