@@ -78,7 +78,8 @@ void AudioOutputOSS::Reconfigure(int laudio_bits, int laudio_channels,
     QDateTime curtime = QDateTime::currentDateTime();
     curtime = curtime.addSecs(2);
     
-    printf("Opening OSS audio device '%s'.\n", audiodevice.ascii());
+    VERBOSE(VB_GENERAL, QString("Opening OSS audio device '%1'.")
+            .arg(audiodevice));
     
     while (QDateTime::currentDateTime() < curtime && audiofd == -1)
     {
@@ -226,16 +227,17 @@ void AudioOutputOSS::WriteAudio(unsigned char *aubuf, int size)
     while ((written < size) && 
            ((lw = write(audiofd, tmpbuf, size - written)) > 0))
     {
-        if (lw == -1)
-        {
-            cerr << "Error writing to audio device, exiting\n";
-            close(audiofd);
-            audiofd = -1;
-            return;
-        }
         written += lw;
         tmpbuf += lw;
     }
+
+    if (lw < 0)
+    {
+        perror("Writing to audio device");
+        close(audiofd);
+        audiofd = -1;
+        return;
+    }
 }
 
 void AudioOutputOSS::SetTimecode(long long timecode)
