@@ -9,6 +9,9 @@
 #include <qurl.h>
 #include <qnetwork.h>
 
+#include <qsocketdevice.h>
+#include <qhostaddress.h>
+
 #include "mythcontext.h"
 #include "oldsettings.h"
 #include "themedmenu.h"
@@ -78,7 +81,14 @@ MythContext::MythContext(const QString &binversion, bool gui, bool lcd)
         m_height = GetNumSetting("GuiHeight");
 
     serverSock = NULL;
-    expectingReply = false;
+    eventSock = new QSocket(0);
+    
+    connect(eventSock, SIGNAL(connected()), 
+             this, SLOT(EventSocketConnected()));
+    connect(eventSock, SIGNAL(readyRead()), 
+             this, SLOT(EventSocketRead()));
+    connect(eventSock, SIGNAL(connectionClosed()), 
+             this, SLOT(EventSocketClosed()));
 
     mainWindow = NULL;
 
@@ -86,6 +96,8 @@ MythContext::MythContext(const QString &binversion, bool gui, bool lcd)
         lcd_device = new LCD();
     else
         lcd_device = NULL;
+
+    disablelibrarypopup = false;
 }
 
 MythContext::~MythContext()
@@ -97,11 +109,9 @@ MythContext::~MythContext()
     if (m_qtThemeSettings)
         delete m_qtThemeSettings;
     if (serverSock)
-    {
-        serverSock->close();
         delete serverSock;
-    }
-
+    if (eventSock)
+        delete eventSock;
     if (lcd_device)
         delete lcd_device;
 }
@@ -118,64 +128,73 @@ bool MythContext::ConnectServer(const QString &hostname, int port)
     if (serverSock)
         return true;
 
-    serverSock = new QSocket();
+    int cnt = 0;
 
-    cout << "connecting to backend server: " << hostname << ":" << port << endl;
-    serverSock->connectToHost(hostname, port);
+    int sleepTime = GetNumSetting("WOLbackendReconnectWaitTime", 0);
+    int maxConnTry = GetNumSetting("WOLbackendConnectRetry", 1);
 
-    int num = 0;
-    while (serverSock->state() == QSocket::HostLookup ||
-           serverSock->state() == QSocket::Connecting)
+    do
     {
-        qApp->processEvents();
-        usleep(50);
-        num++;
-        if (num > 100)
+        VERBOSE(VB_GENERAL, QString("Connecting to backend server: "
+                                    "%1:%2 (try %3 of %4)")
+                                    .arg(hostname).arg(port).arg(cnt+1)
+                                    .arg(maxConnTry));
+
+        serverSock = new QSocketDevice(QSocketDevice::Stream);
+
+        if (!connectSocket(serverSock, hostname, port))
         {
-            cerr << "Connection timed out.\n";
-            cerr << "You probably should modify the Master Server settings\n";
-            cerr << "in the setup program and set the proper IP address.\n";
-            if (m_height && m_width)
-            {
-                MythPopupBox::showOkPopup(mainWindow, "connection failure",
-                                          tr("Connection to the master backend "
-                                             "server timed out.  You probably "
-                                             "should modify the Mater Server "
-                                             "setting in the setup program and "
-                                             "set the proper IP address "
-                                             "there."));
-            }
-            serverSock->close();
             delete serverSock;
             serverSock = NULL;
-            return false;
-        }
-    }
+        
+            // only inform the user of a failure if WOL is disabled 
+            if (sleepTime <= 0)
+            {
+                cerr << "Connection timed out.\n";
+                cerr << "You probably should modify the Master Server "
+                     << "settings\nin the setup program and set the proper "
+                     << "IP address.\n";
+                if (m_height && m_width)
+                {
+                    MythPopupBox::showOkPopup(mainWindow, "connection failure",
+                                              tr("Could not connect to the "
+                                                 "master backend server -- is "
+                                                 "it running?  Is the IP "
+                                                 "address set for it in the "
+                                                 "setup program correct?"));
+                }
 
-    if (serverSock->state() != QSocket::Connected)
-    {
-        cout << "Could not connect to backend server\n";
-        if (m_height && m_width)
-        {
-            MythPopupBox::showOkPopup(mainWindow, "connection failure",
-                                      tr("Could not connect to the master "
-                                         "backend server -- is it running?  Is "
-                                         "the IP address set for it in the "
-                                         "setup program correct?"));
-        }
-        serverSock->close();
-        delete serverSock;
-        serverSock = NULL;
-        return false;
-    }
+                return false;
+            }
+            else
+            {
+                VERBOSE(VB_GENERAL, "Trying to wake up the MasterBackend "
+                                    "now.");
+                QString wol_cmd = GetSetting("WOLbackendCommand",
+                                             "echo \'would run the "
+                                             "WakeServerCommand now, if "
+                                             "set!\'");
+                system(wol_cmd.ascii());
 
-    QString str = QString("ANN Playback %1 %2").arg(m_localhostname).arg(true);
+                VERBOSE(VB_GENERAL, QString("Waiting for %1 seconds until I "
+                                            "try to reconnect again.")
+                                            .arg(sleepTime));
+                sleep(sleepTime);
+                ++cnt;
+            }
+        }
+        else
+            break;
+    }
+    while (cnt <= maxConnTry);
+    
+    QString str = QString("ANN Playback %1 %2").arg(m_localhostname).arg(false);
     QStringList strlist = str;
     WriteStringList(serverSock, strlist);
-    ReadStringList(serverSock, strlist);
-
-    connect(serverSock, SIGNAL(readyRead()), this, SLOT(readSocket()));
-
+    ReadStringList(serverSock, strlist, true);
+    
+    eventSock->connectToHost(hostname, port);
+    
     return true;
 }
 
@@ -185,9 +204,9 @@ QString MythContext::GetMasterHostPrefix(void)
 
     if (!serverSock)
         ConnectToMasterServer();
-
+    
     if (serverSock)
-        ret = QString("myth://%1:%2/").arg(serverSock->peerName())
+        ret = QString("myth://%1:%2/").arg(serverSock->peerAddress().toString())
                                       .arg(serverSock->peerPort());
     return ret;
 }
@@ -377,15 +396,17 @@ void MythContext::CacheThemeImagesDirectory(const QString &dir)
         if (!cacheinfo.exists() ||
             (cacheinfo.lastModified() < fi->lastModified()))
         {
-            cout << "generating cache image for: " << fi->absFilePath() << endl;
+            VERBOSE(VB_FILE, QString("generating cache image for: %1")
+                    .arg(fi->absFilePath()));
+
             QImage *tmpimage = LoadScaleImage(fi->absFilePath(), false);
 
             if (tmpimage)
             {
                 if (!tmpimage->save(themecachedir + filename, "PNG"))
                 {
-                    cerr << "Couldn't save cache image: " 
-                         << themecachedir + filename << endl;
+                    VERBOSE(VB_FILE, QString("Couldn't save cache image: %1")
+                            .arg(themecachedir + filename));
                 }
              
                 delete tmpimage;
@@ -933,7 +954,7 @@ QPixmap *MythContext::LoadScalePixmap(QString filename, bool fromcache)
     return ret;
 }
 
-QImage *MythContext::CacheRemotePixmap(const QString &url, bool needevents)
+QImage *MythContext::CacheRemotePixmap(const QString &url)
 {
     QUrl qurl = url;
     if (qurl.host() == "")
@@ -947,7 +968,7 @@ QImage *MythContext::CacheRemotePixmap(const QString &url, bool needevents)
     RemoteFile *rf = new RemoteFile(url, true);
 
     QByteArray data;
-    bool ret = rf->SaveAs(data, needevents);
+    bool ret = rf->SaveAs(data);
 
     delete rf;
 
@@ -969,71 +990,68 @@ void MythContext::SetSetting(const QString &key, const QString &newValue)
     m_settings->SetSetting(key, newValue);
 }
 
-bool MythContext::SendReceiveStringList(QStringList &strlist)
+bool MythContext::SendReceiveStringList(QStringList &strlist, bool quickTimeout)
 {
+    serverSockLock.lock();
+    
     if (!serverSock)
         ConnectToMasterServer();
 
-    if (!serverSock)
-        return false;
-
-    serverSockLock.lock();
-    expectingReply = true;
-
-    WriteStringList(serverSock, strlist);
-    bool ok = ReadStringList(serverSock, strlist);
-
-    while (ok && strlist[0] == "BACKEND_MESSAGE")
+    bool ok = false;
+    
+    if (serverSock)
     {
-        // oops, not for us
-        QString message = strlist[1];
-        QString extra = strlist[2];
+        WriteStringList(serverSock, strlist);
+        ok = ReadStringList(serverSock, strlist, quickTimeout);
 
-        MythEvent me(message, extra);
-        dispatch(me);
+        // this should be obsolete...
+        while (ok && strlist[0] == "BACKEND_MESSAGE")
+        {
+            // oops, not for us
+            cerr << "SRSL you shouldn't see this!!";
+            QString message = strlist[1];
+            QString extra = strlist[2];
 
-        ok = ReadStringList(serverSock, strlist);
-    }
+            MythEvent me(message, extra);
+            dispatch(me);
 
-    if (!ok)
-    {
-        qApp->lock();
-        cout << "Connection to backend server lost\n";
-        MythPopupBox::showOkPopup(mainWindow, "connection failure",
-                                  tr("The connection to the master backend "
-                                     "server has gone away for some reason.. "
-                                     "Is it running?"));
+            ok = ReadStringList(serverSock, strlist, quickTimeout);
+        }
+        // .
 
-        serverSock->close();
-        delete serverSock;
-        serverSock = NULL;
-        qApp->unlock();
-    }
+        if (!ok)
+        {
+            qApp->lock();
+            cout << "Connection to backend server lost\n";
+            MythPopupBox::showOkPopup(mainWindow, "connection failure",
+                             tr("The connection to the master backend "
+                                "server has gone away for some reason.. "
+                                "Is it running?"));
+
+            delete serverSock;
+            serverSock = NULL;
+            qApp->unlock();
+        }
+    }    
 
-    expectingReply = false;
     serverSockLock.unlock();
-
+    
     return ok;
 }
 
-void MythContext::readSocket(void)
+void MythContext::EventSocketRead(void)
 {
-    if (expectingReply)
-        return;
-
-    serverSockLock.lock();
-
-    while (serverSock->state() == QSocket::Connected &&
-           serverSock->bytesAvailable() > 0)
+    while (eventSock->state() == QSocket::Connected &&
+           eventSock->bytesAvailable() > 0)
     {
         QStringList strlist;
-        if (!ReadStringList(serverSock, strlist))
+        if (!ReadStringList(eventSock, strlist))
             continue;
 
         QString prefix = strlist[0];
         QString message = strlist[1];
         QString extra = strlist[2];
-
+        
         if (prefix != "BACKEND_MESSAGE")
         {
             cerr << "Received a: " << prefix << " message from the backend\n";
@@ -1045,8 +1063,19 @@ void MythContext::readSocket(void)
             dispatch(me);
         }
     }
+}
 
-    serverSockLock.unlock();
+void MythContext::EventSocketConnected(void)
+{
+    QString str = QString("ANN Playback %1 %2").arg(m_localhostname).arg(true);
+    QStringList strlist = str;
+    WriteStringList(eventSock, strlist);
+    ReadStringList(eventSock, strlist);
+}
+
+void MythContext::EventSocketClosed(void)
+{
+    cerr << "Errm, event socket just closed.\n";
 }
 
 void MythContext::addListener(QObject *obj)
@@ -1083,20 +1112,18 @@ void MythContext::dispatchNow(MythEvent &e)
 
 QFont MythContext::GetBigFont(void)
 {
-    return QFont("Arial", (int)(gContext->GetBigFontSize() * m_hmult),
-                 QFont::Bold);
+    return QFont("Arial", (int)ceil(GetBigFontSize() * m_hmult), QFont::Bold);
 }
 
 QFont MythContext::GetMediumFont(void)
 {
-    return QFont("Arial", (int)(gContext->GetMediumFontSize() * m_hmult),
+    return QFont("Arial", (int)ceil(GetMediumFontSize() * m_hmult), 
                  QFont::Bold);
 }
 
 QFont MythContext::GetSmallFont(void)
 {
-    return QFont("Arial", (int)(gContext->GetSmallFontSize() * m_hmult),
-                 QFont::Bold);
+    return QFont("Arial", (int)ceil(GetSmallFontSize() * m_hmult), QFont::Bold);
 }
 
 QString MythContext::GetLanguage(void)
@@ -1129,10 +1156,13 @@ bool MythContext::TestPopupVersion(const QString &name,
                   "libmyth is at version: " + libversion + ".  You probably " +
                   "want to recompile the " + name + " plugin after doing a " +
                   "make distclean.";
-                  
-    DialogBox dbox(gContext->GetMainWindow(), err);
-    dbox.AddButton("OK");
-    dbox.exec();
+
+    if (gContext->GetMainWindow() && !disablelibrarypopup)
+    {    
+        DialogBox dbox(gContext->GetMainWindow(), err);
+        dbox.AddButton("OK");
+        dbox.exec();
+    }
 
     return false;
 }
