@@ -9,10 +9,16 @@
 #include <qptrlist.h>
 #include <qevent.h>
 #include <qmutex.h>
+#include <qsocketdevice.h>
+#include <qnetwork.h> 
 
 #include <vector>
 using namespace std;
 
+#if (QT_VERSION < 0x030100)
+#error You need Qt version >= 3.1.0 to compile MythTV.
+#endif
+
 class Settings;
 class QSqlDatabase;
 class QSqlQuery;
@@ -67,7 +73,7 @@ class MythEvent : public QCustomEvent
     QString extradata;
 };
 
-#define MYTH_BINARY_VERSION "0.12.10132003-1"
+#define MYTH_BINARY_VERSION "0.13.12102003-1"
 
 extern int print_verbose_messages;
 
@@ -84,6 +90,7 @@ class MythContext : public QObject
 
     bool ConnectToMasterServer(void);
     bool ConnectServer(const QString &hostname, int port);
+    bool IsConnectedToMaster(void) { return serverSock; }
 
     QString GetInstallPrefix() { return m_installprefix; }
     QString GetShareDir() { return m_installprefix + "/share/mythtv/"; }
@@ -143,9 +150,9 @@ class MythContext : public QObject
     void dispatch(MythEvent &e);
     void dispatchNow(MythEvent &e);
 
-    bool SendReceiveStringList(QStringList &strlist);
+    bool SendReceiveStringList(QStringList &strlist, bool quickTimeout = false);
 
-    QImage *CacheRemotePixmap(const QString &url, bool needevents = true);
+    QImage *CacheRemotePixmap(const QString &url);
 
     void SetMainWindow(MythMainWindow *mainwin);
     MythMainWindow *GetMainWindow(void);
@@ -154,8 +161,13 @@ class MythContext : public QObject
 
     bool TestPopupVersion(const QString &name, const QString &libversion,
                           const QString &pluginversion);
+
+    void SetDisableLibraryPopup(bool check) { disablelibrarypopup = check; }
+    
   private slots:
-    void readSocket();
+    void EventSocketRead();
+    void EventSocketConnected();
+    void EventSocketClosed();
 
   private:
     void SetPalette(QWidget *widget);
@@ -179,11 +191,9 @@ class MythContext : public QObject
     int m_xbase, m_ybase;
     int m_height, m_width;
 
-    QSocket *serverSock;
     QString m_localhostname;
 
     QMutex serverSockLock;
-    bool expectingReply;
 
     QPtrList<QObject> listeners;
 
@@ -204,40 +214,13 @@ class MythContext : public QObject
     QString themecachedir;
 
     int bigfontsize, mediumfontsize, smallfontsize; 
+
+    QSocketDevice *serverSock;
+    QSocket *eventSock;
+
+    bool disablelibrarypopup;
 };
 
 extern MythContext *gContext;
 
-#if (QT_VERSION < 0x030100)
-class QMutexLocker
-{
-  public:
-    QMutexLocker(QMutex *);
-   ~QMutexLocker();
-
-    QMutex *mutex() const;
-
-  private:
-    QMutex *mtx;
-};
-
-inline QMutexLocker::QMutexLocker(QMutex *m)
-{
-    mtx = m;
-    if (mtx)
-        mtx->lock();
-}
-
-inline QMutexLocker::~QMutexLocker()
-{
-    if (mtx)
-        mtx->unlock();
-}
-
-inline QMutex *QMutexLocker::mutex() const
-{
-    return mtx;
-}
-#endif
-
 #endif
