@@ -9,6 +9,8 @@
 #include <qregexp.h>
 #include <qaccel.h>
 #include <qfocusdata.h>
+#include <qdict.h>
+#include <qsqldatabase.h>
 
 #include <iostream>
 using namespace std;
@@ -38,11 +40,66 @@ static void *SpawnLirc(void *param)
 }
 #endif
 
+class KeyContext
+{
+  public:
+    void AddMapping(int key, QString action)
+    {
+        actionMap[key] = action;
+    }
+
+    bool GetMapping(int key, QString &action)
+    {
+        if (actionMap.count(key) > 0)
+        {
+            action = actionMap[key];
+            return true;
+        }
+        return false;
+    }
+
+    QMap<int, QString> actionMap;
+};
+
+struct JumpData
+{
+    void (*callback)(void);
+    QString destination;
+    QString description;
+};
+
+class MythMainWindowPrivate
+{
+  public:
+    float wmult, hmult;
+    int screenwidth, screenheight;
+    int xbase, ybase;
+
+    vector<QWidget *> widgetList;
+
+    bool ignore_lirc_keys;
+
+    bool exitingtomain;
+
+    QDict<KeyContext> keyContexts;
+    QMap<int, JumpData> jumpMap;
+
+    void (*exitmenucallback)(void);
+
+    int escapekey;
+};
+
 MythMainWindow::MythMainWindow(QWidget *parent, const char *name, bool modal)
               : QDialog(parent, name, modal)
 {
+    d = new MythMainWindowPrivate;
+
     Init();
-    ignore_lirc_keys = false;
+    d->ignore_lirc_keys = false;
+    d->exitingtomain = false;
+    d->exitmenucallback = false;
+    d->escapekey = Key_Escape;
+
 #ifdef USE_LIRC
     pthread_t lirc_tid;
     pthread_attr_t attr;
@@ -51,17 +108,46 @@ MythMainWindow::MythMainWindow(QWidget *parent, const char *name, bool modal)
 
     pthread_create(&lirc_tid, &attr, SpawnLirc, this);
 #endif
+
+    d->keyContexts.setAutoDelete(true);
+
+    RegisterKey("Global", "UP", "Up Arrow", "Up");
+    RegisterKey("Global", "DOWN", "Down Arrow", "Down");
+    RegisterKey("Global", "LEFT", "Left Arrow", "Left");
+    RegisterKey("Global", "RIGHT", "Right Arrow", "Right");
+    RegisterKey("Global", "SELECT", "Select", "Return,Enter,Space");
+    RegisterKey("Global", "ESCAPE", "Escape", "Esc");
+    RegisterKey("Global", "MENU", "Pop-up menu", "M");
+    RegisterKey("Global", "INFO", "More information", "I");
+
+    RegisterKey("Global", "PAGEUP", "Page Up", "PgUp");
+    RegisterKey("Global", "PAGEDOWN", "Page Down", "PgDown");
+
+    RegisterKey("Global", "0", "0", "0");
+    RegisterKey("Global", "1", "1", "1");
+    RegisterKey("Global", "2", "2", "2");
+    RegisterKey("Global", "3", "3", "3");
+    RegisterKey("Global", "4", "4", "4");
+    RegisterKey("Global", "5", "5", "5");
+    RegisterKey("Global", "6", "6", "6");
+    RegisterKey("Global", "7", "7", "7");
+    RegisterKey("Global", "8", "8", "8");
+    RegisterKey("Global", "9", "9", "9");
+}
+
+MythMainWindow::~MythMainWindow()
+{
+    delete d;
 }
 
 void MythMainWindow::Init(void)
 {
-    gContext->GetScreenSettings(xbase, screenwidth, wmult,
-                                ybase, screenheight, hmult);
-    setGeometry(xbase, ybase, screenwidth, screenheight);
-    setFixedSize(QSize(screenwidth, screenheight));
+    gContext->GetScreenSettings(d->xbase, d->screenwidth, d->wmult,
+                                d->ybase, d->screenheight, d->hmult);
+    setGeometry(d->xbase, d->ybase, d->screenwidth, d->screenheight);
+    setFixedSize(QSize(d->screenwidth, d->screenheight));
 
-    setFont(QFont("Arial", (int)(gContext->GetMediumFontSize() * hmult),
-            QFont::Bold));
+    setFont(gContext->GetMediumFont());
     setCursor(QCursor(Qt::BlankCursor));
 
     gContext->ThemeWidget(this);
@@ -80,33 +166,243 @@ void MythMainWindow::Show(void)
 
 void MythMainWindow::attach(QWidget *child)
 {
-    widgetList.push_back(child);
+    d->widgetList.push_back(child);
     child->raise();
     child->setFocus();
 }
 
 void MythMainWindow::detach(QWidget *child)
 {
-    if (widgetList.back() != child)
+    if (d->widgetList.back() != child)
     {
         cerr << "Not removing top most widget, error\n";
         return;
     }
 
-    widgetList.pop_back();
+    d->widgetList.pop_back();
     QWidget *current = currentWidget();
 
     if (current)
         current->setFocus();
+
+    if (d->exitingtomain)
+        QApplication::postEvent(this, new ExitToMainMenuEvent());
 }
 
 QWidget *MythMainWindow::currentWidget(void)
 {
-    if (widgetList.size() > 0)
-        return widgetList.back();
+    if (d->widgetList.size() > 0)
+        return d->widgetList.back();
     return NULL;
 }
 
+void MythMainWindow::ExitToMainMenu(void)
+{
+    QWidget *current = currentWidget();
+
+    if (current && d->exitingtomain)
+    {
+        if (current->name() != QString("mainmenu"))
+        {
+            if (current->name() == QString("video playback window"))
+            {
+                MythEvent *me = new MythEvent("EXIT_TO_MENU");
+                QApplication::postEvent(current, me);
+                d->exitingtomain = true;
+            }
+            else if (MythDialog *dial = dynamic_cast<MythDialog*>(current))
+            {
+                (void)dial;
+                QKeyEvent *key = new QKeyEvent(QEvent::KeyPress, d->escapekey, 
+                                               0, Qt::NoButton);
+                QObject *key_target = getTarget(*key);
+                QApplication::postEvent(key_target, key);
+                d->exitingtomain = true;
+            }
+        }
+        else
+        {
+            d->exitingtomain = false;
+            if (d->exitmenucallback)
+            {
+                void (*callback)(void) = d->exitmenucallback;
+                d->exitmenucallback = NULL;
+
+                callback();
+            }
+        }
+    }
+}
+
+bool MythMainWindow::TranslateKeyPress(const QString &context,
+                                       QKeyEvent *e, QStringList &actions)
+{
+    actions = QStringList();
+    int keynum = e->key();
+
+    if (d->jumpMap.count(keynum) > 0 && d->exitmenucallback == NULL)
+    {
+        d->exitingtomain = true;
+        d->exitmenucallback = d->jumpMap[keynum].callback;
+        QApplication::postEvent(this, new ExitToMainMenuEvent());
+        return false;
+    }
+
+    bool retval = false;
+
+    QString action;
+
+    if (d->keyContexts[context])
+    {
+        action = "";
+        if (d->keyContexts[context]->GetMapping(keynum, action))
+        {
+            actions += action;
+            retval = true;
+        }
+    }
+
+    action = "";
+    if (d->keyContexts["Global"]->GetMapping(keynum, action))
+    {
+        actions += action;
+        retval = true;
+    }
+
+    return retval;
+}
+
+void MythMainWindow::RegisterKey(const QString &context, const QString &action,
+                                 const QString &description, const QString &key)
+{
+    QString keybind = key;
+
+    QSqlDatabase *db = QSqlDatabase::database();
+
+    QString thequery = QString("SELECT keylist FROM keybindings WHERE "
+                               "context = \"%1\" AND action = \"%2\" AND "
+                               "hostname = \"%2\";")
+                              .arg(context).arg(action)
+                              .arg(gContext->GetHostName());
+
+    QSqlQuery query = db->exec(thequery);
+
+    if (query.isActive() && query.numRowsAffected() > 0)
+    {
+        query.next();
+
+        keybind = query.value(0).toString();
+    }
+    else
+    {
+        QString inskey = keybind;
+        inskey.replace('\\', "\\\\");
+        inskey.replace('\"', "\\\"");
+
+        thequery = QString("INSERT INTO keybindings (context, action, "
+                           "description, keylist, hostname) VALUES "
+                           "(\"%1\", \"%2\", \"%3\", \"%4\", \"%5\");")
+                           .arg(context).arg(action).arg(description)
+                           .arg(inskey).arg(gContext->GetHostName());
+
+        query = db->exec(thequery);
+        if (!query.isActive())
+            MythContext::DBError("Insert Keybinding", query);
+    }
+
+    QKeySequence keyseq(keybind);
+
+    if (!d->keyContexts[context])
+        d->keyContexts.insert(context, new KeyContext());
+
+    for (unsigned int i = 0; i < keyseq.count(); i++)
+    {
+        int keynum = keyseq[i];
+        keynum &= ~Qt::UNICODE_ACCEL;
+
+        QString dummyaction = "";
+        if (d->keyContexts[context]->GetMapping(keynum, dummyaction))
+        {
+            VERBOSE(VB_GENERAL, QString("Key %1 is already bound in context "
+                                        "%2.").arg(keybind).arg(context));
+        }
+        else
+        {
+            d->keyContexts[context]->AddMapping(keynum, action);
+            //VERBOSE(VB_GENERAL, QString("Binding: %1 to action: %2 (%3)")
+            //                           .arg(key).arg(action)
+            //                           .arg(context));
+        }
+
+        if (action == "ESCAPE" && context == "Global" && i == 0)
+            d->escapekey = keynum;
+    }
+}
+
+void MythMainWindow::RegisterJump(const QString &destination, 
+                                  const QString &description,
+                                  const QString &key, void (*callback)(void))
+{
+    QString keybind = key;
+
+    QSqlDatabase *db = QSqlDatabase::database();
+
+    QString thequery = QString("SELECT keylist FROM jumppoints WHERE "
+                               "destination = \"%1\" and hostname = \"%2\";")
+                              .arg(destination).arg(gContext->GetHostName());
+
+    QSqlQuery query = db->exec(thequery);
+
+    if (query.isActive() && query.numRowsAffected() > 0)
+    {
+        query.next();
+ 
+        keybind = query.value(0).toString();
+    }
+    else
+    {
+        QString inskey = keybind;
+        inskey.replace('\\', "\\\\");
+        inskey.replace('\"', "\\\"");
+
+        thequery = QString("INSERT INTO jumppoints (destination, description, "
+                           "keylist, hostname) VALUES (\"%1\", \"%2\", \"%3\", "
+                           "\"%4\");").arg(destination).arg(description)
+                                      .arg(inskey)
+                                      .arg(gContext->GetHostName());
+
+        query = db->exec(thequery);
+        if (!query.isActive())
+            MythContext::DBError("Insert Jump Point", query);
+    }
+    
+    QKeySequence keyseq(keybind);
+
+    if (!keyseq.isEmpty())
+    {
+        int keynum = keyseq[0];
+        keynum &= ~Qt::UNICODE_ACCEL;
+
+        if (d->jumpMap.count(keynum) == 0)
+        {
+            JumpData jd = { callback, destination, description };
+
+            //VERBOSE(VB_GENERAL, QString("Binding: %1 to JumpPoint: %2")
+            //                           .arg(keybind).arg(destination));
+
+            d->jumpMap[keynum] = jd;
+        }
+        else
+        {
+            VERBOSE(VB_GENERAL, QString("Key %1 is already bound to a jump "
+                                        "point.").arg(keybind));
+        }
+    }
+    //else
+    //    VERBOSE(VB_GENERAL, QString("JumpPoint: %2 exists, no keybinding")
+    //                               .arg(destination));
+}
+
 void MythMainWindow::keyPressEvent(QKeyEvent *e)
 {
     QWidget *current = currentWidget();
@@ -118,7 +414,11 @@ void MythMainWindow::keyPressEvent(QKeyEvent *e)
 
 void MythMainWindow::customEvent(QCustomEvent *ce)
 {
-    if (ce->type() == kExternalKeycodeEventType)
+    if (ce->type() == kExitToMainMenuEventType && d->exitingtomain)
+    {
+        ExitToMainMenu();
+    }
+    else if (ce->type() == kExternalKeycodeEventType)
     {
         ExternalKeycodeEvent *eke = (ExternalKeycodeEvent *)ce;
         int keycode = eke->getKeycode();
@@ -130,7 +430,7 @@ void MythMainWindow::customEvent(QCustomEvent *ce)
         QApplication::sendEvent(key_target, &key);
     }
 #ifdef USE_LIRC
-    else if (ce->type() == kLircKeycodeEventType && !ignore_lirc_keys) 
+    else if (ce->type() == kLircKeycodeEventType && !d->ignore_lirc_keys) 
     {
         LircKeycodeEvent *lke = (LircKeycodeEvent *)ce;
         int keycode = lke->getKeycode();
@@ -166,7 +466,7 @@ void MythMainWindow::customEvent(QCustomEvent *ce)
     else if (ce->type() == kLircMuteEventType)
     {
         LircMuteEvent *lme = (LircMuteEvent *)ce;
-        ignore_lirc_keys = lme->eventsMuted();
+        d->ignore_lirc_keys = lme->eventsMuted();
     }
 #endif
 }
@@ -186,7 +486,7 @@ QObject *MythMainWindow::getTarget(QKeyEvent &key)
 
             // Yes this is special code for handling the
             // the escape key.
-            if (key.key() == Key_Escape && focus_widget->topLevelWidget())
+            if (key.key() == d->escapekey && focus_widget->topLevelWidget())
                 key_target = focus_widget->topLevelWidget();
         }
     }
@@ -237,9 +537,11 @@ MythDialog::~MythDialog()
 
 void MythDialog::setNoErase(void)
 {
+#ifndef QWS
     WFlags flags = getWFlags();
     flags |= WRepaintNoErase;
     setWFlags(flags);
+#endif
 }
 
 void MythDialog::Show(void)
@@ -284,7 +586,7 @@ int MythDialog::exec()
     return res;
 }
 
-void MythDialog::hide()
+void MythDialog::hide(void)
 {
     if (isHidden())
         return;
@@ -300,36 +602,45 @@ void MythDialog::hide()
 
 void MythDialog::keyPressEvent( QKeyEvent *e )
 {
-    //   Calls reject() if Escape is pressed. Simulates a button
-    //   click for the default button if Enter is pressed. Move focus
-    //   for the arrow keys. Ignore the rest.
-    if ( e->state() == 0 || ( e->state() & Keypad && e->key() == Key_Enter ) ) {
-        switch ( e->key() ) {
-        case Key_Escape:
-            reject();
-            break;
-        case Key_Up:
-        case Key_Left:
-            if ( focusWidget() &&
-                 ( focusWidget()->focusPolicy() == QWidget::StrongFocus ||
-                   focusWidget()->focusPolicy() == QWidget::WheelFocus ) ) {
-                break;
+    if (e->state() != 0)
+        return;
+
+    bool handled = false;
+    QStringList actions;
+
+    if (gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions))
+    {
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            handled = true;
+
+            if (action == "ESCAPE")
+                reject();
+            else if (action == "UP" || action == "LEFT")
+            {
+                if (focusWidget() &&
+                    (focusWidget()->focusPolicy() == QWidget::StrongFocus ||
+                     focusWidget()->focusPolicy() == QWidget::WheelFocus))
+                {
+                }
+                else
+                    focusNextPrevChild(false);
             }
-            // call ours, since c++ blocks us from calling the one
-            // belonging to focusWidget().
-            focusNextPrevChild( FALSE );
-            break;
-        case Key_Down:
-        case Key_Right:
-            if ( focusWidget() &&
-                 ( focusWidget()->focusPolicy() == QWidget::StrongFocus ||
-                   focusWidget()->focusPolicy() == QWidget::WheelFocus ) ) {
-                break;
+            else if (action == "DOWN" || action == "RIGHT")
+            {
+                if (focusWidget() &&
+                    (focusWidget()->focusPolicy() == QWidget::StrongFocus ||
+                     focusWidget()->focusPolicy() == QWidget::WheelFocus)) 
+                {
+                }
+                else
+                    focusNextPrevChild(true);
             }
-            focusNextPrevChild( TRUE );
-            break;
-        default:
-            return;
+            else if (action == "MENU")
+                emit menuButtonPressed();
+            else
+                handled = false;
         }
     }
 }
@@ -470,6 +781,12 @@ QButton *MythPopupBox::addButton(QString caption, QObject *target,
 }
 
 void MythPopupBox::ShowPopup(QObject *target, const char *slot)
+{
+    ShowPopupAtXY(-1, -1, target, slot);
+}
+
+void MythPopupBox::ShowPopupAtXY(int destx, int desty, 
+                                 QObject *target, const char *slot)
 {
     const QObjectList *objlist = children();
     QObjectListIt it(*objlist);
@@ -516,22 +833,48 @@ void MythPopupBox::ShowPopup(QObject *target, const char *slot)
         height = parentWidget()->height();
     }
 
-    x = (int)(width / 2) - (int)(maxw / 2);
-    y = (int)(height / 2) - (int)(poph / 2);
+    if (destx == -1)
+        x = (int)(width / 2) - (int)(maxw / 2);
+    else
+        x = destx;
+
+    if (desty == -1)
+        y = (int)(height / 2) - (int)(poph / 2);
+    else
+        y = desty;
+
+    if (poph + y > height)
+        y = height - poph - (int)(8 * hmult);
 
     setFixedSize(maxw, poph);
     setGeometry(x, y, maxw, poph);
 
     if (target && slot)
-    {
-        QAccel *popaccel = new QAccel(this);
-        popaccel->connectItem(popaccel->insertItem(m_parent->Key_Escape),
-                              target, slot);
-    }
+        connect(this, SIGNAL(popupDone()), target, slot);
 
     Show();
 }
 
+void MythPopupBox::keyPressEvent(QKeyEvent *e)
+{
+    bool handled = false;
+    QStringList actions;
+    gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions);
+    for (unsigned int i = 0; i < actions.size() && !handled; i++)
+    {
+        QString action = actions[i];
+
+        if (action == "ESCAPE")
+        {
+            emit popupDone();
+            handled = true;
+        }
+    }
+
+    if (!handled)
+        MythDialog::keyPressEvent(e);
+}
+
 int MythPopupBox::ExecPopup(QObject *target, const char *slot)
 {
     if (!target)
@@ -600,8 +943,7 @@ MythProgressDialog::MythProgressDialog(const QString &message, int totalSteps)
 
     gContext->GetScreenSettings(screenwidth, wmult, screenheight, hmult);
 
-    setFont(QFont("Arial", (int)(gContext->GetMediumFontSize() * hmult),
-            QFont::Bold));
+    setFont(gContext->GetMediumFont());
     setCursor(QCursor(Qt::BlankCursor));
 
     gContext->ThemeWidget(this);
@@ -680,9 +1022,19 @@ void MythProgressDialog::setProgress(int curprogress)
 
 void MythProgressDialog::keyPressEvent(QKeyEvent *e)
 {
-    if (e->key() == Key_Escape)
-        ;
-    else
+    bool handled = false;
+    QStringList actions;
+    if (gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions))
+    {
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            if (action == "ESCAPE")
+                handled = true;
+        }
+    }
+
+    if (!handled)
         MythDialog::keyPressEvent(e);
 }
 
@@ -1404,9 +1756,19 @@ MythPasswordDialog::MythPasswordDialog(QString message,
 
 void MythPasswordDialog::keyPressEvent(QKeyEvent *e)
 {
-    if (e->key() == Key_Escape)
+    bool handled = false;
+    QStringList actions;
+    if (gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions))
     {
-        MythDialog::keyPressEvent(e);
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            if (action == "ESCAPE")
+            {
+                handled = true;
+                MythDialog::keyPressEvent(e);
+            }
+        }
     }
 }
 
@@ -1438,10 +1800,8 @@ Myth2ButtonDialog::Myth2ButtonDialog(MythMainWindow *parent, QString title1,
                  : MythDialog(parent, title1, false)
 {
     gContext->GetScreenSettings(screenwidth, wmult, screenheight, hmult);
-    QFont bigFont("Arial", (int)(gContext->GetBigFontSize() * hmult),
-                  QFont::Bold);
-    QFont medFont("Arial", (int)(gContext->GetMediumFontSize() * hmult),
-                  QFont::Bold);
+    QFont bigFont = gContext->GetBigFont();
+    QFont medFont = gContext->GetMediumFont();
 
     popup = new MythPopupBox(gContext->GetMainWindow(), "2 button dialog");
     popup->setFrameStyle( QFrame::Box | QFrame::Plain );
@@ -1511,26 +1871,34 @@ Myth2ButtonDialog::Myth2ButtonDialog(MythMainWindow *parent, QString title1,
 
 void Myth2ButtonDialog::keyPressEvent(QKeyEvent *e)
 {
-    switch (e->key()) 
+    bool handled = false;
+    QStringList actions;
+    if (gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions))
     {
-        case Key_Escape:
-            done(0);
-            break;
-        case Key_Enter:
-        case Key_Return:
-        case Key_Space:
-            if (but1->hasFocus())
-                done(1);
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            handled = true;
+
+            if (action == "ESCAPE")
+                done(0);
+            else if (action == "SELECT")
+            {
+                if (but1->hasFocus())
+                    done(1);
+                else
+                    done(2);
+            }
+            else if (action == "UP" || action == "DOWN")
+            {
+                if (but1->hasFocus())
+                    but2->setFocus();
+                else
+                    but1->setFocus();
+            }
             else
-                done(2);
-            break;
-        case Key_Up:
-        case Key_Down:
-            if (but1->hasFocus())
-                but2->setFocus();
-            else
-                but1->setFocus();
-            break;
+                handled = false;
+        }
     }
 }
 
@@ -1636,21 +2004,36 @@ MythImageFileDialog::MythImageFileDialog(QString *result,
 
 void MythImageFileDialog::keyPressEvent(QKeyEvent *e)
 {
-    switch(e->key())
+    bool handled = false;
+    QStringList actions;
+    if (gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions))
     {
-        case Key_Up:       file_browser->moveUp();             break;
-        case Key_Down:     file_browser->moveDown();           break;
-        case Key_Left:     file_browser->popUp();              break;
-        case Key_Right:    file_browser->pushDown();           break;
-        case Key_PageUp:   file_browser->pageUp();             break;
-        case Key_PageDown: file_browser->pageDown();           break;
-        
-        case Key_Space:
-        case Key_Enter:
-        case Key_Return:   file_browser->select();             break;
-        
-        default:           MythThemedDialog::keyPressEvent(e); break;
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            handled = true;
+
+            if (action == "UP")
+                file_browser->moveUp();
+            else if (action == "DOWN")
+                file_browser->moveDown();
+            else if (action == "LEFT")
+                file_browser->popUp();
+            else if (action == "RIGHT")
+                file_browser->pushDown();
+            else if (action == "PAGEUP")
+                file_browser->pageUp();
+            else if (action == "PAGEDOWN")
+                file_browser->pageDown();
+            else if (action == "SELECT")
+                file_browser->select();
+            else
+                handled = false;
+        }
     }
+
+    if (!handled)
+        MythThemedDialog::keyPressEvent(e);
 }
 
 void MythImageFileDialog::buildTree(QString starting_where)
@@ -1720,6 +2103,16 @@ void MythImageFileDialog::buildFileList(QString directory)
 {
     QStringList imageExtensions = QImage::inputFormatList();
 
+    //
+    //  Expand the list Qt gives us, working off what we know was built into
+    //  Qt based on the list it gave us
+    // 
+
+    if(imageExtensions.contains("jpeg"))
+    {
+        imageExtensions += "jpg";
+    }
+
     QDir d(directory);
        
     if (!d.exists())
