@@ -9,6 +9,7 @@
 #include <qpixmap.h>
 #include <qpushbutton.h>
 #include <qevent.h>
+#include <qvaluevector.h>
 
 #include <vector>
 using namespace std;
@@ -32,6 +33,7 @@ class LayerSet;
 class GenericTree;
 
 const int kExternalKeycodeEventType = 33213;
+const int kExitToMainMenuEventType = 33214;
 
 class ExternalKeycodeEvent : public QCustomEvent
 {
@@ -45,11 +47,23 @@ class ExternalKeycodeEvent : public QCustomEvent
     int keycode;
 };
 
+class ExitToMainMenuEvent : public QCustomEvent
+{
+  public:
+    ExitToMainMenuEvent(void) : QCustomEvent(kExitToMainMenuEventType) {}
+};
+
+#define REG_KEY(a, b, c, d) gContext->GetMainWindow()->RegisterKey(a, b, c, d)
+#define REG_JUMP(a, b, c, d) gContext->GetMainWindow()->RegisterJump(a, b, c, d)
+
+class MythMainWindowPrivate;
+
 class MythMainWindow : public QDialog
 {
   public:
     MythMainWindow(QWidget *parent = 0, const char *name = 0, 
                    bool modal = FALSE);
+    virtual ~MythMainWindow();
 
     void Init(void);
     void Show(void);
@@ -59,19 +73,23 @@ class MythMainWindow : public QDialog
 
     QWidget *currentWidget(void);
 
-   protected:
+    bool TranslateKeyPress(const QString &context, QKeyEvent *e, 
+                           QStringList &actions);
+
+    void RegisterKey(const QString &context, const QString &action,
+                     const QString &description, const QString &key);
+    void RegisterJump(const QString &destination, const QString &description,
+                      const QString &key, void (*callback)(void));
+
+  protected:
     void keyPressEvent(QKeyEvent *e);
     void customEvent(QCustomEvent *ce);
 
+    void ExitToMainMenu();
+
     QObject *getTarget(QKeyEvent &key);
 
-    float wmult, hmult;
-    int screenwidth, screenheight;
-    int xbase, ybase;
-
-    vector<QWidget *> widgetList;
-
-    bool ignore_lirc_keys;
+    MythMainWindowPrivate *d;
 };
 
 class MythDialog : public QFrame
@@ -86,12 +104,15 @@ class MythDialog : public QFrame
 
     int result(void) const { return rescode; }
 
-    virtual void Show();
+    virtual void Show(void);
 
-    void hide();
+    void hide(void);
 
     void setNoErase(void);
 
+  signals:
+    void menuButtonPressed();
+
   public slots:
     int exec();
     virtual void done( int );
@@ -137,6 +158,9 @@ class MythPopupBox : public MythDialog
                        const char *slot = NULL);
 
     void ShowPopup(QObject *target = NULL, const char *slot = NULL);
+    void ShowPopupAtXY(int destx, int desty, 
+                       QObject *target = NULL, const char *slot = NULL);
+
     int ExecPopup(QObject *target = NULL, const char *slot = NULL);
 
     static void showOkPopup(MythMainWindow *parent, QString title,
@@ -144,8 +168,12 @@ class MythPopupBox : public MythDialog
     static bool showOkCancelPopup(MythMainWindow *parent, QString title,
                                   QString message, bool focusOk);
 
+  signals:
+    void popupDone();
+
   protected:
     bool focusNextPrevChild(bool next);
+    void keyPressEvent(QKeyEvent *e);
 
   protected slots:
     void defaultButtonPressedHandler(void);
