@@ -1,5 +1,7 @@
 #include "mythplugin.h"
-#include "qdict.h"
+#include <qdict.h>
+#include <qstringlist.h>
+#include <qdir.h>
 #include <iostream>
 #include <dlfcn.h>
 
@@ -51,6 +53,33 @@ QDict<MythPluginManager::MythPlugin> MythPluginManager::m_dict;
 void MythPluginManager::init(void)
 {
     m_dict.setAutoDelete(true);
+
+    QString pluginprefix = QString(PREFIX) + "/lib/mythtv/plugins/";
+
+    QDir filterDir(pluginprefix);
+
+    filterDir.setFilter(QDir::Files | QDir::Readable);
+    filterDir.setNameFilter("lib*.so");
+
+    gContext->SetDisableLibraryPopup(true);
+
+    if (filterDir.exists())
+    {
+        QStringList libraries = filterDir.entryList();
+        for (QStringList::iterator i = libraries.begin(); i != libraries.end();
+             i++)
+        {
+            QString library = *i;
+
+            // pull out the base library name
+            library = library.right(library.length() - 3);
+            library = library.left(library.length() - 3);
+
+            init_plugin(library);
+        }
+    }
+
+    gContext->SetDisableLibraryPopup(false);
 }
 
 bool MythPluginManager::init_plugin(const QString & plugname)
@@ -76,7 +105,7 @@ bool MythPluginManager::init_plugin(const QString & plugname)
     return true;
 }
 
-void MythPluginManager::run_plugin(const QString & plugname)
+bool MythPluginManager::run_plugin(const QString & plugname)
 {
     QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + plugname +
                       ".so";
@@ -85,13 +114,14 @@ void MythPluginManager::run_plugin(const QString & plugname)
     {
         cerr << "Unable to run plugin '" << plugname 
              << "': not initialized" << endl;
-        return;
+        return false;
     }
 
     m_dict[newname]->run();
+    return true;
 }
 
-void MythPluginManager::config_plugin(const QString & plugname)
+bool MythPluginManager::config_plugin(const QString & plugname)
 {
     QString newname = QString(PREFIX) + "/lib/mythtv/plugins/lib" + plugname +
                       ".so";
@@ -100,10 +130,11 @@ void MythPluginManager::config_plugin(const QString & plugname)
     {
         cerr << "Unable to run plugin '" << plugname
              << "': not initialized" << endl;
-        return;
+        return false;
     }
 
     m_dict[newname]->config();
+    return true;
 }
 
 
