@@ -61,10 +61,15 @@ class MythSpinBox: public QSpinBox
 {
     Q_OBJECT
   public:
-    MythSpinBox(QWidget* parent = NULL, const char* widgetName = 0):
-        QSpinBox(parent, widgetName) {};
+    MythSpinBox(QWidget* parent = NULL, const char* widgetName = 0, 
+                bool allow_single_step = false) :
+        QSpinBox(parent, widgetName),
+        singlestep(allow_single_step) { if (singlestep) setLineStep(10); }
 
     void setHelpText(QString help) { helptext = help; }
+    
+    bool singleStep(void) { return singlestep; }
+    void setSingleStep(bool arg = true) { singlestep = arg; }
 
   signals:
     void changeHelpText(QString);
@@ -76,6 +81,7 @@ class MythSpinBox: public QSpinBox
 
   private:
     QString helptext;
+    bool singlestep;
 };
 
 class MythSlider: public QSlider 
@@ -217,21 +223,6 @@ class MythButtonGroup : public QButtonGroup
     void moveFocus(int key);
 };
 
-class MythToolButton : public QToolButton
-{
-  public:
-    MythToolButton(QWidget *parent) : QToolButton(parent)
-                    { setFocusPolicy(StrongFocus);
-                      setBackgroundOrigin(WindowOrigin); }
-
-    void drawButton(QPainter *p);
-    void keyPressEvent(QKeyEvent *e);
-    void keyReleaseEvent(QKeyEvent *e);
-
-  private:
-    QColor origcolor;
-};
-
 class MythPushButton : public QPushButton
 {
   public:
@@ -277,25 +268,11 @@ class MythListView : public QListView
   public:
     MythListView(QWidget *parent);
 
-    void SetAllowKeypress(bool allow) { allowkeypress = allow; }
-    bool GetAllowKeypress(void) { return allowkeypress; }
-    void DontFixSpaceBar(void) { fixspace = false; }
     void ensureItemVCentered (const QListViewItem *i);
 
   protected:
     void keyPressEvent(QKeyEvent *e);
     void focusInEvent(QFocusEvent *e);
-
-  signals:
-    void playPressed(QListViewItem *);
-    void deletePressed(QListViewItem *);
-    void infoPressed(QListViewItem *);
-    void numberPressed(QListViewItem *, int);
-    void unhandledKeyPress(QKeyEvent *);
-
-  private:
-    bool allowkeypress;
-    bool fixspace;
 };
 
 class MythListBox: public QListBox {
