@@ -236,7 +236,7 @@ void SelectSetting::addSelection(const QString& label, QString value, bool selec
         setValue(value);
 }
 
-void SelectSetting::fillSelectionsFromDir(const QDir& dir) {
+void SelectSetting::fillSelectionsFromDir(const QDir& dir, bool absPath) {
      const QFileInfoList *il = dir.entryInfoList();
      if (!il)
          return;
@@ -245,7 +245,10 @@ void SelectSetting::fillSelectionsFromDir(const QDir& dir) {
      QFileInfo *fi;
 
      for(; (fi = it.current()) != 0; ++it)
-         addSelection(fi->absFilePath());
+         if (absPath)
+             addSelection(fi->absFilePath());
+         else
+             addSelection(fi->fileName());
 }
 
 void SelectSetting::clearSelections(void) {
@@ -364,12 +367,16 @@ QWidget* SpinBoxSetting::configWidget(ConfigurationGroup *cg, QWidget* parent,
     label->setBackgroundOrigin(QWidget::WindowOrigin);
     label->setText(getLabel() + ":     ");
 
-    MythSpinBox* spinbox = new MythSpinBox(box);
+    MythSpinBox* spinbox = new MythSpinBox(box, QString(widgetName) + 
+                                           "MythSpinBox", sstep);
     spinbox->setHelpText(getHelpText());
     spinbox->setBackgroundOrigin(QWidget::WindowOrigin);
     spinbox->setMinValue(min);
     spinbox->setMaxValue(max);
-    spinbox->setLineStep(step);
+    // only set step size if greater than default (1), otherwise
+    // this will screw up the single-step/jump behavior of the MythSpinBox
+    if (1 < step)
+	spinbox->setLineStep(step);
     spinbox->setValue(intValue());
 
     connect(spinbox, SIGNAL(valueChanged(int)), this, SLOT(setValue(int)));
@@ -425,8 +432,12 @@ QWidget* ComboBoxSetting::configWidget(ConfigurationGroup *cg, QWidget* parent,
     if (isSet)
         widget->setCurrentItem(current);
 
-    connect(widget, SIGNAL(highlighted(int)),
-            this, SLOT(setValue(int)));
+    if (rw)
+        connect(widget, SIGNAL(highlighted(const QString &)),
+                this, SLOT(setValue(const QString &)));
+    else
+        connect(widget, SIGNAL(highlighted(int)),
+                this, SLOT(setValue(int)));
     connect(this, SIGNAL(selectionAdded(const QString&,QString)),
             widget, SLOT(insertItem(const QString&)));
     connect(this, SIGNAL(selectionsCleared()),
@@ -525,19 +536,28 @@ QWidget* CheckBoxSetting::configWidget(ConfigurationGroup *cg, QWidget* parent,
     return widget;
 }
 
-void ConfigurationDialogWidget::keyPressEvent(QKeyEvent* e) {
-    switch (e->key()) {
-    case Key_Enter:
-    case Key_Return:
-    case Key_Space:
-        accept();
-        break;
-    case Key_Escape:
-        reject();
-        break;
-    default:
-        MythDialog::keyPressEvent(e);
+void ConfigurationDialogWidget::keyPressEvent(QKeyEvent* e) 
+{
+    bool handled = false;
+    QStringList actions;
+    if (gContext->GetMainWindow()->TranslateKeyPress("qt", e, actions))
+    {
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            handled = true;
+
+            if (action == "SELECT")
+                accept();
+            else if (action == "ESCAPE")
+                reject();
+            else
+                handled = false;
+        }
     }
+
+    if (!handled)
+        MythDialog::keyPressEvent(e);
 }
 
 MythDialog* ConfigurationDialog::dialogWidget(MythMainWindow *parent,
