@@ -3,6 +3,7 @@
 
 #include <qobject.h>
 #include <qstring.h>
+#include <qregexp.h>
 #include <qstringlist.h>
 #include <qrect.h>
 #include <qfile.h>
@@ -57,6 +58,10 @@ class LayerSet
     UIType  *GetType(const QString &name);
     vector<UIType *> *getAllTypes(){return allTypes;}
 
+    void    ClearAllText(void);
+    void    SetTextByRegexp(QMap<QString, QString> &regexpMap);
+
+    void    UseAlternateArea(bool useAlt);
 
   private:
     bool    m_debug;
@@ -185,16 +190,17 @@ class UIGuideType : public UIType
     void SetFillType(int type) { m_filltype = type; }
 
     void SetWindow(MythDialog *win) { m_window = win; }
-    void SetRecordingColor(QString col) { m_reccolor = col; }
+    void SetRecordingColors(QString reccol, QString concol) 
+                          { m_reccolor = reccol; m_concolor = concol; }
     void SetSelectorColor(QString col) { m_selcolor = col; }
     void SetSelectorType(int type) { m_seltype = type; }
     void SetSolidColor(QString col) { m_solidcolor = col; }
     void SetCategoryColors(QMap<QString, QString> catC)
                           { categoryColors = catC; }
-    void SetProgramInfo(unsigned int, int, QRect, QString, QString, int, int);
+    void SetProgramInfo(unsigned int, int, QRect, QString, QString, int, int, int);
     void SetCurrentArea(QRect myArea) { curArea = myArea; }
     void ResetData() { drawArea.clear(); dataMap.clear(); m_count = 0;
-                       categoryMap.clear(); recStatus.clear();
+                       categoryMap.clear(); recType.clear(); recStat.clear();
                        countMap.clear(); arrowUsage.clear(); }
     void ResetRow(unsigned int);
     void SetArea(QRect area) { m_area = area; }
@@ -213,7 +219,7 @@ class UIGuideType : public UIType
     void drawBox(QPainter *, int, QString);
     void drawBackground(QPainter *, int); 
     void drawText(QPainter *, int);
-    void drawRecStatus(QPainter *, int);
+    void drawRecType(QPainter *, int);
     void Blender(QPainter *, QRect, int, QString force = "");
     //QString cutDown(QString, QFont *, int, int);
     int m_justification;
@@ -222,6 +228,7 @@ class UIGuideType : public UIType
     QString m_selcolor;
     int m_seltype;
     QString m_reccolor;
+    QString m_concolor;
     int m_filltype;
     bool m_cutdown;
     QRect curArea;
@@ -231,7 +238,8 @@ class UIGuideType : public UIType
     QMap<int, QRect> drawArea;
     QMap<int, QString> dataMap;
     QMap<int, QString> categoryMap;
-    QMap<int, int> recStatus;
+    QMap<int, int> recType;
+    QMap<int, int> recStat;
     QMap<int, QPixmap> recImages;
     QMap<int, QPixmap> arrowImages;
     QMap<int, int> arrowUsage;
@@ -397,11 +405,16 @@ class UITextType : public UIType
 {
   public:
     UITextType(const QString &, fontProp *, const QString &, int,
-                QRect displayrect);
+                QRect displayrect, QRect altdisplayrect);
     ~UITextType();
 
+    QString Name() { return m_name; }
+
+    void UseAlternateArea(bool useAlt);
+
     void SetText(const QString &text);
     QString GetText() { return m_message; }
+    QString GetDefaultText() { return m_default_msg; }
 
     void SetJustification(int jst) { m_justification = jst; }
     int GetJustification() { return m_justification; }
@@ -416,7 +429,11 @@ class UITextType : public UIType
     //QString cutDown(QString, QFont *, int, int);
     int m_justification;
     QRect m_displaysize;
+    QRect m_origdisplaysize;
+    QRect m_altdisplaysize;
     QString m_message;
+    QString m_default_msg;
+    QString m_name;
 
     fontProp *m_font;
 
