@@ -25,6 +25,8 @@ bool XMLParse::LoadTheme(QDomElement &ele, QString winName, QString specialfile)
 {
     usetrans = gContext->GetNumSetting("PlayBoxTransparency", 1);
 
+    fontSizeType = gContext->GetSetting("ThemeFontSizeType", "default");
+    
     QString themepath = gContext->GetThemeDir();
     QString themefile = themepath + specialfile + "ui.xml";
 
@@ -110,6 +112,8 @@ void XMLParse::parseFont(QDomElement &element)
     QString face;
     QString bold;
     int size = -1;
+    int sizeSmall = -1;
+    int sizeBig = -1;
     QPoint shadowOffset = QPoint(0, 0);
     QString color = "#ffffff";
     QString dropcolor = "#000000";
@@ -138,6 +142,14 @@ void XMLParse::parseFont(QDomElement &element)
             {
                 size = getFirstText(info).toInt();
             }
+            else if (info.tagName() == "size:small")
+            {
+                sizeSmall = getFirstText(info).toInt();
+            }
+            else if (info.tagName() == "size:big")
+            {
+                sizeBig = getFirstText(info).toInt();
+            }
             else if (info.tagName() == "color")
             {
                 color = getFirstText(info);
@@ -171,13 +183,24 @@ void XMLParse::parseFont(QDomElement &element)
         exit(0);
     }
 
+    if (fontSizeType == "small")
+    {
+        if(sizeSmall > 0)
+            size = sizeSmall;
+    }
+    else if (fontSizeType == "big")
+    {
+        if(sizeBig > 0)
+            size = sizeBig;
+    }
+    
     if (size < 0)
     {
         cerr << "Error: font size must be > 0\n";
         exit(0);
     }
 
-    size = (int)(size * hmult);
+    size = (int)ceil(size * hmult);
     QFont temp(face, size);
     if (bold.lower() == "yes")
         temp.setBold(true);
@@ -395,6 +418,7 @@ void XMLParse::parseGuideGrid(LayerSet *container, QDomElement &element)
     QString seltype = "";
     QString selcolor = "";
     QString reccolor = "";
+    QString concolor = "";
     QRect area;
     QPoint textoff = QPoint(0, 0);
     bool cutdown = true;
@@ -460,6 +484,10 @@ void XMLParse::parseGuideGrid(LayerSet *container, QDomElement &element)
             {
                 reccolor = getFirstText(info);
             }
+            else if (info.tagName() == "conflictingcolor")
+            {
+                concolor = getFirstText(info);
+            }
             else if (info.tagName() == "multiline")
             {
                 if (getFirstText(info).lower() == "yes")
@@ -539,7 +567,9 @@ void XMLParse::parseGuideGrid(LayerSet *container, QDomElement &element)
     guide->SetArea(area);
     guide->SetCategoryColors(catColors);
     guide->SetTextOffset(textoff);
-    guide->SetRecordingColor(reccolor);
+    if (concolor == "")
+        concolor = reccolor;
+    guide->SetRecordingColors(reccolor, concolor);
     guide->SetSelectorColor(selcolor);
     for (int i = 1; i < 6; i++)
         guide->LoadImage(i, recImgs[i]);
@@ -854,6 +884,7 @@ void XMLParse::parseTextArea(LayerSet *container, QDomElement &element)
 {
     int context = -1;
     QRect area = QRect(0, 0, 0, 0);
+    QRect altArea = QRect(0, 0, 0, 0);
     QPoint shadowOffset = QPoint(0, 0);
     QString font = "";
     QString cutdown = "";
@@ -892,6 +923,11 @@ void XMLParse::parseTextArea(LayerSet *container, QDomElement &element)
                 area = parseRect(getFirstText(info));
                 normalizeRect(area);
             }
+            else if (info.tagName() == "altarea")
+            {
+                altArea = parseRect(getFirstText(info));
+                normalizeRect(altArea);
+            }
             else if (info.tagName() == "font")
             {
                 font = getFirstText(info);
@@ -938,7 +974,8 @@ void XMLParse::parseTextArea(LayerSet *container, QDomElement &element)
         exit(0);
     }
 
-    UITextType *text = new UITextType(name, testfont, value, draworder, area);
+    UITextType *text = new UITextType(name, testfont, value, draworder, area,
+                                      altArea);
     text->SetScreen(wmult, hmult);
     if (context != -1)
     {
