@@ -1,7 +1,6 @@
 #ifndef NUPPELVIDEOPLAYER
 #define NUPPELVIDEOPLAYER
 
-#include <vector>
 #include <qstring.h>
 #include <qmutex.h>
 #include <qwaitcondition.h>
@@ -32,6 +31,8 @@ class QSqlDatabase;
 class ProgramInfo;
 class DecoderBase;
 class AudioOutput;
+class FilterManager;
+class FilterChain;
 
 struct TextContainer
 {
@@ -56,7 +57,7 @@ class NuppelVideoPlayer
     void SetFileName(QString lfilename) { filename = lfilename; }
 
     void SetExactSeeks(bool exact) { exactseeks = exact; }
-    void SetAutoCommercialSkip(int autoskip) { autocommercialskip = autoskip; }
+    void SetAutoCommercialSkip(int autoskip);
     void SetCommercialSkipMethod(int method) { commercialskipmethod = method; }
 
     void StartPlaying(void);
@@ -77,7 +78,7 @@ class NuppelVideoPlayer
     bool GetPause(void);
 
     float GetPlaySpeed(void) { return play_speed; };
-    void SetPlaySpeed(float speed);
+    void SetPlaySpeed(float speed, bool normal);
 
     bool FastForward(float seconds);
     bool Rewind(float seconds);
@@ -128,8 +129,7 @@ class NuppelVideoPlayer
 
     // edit mode stuff
     bool EnableEdit(void);
-    void DoKeypress(int keypress);
-
+    bool DoKeypress(QKeyEvent *e);
     bool GetEditMode(void) { return editmode; }
 
     void EmbedInWidget(unsigned long wid, int x, int y, int w, int h);
@@ -256,6 +256,8 @@ class NuppelVideoPlayer
     int eof;
     int video_width;
     int video_height;
+    int postfilt_width;
+    int postfilt_height;
     int video_size;
     double video_frame_rate;
     float video_aspect;
@@ -330,7 +332,8 @@ class NuppelVideoPlayer
     bool needsetpipplayer;
 
     QString videoFilterList;
-    vector<VideoFilter *> videoFilters;
+    FilterChain *videoFilters;
+    FilterManager *FiltMan;
 
     int keyframedist;
 
