@@ -1,5 +1,6 @@
 #include <iostream>
 #include <assert.h>
+#include <unistd.h>
 
 using namespace std;
 
@@ -14,8 +15,11 @@ extern "C" {
 #ifdef USING_XVMC
 #include "../libavcodec/xvmc_render.h"
 #endif
+#include "../libavcodec/liba52/a52.h"
 }
 
+#define MAX_AC3_FRAME_SIZE 6144
+
 extern pthread_mutex_t avcodeclock;
 
 AvFormatDecoder::AvFormatDecoder(NuppelVideoPlayer *parent, QSqlDatabase *db,
@@ -27,7 +31,7 @@ AvFormatDecoder::AvFormatDecoder(NuppelVideoPlayer *parent, QSqlDatabase *db,
 
     ic = NULL;
     directrendering = false;
-    lastapts = lastvpts = 0;
+    video_last_P_pts = lastapts = lastvpts = 0;
     framesPlayed = 0;
     framesRead = 0;
 
@@ -45,11 +49,16 @@ AvFormatDecoder::AvFormatDecoder(NuppelVideoPlayer *parent, QSqlDatabase *db,
     ateof = false;
     gopset = false;
     firstgoppos = 0;
+    prevgoppos = 0;
 
     fps = 29.97;
-    validvpts = false;
 
     lastKey = 0;
+
+    memset(&params, 0, sizeof(AVFormatParameters));
+    memset(prvpkt, 0, 3);
+
+    do_ac3_passthru = gContext->GetNumSetting("AC3PassThru", false);
 }
 
 AvFormatDecoder::~AvFormatDecoder()
@@ -59,7 +68,8 @@ AvFormatDecoder::~AvFormatDecoder()
         for (int i = 0; i < ic->nb_streams; i++) 
         {
             AVStream *st = ic->streams[i];
-            avcodec_close(&st->codec);
+            if (st->codec.codec)
+                avcodec_close(&st->codec);
         } 
 
         ic->iformat->flags |= AVFMT_NOFILE;
@@ -74,13 +84,9 @@ void AvFormatDecoder::SeekReset(void)
 {
     lastapts = 0;
     lastvpts = 0;
+    video_last_P_pts = 0;
 
-    AVPacketList *pktl = NULL;
-    while ((pktl = ic->packet_buffer))
-    {
-        ic->packet_buffer = pktl->next;
-        av_free(pktl);
-    }
+    av_read_frame_flush(ic);
 
     ic->pb.pos = ringBuffer->GetTotalReadPosition();
     ic->pb.buf_ptr = ic->pb.buffer;
@@ -89,7 +95,8 @@ void AvFormatDecoder::SeekReset(void)
     for (int i = 0; i < ic->nb_streams; i++)
     {
         AVCodecContext *enc = &ic->streams[i]->codec;
-        avcodec_flush_buffers(enc);
+        if (enc->codec)
+            avcodec_flush_buffers(enc);
     }
 
     VideoFrame *buffer;
@@ -107,6 +114,9 @@ void AvFormatDecoder::SeekReset(void)
         av_free_packet(pkt);
         delete pkt;
     }
+
+    prevgoppos = 0;
+    gopset = false;
 }
 
 void AvFormatDecoder::Reset(void)
@@ -222,6 +232,8 @@ void AvFormatDecoder::InitByteContext(void)
     ic->pb.max_packet_size = 0;
 }
 
+#define ALIGN(x, a) (((x) + (a) - 1) & ~((a) - 1))
+
 int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
                               char testbuf[2048])
 {
@@ -286,7 +298,13 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
                 if (fps < 26 && fps > 24)
                     keyframedist = 12;
 
-                float aspect_ratio = enc->aspect_ratio;
+                float aspect_ratio;
+                if (enc->sample_aspect_ratio.num == 0)
+                    aspect_ratio = 0;
+                else
+                    aspect_ratio = av_q2d(enc->sample_aspect_ratio) * 
+                                   enc->width / enc->height;
+
                 if (aspect_ratio <= 0.0)
                     aspect_ratio = (float)enc->width / (float)enc->height;
 
@@ -294,7 +312,8 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
                 current_height = enc->height;
                 current_aspect = aspect_ratio;
 
-                m_parent->SetVideoParams(enc->width, enc->height, fps, 
+                m_parent->SetVideoParams(ALIGN(enc->width, 16), 
+                                         ALIGN(enc->height, 16), fps, 
                                          keyframedist, aspect_ratio);
              
                 enc->error_resilience = 2;
@@ -317,9 +336,6 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
 
                 AVCodec *codec = avcodec_find_decoder(enc->codec_id);
 
-                if (codec && codec->capabilities & CODEC_CAP_TRUNCATED)
-                    enc->flags |= CODEC_FLAG_TRUNCATED;
-
                 if (codec && codec->id == CODEC_ID_MPEG2VIDEO_XVMC)
                 {
                     enc->flags |= CODEC_FLAG_EMU_EDGE;
@@ -333,7 +349,7 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
                     setLowBuffers();
                     m_parent->ForceVideoOutputType(kVideoOutput_XvMC);
                 }
-		else if (codec && codec->id == CODEC_ID_MPEG2VIDEO_VIA)
+                else if (codec && codec->id == CODEC_ID_MPEG2VIDEO_VIA)
                 {
                     enc->flags |= CODEC_FLAG_EMU_EDGE;
                     enc->get_buffer = get_avf_buffer_via;
@@ -363,10 +379,29 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
             {
                 bitrate += enc->bit_rate;
                 m_parent->SetEffDsp(enc->sample_rate * 100);
-                m_parent->SetAudioParams(16, enc->channels, enc->sample_rate);
-                audio_sample_size = enc->channels * 2;
-                audio_sampling_rate = enc->sample_rate;
-                audio_channels = enc->channels;
+                if (do_ac3_passthru && enc->codec_id == CODEC_ID_AC3) 
+                {
+                    // An AC3 stream looks like a 48KHz 2ch audio stream to 
+                    // the sound card 
+                    audio_sample_size = 4;
+                    audio_sampling_rate = 48000;
+                    audio_channels = 2;
+                }
+                else
+                {
+                    audio_sample_size = enc->channels * 2;
+                    audio_sampling_rate = enc->sample_rate;
+                    audio_channels = enc->channels;
+                }
+                m_parent->SetAudioParams(16, audio_channels, 
+                                         audio_sampling_rate);
+                break;
+            }
+            case CODEC_TYPE_DATA:
+            {
+                bitrate += enc->bit_rate;
+                // otherwise, ignore it
+                continue;
                 break;
             }
             default:
@@ -391,8 +426,6 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
         }
     }
 
-    ptsmultiplier = ((double)ic->pts_num) / (ic->pts_den / 1000.0);
-
     ringBuffer->CalcReadAheadThresh(bitrate);
 
     if (m_playbackinfo && m_db)
@@ -400,7 +433,9 @@ int AvFormatDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
         m_playbackinfo->GetPositionMap(positionMap, MARK_GOP_START, m_db);
         if (positionMap.size() && !livetv && !watchingrecording)
         {
-            long long totframes = positionMap.size() * keyframedist;
+            QMap<long long,long long>::const_iterator it = positionMap.end();
+            it--;
+            long long totframes = it.key() * keyframedist;
             int length = (int)((totframes * 1.0) / fps);
             m_parent->SetFileLength(length, totframes);            
             hasFullPositionMap = true;
@@ -429,7 +464,8 @@ bool AvFormatDecoder::CheckVideoParams(int width, int height)
     if (width == current_width && height == current_height)
         return false;
 
-    cerr << "Video has changed: " << width << " " << height << endl;
+    cerr << "Video has changed: " << width << " " << height << " from: "
+         << current_width << " " << current_height << endl;
 
     for (int i = 0; i < ic->nb_streams; i++)
     {
@@ -465,8 +501,8 @@ bool AvFormatDecoder::CheckAudioParams(int freq, int channels)
     }
     else
     {
-        if ((freq != audio_sampling_rate_2nd && channels != audio_channels_2nd)
-            || (freq == audio_sampling_rate && channels == audio_channels))
+        if (freq != audio_sampling_rate_2nd || channels != audio_channels_2nd ||
+            (freq == audio_sampling_rate && channels == audio_channels))
         {
             audio_sampling_rate_2nd = -1;
             audio_channels_2nd = -1;
@@ -513,11 +549,11 @@ int get_avf_buffer(struct AVCodecContext *c, AVFrame *pic)
 {
     AvFormatDecoder *nd = (AvFormatDecoder *)(c->opaque);
 
-    int width = c->width;
-    int height = c->height;
-
     VideoFrame *frame = nd->m_parent->GetNextVideoFrame();
 
+    int width = frame->width;
+    int height = frame->height;
+
     pic->data[0] = frame->buf;
     pic->data[1] = pic->data[0] + width * height;
     pic->data[2] = pic->data[1] + width * height / 4;
@@ -604,8 +640,8 @@ void release_avf_buffer_xvmc(struct AVCodecContext *c, AVFrame *pic)
 
 }
 
-void render_slice_xvmc(struct AVCodecContext *s, AVFrame *src, int offset[4],
-                       int y, int type, int height)
+void render_slice_xvmc(struct AVCodecContext *s, const AVFrame *src, 
+                       int offset[4], int y, int type, int height)
 {
     (void)offset;
     (void)type;
@@ -653,8 +689,8 @@ void release_avf_buffer_via(struct AVCodecContext *c, AVFrame *pic)
         pic->data[i] = NULL;
 }
 
-void render_slice_via(struct AVCodecContext *s, AVFrame *src, int offset[4],
-                      int y, int type, int height)
+void render_slice_via(struct AVCodecContext *s, const AVFrame *src, 
+                      int offset[4], int y, int type, int height)
 {
     (void)offset;
     (void)type;
@@ -673,29 +709,174 @@ void render_slice_via(struct AVCodecContext *s, AVFrame *src, int offset[4],
 #define SLICE_MIN     0x00000101
 #define SLICE_MAX     0x000001af
 
-int AvFormatDecoder::PacketHasHeader(unsigned char *buf, int len,
-                                     unsigned int startcode)
+void AvFormatDecoder::MpegPreProcessPkt(AVStream *stream, AVPacket *pkt)
 {
-    unsigned char *bufptr;
-    unsigned int state = 0xFFFFFFFF, v;
+    AVCodecContext *context = &(stream->codec);
+    unsigned char *bufptr = pkt->data;
+    unsigned int state = 0xFFFFFFFF, v = 0;
     
-    bufptr = buf;
+    int prvcount = -1;
 
-    while (bufptr < buf + len)
+    while (bufptr < pkt->data + pkt->size)
     {
-        v = *bufptr++;
+        if (++prvcount < 3)
+            v = prvpkt[prvcount];
+        else
+            v = *bufptr++;
+
         if (state == 0x000001)
         {
             state = ((state << 8) | v) & 0xFFFFFF;
             if (state >= SLICE_MIN && state <= SLICE_MAX)
-                return 0;
-            if (state == startcode)
-                return (bufptr - buf);
+                continue;
+
+            switch (state)
+            {
+                case SEQ_START:
+                {
+                    unsigned char *test = bufptr;
+                    int width = (test[0] << 4) | (test[1] >> 4);
+                    int height = ((test[1] & 0xff) << 8) | test[2];
+
+                    int aspectratioinfo = (test[3] >> 4);
+
+                    float aspect = GetMpegAspect(context, aspectratioinfo,
+                                                 width, height);
+
+                    if (CheckVideoParams(width, height) ||
+                        aspect != current_aspect)
+                    {
+                        m_parent->SetVideoParams(ALIGN(width,16),
+                                                 ALIGN(height,16), fps,
+                                                 keyframedist, aspect);
+                        m_parent->ReinitVideo();
+                        current_width = width;
+                        current_height = height;
+                        current_aspect = aspect;
+
+                        gopset = false;
+                        prevgoppos = 0;
+                        video_last_P_pts = lastapts = lastvpts = 0;
+                    }
+                }
+                break;
+
+                case GOP_START:
+                {
+                    int tempKeyFrameDist = keyframedist;
+                    if (hasFullPositionMap) 
+                    {
+                        int low_keyframenum = 0;
+                        int hi_keyframenum = 0;
+                        if (keyframedist != 0) 
+                            low_keyframenum = hi_keyframenum = 
+                                (framesRead-1)/tempKeyFrameDist;
+                        // We think we should be at #'keyframenum' keyframe
+                        // in the stream.  If we are not, find where we are
+                        // and adjust keyframedist accordingly.
+                        
+                        if (low_keyframenum == 0)
+                            low_keyframenum = 1;
+                        int map_pos = positionMap[low_keyframenum];
+                        // try to skip 1 missing keyframe
+                        if (map_pos == 0)
+                        {
+                            low_keyframenum++;
+                            map_pos = positionMap[low_keyframenum];
+                        }
+                        while (map_pos < pkt->startpos && map_pos != 0) 
+                        {
+                            low_keyframenum++;
+                            // try to skip 1 missing keyframe
+                            if (positionMap[low_keyframenum] == 0)
+                                low_keyframenum++;
+                            map_pos = positionMap[low_keyframenum];
+                        }
+                        if (low_keyframenum > hi_keyframenum)
+                            hi_keyframenum = low_keyframenum;
+
+                        map_pos = positionMap[hi_keyframenum];
+                        // try to skip 1 missing keyframe
+                        if (map_pos == 0 && hi_keyframenum > 0)
+                        {
+                            hi_keyframenum--;
+                            map_pos = positionMap[hi_keyframenum];
+                        }
+                        while (map_pos > pkt->startpos && map_pos != 0)
+                        {
+                            hi_keyframenum--;
+                            // try to skip 1 missing keyframe
+                            if (positionMap[hi_keyframenum] == 0 &&
+                                hi_keyframenum > 0)
+                                hi_keyframenum--;
+                            map_pos = positionMap[hi_keyframenum];
+                        }
+                        // if either is spot on, take it
+                        if (positionMap[low_keyframenum] == pkt->startpos)
+                            hi_keyframenum = low_keyframenum;
+                        if (positionMap[hi_keyframenum] == pkt->startpos)
+                            low_keyframenum = hi_keyframenum;
+                        
+                        // use the lower of the two
+                        int keyframenum = (low_keyframenum < hi_keyframenum) ?
+                            low_keyframenum : hi_keyframenum;
+                        
+                        if (keyframenum > 0 && positionMap[keyframenum] != 0) 
+                            tempKeyFrameDist = (framesRead)/(keyframenum);
+                    }
+                    else 
+                    {
+                        tempKeyFrameDist = framesRead - 1 - prevgoppos;
+                    }
+
+                    if (!gopset)
+                    {
+                        if (prevgoppos > 0 && tempKeyFrameDist > 0)
+                        {
+                            gopset = true;
+                            keyframedist = tempKeyFrameDist;
+                            m_parent->SetVideoParams(-1, -1, -1, keyframedist);
+                        }
+                    }
+                    else
+                    {
+                        if (keyframedist != tempKeyFrameDist && 
+                            tempKeyFrameDist > 0)
+                        {
+                            //cerr << "KeyFrameDistance has changed to "
+                            //     << tempKeyFrameDist << "." << endl;
+                            keyframedist = tempKeyFrameDist;
+                            m_parent->SetVideoParams(-1, -1, -1, keyframedist);
+                            // also reset length
+                            QMap<long long,long long>::const_iterator it = 
+                                positionMap.end();
+                            it--;
+                            long long totframes = it.key() * keyframedist;
+                            int length = (int)((totframes * 1.0) / fps);
+                            m_parent->SetFileLength(length, totframes);
+                        }
+                    }
+
+                    lastKey = prevgoppos = framesRead - 1;
+
+                    if (!hasFullPositionMap)
+                    {
+                        long long startpos = pkt->startpos;
+
+//cout << prevgoppos << " " << startpos << " " << pkt->dts << endl;
+                        //cerr << "positionMap[" << prevgoppos / keyframedist <<
+                        //        "] = " << pkt->startpos << "." << endl;
+                        positionMap[prevgoppos / keyframedist] = startpos;
+                    }
+                }
+                break;
+            }
+            continue;
         }
         state = ((state << 8) | v) & 0xFFFFFF;
     }
 
-    return 0;
+    memcpy(prvpkt, pkt->data + pkt->size - 3, 3);
 }
 
 static const float avfmpeg1_aspect[16]={
@@ -748,9 +929,10 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
     unsigned char *ptr;
     short samples[AVCODEC_MAX_AUDIO_FRAME_SIZE / 2];
     int data_size = 0;
-    long long temppts;
+    long long pts;
+    bool firstloop = false;
 
-    bool gotvideo = false;
+    gotvideo = false;
 
     frame_decoded = 0;
 
@@ -761,7 +943,8 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
     {
         if (gotvideo)
         {
-            if (lowbuffers && onlyvideo == 0 && lastapts < lastvpts + 100)
+            if (lowbuffers && onlyvideo == 0 && lastapts < lastvpts + 100 &&
+                lastapts > lastvpts - 10000)
             {
                 //cout << "behind: " << lastapts << " " << lastvpts << endl;
                 storevideoframes = true;
@@ -776,7 +959,10 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
         if (!storevideoframes && storedPackets.count() > 0)
         {
             if (pkt)
+            {
+                av_free_packet(pkt);
                 delete pkt;
+            }
             pkt = storedPackets.first();
             storedPackets.removeFirst();
         }
@@ -785,7 +971,7 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
             if (!pkt)
                 pkt = new AVPacket;
 
-            if (av_read_packet(ic, pkt) < 0)
+            if (av_read_frame(ic, pkt) < 0)
             {
                 ateof = true;
                 m_parent->SetEof();
@@ -793,9 +979,6 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
             }
         }
 
-        len = pkt->size;
-        ptr = pkt->data;
-
         if (pkt->stream_index > ic->nb_streams)
         {
             cerr << "bad stream\n";
@@ -803,11 +986,18 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
             continue;
         }
 
+        len = pkt->size;
+        ptr = pkt->data;
+        pts = 0;
+        if (pkt->pts != AV_NOPTS_VALUE)
+            pts = pkt->pts / (AV_TIME_BASE / 1000);
+
         AVStream *curstream = ic->streams[pkt->stream_index];
 
         if (storevideoframes && 
             curstream->codec.codec_type == CODEC_TYPE_VIDEO)
         {
+            av_dup_packet(pkt);
             storedPackets.append(pkt);
             pkt = NULL;
             continue;
@@ -815,72 +1005,39 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
 
         if (len > 0 && curstream->codec.codec_type == CODEC_TYPE_VIDEO)
         {
+            framesRead++;
+            if (exitafterdecoded)
+                gotvideo = 1;
+
             AVCodecContext *context = &(curstream->codec);
+
             if (context->codec_id == CODEC_ID_MPEG1VIDEO ||
                 context->codec_id == CODEC_ID_MPEG2VIDEO ||
                 context->codec_id == CODEC_ID_MPEG2VIDEO_XVMC ||
                 context->codec_id == CODEC_ID_MPEG2VIDEO_VIA)
             {
-                int startpos = 0;
-                if ((startpos = PacketHasHeader(ptr, len, SEQ_START)))
-                {
-                    unsigned char *test = ptr + startpos;
-                    int width = (test[0] << 4) | (test[1] >> 4);
-                    int height = ((test[1] & 0xff) << 8) | test[2];
-
-                    int aspectratioinfo = (test[3] >> 4);
-
-                    float aspect = GetMpegAspect(context, aspectratioinfo, 
-                                                 width, height);
-
-                    if (CheckVideoParams(width, height) || 
-                        aspect != current_aspect)
-                    {
-                        m_parent->SetVideoParams(width, height, fps,
-                                                 keyframedist, aspect);
-                        m_parent->ReinitVideo();
-                        current_width = width;
-                        current_height = height;
-                        current_aspect = aspect;
-                    }
-                }
-                 
-                if (PacketHasHeader(ptr, len, PICTURE_START))
-                {
-                    framesRead++;
-                    if (exitafterdecoded)
-                        gotvideo = 1;
-                }
-
-                if (PacketHasHeader(ptr, len, GOP_START))
-                {
-                    int frameNum = framesRead - 1;
- 
-                    if (!gopset && frameNum > 0)
-                    {
-                        if (firstgoppos > 0)
-                        {
-                            keyframedist = frameNum - firstgoppos;
-                            gopset = true;
-                            m_parent->SetVideoParams(-1, -1, -1, keyframedist);
-                        }
-                        else
-                            firstgoppos = frameNum;
-                    }
-
-                    lastKey = frameNum;
-                    if (!hasFullPositionMap)
-                        positionMap[lastKey / keyframedist] = pkt->startpos;
-                }
+                MpegPreProcessPkt(curstream, pkt);
             }
         }
+
+        if (!curstream->codec.codec)
+        {
+            cerr << "no codec for stream index " << pkt->stream_index << endl;
+            av_free_packet(pkt);
+            continue;
+        }
  
+        firstloop = true;
+
         while (len > 0)
         {
             switch (curstream->codec.codec_type)
             {
                 case CODEC_TYPE_AUDIO:
                 {
+                    if (firstloop && pkt->pts != AV_NOPTS_VALUE)
+                        lastapts = pkt->pts / (AV_TIME_BASE / 1000);
+
                     if (onlyvideo != 0)
                     {
                         ptr += pkt->size;
@@ -888,41 +1045,46 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
                         continue;
                     }
 
-                    ret = avcodec_decode_audio(&curstream->codec, samples,
-                                               &data_size, ptr, len);
-                    if (data_size <= 0)
+                    if (do_ac3_passthru)
                     {
-                        ptr += ret;
-                        len -= ret;
-                        continue;
-                    }
-
-                    if (CheckAudioParams(curstream->codec.sample_rate,
-                                         curstream->codec.channels))
-                    {
-                        audio_sampling_rate = curstream->codec.sample_rate;
-                        audio_channels = curstream->codec.channels;
-                        audio_sample_size = audio_channels * 2;
-
-                        m_parent->SetEffDsp(audio_sampling_rate * 100);
-                        m_parent->SetAudioParams(16, audio_channels,
-                                                 audio_sampling_rate);
-                        m_parent->ReinitAudio();
-                    }
-
-                    temppts = (long long)((double)pkt->pts * ptsmultiplier); 
-
-                    if (lastapts != temppts && temppts > 0 && validvpts)
-                    {
-                        lastapts = temppts;
+                        data_size = pkt->size;
+                        ret = EncodeAC3Frame(ptr, len, samples, data_size);
                     }
                     else
                     {
-                        lastapts += (long long)((double)(data_size * 1000) / 
-                                    audio_sample_size / audio_sampling_rate);
+                        ret = avcodec_decode_audio(&curstream->codec, samples,
+                                                   &data_size, ptr, len);
                     }
+
+                    ptr += ret;
+                    len -= ret;
+
+                    if (data_size <= 0)
+                        continue;
+
+                    if (!do_ac3_passthru)
+                    {
+                        if (CheckAudioParams(curstream->codec.sample_rate,
+                                             curstream->codec.channels))
+                        {
+                            audio_sampling_rate = curstream->codec.sample_rate;
+                            audio_channels = curstream->codec.channels;
+                            audio_sample_size = audio_channels * 2;
+
+                            m_parent->SetEffDsp(audio_sampling_rate * 100);
+                            m_parent->SetAudioParams(16, audio_channels,
+                                                     audio_sampling_rate);
+                            m_parent->ReinitAudio();
+                        }
+                    }
+
+                    long long temppts = lastapts;
+                    // calc for next frame
+                    lastapts += (long long)((double)(data_size * 1000) /
+                                audio_sample_size / audio_sampling_rate);
+
                     m_parent->AddAudioData((char *)samples, data_size, 
-                                           lastapts);
+                                           temppts);
                     break;
                 }
                 case CODEC_TYPE_VIDEO:
@@ -981,26 +1143,53 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
                                     context->height);
                     }
 
-                    if (mpa_pic.pict_type == FF_I_TYPE ||
-                        mpa_pic.pict_type == FF_P_TYPE)
+                    long long temppts = pts;
+
+                    if (context->has_b_frames && mpa_pic.pict_type != FF_B_TYPE)
                     {
-                        long long newvpts = 0;
-                        if (pkt->pts > 0)
+                        temppts = video_last_P_pts;
+                        video_last_P_pts = pts;
+                    }
+
+                    if (temppts != 0)
+                        lastvpts = temppts;
+                    else
+                        temppts = lastvpts;
+
+                    // update video clock for next frame
+                    int frame_delay = (int)(1000.0 / fps);
+
+                    if (mpa_pic.repeat_pict)
+                    {
+                        //cerr << "repeat, unhandled?\n";
+                        frame_delay += (int)(mpa_pic.repeat_pict * 
+                                             frame_delay * 0.5);
+                    }
+
+                    lastvpts += frame_delay;
+
+/* XXX: Broken.
+                    if (mpa_pic.qscale_table != NULL && mpa_pic.qstride > 0 &&
+                        context->height == picframe->height)
+                    {
+                        int tblsize = mpa_pic.qstride * 
+                                      ((picframe->height + 15) / 16);
+
+                        if (picframe->qstride != mpa_pic.qstride ||
+                            picframe->qscale_table == NULL)
                         {
-                            validvpts = true;
-                            newvpts = (long long)((double)pkt->pts * 
-                                                  ptsmultiplier); 
+                            picframe->qstride = mpa_pic.qstride;
+                            if (picframe->qscale_table)
+                                delete [] picframe->qscale_table;
+                            picframe->qscale_table = new unsigned char[tblsize];
                         }
 
-                        if (newvpts <= lastvpts)
-                            lastvpts += (int)(1000.0 / fps);
-                        else
-                            lastvpts = newvpts;
+                        memcpy(picframe->qscale_table, mpa_pic.qscale_table,
+                               tblsize);
                     }
-                    else
-                        lastvpts += (int)(1000.0 / fps);
+*/
 
-                    m_parent->ReleaseNextVideoFrame(picframe, lastvpts);
+                    m_parent->ReleaseNextVideoFrame(picframe, temppts);
                     if (directrendering)
                         inUseBuffers.removeRef(picframe);
                     gotvideo = 1;
@@ -1017,8 +1206,9 @@ void AvFormatDecoder::GetFrame(int onlyvideo)
             ptr += ret;
             len -= ret;
             frame_decoded = 1;
+            firstloop = false;
         }
-        
+       
         av_free_packet(pkt);
     }                    
 
@@ -1239,3 +1429,47 @@ void AvFormatDecoder::SetPositionMap(void)
         m_playbackinfo->SetPositionMap(positionMap, MARK_GOP_START, m_db);
 }
 
+int AvFormatDecoder::EncodeAC3Frame(unsigned char *data, int len,
+                                    short *samples, int &samples_size)
+{
+    int enc_len;
+    int flags, sample_rate, bit_rate;
+    unsigned char* ucsamples = (unsigned char*) samples;
+
+    // we don't do any length/crc validation of the AC3 frame here; presumably
+    // the receiver will have enough sense to do that.  if someone has a
+    // receiver that doesn't, here would be a good place to put in a call
+    // to a52_crc16_block(samples+2, data_size-2) - but what do we do if the
+    // packet is bad?  we'd need to send something that the receiver would
+    // ignore, and if so, may as well just assume that it will ignore
+    // anything with a bad CRC...
+
+    enc_len = a52_syncinfo(data, &flags, &sample_rate, &bit_rate);
+
+    if (enc_len == 0 || enc_len > len)
+    {
+        samples_size = 0;
+        return len;
+    }
+
+    if (enc_len > MAX_AC3_FRAME_SIZE - 8)
+        enc_len = MAX_AC3_FRAME_SIZE - 8;
+
+    swab(data, ucsamples + 8, enc_len);
+
+    // the following values come from ao_hwac3.c in mplayer.
+    // they form a valid IEC958 AC3 header.
+    ucsamples[0] = 0x72;
+    ucsamples[1] = 0xF8;
+    ucsamples[2] = 0x1F;
+    ucsamples[3] = 0x4E;
+    ucsamples[4] = 0x01;
+    ucsamples[5] = 0x00;
+    ucsamples[6] = (enc_len << 3) & 0xFF;
+    ucsamples[7] = (enc_len >> 5) & 0xFF;
+    memset(ucsamples + 8 + enc_len, 0, MAX_AC3_FRAME_SIZE - 8 - enc_len);
+    samples_size = MAX_AC3_FRAME_SIZE;
+
+    return len;  // consume whole frame even if len > enc_len ?
+}
+
