@@ -57,12 +57,12 @@ class AvFormatDecoder : public DecoderBase
 
     friend int get_avf_buffer_xvmc(struct AVCodecContext *c, AVFrame *pic);
     friend void release_avf_buffer_xvmc(struct AVCodecContext *c, AVFrame *pic);
-    friend void render_slice_xvmc(struct AVCodecContext *c, AVFrame *src, 
+    friend void render_slice_xvmc(struct AVCodecContext *c, const AVFrame *src, 
                                   int offset[4], int y, int type, int height);
 
     friend int get_avf_buffer_via(struct AVCodecContext *c, AVFrame *pic);
     friend void release_avf_buffer_via(struct AVCodecContext *c, AVFrame *pic);
-    friend void render_slice_via(struct AVCodecContext *c, AVFrame *src,
+    friend void render_slice_via(struct AVCodecContext *c, const AVFrame *src,
                                  int offset[4], int y, int type, int height);
 	
     friend int open_avf(URLContext *h, const char *filename, int flags);
@@ -72,7 +72,7 @@ class AvFormatDecoder : public DecoderBase
     friend int close_avf(URLContext *h);
 
     void InitByteContext(void);
-    int PacketHasHeader(unsigned char *buf, int len, unsigned int startcode);
+    void MpegPreProcessPkt(AVStream *stream, AVPacket *pkt);
     float GetMpegAspect(AVCodecContext *context, int aspect_ratio_info,
                         int width, int height);
 
@@ -81,6 +81,9 @@ class AvFormatDecoder : public DecoderBase
     bool CheckVideoParams(int width, int height);
     bool CheckAudioParams(int freq, int channels);
 
+    int EncodeAC3Frame(unsigned char* data, int len, short *samples,
+		       int &samples_size);
+
     RingBuffer *ringBuffer;
 
     AVFormatContext *ic;
@@ -103,9 +106,6 @@ class AvFormatDecoder : public DecoderBase
     int audio_sampling_rate_2nd;
     int audio_channels_2nd;
 
-    long long lastapts;
-    long long lastvpts;
-
     bool hasbframes;
 
     bool hasFullPositionMap;
@@ -126,9 +126,6 @@ class AvFormatDecoder : public DecoderBase
     ProgramInfo *m_playbackinfo;
 
     double fps;
-    bool validvpts;
-
-    double ptsmultiplier;
 
     QPtrList<VideoFrame> inUseBuffers;
 
@@ -139,6 +136,17 @@ class AvFormatDecoder : public DecoderBase
     QPtrList<AVPacket> storedPackets;
 
     int firstgoppos;
+    int prevgoppos;
+
+    bool gotvideo;
+
+    unsigned char prvpkt[3];
+
+    long long video_last_P_pts;
+    long long lastvpts;
+    long long lastapts; 
+
+    bool do_ac3_passthru;
 };
 
 #endif
