@@ -8,7 +8,7 @@ using namespace std;
 
 #include "mythcontext.h"
 
-const QString currentDatabaseVersion = "1007";
+const QString currentDatabaseVersion = "1019";
 
 void UpdateDBVersionNumber(const QString &newnumber)
 {
@@ -217,6 +217,219 @@ void UpgradeTVDatabaseSchema(void)
 };
         performActualUpdate(updates, "1007", dbver);
     }
+
+    if (dbver == "1007")
+    {
+        const QString updates[] = {
+"ALTER TABLE capturecard CHANGE use_ts dvb_swfilter INT DEFAULT '0';",
+"ALTER TABLE capturecard CHANGE dvb_type dvb_recordts INT DEFAULT '0';",
+"DROP TABLE IF EXISTS channel_dvb;",
+"CREATE TABLE IF NOT EXISTS dvb_channel ("
+"   chanid              SMALLINT NOT NULL,"
+"   serviceid           SMALLINT NULL,"
+"   networkid           SMALLINT NULL,"
+"   providerid          SMALLINT NULL,"
+"   transportid         SMALLINT NULL,"
+"   frequency           INTEGER NULL,"
+"   inversion           CHAR(1) NULL,"
+"   symbolrate          INTEGER NULL,"
+"   fec                 VARCHAR(10) NULL,"
+"   polarity            CHAR(1) NULL,"
+"   satid               SMALLINT NULL,"
+"   modulation          VARCHAR(10) NULL,"
+"   bandwidth           CHAR(1) NULL,"
+"   lp_code_rate        VARCHAR(10) NULL,"
+"   transmission_mode   CHAR(1) NULL,"
+"   guard_interval      VARCHAR(10) NULL,"
+"   hierarchy           CHAR(1) NULL,"
+"   PRIMARY KEY (chanid)"
+");",
+"CREATE TABLE IF NOT EXISTS dvb_sat ("
+"   satid   SMALLINT NOT NULL AUTO_INCREMENT,"
+"   lnbid   SMALLINT NOT NULL,"
+"   cardnum SMALLINT NOT NULL,"
+"   PRIMARY KEY (cardnum,satid,lnbid)"
+");",
+"CREATE TABLE IF NOT EXISTS dvb_lnb ("
+"   lnbid       SMALLINT NOT NULL AUTO_INCREMENT,"
+"   disecqid    SMALLINT NULL,"
+"   diseqc_port SMALLINT NULL,"
+"   lof_switch  INTEGER DEFAULT 11700000 NOT NULL,"
+"   lof_hi      INTEGER DEFAULT 10600000 NOT NULL,"
+"   lof_lo      INTEGER DEFAULT 9750000 NOT NULL,"
+"   PRIMARY KEY (lnbid)"
+");",
+"CREATE TABLE IF NOT EXISTS dvb_pids ("
+"   chanid  SMALLINT NOT NULL,"
+"   pid     SMALLINT NOT NULL,"
+"   type    CHAR(1) DEFAULT 'o' NOT NULL,"
+"   lang    CHAR(3) DEFAULT '' NOT NULL,"
+"   PRIMARY KEY (chanid,pid)"
+");",
+""
+};
+        performActualUpdate(updates, "1008", dbver);
+    }
+
+    if (dbver == "1008")
+    {
+        const QString updates[] = {
+"CREATE TABLE IF NOT EXISTS dvb_sat ("
+"   satid   SMALLINT NOT NULL AUTO_INCREMENT,"
+"   lnbid   SMALLINT NOT NULL,"
+"   cardnum SMALLINT NOT NULL,"
+"   PRIMARY KEY (cardnum,satid,lnbid)"
+");",
+""
+};
+        performActualUpdate(updates, "1009", dbver);
+    }
+
+    if (dbver == "1009")
+    {
+        const QString updates[] = {
+"ALTER TABLE record ADD COLUMN preroll INT DEFAULT 0 NOT NULL;",
+"ALTER TABLE record ADD COLUMN postroll INT DEFAULT 0 NOT NULL;",
+""
+};
+        performActualUpdate(updates, "1010", dbver);
+    }
+
+    if (dbver == "1010")
+    {
+        const QString updates[] = {
+"DROP TABLE IF EXISTS dvb_diseqc;",
+"DROP TABLE IF EXISTS dvb_lnb;",
+"DROP TABLE IF EXISTS dvb_sat;",
+"CREATE TABLE IF NOT EXISTS dvb_sat ("
+"   satid SMALLINT NOT NULL AUTO_INCREMENT,"
+"   sourceid INT DEFAULT 0,"
+"   pos SMALLINT DEFAULT 0,"
+"   name VARCHAR(128),"
+"   diseqc_type SMALLINT DEFAULT 0,"
+"   diseqc_port SMALLINT DEFAULT 0,"
+"   lnb_lof_switch SMALLINT DEFAULT 11700000,"
+"   lnb_lof_hi INTEGER DEFAULT 10600000,"
+"   lnb_lof_lo INTEGER DEFAULT 9750000,"
+"   PRIMARY KEY(satid)"
+");",
+""
+};
+        performActualUpdate(updates, "1011", dbver);
+    }
+
+    if (dbver == "1011")
+    {
+        const QString updates[] = {
+"CREATE TABLE IF NOT EXISTS recordoverride ("
+"   recordid INT UNSIGNED NOT NULL, "
+"   type INT UNSIGNED NOT NULL, "
+"   chanid INT UNSIGNED NULL, "
+"   starttime TIMESTAMP NOT NULL, "
+"   endtime TIMESTAMP NOT NULL, "
+"   title VARCHAR(128) NULL, "
+"   subtitle VARCHAR(128) NULL, "
+"   description TEXT NULL "
+");",
+""
+};
+        performActualUpdate(updates, "1012", dbver);
+    }
+
+    if (dbver == "1012")
+    {
+        const QString updates[] = {
+"INSERT INTO settings SET value=\"mythfilldatabaseLastRunStart\";",
+"INSERT INTO settings SET value=\"mythfilldatabaseLastRunEnd\";",
+"INSERT INTO settings SET value=\"mythfilldatabaseLastRunStatus\";",
+""
+};
+        performActualUpdate(updates, "1013", dbver);
+    }
+
+    if (dbver == "1013")
+    {
+        const QString updates[] = {
+"ALTER TABLE record CHANGE rank recpriority INT(10) DEFAULT '0' NOT NULL;",
+"ALTER TABLE channel CHANGE rank recpriority INT(10) DEFAULT '0' NOT NULL;",
+"UPDATE settings SET value='RecPriorityingActive' WHERE value='RankingActive';",
+"UPDATE settings SET value='RecPriorityingOrder' WHERE value='RankingOrder';",
+"UPDATE settings SET value='SingleRecordRecPriority' WHERE value='SingleRecordRank';",
+"UPDATE settings SET value='TimeslotRecordRecPriority' WHERE value='TimeslotRecordRank';",
+"UPDATE settings SET value='WeekslotRecordRecPriority' WHERE value='WeekslotRecordRank';",
+"UPDATE settings SET value='ChannelRecordRecPriority' WHERE value='ChannelRecordRank';",
+"UPDATE settings SET value='AllRecordRecPriority' WHERE value='AllRecordRank';",
+"UPDATE settings SET value='ChannelRecPrioritySorting' WHERE value='ChannelRankSorting';",
+"UPDATE settings SET value='ProgramRecPrioritySorting' WHERE value='ProgramRankSorting';",
+""
+};
+        performActualUpdate(updates, "1014", dbver);
+    }
+
+    if (dbver == "1014")
+    {
+        const QString updates[] = {
+"ALTER TABLE dvb_sat CHANGE lnb_log_switch lnb_lof_switch INTEGER DEFAULT 11700000;",
+"UPDATE settings SET value='RecPriorityOrder' WHERE value='RecPriorityingOrder';",
+""
+};
+
+        performActualUpdate(updates, "1015", dbver);
+    }
+
+    if (dbver == "1015")
+    {
+        const QString updates[] = {
+"CREATE TABLE jumppoints ("
+"  destination varchar(128) NOT NULL,"
+"  description varchar(255) default NULL,"
+"  keylist varchar(32) default NULL,"
+"  hostname varchar(255) NOT NULL"
+");",
+"CREATE TABLE keybindings ("
+"  context varchar(32) NOT NULL,"
+"  action varchar(32) NOT NULL,"
+"  description varchar(255) default NULL,"
+"  keylist varchar(32) default NULL,"
+"  hostname varchar(255) NOT NULL"
+");",
+""
+};
+
+        performActualUpdate(updates, "1016", dbver);
+    }
+
+    if (dbver == "1016")
+    {
+        const QString updates[] = {
+"ALTER TABLE jumppoints ADD PRIMARY KEY (destination, hostname);",
+"ALTER TABLE keybindings ADD PRIMARY KEY (context, action, hostname);",
+""
+};
+
+        performActualUpdate(updates, "1017", dbver);
+    }
+
+    if (dbver == "1017")
+    {
+        const QString updates[] = {
+"UPDATE settings SET value='RecPriorityActive' WHERE value='RecPriorityingActive';",
+""
+};
+
+        performActualUpdate(updates, "1018", dbver);
+    }
+
+    if (dbver == "1018")
+    {
+        const QString updates[] = {
+"ALTER TABLE channel ADD COLUMN tvformat VARCHAR(10) NOT NULL default 'Default';",
+""
+};
+
+        performActualUpdate(updates, "1019", dbver);
+    }
+
 }
 
 void InitializeDatabase(void)
