@@ -27,6 +27,7 @@ using namespace std;
 #include "tv.h"
 #include "progfind.h"
 #include "util.h"
+#include "remoteutil.h"
 
 QString RunProgramGuide(QString startchannel, bool thread, TV *player)
 {
@@ -73,11 +74,14 @@ GuideGrid::GuideGrid(MythMainWindow *parent, const QString &channel, TV *player,
                      const char *name)
          : MythDialog(parent, name)
 {
+    updateLock = new QMutex(true);
+    
     desiredDisplayChans = DISPLAY_CHANS = 6;
     DISPLAY_TIMES = 30;
     int maxchannel = 0;
     m_currentStartChannel = 0;
     ignoreevents = false;
+    doProgramInfoUpdate = false;
 
     m_player = player;
     m_db = QSqlDatabase::database();
@@ -198,6 +202,7 @@ GuideGrid::GuideGrid(MythMainWindow *parent, const QString &channel, TV *player,
 
     //int fillchannels = clock.elapsed();
     //clock.restart();
+    fillRecordInfos();
     fillProgramInfos();
     //int fillprogs = clock.elapsed();
 
@@ -235,72 +240,134 @@ GuideGrid::~GuideGrid()
 
     m_channelInfos.clear();
 
+    while (!m_recList.empty())
+    {
+        ProgramInfo *p = m_recList.back();
+        delete p;
+        m_recList.pop_back();
+    }
+
     delete theme;
+    delete updateLock;
 }
 
 void GuideGrid::keyPressEvent(QKeyEvent *e)
 {
-    //keyDown limits keyrepeats to prevent continued scrolling
-    //after key is released. Note: Qt's keycompress should handle
-    //this but will fail with fast key strokes and keyboard repeat
-    //enabled. Keys will not be marked as autorepeat and flood buffer.
-    //setFocusPolicy(QWidget::ClickFocus) in constructor is important 
-    //or keyRelease events will not be received after a refocus.
+    // keyDown limits keyrepeats to prevent continued scrolling
+    // after key is released. Note: Qt's keycompress should handle
+    // this but will fail with fast key strokes and keyboard repeat
+    // enabled. Keys will not be marked as autorepeat and flood buffer.
+    // setFocusPolicy(QWidget::ClickFocus) in constructor is important 
+    // or keyRelease events will not be received after a refocus.
     
-    if(keyDown && e->key() != Key_Escape && e->key() != Key_C)
-        return; //check for Key_Escape incase something goes wrong 
+    if (ignoreevents)
+        return;
+
+    bool handled = false;
+
+    QStringList actions;
+    gContext->GetMainWindow()->TranslateKeyPress("TV Frontend", e, actions);
+
+    if (actions.size() > 0 && keyDown && actions[0] != "ESCAPE")
+        return; //check for Escape in case something goes wrong 
                 //with KeyRelease events, shouldn't happen.
-       
-    if(e->key() != Key_Control)
+
+    if (e->key() != Key_Control)
         keyDown = true;    
+
+    ignoreevents = true;  //prevent customEvent from updating
+    updateLock->lock();    //wait if customEvent is updating 
     
     if (e->state() == Qt::ControlButton)
     {
-        switch (e->key())
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
         {
-            case Key_Left: pageLeft(); return;
-            case Key_Right: pageRight(); return;
-            case Key_Up: pageUp(); return;
-            case Key_Down: pageDown(); return;
-            default: break;
+            QString action = actions[i];
+            handled = true;
+
+            if (action == "LEFT")
+                pageLeft();
+            else if (action == "RIGHT")
+                pageRight();
+            else if (action == "UP")
+                pageUp();
+            else if (action == "DOWN")
+                pageDown();
+            else
+                handled = false;
+        }
+        handled = true;
+    }
+    else
+    {
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
+        {
+            QString action = actions[i];
+            handled = true;
+
+            if (action == "LEFT")
+                cursorLeft();
+            else if (action == "RIGHT")
+                cursorRight();
+            else if (action == "DOWN")
+                cursorDown();
+            else if (action == "UP")
+                cursorUp();
+            else if (action == "PAGEUP")
+                pageUp();
+            else if (action == "PAGEDOWN")
+                pageDown();
+            else if (action == "PAGELEFT")
+                pageLeft();
+            else if (action == "PAGERIGHT")
+                pageRight();
+            else if (action == "DAYLEFT")
+                dayLeft();
+            else if (action == "DAYRIGHT")
+                dayRight();
+            else if (action == "NEXTFAV" || action == "4")
+                toggleGuideListing();
+            else if (action == "6")
+                showProgFinder();
+            else if (action == "MENU")
+                enter();
+            else if (action == "ESCAPE")
+                escape();
+            else if (action == "SELECT")
+                editRecording();
+            else if (action == "INFO")
+                editScheduled();
+            else if (action == "TOGGLERECORD")
+                quickRecord();
+            else if (action == "TOGGLEFAV")
+                toggleChannelFavorite();
+            else if (action == "CHANUPDATE")
+                channelUpdate();
+            else
+                handled = false;
         }
     }
 
-    switch (e->key())
+    if (!handled)
+        MythDialog::keyPressEvent(e);
+
+    if (doProgramInfoUpdate) 
     {
-        case Key_Left: case Key_A: cursorLeft(); break;
-        case Key_Right: case Key_D: cursorRight(); break;
-        case Key_Down: case Key_S: cursorDown(); break;
-        case Key_Up: case Key_W: cursorUp(); break;
-
-        case Key_Home: case Key_7: dayLeft(); break;
-        case Key_End: case Key_1: dayRight(); break;
-        case Key_PageUp: case Key_3: pageUp(); break;
-        case Key_PageDown: case Key_9: pageDown(); break;
-      
-        case Key_4: toggleGuideListing(); break;
-        case Key_6: showProgFinder(); break;   
-      
-        case Key_Slash: toggleChannelFavorite(); break;
- 
-        case Key_C: case Key_Escape: escape(); break;
-        case Key_M: enter(); break;
-
-        case Key_I: case Key_Space: 
-        case Key_Enter: case Key_Return:  displayInfo(); break;
-
-        case Key_R: quickRecord(); break;
-        case Key_X: channelUpdate(); break;
-
-        default: MythDialog::keyPressEvent(e);
+        fillRecordInfos();
+        fillProgramInfos();
+        update(fullRect);
     }
+    
+    ignoreevents = false;
+
+    updateLock->unlock();
 }
 
 void GuideGrid::keyReleaseEvent(QKeyEvent *e)
 {
-    //note: KeyRelease events may not reflect the released 
-    //key if delayed (key==0 instead).
-    e->key(); //stop compiler warning
+    // note: KeyRelease events may not reflect the released 
+    // key if delayed (key==0 instead).
+    (void)e;
     keyDown = false;
 }
 
@@ -368,18 +435,6 @@ void GuideGrid::parseContainer(QDomElement &element)
         videoRect = area;
 }
 
-QString GuideGrid::getDateLabel(ProgramInfo *pginfo)
-{
-    QDateTime startts = pginfo->startts;
-    QDateTime endts = pginfo->endts;
-
-    QString timedate = startts.date().toString(dateformat) + QString(", ") +
-                       startts.time().toString(timeformat) + QString(" - ") +
-                       endts.time().toString(timeformat);
-
-    return timedate;
-}
-
 QString GuideGrid::getLastChannel(void)
 {
     unsigned int chanNum = m_currentRow + m_currentStartChannel;
@@ -542,6 +597,18 @@ void GuideGrid::fillTimeInfos()
     m_currentEndTime = t;
 }
 
+void GuideGrid::fillRecordInfos(void)
+{
+    while (!m_recList.empty())
+    {
+        ProgramInfo *p = m_recList.back();
+        delete p;
+        m_recList.pop_back();
+    }
+
+    RemoteGetAllPendingRecordings(m_recList);
+}
+
 void GuideGrid::fillProgramInfos(void)
 {
     LayerSet *container = NULL;
@@ -557,10 +624,13 @@ void GuideGrid::fillProgramInfos(void)
             type->SetScreenLocation(programRect.topLeft());
         }
     }
+
     for (int y = 0; y < DISPLAY_CHANS; y++)
     {
         fillProgramRowInfos(y);
     }
+    
+    doProgramInfoUpdate = false;        
 }
 
 void GuideGrid::fillProgramRowInfos(unsigned int row)
@@ -614,6 +684,9 @@ void GuideGrid::fillProgramRowInfos(unsigned int row)
     ProgramInfo::GetProgramRangeDateTime(m_db, proglist, chanid, starttime, 
                                          endtime);
 
+    for (program = proglist->first(); program; program = proglist->next())
+            program->FillInRecordInfo(m_recList);
+
     QDateTime ts = m_currentStartTime;
 
     program = proglist->first();
@@ -676,7 +749,6 @@ void GuideGrid::fillProgramRowInfos(unsigned int row)
 
     int arrow = 0;
     int cnt = 0;
-    int recFlag = 0;
     int spread = 1;
     QDateTime lastprog; 
     QRect tempRect;
@@ -734,39 +806,44 @@ void GuideGrid::fillProgramRowInfos(unsigned int row)
 
             if (type)
             {
-                recFlag = 0;
-                RecordingType recordtype;
-                recordtype = proginfo->GetProgramRecordingStatus(m_db);
-                if (recordtype > kNotRecording)
+                int recFlag;
+                switch (proginfo->rectype) 
                 {
-                    switch (recordtype) 
-                    {
-                        case kSingleRecord:
-                            recFlag = 1;
-                            break;
-                        case kTimeslotRecord:
-                            recFlag = 2;
-                            break;
-                        case kChannelRecord:
-                            recFlag = 3;
-                            break;
-                        case kAllRecord:
-                            recFlag = 4;
-                            break;
-                        case kWeekslotRecord:
-                            recFlag = 5;
-                            break;
-                        case kNotRecording:
-                            break;
-                    }
+                case kSingleRecord:
+                    recFlag = 1;
+                    break;
+                case kTimeslotRecord:
+                    recFlag = 2;
+                    break;
+                case kChannelRecord:
+                    recFlag = 3;
+                    break;
+                case kAllRecord:
+                    recFlag = 4;
+                    break;
+                case kWeekslotRecord:
+                    recFlag = 5;
+                    break;
+                case kNotRecording:
+                default:
+                    recFlag = 0;
+                    break;
                 }
 
+                int recStat;
+                if (!proginfo->recording)
+                    recStat = 0;
+                else if (!proginfo->conflicting)
+                    recStat = 1;
+                else
+                    recStat = 2;
+
                 type->SetProgramInfo(row + 1, cnt, tempRect, proginfo->title,
-                                     proginfo->category, arrow, recFlag);
+                                     proginfo->category, arrow, recFlag, 
+                                     recStat);
+
                 if (isCurrent == true)
-                { 
                     type->SetCurrentArea(tempRect);
-                }
 
                 cnt++;
             }
@@ -778,9 +855,6 @@ void GuideGrid::fillProgramRowInfos(unsigned int row)
 
 void GuideGrid::customEvent(QCustomEvent *e)
 {
-    if (ignoreevents)
-        return;
-
     if ((MythEvent::Type)(e->type()) == MythEvent::MythEventMessage)
     {
         MythEvent *me = (MythEvent *)e;
@@ -788,7 +862,17 @@ void GuideGrid::customEvent(QCustomEvent *e)
 
         if (message == "SCHEDULE_CHANGE")
         {
+            if (ignoreevents)
+            {
+                doProgramInfoUpdate = true;
+                return;
+            }    
+            updateLock->lock();
+            ignoreevents = true; 
+            fillRecordInfos();
             fillProgramInfos();
+            ignoreevents = false;
+            updateLock->unlock();
             update(fullRect);
         }
     }
@@ -801,7 +885,7 @@ void GuideGrid::paintEvent(QPaintEvent *e)
 
     if (!showInfo)
     {
-        ignoreevents = true;
+        updateLock->lock(); 
         if (r.intersects(infoRect))
             paintInfo(&p);
         if (r.intersects(dateRect))
@@ -814,7 +898,7 @@ void GuideGrid::paintEvent(QPaintEvent *e)
             paintPrograms(&p);
         if (r.intersects(curInfoRect))
             paintCurrentInfo(&p);
-        ignoreevents = false;
+        updateLock->unlock();
     }
 }
 
@@ -1017,35 +1101,11 @@ void GuideGrid::paintInfo(QPainter *p)
     if (!pginfo)
         return;
 
+    QMap<QString, QString> regexpMap;
     QRect pr = infoRect;
     QPixmap pix(pr.size());
     pix.fill(this, pr.topLeft());
     QPainter tmp(&pix);
-    QString recStatus = "";
-
-    RecordingType recordtype;
-    recordtype = pginfo->GetProgramRecordingStatus(m_db);
-    switch (recordtype) 
-    {
-        case kSingleRecord:
-            recStatus = tr("Recording Once");
-            break;
-        case kTimeslotRecord:
-            recStatus = tr("Timeslot Recording");
-            break;
-        case kWeekslotRecord:
-            recStatus = tr("Weekly Recording");
-            break;
-        case kChannelRecord:
-            recStatus = tr("Channel Recording");
-            break;
-        case kAllRecord:
-            recStatus = tr("All Recording");
-            break;
-        case kNotRecording:
-            recStatus = tr("Not Recording");
-            break;
-    }
 
     int chanNum = m_currentRow + m_currentStartChannel;
     if (chanNum >= (int)m_channelInfos.size())
@@ -1055,38 +1115,20 @@ void GuideGrid::paintInfo(QPainter *p)
 
     ChannelInfo *chinfo = &(m_channelInfos[chanNum]);
 
+    pginfo->ToMap(m_db, regexpMap);
+
     LayerSet *container = theme->GetSet("program_info");
     if (container)
     {
-        UITextType *type = (UITextType *)container->GetType("title");
-        if (type)
-            type->SetText(pginfo->title);
+        container->ClearAllText();
+        container->SetTextByRegexp(regexpMap);
+
+        UITextType *type;
+
         type = (UITextType *)container->GetType("misicon");
         if (type)
             type->SetText(chinfo->callsign);
 
-        if ((pginfo->subtitle).stripWhiteSpace().length() != 0)
-        {
-           type = (UITextType *)container->GetType("subtitle");
-           if (type)
-               type->SetText("\"" + pginfo->subtitle + "\"");
-        }  
-        else
-        {
-           type = (UITextType *)container->GetType("subtitle");
-           if (type)
-               type->SetText("");
-    
-        }
-        type = (UITextType *)container->GetType("timedate");
-        if (type)
-            type->SetText(getDateLabel(pginfo));
-        type = (UITextType *)container->GetType("description");
-        if (type)
-            type->SetText(pginfo->description);
-        type = (UITextType *)container->GetType("recordingstatus");
-        if (type)
-            type->SetText(recStatus);
         UIImageType *itype = (UIImageType *)container->GetType("icon");
         if (itype)
         {
@@ -1125,6 +1167,7 @@ void GuideGrid::generateListings()
     if (DISPLAY_CHANS > maxchannel)
         DISPLAY_CHANS = maxchannel;
 
+    fillRecordInfos();
     fillProgramInfos();
     update(fullRect);
 }
@@ -1500,15 +1543,14 @@ void GuideGrid::quickRecord()
 
     pginfo->ToggleRecord(m_db);
 
+    fillRecordInfos();
     fillProgramInfos();
     update(programRect);
     update(infoRect);
 }
 
-void GuideGrid::displayInfo()
+void GuideGrid::editRecording()
 {
-    showInfo = 1;
-
     ProgramInfo *pginfo = m_programInfos[m_currentRow][m_currentCol];
 
     if (!pginfo)
@@ -1517,34 +1559,46 @@ void GuideGrid::displayInfo()
     if (pginfo->title == unknownTitle)
         return;
 
-    if (pginfo)
-    {
-        FocusPolicy storeFocus = focusPolicy();
-        setFocusPolicy(QWidget::NoFocus);
-        if ((gContext->GetNumSetting("AdvancedRecord", 0)) ||
-            (pginfo->GetProgramRecordingStatus(m_db) > kAllRecord))
-        {
-            ScheduledRecording record;
-            record.loadByProgram(m_db, pginfo);
-            record.exec(m_db);
-        }
-        else
-        {
-            InfoDialog diag(pginfo, gContext->GetMainWindow(), "Program Info");
-            diag.exec();
-        }
-        setFocusPolicy(storeFocus);
-    }
-    else
-        return;
+    showInfo = 1;
+
+    FocusPolicy storeFocus = focusPolicy();
+    setFocusPolicy(QWidget::NoFocus);
+    pginfo->EditRecording(m_db);
+    setFocusPolicy(storeFocus);
 
     showInfo = 0;
 
-    pginfo->GetProgramRecordingStatus(m_db);
-
     setActiveWindow();
     setFocus();
 
+    fillRecordInfos();
+    fillProgramInfos();
+    update(fullRect);
+}
+
+void GuideGrid::editScheduled()
+{
+    ProgramInfo *pginfo = m_programInfos[m_currentRow][m_currentCol];
+
+    if (!pginfo)
+        return;
+
+    if (pginfo->title == unknownTitle)
+        return;
+
+    showInfo = 1;
+
+    FocusPolicy storeFocus = focusPolicy();
+    setFocusPolicy(QWidget::NoFocus);
+    pginfo->EditScheduled(m_db);
+    setFocusPolicy(storeFocus);
+
+    showInfo = 0;
+
+    setActiveWindow();
+    setFocus();
+
+    fillRecordInfos();
     fillProgramInfos();
     update(fullRect);
 }
