@@ -12,6 +12,31 @@
      and no audio stutter on stations with >1 audio stream
    * Emits proper keyframe data to recordedmarkup db, enabling seeking
 
+   Oct. 22, 2003:
+   * delay until GOP before writing output stream at start and reset
+     (i.e. channel change)
+   * Rewrite PIDs after channel change to be the same as before, so
+     decoder can follow
+
+   Oct. 27, 2003 by Jason Hoos:
+   * if no GOP is detected within the first 30 frames of the stream, then
+     assume that it's safe to treat a picture start as a GOP.
+
+   Oct. 30, 2003 by Jason Hoos:
+   * added code to rewrite PIDs in the MPEG PAT and PMT tables.  fixes 
+     a problem with stations (particularly, WGN in Chicago) that list their 
+     programs in reverse order in the PAT, which was confusing ffmpeg 
+     (ffmpeg was looking for program 5, but only program 2 was left in 
+     the stream, so it choked).
+
+   Nov. 3, 2003 by Doug Larrick:
+   * code to enable selecting a program number for stations with
+     multiple programs
+   * always renumber PIDs to match outgoing program number (#1:
+     0x10 (base), 0x11 (video), 0x14 (audio))
+   * change expected keyframe distance to 30 frames to see if this
+     lets people seek past halfway in recordings
+
    References / example code: 
      ATSC standards a.54, a.69 (www.atsc.org)
      ts2pes from mpegutils from dvb (www.linuxtv.org)
@@ -41,15 +66,18 @@ using namespace std;
 extern "C" {
 #include "../libavcodec/avcodec.h"
 #include "../libavformat/avformat.h"
+#include "../libavformat/mpegts.h"
 }
 
-//#define BUFFER_SIZE 4096
-//#define BUFFER_SIZE 256001
-#define BUFFER_SIZE 255868
-#define PACKETS (BUFFER_SIZE / 188)
+#define PACKETS (HD_BUFFER_SIZE / 188)
 
 #define SYNC_BYTE 0x47
 
+// n.b. these PID relationships are only a recommendation from ATSC,
+// but seem to be universal
+#define VIDEO_PID(bp) ((bp)+1)
+#define AUDIO_PID(bp) ((bp)+4)
+
 HDTVRecorder::HDTVRecorder()
             : RecorderBase()
 {
@@ -61,16 +89,18 @@ HDTVRecorder::HDTVRecorder()
 
     chanfd = -1; 
 
-    keyframedist = 15;
+    keyframedist = 30;
     gopset = false;
+    pict_start_is_gop = false;
 
     firstgoppos = 0;
 
+    desired_program = 1; // default to program #1
     pat_pid = 0;
     psip_pid = 0x1ffb;
-    video_pid = 0; // video, audio, base PIDs will be filled in when we 
-    audio_pid = 0; // find them
-    base_pid = 0;
+    audio_pid = video_pid = -1;
+    pmt_pid = -1;
+    output_base_pid = 0;
     ts_packets = 0; // cumulative packet count
 
     // temporary to find lowest PID in first 500 packets
@@ -109,8 +139,6 @@ void HDTVRecorder::StartRecording(void)
         return;
     }
 
-    static uint8_t buffer[BUFFER_SIZE];
-
     if (!SetupRecording())
     {
         cerr << "HD Error initializing recording\n";
@@ -218,29 +246,6 @@ int HDTVRecorder::GetVideoFd(void)
 
 // start common code to the dvbrecorder class.
 
-static void mpg_write_packet(void *opaque, uint8_t *buf, int buf_size)
-{
-    (void)opaque;
-    (void)buf;
-    (void)buf_size;
-}
-
-static int mpg_read_packet(void *opaque, uint8_t *buf, int buf_size)
-{
-    (void)opaque;
-    (void)buf;
-    (void)buf_size;
-    return 0;
-}
-
-static int mpg_seek_packet(void *opaque, int64_t offset, int whence)
-{
-    (void)opaque;
-    (void)offset;
-    (void)whence;
-    return 0;
-}
-
 bool HDTVRecorder::SetupRecording(void)
 {
     prev_gop_save_pos = -1;
@@ -334,9 +339,19 @@ void HDTVRecorder::FindKeyframes(const unsigned char *buffer,
                         if (buffer[i+1] == 0x00) // picture_start
                         {
                             framesWritten++;
+                            if (framesWritten >= 30 && firstgoppos <= 0)
+                            {
+                                // seen 30 frames with no GOP; assume that
+                                // each GOP only contains one I-frame, and
+                                // treat the I-frame as the beginning of the
+                                // GOP.
+                                pict_start_is_gop = true;
+                            }
                         }
-                        else if (buffer[i+1] == 0xB8) // group_of_pictures
+                        if (buffer[i+1] == 0xB8 || 
+                            (pict_start_is_gop && buffer[i+1] == 0x00))
                         {
+                            // group_of_pictures
                             int frameNum = framesWritten - 1;
                             
                             if (!gopset && frameNum > 0)
@@ -405,6 +420,146 @@ int HDTVRecorder::ResyncStream(unsigned char *buffer, int curr_pos, int len)
     return pos;
 }
 
+void HDTVRecorder::RewritePID(unsigned char *buffer, int pid)
+{
+    // We need to rewrite the outgoing PIDs to match the first one
+    // the decoder saw ... it does not seem to track PID changes.
+    char b1, b2;
+    // PID is 13 bits starting in byte 1, bit 4
+    b1 = ((pid >> 8) & 0x1F) | (buffer[1] & 0xE0);
+    b2 = (pid & 0xFF);
+    buffer[1] = b1;
+    buffer[2] = b2;
+}
+
+bool HDTVRecorder::RewritePAT(unsigned char *buffer, int pid, int pkt_len)
+{
+    int pos = 0;
+
+    // Rewrite the PAT table, eliminating any other streams that the old
+    // one may have described so that ffmpeg can only find ours (useful since
+    // some stations put programs in their PAT tables in descending order 
+    // instead of ascending, which would confuse ffmpeg).  While we're at it
+    // change the program number to 1 in case it wasn't that already.
+    
+    // PAT format: 2-byte TSID, 2-byte PID, repeated for each PID
+    // TODO: typically PIDs seem to be padded with 1-bits.  Someone 
+    // with better knowledge of PAT table formats should confirm this.
+    // If it is wrong, fix the '0xe0' values in RewritePMT too.
+  
+    // new_len is the length of the new PAT we're creating, including the
+    // 3 bytes of the header that occur before the length word.  We'll 
+    // account for those 3 bytes later.  If the contents of the new PAT
+    // ever change, be sure to update this!
+    int new_len = 16;
+
+    if (new_len > pkt_len)
+        return false;  // new packet would exceed boundary, skip it
+
+    pos = 8;  // section header is 8 bytes, skip it
+
+    buffer[pos] = 0x00;
+    buffer[pos+1] = 0x01;
+    buffer[pos+2] = 0xe0 | ((pid & 0x1f00) >> 8);
+    buffer[pos+3] = pid & 0xff;
+    pos += 4;
+
+    // rewrite section length
+    new_len -= 3; // account for 3 bytes before length word in header
+    buffer[1] = (buffer[1] & 0xf0) | ((new_len & 0x0f00) >> 8);
+    buffer[2] = new_len & 0xff;
+
+    // fix the checksum
+    unsigned int crc = mpegts_crc32(buffer, pos);
+    buffer[pos++] = (crc & 0xff000000) >> 24;
+    buffer[pos++] = (crc & 0x00ff0000) >> 16;
+    buffer[pos++] = (crc & 0x0000ff00) >> 8;
+    buffer[pos++] = (crc & 0x000000ff);
+
+    // pad the rest of the packet with 0xff
+    memset(buffer + pos, 0xff, pkt_len - pos);
+
+    return true;
+}
+
+bool HDTVRecorder::RewritePMT(unsigned char *buffer, int new_pid, int pkt_len)
+{
+    // TODO: if it's possible for a PMT to span packets, then this function
+    // doesn't know how to deal with anything after the first packet.  On the
+    // other hand, neither does ffmpeg as near as I can tell.
+    
+    int pos = 8;
+    int pid;
+    int sec_len = ((buffer[1] & 0x0f) << 8) + buffer[2];
+    sec_len += 3;  // adjust for 3 header bytes
+
+    // make sure section doesn't span packet bounds
+    if (sec_len > pkt_len)
+        sec_len = pkt_len;
+
+    // rewrite program number to 1
+    buffer[3] = 0x00;
+    buffer[4] = 0x01;
+    pos += 2;
+
+    // skip program info
+    if (buffer[pos] == 0xff)
+        return false;  // premature end of packet
+    pos += 2 + (((buffer[pos] << 8) | buffer[pos+1]) & 0x0fff);
+
+    video_pid = audio_pid = -1;
+    // rewrite other pids
+    while (pos < sec_len - 4) {
+        if (buffer[pos] == 0xff)
+            break;  // hit end of packet, ok here
+        int stream_type = (int)buffer[pos];
+        pos++;
+
+        pid = ((buffer[pos] << 8) | buffer[pos+1]) & 0x1fff;
+        if (stream_type == 0x02) {
+            video_pid = pid;
+            pid = VIDEO_PID(new_pid);
+        } 
+        else if ((stream_type == 0x81 | stream_type == 0x04) && (audio_pid < 0)) {
+            audio_pid = pid;
+            pid = AUDIO_PID(new_pid);
+        }
+
+        buffer[pos] = ((pid & 0x1f00) >> 8) | 0xe0;
+        buffer[pos+1] = pid & 0x00ff;
+        pos += 2;
+
+        if (buffer[pos] == 0xff)
+            return false;  // premature end of packet
+        // bounds checked at top of while loop
+        pos += 2 + (((buffer[pos] << 8) | buffer[pos+1]) & 0x0fff);
+    }
+
+    // rewrite pcr_pid
+    pid = ((buffer[8] << 8) | buffer[9]) & 0x1fff;
+    if (pid == video_pid) {
+        pid = VIDEO_PID(new_pid);
+    }
+    else if (pid == audio_pid) {
+        pid = AUDIO_PID(new_pid);
+    }
+    else {
+        return false;  // don't know how to rewrite
+    }
+    buffer[8] = ((pid & 0x1f00) >> 8) | 0xe0;
+    buffer[9] = pid & 0x00ff;
+
+    // fix the checksum
+    unsigned int crc = mpegts_crc32(buffer, sec_len - 4);
+    buffer[sec_len - 4] = (crc & 0xff000000) >> 24;
+    buffer[sec_len - 3] = (crc & 0x00ff0000) >> 16;
+    buffer[sec_len - 2] = (crc & 0x0000ff00) >> 8;
+    buffer[sec_len - 1] = (crc & 0x000000ff);
+
+    return true;
+}
+
+    
 int HDTVRecorder::ProcessData(unsigned char *buffer, int len)
 {
     int pos = 0;
@@ -512,8 +667,8 @@ int HDTVRecorder::ProcessData(unsigned char *buffer, int len)
             // PID 0: Program Association Table -- lists all other
             // PIDs that make up the program(s) in the whole stream.
             // Based on info in this table, and on which subprogram
-            // the user // desires, we should determine which PIDs'
-            // payloads to write // to the ring buffer.
+            // the user desires, we should determine which PIDs'
+            // payloads to write to the ring buffer.
 
             // Example PAT scan code is in the pcHDTV's dtvscan.c,
             // demux_ts_parse_pat
@@ -524,10 +679,39 @@ int HDTVRecorder::ProcessData(unsigned char *buffer, int len)
             // PIDs we are looking for, and can thus "tune" the
             // subprogram more quickly.
 
-            // For now we're using the dirty hack below instead.
-            
-            // decoder needs PAT, write it to the stream
-            ringBuffer->Write(&buffer[packet_start_pos], 188);
+            // We rewrite the PAT to describe just the one
+            // stream we are recording.  Always use the same set of
+            // PIDs so the decoder has an easier time following
+            // channel changes.
+            //
+            // Basically, the output PMT is pid 0x10, video is 0x11 and
+            // audio is 0x14.
+            //
+            // sec_start should pretty much always be pos + 1, but
+            // just in case...
+            int sec_start = pos + buffer[pos] + 1;
+            int sec_len = (buffer[sec_start + 1] & 0x0f) << 8 | buffer[sec_start + 2];
+            int i;
+            pmt_pid = -1;
+
+            for (i = sec_start + 8; i < sec_start + 3 + sec_len - 4; i += 4) {
+                int prog_num = (buffer[i] << 8) | buffer[i + 1];
+                int prog_pid = (buffer[i + 2] & 0x0e) << 8 | buffer[i + 3];
+                if (prog_num == desired_program) {
+                    pmt_pid = prog_pid;
+                    break;
+                }
+            }
+            if (pmt_pid == -1) {
+                pmt_pid = (buffer[sec_start + 8 + 2] & 0x0e) << 8 |
+                                buffer[sec_start + 8 + 3];
+            }
+            output_base_pid = 16;
+
+            // write to ringbuffer if pids gets rewritten successfully.
+            if (RewritePAT(&buffer[sec_start], output_base_pid,
+                           packet_end_pos - sec_start))
+                ringBuffer->Write(&buffer[packet_start_pos], 188);
         }
         else if (pid == psip_pid)
         {
@@ -546,40 +730,42 @@ int HDTVRecorder::ProcessData(unsigned char *buffer, int len)
             FindKeyframes(buffer, packet_start_pos, pos, 
                     adaptation_field_control, payload_unit_start_indicator);
             // decoder needs video, of course (just this PID)
-            ringBuffer->Write(&buffer[packet_start_pos], 188);
+            if (gopset || firstgoppos) 
+            {
+                 // delay until first GOP to avoid decoder crash on res change
+                RewritePID(&(buffer[packet_start_pos]), 
+                           VIDEO_PID(output_base_pid));
+                ringBuffer->Write(&buffer[packet_start_pos], 188);
+            }
         }
         else if (pid == audio_pid)
         {
             // decoder needs audio, of course (just this PID)
-            ringBuffer->Write(&buffer[packet_start_pos], 188);
+            if (gopset || firstgoppos) 
+            {
+                RewritePID(&(buffer[packet_start_pos]), 
+                           AUDIO_PID(output_base_pid));
+                ringBuffer->Write(&buffer[packet_start_pos], 188);
+            }
         }
-        else if (pid == base_pid)
+        else if (pid == pmt_pid)
         {
             // decoder needs base PID
-            ringBuffer->Write(&buffer[packet_start_pos], 188);
-        }
-        else 
-        {
-            // Not a PID we're watching
-            
-            // As a hack until we start decoding PAT, find the lowest
-            // video PID in the first 50 packets and record only that
-            // stream
-            if ((pid & 0xff01) == 0x0001 && !video_pid) 
-            {
-                if (pid < lowest_video_pid)
-                    lowest_video_pid = pid;
-                video_pid_packets++;
-                if (video_pid_packets >= 50) 
+            int sec_start = pos + buffer[pos] + 1;
+            RewritePID(&(buffer[packet_start_pos]), output_base_pid);
+
+            // if it's a PMT table, rewrite the PIDs contained in it too
+            if (buffer[sec_start] == 0x02) {
+                if (RewritePMT(&(buffer[sec_start]), output_base_pid,
+                               packet_end_pos - sec_start))
                 {
-                    // n.b. these PID relationships are only a
-                    // recommendation from ATSC, but seem to be
-                    // universal
-                    video_pid = lowest_video_pid;
-                    audio_pid = video_pid + 3;
-                    base_pid = lowest_video_pid - 1;
+                    ringBuffer->Write(&buffer[packet_start_pos], 188);
                 }
             }
+            else {
+                // some other kind of packet?  possible?  do we care?
+                ringBuffer->Write(&buffer[packet_start_pos], 188);
+            }
         }
         // Advance to next TS packet
         pos = packet_end_pos;
@@ -598,10 +784,9 @@ void HDTVRecorder::Reset(void)
     framesWritten = 0;
     gopset = false;
     firstgoppos = 0;
-    video_pid = 0;
-    audio_pid = 0;
-    base_pid = 0;
     ts_packets = 0;
+    pmt_pid = -1;
+    video_pid = audio_pid = -1;
     lowest_video_pid = 0x1fff;
     video_pid_packets = 0;
     
@@ -676,3 +861,29 @@ void HDTVRecorder::GetBlankFrameMap(QMap<long long, int> &blank_frame_map)
 {
     (void)blank_frame_map;
 }
+
+void HDTVRecorder::ChannelNameChanged(const QString& new_chan)
+{
+    RecorderBase::ChannelNameChanged(new_chan);
+    // look up freqid
+    pthread_mutex_lock(db_lock);
+    QString thequery = QString("SELECT freqid "
+                               "FROM channel WHERE channum = \"%1\";")
+        .arg(curChannelName);
+    QSqlQuery query = db_conn->exec(thequery);
+    if (!query.isActive())
+        MythContext::DBError("fetchtuningparamschanid", query);
+    if (query.numRowsAffected() <= 0)
+    {
+        pthread_mutex_unlock(db_lock);
+        return;
+    }
+    query.next();
+    QString freqid(query.value(0).toString());
+    pthread_mutex_unlock(db_lock);
+    int pos = freqid.find('-');
+    if (pos != -1) 
+        desired_program = atoi(freqid.mid(pos+1).ascii());
+    else
+        desired_program = 1; // default to program #1
+}
