@@ -38,13 +38,15 @@ InfoDialog::InfoDialog(ProgramInfo *pginfo, MythMainWindow *parent,
                        const char *name)
           : MythDialog(parent, name)
 {
+    myinfo = new ProgramInfo(*pginfo);
+
     int mediumfont = gContext->GetMediumFontSize();
 
     QVBoxLayout *vbox = new QVBoxLayout(this, (int)(20 * wmult));
 
-    if (pginfo)
+    if (myinfo)
     {
-        QGridLayout *grid = pginfo->DisplayWidget(NULL, this);
+        QGridLayout *grid = myinfo->DisplayWidget(NULL, this);
         vbox->addLayout(grid);
     }
 
@@ -53,8 +55,8 @@ InfoDialog::InfoDialog(ProgramInfo *pginfo, MythMainWindow *parent,
     f->setLineWidth((int)(4 * hmult));
     vbox->addWidget(f);    
 
-    programtype = pginfo->IsProgramRecurring();
-    recordstatus = pginfo->GetProgramRecordingStatus(QSqlDatabase::database());
+    programtype = myinfo->IsProgramRecurring();
+    recordstatus = myinfo->GetProgramRecordingStatus(QSqlDatabase::database());
 
     if (recordstatus == kTimeslotRecord && programtype == 0)
     {
@@ -74,14 +76,7 @@ InfoDialog::InfoDialog(ProgramInfo *pginfo, MythMainWindow *parent,
     lview->setFixedHeight((int)(225 * hmult));
     lview->header()->hide();
 
-    connect(lview, SIGNAL(returnPressed(QListViewItem *)), this,
-            SLOT(selected(QListViewItem *)));
-    connect(lview, SIGNAL(spacePressed(QListViewItem *)), this,
-            SLOT(selected(QListViewItem *)));
-    connect(lview, SIGNAL(infoPressed(QListViewItem *)), this,
-            SLOT(advancedEdit(QListViewItem *)));
-    connect(lview, SIGNAL(numberPressed(QListViewItem *, int)), this,
-            SLOT(numberPress(QListViewItem *, int)));
+    lview->installEventFilter(this);
 
     RecListItem *item = new RecListItem(lview, tr("Record this program whenever"
                                         " it's shown anywhere"), kAllRecord);
@@ -148,9 +143,13 @@ InfoDialog::InfoDialog(ProgramInfo *pginfo, MythMainWindow *parent,
 
     lview->setFocus();
  
-    myinfo = pginfo;
 }
 
+InfoDialog::~InfoDialog()
+{
+    delete myinfo;
+} 
+
 QLabel *InfoDialog::getDateLabel(ProgramInfo *pginfo)
 {
     QDateTime startts = pginfo->startts;
@@ -168,6 +167,42 @@ QLabel *InfoDialog::getDateLabel(ProgramInfo *pginfo)
     return date;
 }
 
+bool InfoDialog::eventFilter(QObject *o, QEvent *e)
+{
+    (void)o;
+
+    if (e->type() != QEvent::KeyPress)
+        return false;
+
+    QKeyEvent *ke = (QKeyEvent *)e;
+
+    bool handled = false;
+    QStringList actions;
+    gContext->GetMainWindow()->TranslateKeyPress("qt", ke, actions);
+
+    for (unsigned int i = 0; i < actions.size() && !handled; i++)
+    {
+        QString action = actions[i];
+        handled = true;
+
+        if (action == "MENU" || action == "INFO")
+            advancedEdit(lview->currentItem());
+        else if (action == "SELECT")
+            selected(lview->currentItem());
+        else if (action == "0" || action == "1" || action == "2" ||
+                 action == "3" || action == "4" || action == "5" ||
+                 action == "6" || action == "7" || action == "8" ||
+                 action == "9")
+        {
+            numberPress(lview->currentItem(), action.toInt());
+        }
+        else
+            handled = false;
+    }
+
+    return handled;
+}
+
 void InfoDialog::selected(QListViewItem *selitem)
 {
     RecordingType currentSelected = kNotRecording;
