@@ -240,7 +240,7 @@ int NuppelDecoder::OpenFile(RingBuffer *rbuffer, bool novideo,
         }
     }
 
-    if (usingextradata && extradata.seektable_offset > 0 && !disablevideo)
+    if (usingextradata && extradata.seektable_offset > 0)
     {
         long long currentpos = ringBuffer->GetTotalReadPosition();
         struct rtframeheader seek_frameheader;
@@ -568,7 +568,7 @@ bool NuppelDecoder::InitAVCodec(int codec)
         return false;
     }
 
-    if (mpa_codec->capabilities & CODEC_CAP_DR1)
+    if (mpa_codec->capabilities & CODEC_CAP_DR1 && codec != CODEC_ID_MJPEG)
         directrendering = true;
 
     if (mpa_ctx)
@@ -724,6 +724,26 @@ bool NuppelDecoder::DecodeFrame(struct rtframeheader *frameheader,
             return false;
         }
 
+/* XXX: Broken
+        if (mpa_pic->qscale_table != NULL && mpa_pic->qstride > 0)
+        {
+            int tablesize = mpa_pic->qstride * ((video_height + 15) / 16);
+
+            if (frame->qstride != mpa_pic->qstride ||
+                frame->qscale_table == NULL)
+            {
+                frame->qstride = mpa_pic->qstride;
+
+                if (frame->qscale_table)
+                    delete [] frame->qscale_table;
+
+                frame->qscale_table = new unsigned char[tablesize]; 
+            }
+
+            memcpy(frame->qscale_table, mpa_pic->qscale_table, tablesize);
+        }
+*/
+
         if (directrendering)
             return true;
 
