@@ -20,6 +20,7 @@ using namespace std;
 #include "osdsurface.h"
 #include "mythcontext.h"
 #include "libmyth/oldsettings.h"
+#include "udpnotify.h"
 
 OSD::OSD(int width, int height, int frint, const QString &font, 
          const QString &ccfont, const QString &prefix, const QString &osdtheme,
@@ -52,6 +53,8 @@ OSD::OSD(int width, int height, int frint, const QString &font,
 
     setList = new vector<OSDSet *>;
 
+    fontSizeType = gContext->GetSetting("OSDThemeFontSizeType", "default");
+    
     themepath = FindTheme(osdtheme);
 
     if (themepath == "")
@@ -120,7 +123,6 @@ void OSD::SetDefaults(void)
     {
         QString name = "cc_font";
         int fontsize = 480 / 27;
-        fontsize = (int)(fontsize * hmult);
 
         ccfont = LoadFont(ccfontname, fontsize);
 
@@ -148,6 +150,8 @@ void OSD::SetDefaults(void)
 void OSD::Reinit(int width, int height, int frint, int dispx, int dispy, 
                  int dispw, int disph)
 {
+    osdlock.lock();
+
     vid_width = width;
     vid_height = height;
     if (frint != -1)
@@ -166,7 +170,7 @@ void OSD::Reinit(int width, int height, int frint, int dispx, int dispy,
     {
         TTFFont *font = (*fonts);
         if (font)
-            font->Reinit(vid_width, vid_height);
+            font->Reinit(vid_width, vid_height, hmult);
     }
 
     QMap<QString, OSDSet *>::iterator sets = setMap.begin();
@@ -179,7 +183,9 @@ void OSD::Reinit(int width, int height, int frint, int dispx, int dispy,
     }
 
     delete drawSurface;
-    drawSurface = new OSDSurface(displaywidth, displayheight);
+    drawSurface = new OSDSurface(width, height);
+
+    osdlock.unlock();
 }
 
 QString OSD::FindTheme(QString name)
@@ -207,7 +213,7 @@ TTFFont *OSD::LoadFont(QString name, int size)
 {
     QString fullname = QDir::homeDirPath() + "/.mythtv/" + name;
     TTFFont *font = new TTFFont((char *)fullname.ascii(), size, vid_width,
-                                vid_height);
+                                vid_height, hmult);
 
     if (font->isValid())
         return font;
@@ -216,7 +222,7 @@ TTFFont *OSD::LoadFont(QString name, int size)
     fullname = fontprefix + "/share/mythtv/" + name;
 
     font = new TTFFont((char *)fullname.ascii(), size, vid_width,
-                       vid_height);
+                       vid_height, hmult);
 
     if (font->isValid())
         return font;
@@ -226,7 +232,7 @@ TTFFont *OSD::LoadFont(QString name, int size)
     {
         fullname = themepath + "/" + name;
         font = new TTFFont((char *)fullname.ascii(), size, vid_width,
-                           vid_height);
+                           vid_height, hmult);
         if (font->isValid())
             return font;
     }
@@ -234,7 +240,8 @@ TTFFont *OSD::LoadFont(QString name, int size)
     delete font;
 
     fullname = name;
-    font = new TTFFont((char *)fullname.ascii(), size, vid_width, vid_height);
+    font = new TTFFont((char *)fullname.ascii(), size, vid_width, vid_height,
+                       hmult);
 
     if (font->isValid())
         return font;
@@ -263,6 +270,8 @@ void OSD::parseFont(QDomElement &element)
     QString name;
     QString fontfile = fontname;
     int size = -1;
+    int sizeSmall = -1;
+    int sizeBig = -1;    
     bool outline = false;
     QPoint shadowOffset = QPoint(0, 0);
     int color = 255;
@@ -284,6 +293,14 @@ void OSD::parseFont(QDomElement &element)
             {
                 size = getFirstText(info).toInt();
             }
+            else if (info.tagName() == "size:small")
+            {
+                sizeSmall = getFirstText(info).toInt();
+            }
+            else if (info.tagName() == "size:big")
+            {
+                sizeBig = getFirstText(info).toInt();
+            }
             else if (info.tagName() == "color")
             {
                 color = getFirstText(info).toInt();
@@ -318,14 +335,23 @@ void OSD::parseFont(QDomElement &element)
         exit(0);
     }
 
+    if (fontSizeType == "small")
+    {
+        if(sizeSmall > 0)
+            size = sizeSmall;
+    }
+    else if (fontSizeType == "big")
+    {
+        if(sizeBig > 0)
+            size = sizeBig;
+    }
+    
     if (size < 0) 
     {
         cerr << "Error: font size must be > 0\n";
         exit(0); 
     }
 
-    size = (int)(size * hmult);
-
     font = LoadFont(fontfile, size);
     if (!font)
     {
@@ -431,6 +457,10 @@ void OSD::parseTextArea(OSDSet *container, QDomElement &element)
     QString statictext = "";
     QString defaulttext = "";
     bool multiline = false;
+    bool scroller = false;
+    int scrollx = 0;
+    int scrolly = 0;
+    float linespacing = 1.5;
 
     QString name = element.attribute("name", "");
     if (name.isNull() || name.isEmpty())
@@ -471,6 +501,24 @@ void OSD::parseTextArea(OSDSet *container, QDomElement &element)
             {
                 defaulttext = getFirstText(info);
             }
+            else if (info.tagName() == "scroller")
+            {
+                if (getFirstText(info).lower() == "yes")
+                    scroller = true;
+            }
+            else if (info.tagName() == "linespacing")
+            {
+                linespacing = getFirstText(info).toFloat();
+            }
+            else if (info.tagName() == "scrollmovement")
+            {
+                QPoint pos = parsePoint(getFirstText(info));
+                pos.setX((int)(pos.x() * wmult));
+                pos.setY((int)(pos.y() * hmult));
+
+                scrollx = pos.x();
+                scrolly = pos.y();
+            }
             else
             {
                 cerr << "Unknown tag in textarea: " << info.tagName() << endl;
@@ -490,6 +538,7 @@ void OSD::parseTextArea(OSDSet *container, QDomElement &element)
     container->AddType(text);
 
     text->SetMultiLine(multiline);
+    text->SetLineSpacing(linespacing);
 
     if (altfont != "")
     {
@@ -516,6 +565,17 @@ void OSD::parseTextArea(OSDSet *container, QDomElement &element)
         else if (align.lower() == "right")
             text->SetRightJustified(true);
     }
+
+    if (scroller)
+    {
+        if (scrollx == 0 && scrolly == 0)
+        {
+            cerr << "Text area set as scrolling, but no movement\n";
+            scrollx = -5;
+        }
+
+        text->SetScrolling(scrollx, scrolly);
+    }
 }
 
 void OSD::parseSlider(OSDSet *container, QDomElement &element)
@@ -1081,14 +1141,30 @@ void OSD::UpdatePause(int position, QString slidertext)
     {
         OSDTypeText *type = (OSDTypeText *)container->GetType("slidertext");
         if (type)
-            type->SetText(slidertext);
+        {
+            if (type->GetText() != slidertext)
+            {
+                type->SetText(slidertext);
+                m_setsvisible = true;
+                changed = true;
+            }
+        }
+
         OSDTypeFillSlider *slider =
                       (OSDTypeFillSlider *)container->GetType("statusslider");
         if (slider)
-            slider->SetPosition(position);
+        {
+            if (slider->GetPosition() != position)
+            {
+                slider->SetPosition(position);
+                m_setsvisible = true;
+                changed = true;
+            }
+        }
 
-        m_setsvisible = true;
-        changed = true;
+        //test w/ this later.
+        //m_setsvisible = true; 
+        //changed = true;
     }
     osdlock.unlock();
 }
@@ -1438,18 +1514,45 @@ void OSD::HideAll(void)
     osdlock.unlock();
 }
 
-void OSD::HideSet(const QString &name)
+bool OSD::HideSet(const QString &name)
 {
+    bool ret = false;
     osdlock.lock();
 
     OSDSet *set = GetSet(name);
     if (set)
     {
+        if (set->Displaying())
+            ret = true;
         set->Hide();
     }
 
     changed = true;
     osdlock.unlock();
+    return ret;
+}
+
+bool OSD::HideSets(QStringList &name)
+{
+    bool ret = false;
+    osdlock.lock();
+
+    OSDSet *set;
+    QStringList::Iterator i = name.begin();
+    for (; i != name.end(); i++)
+    {
+        set = GetSet(*i);
+        if (set)
+        {
+            if (set->Displaying())
+                ret = true;
+            set->Hide();
+        }
+    }
+
+    changed = true;
+    osdlock.unlock();
+    return ret;
 }
 
 void OSD::UpdateEditText(const QString &seek_amount, const QString &deletemarker, 
@@ -1701,3 +1804,61 @@ void OSD::RemoveSet(OSDSet *set)
     delete set;
 }
 
+/* Ken Bass additions for notify_info container */
+void OSD::StartNotify(UDPNotifyOSDSet *notifySet, int displaytime)
+{
+    if (!notifySet)
+        return;
+
+    vector<UDPNotifyOSDTypeText *> *textList;
+
+    osdlock.lock();
+
+    OSDSet *container = GetSet(notifySet->GetName());
+    if (container)
+    {    
+        textList = notifySet->GetTypeList();
+    
+        vector<UDPNotifyOSDTypeText *>::iterator j = textList->begin();
+        for (; j != textList->end(); j++)
+        {
+            UDPNotifyOSDTypeText *type = (*j);
+            if (type)
+            {
+                OSDTypeText *osdtype = (OSDTypeText *)container->GetType(type->GetName());
+                if (osdtype)
+                    osdtype->SetText(type->GetText());
+            }
+        }
+      
+        if (displaytime > 0)
+            container->DisplayFor(displaytime * 1000000);
+        else
+            container->Display();
+  
+        m_setsvisible = true;
+        changed = true;
+    }
+
+    osdlock.unlock();
+}
+
+void OSD::ClearNotify(UDPNotifyOSDSet *notifySet)
+{
+    if (!notifySet)
+        return;
+
+    osdlock.lock();
+
+    OSDSet *container = GetSet(notifySet->GetName());
+    if (container)
+    {
+        container->ClearAllText();
+        container->Hide();
+        m_setsvisible = true;
+        changed = true;
+    }
+
+    osdlock.unlock();
+}
+
