@@ -29,6 +29,7 @@ class OSDTypeImage;
 class OSDTypePositionIndicator;
 class OSDSurface;
 class TV;
+class UDPNotifyOSDSet;
 
 class OSD : public QObject
 {
@@ -77,7 +78,8 @@ class OSD : public QObject
     bool Visible(void);
 
     void HideAll(void);
-    void HideSet(const QString &name);
+    bool HideSet(const QString &name);
+    bool HideSets(QStringList &name);
 
     void AddSet(OSDSet *set, QString name, bool withlock = true);
 
@@ -100,6 +102,9 @@ class OSD : public QObject
 
     void SetFrameInterval(int frint);
 
+    void StartNotify(UDPNotifyOSDSet *notifySet, int displaytime = 5);
+    void ClearNotify(UDPNotifyOSDSet *notifySet);
+
  private:
     void SetDefaults();
     TTFFont *LoadFont(QString name, int size); 
@@ -127,6 +132,7 @@ class OSD : public QObject
 
     QString fontname;
     QString ccfontname;
+    QString fontSizeType;
 
     int vid_width;
     int vid_height;
