@@ -31,6 +31,8 @@ OSDSet::OSDSet(const QString &name, bool cache, int screenwidth,
     m_timeleft = 0;
     m_allowfade = true;
 
+    m_draweveryframe = false;
+
     m_screenwidth = screenwidth;
     m_screenheight = screenheight;
     m_wmult = wmult;
@@ -218,7 +220,12 @@ void OSDSet::ClearAllText(void)
     {
         OSDType *type = (*iter);
         if (OSDTypeText *item = dynamic_cast<OSDTypeText *>(type))
-            item->SetText(QString(""));
+        {
+            QString defText = item->GetDefaultText();
+            if ((defText == "") ||
+                (defText.contains(QRegExp("%"))))
+                item->SetText(QString(""));
+        }
     }
 }
 
@@ -239,11 +246,16 @@ void OSDSet::SetTextByRegexp(QMap<QString, QString> &regexpMap)
             {
                 new_text = regexpMap[item->Name()];
             }
-            else
+            else if (new_text.contains(QRegExp("%.*%")))
                 for (; riter != regexpMap.end(); riter++)
                 {
-                    full_regex = "%" + riter.key().upper() + "%";
-                    new_text.replace(QRegExp(full_regex), riter.data());
+                   full_regex = "%" + riter.key().upper() + 
+                     "(\\|([^%|]*))?" + "(\\|([^%|]*))?" + "(\\|([^%]*))?%";
+                   if (riter.data() != "")
+                       new_text.replace(QRegExp(full_regex), 
+                                        "\\2" + riter.data() + "\\4");
+                   else
+                       new_text.replace(QRegExp(full_regex), "\\6");
                 }
 
             if (new_text != "")
@@ -312,6 +324,12 @@ void OSDSet::Hide(void)
     m_timeleft = -1;
     m_fadetime = 0;
     m_notimeout = false;
+
+    if (currentOSDFunctionalType)
+    {
+        emit OSDClosed(currentOSDFunctionalType);
+        currentOSDFunctionalType = 0;
+    }
 }
 
 void OSDSet::Draw(OSDSurface *surface, bool actuallydraw)
@@ -331,6 +349,15 @@ void OSDSet::Draw(OSDSurface *surface, bool actuallydraw)
 
     m_hasdisplayed = true;
 
+    if (m_wantsupdates &&
+        ((m_timeleft + 999999) / 1000000 != m_lastupdate))
+        m_needsupdate = true;
+    else
+        m_needsupdate = false;
+
+    if (m_draweveryframe)
+        m_needsupdate = true;
+
     if (m_notimeout)
         return;
 
@@ -365,11 +392,6 @@ void OSDSet::Draw(OSDSurface *surface, bool actuallydraw)
 
     if (m_timeleft <= 0 && m_fadetime <= 0)
         m_displaying = false;
-    else if (m_wantsupdates && 
-             ((m_timeleft + 999999) / 1000000 != m_lastupdate))
-        m_needsupdate = true;
-    else
-        m_needsupdate = false; 
 }
 
 //~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~~ 
@@ -400,6 +422,12 @@ OSDTypeText::OSDTypeText(const QString &name, TTFFont *font,
     m_centered = false;
     m_right = false;
     m_usingalt = false;
+
+    m_scroller = false;
+    m_scrollx = m_scrolly = 0;
+    m_scrollinit = false;
+
+    m_linespacing = 1.5;
 }
 
 OSDTypeText::OSDTypeText(const OSDTypeText &other)
@@ -414,6 +442,10 @@ OSDTypeText::OSDTypeText(const OSDTypeText &other)
     m_multiline = other.m_multiline;
     m_usingalt = other.m_usingalt;
     m_right = other.m_right;
+    m_scroller = other.m_scroller;
+    m_scrollx = other.m_scrollx;
+    m_scrolly = other.m_scrolly;
+    m_linespacing = other.m_linespacing;
 }
 
 OSDTypeText::~OSDTypeText()
@@ -428,12 +460,14 @@ void OSDTypeText::SetAltFont(TTFFont *font)
 void OSDTypeText::SetText(const QString &text)
 {
     m_message = text;
+    m_scrollinit = false;
 }
 
 void OSDTypeText::SetDefaultText(const QString &text)
 {
     m_message = text;
     m_default_msg = text;
+    m_scrollinit = false;
 }
 
 void OSDTypeText::Reinit(float wchange, float hchange)
@@ -457,6 +491,9 @@ void OSDTypeText::Draw(OSDSurface *surface, int fade, int maxfade, int xoff,
     if (m_message.contains("%d"))
         m_parent->SetWantsUpdates(true);
 
+    if (m_scroller)
+        m_parent->SetDrawEveryFrame(true);
+
     m_font->CalcWidth(m_message, &textlength);
 
     int maxlength = m_displaysize.width();
@@ -497,8 +534,8 @@ void OSDTypeText::Draw(OSDSurface *surface, int fade, int maxfade, int xoff,
                 (word == "\n"))
             {
                 QRect drawrect = m_displaysize;
-                drawrect.setTop(m_displaysize.top() + 
-                                m_font->Size() * (lines) * 3 / 2);
+                drawrect.setTop((int)(m_displaysize.top() + m_font->Size() * 
+                                      (lines) * m_linespacing));
                 DrawString(surface, drawrect, line, fade, maxfade, xoff, yoff);
                 length = 0;
 
@@ -525,10 +562,57 @@ void OSDTypeText::Draw(OSDSurface *surface, int fade, int maxfade, int xoff,
         }
 
         QRect drawrect = m_displaysize;
-        drawrect.setTop(m_displaysize.top() + m_font->Size() * (lines) * 3 / 2);
+        drawrect.setTop((int)(m_displaysize.top() + m_font->Size() * (lines) *
+                              m_linespacing));
         DrawString(surface, drawrect, line, fade, maxfade, xoff, yoff);
     }           
-    else        
+    else if (m_scroller)
+    {
+        if (!m_scrollinit)
+        {
+            if (m_scrollx < 0)
+            {
+                int numspaces = m_displaysize.width() / m_font->SpaceWidth();
+                for (int i = 0; i < numspaces; i++)
+                    m_message.prepend(" ");
+
+                int messagewidth = 0;
+                m_font->CalcWidth(m_message, &messagewidth);
+                m_scrollstartx = 0;
+                m_scrollendx = 0 - (messagewidth);
+                m_scrollposx = m_scrollstartx;
+                m_displaysize.setWidth(messagewidth);
+            }
+            else if (m_scrollx > 0)
+            {
+                int messagewidth = 0;
+                m_font->CalcWidth(m_message, &messagewidth);
+                m_scrollstartx = 0 - (messagewidth);
+                m_scrollendx = m_displaysize.width();
+                m_scrollposx = m_scrollstartx;
+                m_displaysize.setWidth(messagewidth);
+            }
+            
+            m_scrollstarty = 0;
+            m_scrollendy = 0;
+            m_scrollposy = 0;
+
+            m_scrollinit = true;
+        }
+        else
+        {
+            m_scrollposx += m_scrollx;
+            m_scrollposy += m_scrolly;
+
+            if ((m_scrollx < 0 && m_scrollposx < m_scrollendx) ||
+                (m_scrollx > 0 && m_scrollposx > m_scrollendx))
+                m_parent->Hide();
+        }
+
+        DrawString(surface, m_displaysize, m_message, fade, maxfade, 
+                   xoff + m_scrollposx, yoff + m_scrollposy);
+    }
+    else       
         DrawString(surface, m_displaysize, m_message, fade, maxfade, xoff, 
                    yoff);
 }           
