@@ -153,27 +153,42 @@ void ProgFinder::keyPressEvent(QKeyEvent *e)
     if (!allowkeypress)
         return;
 
-    switch (e->key())
+    bool handled = false;
+
+    QStringList actions;
+    gContext->GetMainWindow()->TranslateKeyPress("TV Frontend", e, actions);
+
+    for (unsigned int i = 0; i < actions.size() && !handled; i++)
     {
-        case Key_Left: case Key_A: cursorLeft(); break;
-        case Key_Right: case Key_D: cursorRight(); break;
-        case Key_Down: case Key_S: cursorDown(); break;
-        case Key_Up: case Key_W: cursorUp(); break;
+        QString action = actions[i];
+        handled = true;
 
-        case Key_I: case Key_Space:
-        case Key_Enter: case Key_Return: select(); break;
-
-        case Key_R: quickRecord(); break;
-
-        case Key_PageUp: case Key_3: pageUp(); break;
-        case Key_PageDown: case Key_9: pageDown(); break;
-
-        case Key_4: showGuide(); break;
-
-        case Key_C: case Key_M: case Key_Escape: escape(); break;
- 
-        default: MythDialog::keyPressEvent(e);
+        if (action == "UP")
+            cursorUp();
+        else if (action == "DOWN")
+            cursorDown();
+        else if (action == "LEFT")
+            cursorLeft();
+        else if (action == "RIGHT")
+            cursorRight();
+        else if (action == "PAGEUP")
+            pageUp();
+        else if (action == "PAGEDOWN")
+            pageDown();
+        else if (action == "SELECT" || action == "INFO")
+            select();
+        else if (action == "MENU" || action == "ESCAPE")
+            escape();
+        else if (action == "TOGGLERECORD")
+            quickRecord();
+        else if (action == "4")
+            showGuide();
+        else
+            handled = false;
     }
+
+    if (!handled)
+        MythDialog::keyPressEvent(e);
 }
 
 void ProgFinder::updateBackground(void)
