@@ -54,45 +54,34 @@ void RemoteEncoder::SendReceiveStringList(QStringList &strlist)
     pthread_mutex_lock(&lock);
 
     WriteStringList(controlSock, strlist);
-    ReadStringList(controlSock, strlist);
+    if (!ReadStringList(controlSock, strlist, true))
+    {
+        cerr << "Remote encoder not responding.\n";
+    }
 
     pthread_mutex_unlock(&lock);
 }
 
-QSocket *RemoteEncoder::openControlSocket(const QString &host, short port)
+QSocketDevice *RemoteEncoder::openControlSocket(const QString &host, short port)
 {
-    qApp->lock();
-    QSocket *sock = new QSocket();
-    sock->connectToHost(host, port);
-    qApp->unlock();
-
-    int num = 0;
-    while (sock->state() == QSocket::HostLookup ||
-           sock->state() == QSocket::Connecting)
+    QSocketDevice *sock = new QSocketDevice(QSocketDevice::Stream);
+    if (!connectSocket(sock, host, port))
     {
-        usleep(50);
-        num++;
-        if (num > 100)
-        {
-            cerr << "Connection timed out.\n";
-            exit(0);
-        }
+        cerr << "Connection timed out.\n";
+        delete sock;
+        sock = NULL;
     }
-
-    if (sock->state() != QSocket::Connected)
+    else
     {
-        VERBOSE(VB_GENERAL, "Could not connect to server");
-        return NULL;
-    }
-
-    QString hostname = gContext->GetHostName();
+        QString hostname = gContext->GetHostName();
  
-    QStringList strlist;
-
-    strlist = QString("ANN Playback %1 %2").arg(hostname).arg(false);
-    WriteStringList(sock, strlist);
-    ReadStringList(sock, strlist);
+        QStringList strlist;
 
+        strlist = QString("ANN Playback %1 %2").arg(hostname).arg(false);
+        WriteStringList(sock, strlist);
+        ReadStringList(sock, strlist, true);
+    }    
+    
     return sock;
 }
 
@@ -380,6 +369,20 @@ bool RemoteEncoder::CheckChannel(QString channel)
     return retval;
 }
 
+bool RemoteEncoder::CheckChannelPrefix(QString channel, bool &unique) 
+{
+    QStringList strlist = QString("QUERY_RECORDER %1").arg(recordernum);
+    strlist << "CHECK_CHANNEL_PREFIX";
+    strlist << channel;
+
+    SendReceiveStringList(strlist);
+
+    bool retval = strlist[0].toInt();
+    unique = strlist[1].toInt();
+
+    return retval;
+}
+
 void RemoteEncoder::GetNextProgram(int direction,
                                    QString &title, QString &subtitle,
                                    QString &desc, QString &category,
@@ -406,6 +409,27 @@ void RemoteEncoder::GetNextProgram(int direction,
     iconpath = strlist[7];
     channelname = strlist[8];
     chanid = strlist[9];
+
+    if (title == " ")
+        title = "";
+    if (subtitle == " ")
+        subtitle = "";
+    if (desc == " ")
+        desc = "";
+    if (category == " ")
+        category = "";
+    if (starttime == " ")
+        starttime = "";
+    if (endtime == " ")
+        endtime = "";
+    if (callsign == " ")
+        callsign = "";
+    if (iconpath == " ")
+        iconpath = "";
+    if (channelname == " ")
+        channelname = "";
+    if (chanid == " ")
+        chanid = "";
 }
 
 void RemoteEncoder::GetChannelInfo(QString &title, QString &subtitle,
@@ -430,6 +454,27 @@ void RemoteEncoder::GetChannelInfo(QString &title, QString &subtitle,
     channelname = strlist[8];
     chanid = strlist[9];
 
+    if (title == " ")
+        title = "";
+    if (subtitle == " ")
+        subtitle = "";
+    if (desc == " ")
+        desc = "";
+    if (category == " ")
+        category = "";
+    if (starttime == " ")
+        starttime = "";
+    if (endtime == " ")
+        endtime = "";
+    if (callsign == " ")
+        callsign = "";
+    if (iconpath == " ")
+        iconpath = "";
+    if (channelname == " ")
+        channelname = "";
+    if (chanid == " ")
+        chanid = "";
+
     lastchannel = channelname;
 }
 
