@@ -6,7 +6,7 @@
 #include <qmap.h>
 
 class ProgramInfo;
-class QSocket;
+class QSocketDevice;
 
 class RemoteEncoder
 {
@@ -47,6 +47,7 @@ class RemoteEncoder
     void ToggleChannelFavorite(void);
     void SetChannel(QString channel);
     bool CheckChannel(QString channel);
+    bool CheckChannelPrefix(QString channel, bool &unique);
     void GetNextProgram(int direction,
                         QString &title, QString &subtitle, QString &desc, 
                         QString &category, QString &starttime, QString &endtime,
@@ -61,12 +62,12 @@ class RemoteEncoder
     QString GetCurrentChannel(void);
  
   private:
-    QSocket *openControlSocket(const QString &host, short port);
+    QSocketDevice *openControlSocket(const QString &host, short port);
     void SendReceiveStringList(QStringList &strlist);
 
     int recordernum;
 
-    QSocket *controlSock;
+    QSocketDevice *controlSock;
     pthread_mutex_t lock;
 
     QString remotehost;
