@@ -83,12 +83,21 @@ void RemoteStopRecording(ProgramInfo *pginfo)
     gContext->SendReceiveStringList(strlist);
 }
 
-void RemoteDeleteRecording(ProgramInfo *pginfo)
+void RemoteDeleteRecording(ProgramInfo *pginfo, bool forgetHistory)
 {
-    QStringList strlist = QString("DELETE_RECORDING");
+    QStringList strlist;
+    strlist = QString("DELETE_RECORDING");
     pginfo->ToStringList(strlist);
 
     gContext->SendReceiveStringList(strlist);
+
+    if (forgetHistory)
+    {
+        strlist = QString("FORGET_RECORDING");
+        pginfo->ToStringList(strlist);
+
+        gContext->SendReceiveStringList(strlist);
+    }
 }
 
 bool RemoteGetAllPendingRecordings(vector<ProgramInfo *> &recordinglist)
@@ -166,7 +175,7 @@ RemoteEncoder *RemoteRequestRecorder(void)
 {
     QStringList strlist = "GET_FREE_RECORDER";
 
-    if (!gContext->SendReceiveStringList(strlist))
+    if (!gContext->SendReceiveStringList(strlist, true))
         return NULL;
 
     int num = strlist[0].toInt();
@@ -274,4 +283,39 @@ int RemoteGetRecordingMask(void)
     return mask;
 }
 
+int RemoteCheckForRecording(ProgramInfo *pginfo)
+{  //returns recordernum if pginfo recording in progress, else 0
+    QStringList strlist = QString("CHECK_RECORDING");
+    pginfo->ToStringList(strlist);
+
+    gContext->SendReceiveStringList(strlist);
+
+    return strlist[0].toInt();
+}
+
+int RemoteGetRecordingStatus(ProgramInfo *pginfo, int overrecsecs,
+                             int underrecsecs)
+{ //returns 0: not recording, 1: recording, 2: underrecord, 3: overrecord
+    QDateTime curtime = QDateTime::currentDateTime();
+
+    int retval = 0;
+
+    if (pginfo)
+    {
+        if (curtime >= pginfo->startts.addSecs(-underrecsecs) &&
+            curtime < pginfo->endts.addSecs(overrecsecs))
+        {
+            if (curtime >= pginfo->startts && curtime < pginfo->endts)
+                retval = 1;
+            else if (curtime < pginfo->startts && 
+                     RemoteCheckForRecording(pginfo) > 0)
+                retval = 2;
+            else if (curtime > pginfo->endts && 
+                     RemoteCheckForRecording(pginfo) > 0)
+                retval = 3;
+        }
+    }
+
+    return retval;
+}
 
