@@ -9,6 +9,17 @@
 #include <qapplication.h>
 #include <qregexp.h>
 
+// Convert a RecordingType to a simple integer so it's specificity can
+// be compared to another.  Lower number means more specific.
+int RecTypePriority(RecordingType rectype)
+{
+    if (rectype == kChannelRecord ||
+        rectype == kAllRecord)
+        return rectype+3;
+    else
+        return rectype;
+}
+
 class SRSetting: public SimpleDBStorage {
 protected:
     SRSetting(const ScheduledRecording& _parent, QString name):
@@ -41,15 +52,15 @@ public:
         setLabel(QObject::tr("Schedule"));
         addSelection(QObject::tr("Do not record this program"),
                      QString::number(kNotRecording));
-        addSelection(QObject::tr("Record only this showing of the program"),
+        addSelection(QObject::tr("Record only this showing"),
                      QString::number(kSingleRecord));
-        addSelection(QObject::tr("Record this program in this timeslot every day"),
+        addSelection(QObject::tr("Record in this timeslot every day"),
                      QString::number(kTimeslotRecord));
-        addSelection(QObject::tr("Record this program whenever it's shown on this channel"),
+        addSelection(QObject::tr("Record at any time on this channel"),
                      QString::number(kChannelRecord));
-        addSelection(QObject::tr("Record this program whenever it's shown anywhere"),
+        addSelection(QObject::tr("Record at any time on any channel"),
                      QString::number(kAllRecord));
-        addSelection(QObject::tr("Record this program in this timeslot every week"),
+        addSelection(QObject::tr("Record in this timeslot every week"),
                      QString::number(kWeekslotRecord));
     };
 };
@@ -73,12 +84,15 @@ public:
     };
 };
 
-class SRRecordDups: public CheckBoxSetting, public SRSetting {
+class SRRecordDups: public ComboBoxSetting, public SRSetting {
 public:
     SRRecordDups(const ScheduledRecording& parent):
         SRSetting(parent, "recorddups") {
-        setLabel(QObject::tr("Allow recording even if duplicate episode"));
-        setValue(false);
+        setLabel(QObject::tr("Record duplicates"));
+        addSelection(QObject::tr("Never"), QString::number(kRecordDupsNever));
+        addSelection(QObject::tr("If deleted"),
+                     QString::number(kRecordDupsIfDeleted));
+        addSelection(QObject::tr("Always"), QString::number(kRecordDupsAlways));
     };
 };
 
@@ -86,7 +100,25 @@ class SRAutoExpire: public CheckBoxSetting, public SRSetting {
 public:
     SRAutoExpire(const ScheduledRecording& parent):
         SRSetting(parent, "autoexpire") {
-        setLabel(QObject::tr("Allow recordings to be Auto-Expired"));
+        setLabel(QObject::tr("Auto Expire"));
+    };
+};
+
+class SRPreRoll: public SpinBoxSetting, public SRSetting {
+public:
+    SRPreRoll(const ScheduledRecording& parent):
+        SpinBoxSetting(-60, 60, 10, true),
+        SRSetting(parent, "preroll") {
+        setLabel(QObject::tr("Pre-Roll Minutes"));
+    };
+};
+
+class SRPostRoll: public SpinBoxSetting, public SRSetting {
+public:
+    SRPostRoll(const ScheduledRecording& parent):
+        SpinBoxSetting(-60, 240, 10, true),
+        SRSetting(parent, "postroll") {
+        setLabel(QObject::tr("Post-Roll Minutes"));
     };
 };
 
@@ -173,12 +205,12 @@ public:
     };
 };
 
-class SRRank: public SpinBoxSetting, public SRSetting {
+class SRRecPriority: public SpinBoxSetting, public SRSetting {
 public:
-    SRRank(const ScheduledRecording& parent): 
+    SRRecPriority(const ScheduledRecording& parent): 
         SpinBoxSetting(-99, 99, 1),
-        SRSetting(parent, "rank") {
-        setLabel(QObject::tr("Rank"));
+        SRSetting(parent, "recpriority") {
+        setLabel(QObject::tr("Priority"));
         setValue(0);
     };
 };
@@ -198,6 +230,8 @@ ScheduledRecording::ScheduledRecording() {
     addChild(recorddups = new SRRecordDups(*this));
     addChild(autoexpire = new SRAutoExpire(*this));
     addChild(maxepisodes = new SRMaxEpisodes(*this));
+    addChild(preroll = new SRPreRoll(*this));
+    addChild(postroll = new SRPostRoll(*this));
     addChild(maxnewest = new SRMaxNewest(*this));
     addChild(channel = new SRChannel(*this));
     addChild(title = new SRTitle(*this));
@@ -208,7 +242,7 @@ ScheduledRecording::ScheduledRecording() {
     addChild(startDate = new SRStartDate(*this));
     addChild(endDate = new SREndDate(*this));
     addChild(category = new SRCategory(*this));
-    addChild(rank = new SRRank(*this));
+    addChild(recpriority = new SRRecPriority(*this));
 
     m_pginfo = NULL;
 }
@@ -224,7 +258,7 @@ void ScheduledRecording::fromProgramInfo(ProgramInfo* proginfo)
     endTime->setValue(proginfo->endts.time());
     endDate->setValue(proginfo->endts.date());
     category->setValue(proginfo->category);
-    rank->setValue(proginfo->rank.toInt());
+    recpriority->setValue(proginfo->recpriority.toInt());
     autoexpire->setValue(gContext->GetNumSetting("AutoExpireDefault", 0));
 }
 
@@ -236,8 +270,12 @@ void ScheduledRecording::findAllProgramsToRecord(QSqlDatabase* db,
 "program.title, program.subtitle, program.description, "
 "channel.channum, channel.callsign, channel.name, "
 "oldrecorded.starttime IS NOT NULL AS oldrecduplicate, program.category, "
-"record.rank, record.recorddups, "
-"recorded.starttime IS NOT NULL as recduplicate, record.type "
+"record.recpriority, record.recorddups, "
+"recorded.starttime IS NOT NULL as recduplicate, record.type, "
+"record.recordid, recordoverride.type, "
+"program.starttime - INTERVAL record.preroll minute, "
+"program.endtime + INTERVAL record.postroll minute, "
+"program.previouslyshown "
 "FROM record "
 " INNER JOIN channel ON (channel.chanid = program.chanid) "
 " INNER JOIN program ON (program.title = record.title) "
@@ -257,6 +295,16 @@ void ScheduledRecording::findAllProgramsToRecord(QSqlDatabase* db,
 "     AND "
 "    recorded.description IS NOT NULL AND recorded.description <> '' AND program.description = recorded.description"
 "  ) "
+" LEFT JOIN recordoverride ON "
+"  ( "
+"    record.recordid = recordoverride.recordid "
+"    AND program.chanid = recordoverride.chanid "
+"    AND program.starttime = recordoverride.starttime "
+"    AND program.endtime = recordoverride.endtime "
+"    AND program.title = recordoverride.title "
+"    AND program.subtitle = recordoverride.subtitle "
+"    AND program.description = recordoverride.description "
+"  ) "
 "WHERE "
 "((record.type = %1) " // allrecord
 " OR "
@@ -298,6 +346,7 @@ void ScheduledRecording::findAllProgramsToRecord(QSqlDatabase* db,
      {
          while (result.next()) {
              ProgramInfo *proginfo = new ProgramInfo;
+             proginfo->recording = true;
              proginfo->chanid = result.value(0).toString();
              proginfo->sourceid = result.value(1).toInt();
              proginfo->startts = result.value(2).toDateTime();
@@ -308,27 +357,51 @@ void ScheduledRecording::findAllProgramsToRecord(QSqlDatabase* db,
              proginfo->chanstr = result.value(7).toString();
              proginfo->chansign = result.value(8).toString();
              proginfo->channame = result.value(9).toString();
-
-             if (result.value(15).toInt() == kSingleRecord)
-             {
-                 // force single-recording to be non-duplicate
-                 proginfo->duplicate = false;
-             }
-             else
-             {
-                 // if recorddups is set then check if recording still exists
-                 // in recorded table otherwise check for dup in oldrecorded.
-                 if (result.value(13).toInt())
-                     proginfo->duplicate = result.value(14).toInt();
-                 else
-                     proginfo->duplicate = result.value(10).toInt();
-             }
-
-             if (proginfo->duplicate)
-                 proginfo->recording = false;
-
              proginfo->category = QString::fromUtf8(result.value(11).toString());
-             proginfo->rank = result.value(12).toString();
+             proginfo->recpriority = result.value(12).toString();
+             proginfo->recdups = RecordingDupsType(result.value(13).toInt());
+             proginfo->rectype = RecordingType(result.value(15).toInt());
+             proginfo->recordid = result.value(16).toInt();
+             proginfo->override = result.value(17).toInt();
+
+             proginfo->recstartts = result.value(18).toDateTime();
+             proginfo->recendts = result.value(19).toDateTime();
+
+             if (proginfo->recstartts >= proginfo->recendts)
+             {
+                 // pre/post-roll are invalid so ignore
+                 proginfo->recstartts = proginfo->startts;
+                 proginfo->recendts = proginfo->endts;
+             }
+
+             proginfo->repeat = result.value(20).toInt();
+
+             if (proginfo->override == 2)
+             {
+                 proginfo->recording = false;
+                 proginfo->norecord = nrManualOverride;
+             }
+             else if (proginfo->rectype != kSingleRecord &&
+                      proginfo->override != 1 &&
+                      proginfo->recdups != kRecordDupsAlways)
+             {
+                 if (proginfo->recdups == kRecordDupsIfDeleted)
+                 {
+                     if (result.value(14).toInt())
+                     {
+                         proginfo->recording = false;
+                         proginfo->norecord = nrCurrentRecording;
+                     }
+                 }
+                 else
+                 {
+                     if (result.value(10).toInt())
+                     {
+                         proginfo->recording = false;
+                         proginfo->norecord = nrPreviousRecording;
+                     }
+                 }
+             }
 
              // would save many queries to create and populate a
              // ScheduledRecording and put it in the proginfo at the
@@ -348,7 +421,6 @@ void ScheduledRecording::findAllProgramsToRecord(QSqlDatabase* db,
                  delete proginfo;
              else 
                  proglist.push_back(proginfo);
-             
          }
     }
     else if (!result.isActive())
@@ -361,8 +433,8 @@ void ScheduledRecording::findAllScheduledPrograms(QSqlDatabase* db,
     QString temptime, tempdate;
     QString query = QString("SELECT record.chanid, record.starttime, "
 "record.startdate, record.endtime, record.enddate, record.title, "
-"record.subtitle, record.description, record.rank, record.type, "
-"channel.name FROM record "
+"record.subtitle, record.description, record.recpriority, record.type, "
+"channel.name, record.recordid FROM record "
 "LEFT JOIN channel ON (channel.chanid = record.chanid) "
 "ORDER BY title ASC;");
 
@@ -373,10 +445,12 @@ void ScheduledRecording::findAllScheduledPrograms(QSqlDatabase* db,
         {
             ProgramInfo *proginfo = new ProgramInfo;
             proginfo->chanid = result.value(0).toString();
+            proginfo->rectype = RecordingType(result.value(9).toInt());
+            proginfo->recordid = result.value(11).toInt();
 
-            int type = result.value(9).toInt();
-            if (type == kSingleRecord || type == kTimeslotRecord ||
-                type == kWeekslotRecord) 
+            if (proginfo->rectype == kSingleRecord || 
+                proginfo->rectype == kTimeslotRecord ||
+                proginfo->rectype == kWeekslotRecord) 
             {
                 temptime = result.value(1).toString();
                 tempdate = result.value(2).toString();
@@ -398,10 +472,13 @@ void ScheduledRecording::findAllScheduledPrograms(QSqlDatabase* db,
             }
 
             proginfo->title = QString::fromUtf8(result.value(5).toString());
-            proginfo->subtitle = QString::fromUtf8(result.value(6).toString());
+            if (proginfo->rectype == kSingleRecord)
+                proginfo->subtitle = QString::fromUtf8(result.value(6).toString());
             proginfo->description = QString::fromUtf8(result.value(7).toString());
-            proginfo->rank = result.value(8).toString();
+            proginfo->recpriority = result.value(8).toString();
             proginfo->channame = result.value(10).toString();
+            proginfo->recstartts = proginfo->startts;
+            proginfo->recendts = proginfo->endts;
 
             if (proginfo->title == QString::null)
                 proginfo->title = "";
@@ -414,13 +491,18 @@ void ScheduledRecording::findAllScheduledPrograms(QSqlDatabase* db,
         }
 }
 
-
 bool ScheduledRecording::loadByProgram(QSqlDatabase* db,
                                        ProgramInfo* proginfo) {
-    QString sqltitle(proginfo->title);
-
     m_pginfo = proginfo;
 
+    if (proginfo->recordid)
+    {
+        loadByID(db, proginfo->recordid);
+        return true;
+    }
+
+    QString sqltitle(proginfo->title);
+
     // this doesn't have to be a QRegexp in qt 3.1+
     sqltitle.replace(QRegExp("\'"), "\\'");
     sqltitle.replace(QRegExp("\""), "\\\"");
@@ -538,6 +620,8 @@ void ScheduledRecording::save(QSqlDatabase* db) {
 void ScheduledRecording::remove(QSqlDatabase* db) {
     QString query = QString("DELETE FROM record WHERE recordid = %1").arg(getRecordID());
     db->exec(query);
+    query = QString("DELETE FROM recordoverride WHERE recordid = %1").arg(getRecordID());
+    db->exec(query);
 }
 
 void ScheduledRecording::signalChange(QSqlDatabase* db) {
@@ -607,8 +691,8 @@ void ScheduledRecording::doneRecording(QSqlDatabase* db,
                             "VALUES(%1,\"%2\",\"%3\",\"%4\",\"%5\",\"%6\","
                             "\"%7\");")
         .arg(proginfo.chanid)
-        .arg(proginfo.startts.toString(Qt::ISODate))
-        .arg(proginfo.endts.toString(Qt::ISODate))
+        .arg(proginfo.recstartts.toString(Qt::ISODate))
+        .arg(proginfo.recendts.toString(Qt::ISODate))
         .arg(sqltitle.utf8()) 
         .arg(sqlsubtitle.utf8())
         .arg(sqldescription.utf8())
@@ -616,11 +700,15 @@ void ScheduledRecording::doneRecording(QSqlDatabase* db,
 
     QSqlQuery result = db->exec(query);
     if (!result.isActive())
+    {
         MythContext::DBError("doneRecording", result);
-
-    // The addition of an entry to oldrecorded may affect near-future
-    // scheduling decisions, so recalculate
-    signalChange(db);
+    }
+    else
+    {
+        // The addition of an entry to oldrecorded may affect near-future
+        // scheduling decisions, so recalculate
+        signalChange(db);
+    }
 }
 
 void ScheduledRecording::forgetHistory(QSqlDatabase* db,
@@ -639,7 +727,15 @@ void ScheduledRecording::forgetHistory(QSqlDatabase* db,
         .arg(sqldescription.utf8());
     QSqlQuery result = db->exec(query);
     if (!result.isActive())
+    {
         MythContext::DBError("forgetHistory", result);
+    }
+    else
+    {
+        // The removal of an entry from oldrecorded may affect near-future
+        // scheduling decisions, so recalculate
+        signalChange(db);
+    }
 }
 
 MythDialog* ScheduledRecording::dialogWidget(MythMainWindow *parent, 
@@ -649,7 +745,7 @@ MythDialog* ScheduledRecording::dialogWidget(MythMainWindow *parent,
     gContext->GetScreenSettings(wmult, hmult);
 
     MythDialog* dialog = new ConfigurationDialogWidget(parent, name);
-    QVBoxLayout* vbox = new QVBoxLayout(dialog, (int)(20 * wmult));
+    QVBoxLayout* vbox = new QVBoxLayout(dialog, (int)(10 * wmult));
 
     if (m_pginfo)
     {
@@ -666,14 +762,16 @@ MythDialog* ScheduledRecording::dialogWidget(MythMainWindow *parent,
     vbox->addWidget(type->configWidget(this, dialog));
 
     QHBoxLayout* hbox = new QHBoxLayout(vbox, (int)(20 * wmult));
-    QVBoxLayout* vbox1 = new QVBoxLayout(hbox, (int)(20 * wmult));
-    QVBoxLayout* vbox2 = new QVBoxLayout(hbox, (int)(20 * wmult));
+    QVBoxLayout* vbox1 = new QVBoxLayout(hbox, (int)(10 * wmult));
+    QVBoxLayout* vbox2 = new QVBoxLayout(hbox, (int)(10 * wmult));
 
     vbox1->addWidget(profile->configWidget(this, dialog));
-    vbox1->addWidget(rank->configWidget(this, dialog));
+    vbox1->addWidget(recpriority->configWidget(this, dialog));
+    vbox1->addWidget(autoexpire->configWidget(this, dialog));
 
     vbox2->addWidget(recorddups->configWidget(this, dialog));
-    vbox2->addWidget(autoexpire->configWidget(this, dialog));
+    vbox2->addWidget(preroll->configWidget(this, dialog));
+    vbox2->addWidget(postroll->configWidget(this, dialog));
 
     vbox->addWidget(maxepisodes->configWidget(this, dialog));
     vbox->addWidget(maxnewest->configWidget(this, dialog));
@@ -777,8 +875,8 @@ void ScheduledRecording::setEnd(const QDateTime& end) {
     endDate->setValue(end.date());
 }
 
-void ScheduledRecording::setRank(const QString& newrank) {
-    rank->setValue(newrank.toInt());
+void ScheduledRecording::setRecPriority(const QString& newrecpriority) {
+    recpriority->setValue(newrecpriority.toInt());
 }
 
 QString ScheduledRecording::getProfileName(void) const {
