@@ -413,7 +413,7 @@ void TTFFont::DrawString(OSDSurface *surface, int x, int y,
 
    is_pixmap = 1;
 
-   y += fontsize;
+   y += loadedfontsize;
    
    width = maxx;
    height = maxy;
@@ -513,7 +513,8 @@ void TTFFont::KillFace(void)
       free(glyphs_cached);
 }
 
-TTFFont::TTFFont(char *file, int size, int video_width, int video_height)
+TTFFont::TTFFont(char *file, int size, int video_width, int video_height,
+                 float hmult)
 {
    FT_Error            error;
 
@@ -541,6 +542,7 @@ TTFFont::TTFFont(char *file, int size, int video_width, int video_height)
    vid_width = video_width;
    vid_height = video_height;
    m_file = file;
+   m_hmult = hmult;
 
    Init();
 }
@@ -559,13 +561,15 @@ void TTFFont::Init(void)
 	return;
    }
 
+   loadedfontsize = (int)(fontsize * m_hmult);
+
    if (vid_width != vid_height * 4 / 3)
    {
        xdpi = (int)(xdpi * 
               (float)(vid_width / (float)(vid_height * 4 / 3)));
    }
 
-   FT_Set_Char_Size(face, 0, fontsize * 64, xdpi, ydpi);
+   FT_Set_Char_Size(face, 0, loadedfontsize * 64, xdpi, ydpi);
 
    n = face->num_charmaps;
 
@@ -621,10 +625,11 @@ void TTFFont::Init(void)
    spacewidth = twidth - (mwidth * 2);
 }
 
-void TTFFont::Reinit(int width, int height)
+void TTFFont::Reinit(int width, int height, float hmult)
 {
     vid_width = width;
     vid_height = height;
+    m_hmult = hmult;
 
     KillFace();
     Init();
