@@ -23,20 +23,7 @@ using namespace std;
 #include "volumecontrol.h"
 #include "NuppelVideoPlayer.h"
 #include "programinfo.h"
-
-enum SeekSpeeds {
-  SSPEED_NORMAL_WITH_DISPLAY = 0,
-  SSPEED_SLOW_1,
-  SSPEED_SLOW_2,
-  SSPEED_NORMAL,
-  SSPEED_FAST_1,
-  SSPEED_FAST_2,
-  SSPEED_FAST_3,
-  SSPEED_FAST_4,
-  SSPEED_FAST_5,
-  SSPEED_FAST_6,
-  SSPEED_MAX
-};
+#include "udpnotify.h"
 
 struct SeekSpeedInfo {
     QString   dispString;
@@ -59,8 +46,104 @@ SeekSpeedInfo seek_speed_array[] =
     {"16X", 16.72, 132.00, 84.00}
 };
 
+const int SSPEED_NORMAL = 3;
+const int SSPEED_MAX = sizeof seek_speed_array / sizeof seek_speed_array[0];
+
 const int kMuteTimeout = 800;
 
+void TV::InitKeys(void)
+{
+    REG_KEY("TV Frontend", "PAGEUP", "Page Up", "3");
+    REG_KEY("TV Frontend", "PAGEDOWN", "Page Down", "9");
+    REG_KEY("TV Frontend", "DELETE", "Delete Program", "D");
+    REG_KEY("TV Frontend", "PLAYBACK", "Play Program", "P");
+    REG_KEY("TV Frontend", "TOGGLERECORD", "Toggle recording status of current "
+            "program", "R");
+    REG_KEY("TV Frontend", "DAYLEFT", "Page the program guide back one day", 
+            "Home,7");
+    REG_KEY("TV Frontend", "DAYRIGHT", "Page the program guide forward one day",
+            "End,1");
+    REG_KEY("TV Frontend", "PAGELEFT", "Page the program guide left",
+            ",,<");
+    REG_KEY("TV Frontend", "PAGERIGHT", "Page the program guide right",
+            ">,.");
+    REG_KEY("TV Frontend", "TOGGLEFAV", "Toggle the current channel as a "
+            "favorite", "?");
+    REG_KEY("TV Frontend", "NEXTFAV", "Toggle showing all channels or just "
+            "favorites in the program guide.", "/");
+    REG_KEY("TV Frontend", "CHANUPDATE", "Switch channels without exiting "
+            "guide in Live TV mode.", "X");
+
+
+
+    REG_KEY("TV Playback", "PAUSE", "Pause", "P");
+    REG_KEY("TV Playback", "SEEKFFWD", "Fast Forward", "Right");
+    REG_KEY("TV Playback", "SEEKRWND", "Rewind", "Left");
+    REG_KEY("TV Playback", "CHANNELUP", "Channel up", "Up");
+    REG_KEY("TV Playback", "CHANNELDOWN", "Channel down", "Down");
+    REG_KEY("TV Playback", "NEXTFAV", "Switch to the next favorite channel",
+            "/");
+    REG_KEY("TV Playback", "PREVCHAN", "Switch to the previous channel", "H");
+    REG_KEY("TV Playback", "JUMPFFWD", "Jump ahead", "PgDown");
+    REG_KEY("TV Playback", "JUMPRWND", "Jump back", "PgUp");
+    REG_KEY("TV Playback", "FFWDSTICKY", "Fast Forward (Sticky) or Forward one "
+            "frame while paused", ">,.");
+    REG_KEY("TV Playback", "RWNDSTICKY", "Rewind (Sticky) or Rewind one frame "
+            "while paused", ",,<");
+    REG_KEY("TV Playback", "TOGGLEINPUTS", "Toggle Inputs", "C");
+    REG_KEY("TV Playback", "SKIPCOMMERCIAL", "Skip Commercial", "Z,End");
+    REG_KEY("TV Playback", "SKIPCOMMBACK", "Skip Commercial (Reverse)",
+            "Q,Home");
+    REG_KEY("TV Playback", "TOGGLEBROWSE", "Toggle channel browse mode", "O");
+    REG_KEY("TV Playback", "TOGGLERECORD", "Toggle recording status of current "
+            "program", "R");
+    REG_KEY("TV Playback", "TOGGLEFAV", "Toggle the current channel as a "
+            "favorite", "?");
+    REG_KEY("TV Playback", "VOLUMEDOWN", "Volume down", "[,{,F10");
+    REG_KEY("TV Playback", "VOLUMEUP", "Volume up", "],},F11");
+    REG_KEY("TV Playback", "MUTE", "Mute", "|,\\,F9");
+    REG_KEY("TV Playback", "TOGGLEPIPMODE", "Toggle Picture-in-Picture mode",
+            "V");
+    REG_KEY("TV Playback", "TOGGLEPIPWINDOW", "Toggle active PiP window", "B");
+    REG_KEY("TV Playback", "SWAPPIP", "Swap the PiP window channels", "N");
+    REG_KEY("TV Playback", "TOGGLEASPECT", "Toggle the display aspect ratio",
+            "W");
+    REG_KEY("TV Playback", "TOGGLECC", "Toggle Closed Captioning/Teletext",
+            "T");
+    REG_KEY("TV Playback", "QUEUETRANSCODE", "Queue the current recording for "
+            "transcoding", "X");
+    REG_KEY("TV Playback", "SPEEDINC", "Increase the playback speed", "U");
+    REG_KEY("TV Playback", "SPEEDDEC", "Decrease the playback speed", "J");
+    REG_KEY("TV Playback", "TOGGLEPICCONTROLS", "Turn on the playback picture "
+            "adjustment controls", "F");
+    REG_KEY("TV Playback", "CONTRASTDOWN", "Decrease the recording contrast",
+            "F1");
+    REG_KEY("TV Playback", "CONTRASTUP", "Increase the recording contrast",
+            "F2");
+    REG_KEY("TV Playback", "BRIGHTDOWN", "Decrease the recording brightness",
+            "F3");
+    REG_KEY("TV Playback", "BRIGHTUP", "Increase the recording brightness",
+            "F4");
+    REG_KEY("TV Playback", "COLORDOWN", "Decrease the recording color", "F5");
+    REG_KEY("TV Playback", "COLORUP", "Increase the recording color", "F6");
+    REG_KEY("TV Playback", "HUEDOWN", "Decrease the recording hue", "F7");
+    REG_KEY("TV Playback", "HUEUP", "Increase the recording hue", "F8");
+    REG_KEY("TV Playback", "TOGGLEEDIT", "Start Edit Mode", "E");
+
+
+
+    REG_KEY("TV Editing", "CLEARMAP", "Clear editing cut points", "C,Q,Home");
+    REG_KEY("TV Editing", "LOADCOMMSKIP", "Load cut list from commercial skips",
+            "Z,End");
+    REG_KEY("TV Editing", "NEXTCUT", "Jump to the next cut point", "PgDown");
+    REG_KEY("TV Editing", "PREVCUT", "Jump to the previous cut point", "PgUp");
+    REG_KEY("TV Editing", "BIGJUMPREW", "Jump back 10x the normal amount",
+            ",,<");
+    REG_KEY("TV Editing", "BIGJUMPFWD", "Jump forward 10x the normal amount",
+            ">,.");
+    REG_KEY("TV Editing", "TOGGLEEDIT", "Exit out of Edit Mode", "E");
+}
+
 void *SpawnDecode(void *param)
 {
     NuppelVideoPlayer *nvp = (NuppelVideoPlayer *)param;
@@ -97,6 +180,7 @@ TV::TV(QSqlDatabase *db)
     wantsToQuit = true;
 
     myWindow = NULL;
+    udpnotify = NULL;
 
     gContext->addListener(this);
 
@@ -121,6 +205,7 @@ void TV::Init(bool createWindow)
     rewtime = gContext->GetNumSetting("RewindAmount", 5);
     jumptime = gContext->GetNumSetting("JumpAmount", 10);
     usePicControls = gContext->GetNumSetting("UseOutputPictureControls", 0);
+    smartChannelChange = gContext->GetNumSetting("SmartChannelChange", 0);
 
     recorder = piprecorder = activerecorder = NULL;
     nvp = pipnvp = activenvp = NULL;
@@ -137,7 +222,8 @@ void TV::Init(bool createWindow)
 
     if (createWindow)
     {
-        myWindow = new MythDialog(gContext->GetMainWindow(), "tv playback");
+        myWindow = new MythDialog(gContext->GetMainWindow(), 
+                                  "video playback window");
         myWindow->installEventFilter(this);
         myWindow->setNoErase();
         myWindow->show();
@@ -490,10 +576,15 @@ void TV::HandleStateChange(void)
     }
 
     if (!changed)
-        printf("Unknown state transition: %d to %d\n", internalState,
-                                                       nextState);
+    {
+        VERBOSE(VB_IMPORTANT, QString("Unknown state transition: %1 to %2")
+                .arg(internalState).arg(nextState));
+    }
     else
-        printf("Changing from %s to %s\n", origname.ascii(), statename.ascii());
+    {
+        VERBOSE(VB_GENERAL, QString("Changing from %1 to %2")
+                .arg(origname).arg(statename));
+    }
 
     internalState = tmpInternalState;
     changeState = false;
@@ -526,7 +617,8 @@ void TV::StartPlayerAndRecorder(bool startPlayer, bool startRecorder)
 
         frameRate = nvp->GetFrameRate();
         osd = nvp->GetOSD();
-        osd->SetUpOSDClosedHandler(this);
+        if (osd)
+            osd->SetUpOSDClosedHandler(this);
     }
 }
 
@@ -538,8 +630,7 @@ void TV::StopPlayerAndRecorder(bool closePlayer, bool closeRecorder)
         {
             prbuffer->StopReads();
             prbuffer->Pause();
-            while (!prbuffer->isPaused())
-                usleep(50);
+            prbuffer->WaitForPause();
         }
 
         if (nvp)
@@ -549,8 +640,7 @@ void TV::StopPlayerAndRecorder(bool closePlayer, bool closeRecorder)
         {
             piprbuffer->StopReads();
             piprbuffer->Pause();
-            while (!piprbuffer->isPaused())
-                usleep(50);
+            piprbuffer->WaitForPause();
         }
 
         if (pipnvp)
@@ -593,7 +683,9 @@ void TV::SetupPlayer(void)
     nvp->SetAudioDevice(gContext->GetSetting("AudioOutputDevice"));
     nvp->SetLength(playbackLen);
     nvp->SetExactSeeks(gContext->GetNumSetting("ExactSeeking"));
-    nvp->SetAutoCommercialSkip(gContext->GetNumSetting("AutoCommercialSkip"));
+
+    autoCommercialSkip = gContext->GetNumSetting("AutoCommercialSkip");
+    nvp->SetAutoCommercialSkip(autoCommercialSkip);
     nvp->SetCommercialSkipMethod(gContext->GetNumSetting("CommercialSkipMethod"));
 
     osd_display_time = gContext->GetNumSetting("OSDDisplayTime");
@@ -608,6 +700,10 @@ void TV::SetupPlayer(void)
         filters += "linearblend";
     }
 
+    if (filters.length() > 1)
+        filters += ",";
+    filters += gContext->GetSetting("CustomFilters");
+
     nvp->SetVideoFilters(filters);
 
     if (embedid > 0)
@@ -617,6 +713,12 @@ void TV::SetupPlayer(void)
         nvp->SetWatchingRecording(true);
 
     osd = NULL;
+
+    int udp_port = gContext->GetNumSetting("UDPNotifyPort");
+    if (udp_port > 0)
+        udpnotify = new UDPNotify(this, udp_port);
+    else
+        udpnotify = NULL;
 }
 
 void TV::SetupPipPlayer(void)
@@ -650,6 +752,9 @@ void TV::TeardownPlayer(void)
         delete nvp;
     }
 
+    if (udpnotify)
+        delete udpnotify;
+
     paused = false;
     doing_ff_rew = 0;
     ff_rew_index = SSPEED_NORMAL;
@@ -700,10 +805,11 @@ void *TV::EventThread(void *param)
 void TV::RunTV(void)
 { 
     paused = false;
-    int keypressed;
+    QKeyEvent *keypressed;
 
     stickykeys = gContext->GetNumSetting("StickyKeys");
     ff_rew_repos = gContext->GetNumSetting("FFRewRepos", 1);
+    ff_rew_reverse = gContext->GetNumSetting("FFRewReverse", 1);
     smartForward = gContext->GetNumSetting("SmartForward", 0);
 
     doing_ff_rew = 0;
@@ -747,14 +853,15 @@ void TV::RunTV(void)
 
         if (nvp)
         {
-            if (keyList.size() > 0)
+            if (keyList.count() > 0)
             { 
                 keyListLock.lock();
-                keypressed = keyList.front();
-                keyList.pop_front();
+                keypressed = keyList.first();
+                keyList.removeFirst();
                 keyListLock.unlock();
 
                 ProcessKeypress(keypressed);
+                delete keypressed;
             }
             else
                 RepeatFFRew();
@@ -785,7 +892,9 @@ void TV::RunTV(void)
 
         if (++updatecheck >= 20)
         {
-            if (osd && osd->Visible() && update_osd_pos &&
+            OSDSet *oset;
+            if (osd && (oset = osd->GetSet("status")) &&
+                oset->Displaying() && update_osd_pos &&
                 (internalState == kState_WatchingLiveTV || 
                  internalState == kState_WatchingRecording ||
                  internalState == kState_WatchingPreRecorded))
@@ -801,8 +910,12 @@ void TV::RunTV(void)
         if (internalState == kState_WatchingLiveTV ||
             internalState == kState_WatchingRecording)
         {
-            if (channelqueued && nvp->GetOSD() && !osd->Visible())
-                ChannelCommit();
+            if (channelqueued && nvp->GetOSD())
+            {
+                OSDSet *set = osd->GetSet("channel_number");
+                if (!set || !set->Displaying())
+                    ChannelCommit();
+            }
         }
     }
   
@@ -818,11 +931,11 @@ bool TV::eventFilter(QObject *o, QEvent *e)
     {
         case QEvent::KeyPress:
         {
-            QKeyEvent *k = (QKeyEvent *)e;
+            QKeyEvent *k = new QKeyEvent(*(QKeyEvent *)e);
   
             // can't process these events in the Qt event loop. 
             keyListLock.lock();
-            keyList.push_back(k->key());
+            keyList.append(k);
             keyListLock.unlock();
 
             return true;
@@ -833,45 +946,83 @@ bool TV::eventFilter(QObject *o, QEvent *e)
                 nvp->ExposeEvent();
             return true;
         }
+        case MythEvent::MythEventMessage:
+        {
+            customEvent((QCustomEvent *)e);
+            return true;
+        }
         default:
             return false;
     }
 }
 
-void TV::ProcessKeypress(int keypressed)
+void TV::ProcessKeypress(QKeyEvent *e)
 {
     bool was_doing_ff_rew = false;
 
     if (editmode)
     {   
-        nvp->DoKeypress(keypressed);
-        if (keypressed == Key_Escape || 
-            keypressed == Key_E || keypressed == Key_M)
+        if (!nvp->DoKeypress(e))
             editmode = nvp->GetEditMode();
+        if (!editmode)
+            nvp->SetPlaySpeed(1.0, true);
         return;
     }
 
+    QStringList actions;
+    QString action;
+    if (!gContext->GetMainWindow()->TranslateKeyPress("TV Playback", e, 
+                                                      actions))
+        return;
+
+    bool handled = false;
+
     if (browsemode)
     {
         int passThru = 0;
-        switch (keypressed)
+
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
         {
-            case Key_Up: BrowseDispInfo(BROWSE_UP); break;
-            case Key_Down: BrowseDispInfo(BROWSE_DOWN); break;
-            case Key_Left: BrowseDispInfo(BROWSE_LEFT); break;
-            case Key_Right: BrowseDispInfo(BROWSE_RIGHT); break;
+            action = actions[i];
+            handled = true;
 
-            case Key_Escape: BrowseEnd(false); break;
-
-            case Key_Space: case Key_Enter:
-            case Key_Return: BrowseEnd(true); break;
-
-            case Key_R: BrowseToggleRecord(); break;
-
-            case Key_BracketLeft: case Key_BracketRight:
-            case Key_Bar: passThru = 1; break;
-
-            case Key_W: passThru = 1; break;
+            if (action == "UP" || action == "CHANNELUP")
+                BrowseDispInfo(BROWSE_UP);
+            else if (action == "DOWN" || action == "CHANNELDOWN")
+                BrowseDispInfo(BROWSE_DOWN);
+            else if (action == "LEFT")
+                BrowseDispInfo(BROWSE_LEFT);
+            else if (action == "RIGHT")
+                BrowseDispInfo(BROWSE_RIGHT);
+            else if (action == "NEXTFAV")
+                BrowseDispInfo(BROWSE_FAVORITE);
+            else if (action == "0" || action == "1" || action == "2" ||
+                     action == "3" || action == "4" || action == "5" ||
+                     action == "6" || action == "7" || action == "8" ||
+                     action == "9")
+            {
+                ChannelKey(action.toInt());
+            }
+            else if (action == "TOGGLEBROWSE" || action == "ESCAPE")
+            {
+                ChannelCommit(); 
+                BrowseEnd(false);
+            }
+            else if (action == "SELECT")
+            {
+                ChannelCommit(); 
+                BrowseEnd(true);
+            }
+            else if (action == "TOGGLERECORD")
+                BrowseToggleRecord();
+            else if (action == "VOLUMEDOWN" || action == "VOLUMEUP" ||
+                     action == "MUTE" || action == "TOGGLEASPECT")
+            {
+                passThru = 1;
+                handled = false;
+            }
+            else
+                handled = false;
         }
 
         if (!passThru)
@@ -880,14 +1031,19 @@ void TV::ProcessKeypress(int keypressed)
 
     if (nvp->GetOSD() && osd->DialogShowing(dialogname))
     {
-        switch (keypressed)
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
         {
-            case Key_Up: osd->DialogUp(dialogname); break;
-            case Key_Down: osd->DialogDown(dialogname); break;
-            case Key_Escape: osd->DialogAbort(dialogname);
-                // fall through
-            case Key_Space: case Key_Enter: case Key_Return: 
+            action = actions[i];
+            handled = true;
+
+            if (action == "UP")
+                osd->DialogUp(dialogname); 
+            else if (action == "DOWN")
+                osd->DialogDown(dialogname);
+            else if (action == "SELECT" || action == "ESCAPE")
             {
+                if (action == "ESCAPE")
+                    osd->DialogAbort(dialogname);
                 osd->TurnDialogOff(dialogname);
                 if (dialogname == "alreadybeingedited")
                 {
@@ -897,9 +1053,11 @@ void TV::ProcessKeypress(int keypressed)
                     {
                        playbackinfo->SetEditing(false, m_db);
                        editmode = nvp->EnableEdit();
+                       if (editmode)
+                           nvp->SetPlaySpeed(1.0, false);
                     }
                 }
-                if (dialogname == "exitplayoptions") 
+                else if (dialogname == "exitplayoptions") 
                 {
                     int result = osd->GetDialogResponse(dialogname);
                     dialogname = "";
@@ -925,62 +1083,68 @@ void TV::ProcessKeypress(int keypressed)
                             break;
                     }
                 }
-                break;
+                else if (dialogname == "programmenubox") 
+                {
+                    int result = osd->GetDialogResponse(dialogname);
+
+                    osd->HideAll();
+                    dialogname = "";
+
+                    ProgramMenuAction(result);
+                }
             }
-            default: break;
+            else
+                handled = false;
         }
-        
         return;
     }
 
-    switch (keypressed) 
+    if (picAdjustment)
     {
-        case Key_T:
+        for (unsigned int i = 0; i < actions.size(); i++)
         {
+            action = actions[i];
+            handled = true;
+
+            if (action == "LEFT")
+                DoChangePictureAttribute(false);
+            else if (action == "RIGHT")
+                DoChangePictureAttribute(true);
+            else
+                handled = false;
+        }
+    }
+   
+    if (handled)
+        return;
+
+    for (unsigned int i = 0; i < actions.size() && !handled; i++)
+    {
+        action = actions[i];
+        handled = true;
+
+        if (action == "TOGGLECC")
             nvp->ToggleCC();
-            break;
-        }
-        case Key_Z:
-        {
+        else if (action == "SKIPCOMMERCIAL")
             DoSkipCommercials(1);
-            break;
-        }
-        case Key_X:
-        {
-            DoQueueTranscode();
-            break;
-        }
-        case Key_Q:
-        {
+        else if (action == "SKIPCOMMBACK")
             DoSkipCommercials(-1);
-            break;
-        }
-        case Key_S: case Key_P: 
-        {
+        else if (action == "QUEUETRANSCODE")
+            DoQueueTranscode();
+        else if (action == "PAUSE") 
             DoPause();
-            break;
-        }
-        case Key_U:
-        {
+        else if (action == "SPEEDINC")
             ChangeSpeed(1);
-            break;
-        }
-        case Key_J:
-        {
+        else if (action == "SPEEDDEC")
             ChangeSpeed(-1);
-            break;
-        }
-        case Key_F:
+        else if (action == "TOGGLEPICCONTROLS")
         {
             if (usePicControls)
                 DoTogglePictureAttribute();
-            break;
         }
-        case Key_Right: case Key_D: 
+        else if (action == "SEEKFFWD")
         {
-            if (picAdjustment)
-                DoChangePictureAttribute(true);
-            else if (paused)
+            if (paused)
                 DoSeek(1.001 / frameRate, tr("Forward"));
             else if (!stickykeys)
             {
@@ -991,21 +1155,17 @@ void TV::ProcessKeypress(int keypressed)
             }
             else
                 ChangeFFRew(1);
-            break;
         }
-        case Key_Greater: case Key_Period:
+        else if (action == "FFWDSTICKY")
         {
             if (paused)
                 DoSeek(1.0, tr("Forward"));
             else
                 ChangeFFRew(1);
-            break;
         }
-        case Key_Left: case Key_A:
+        else if (action == "SEEKRWND")
         {
-            if (picAdjustment)
-                DoChangePictureAttribute(false);
-            else if (paused)
+            if (paused)
                 DoSeek(-1.001 / frameRate, tr("Rewind"));
             else if (!stickykeys)
             {
@@ -1015,37 +1175,34 @@ void TV::ProcessKeypress(int keypressed)
             }
             else
                 ChangeFFRew(-1);
-            break;
         }
-        case Key_Less: case Key_Comma:
+        else if (action == "RWNDSTICKY")
         {
             if (paused)
                 DoSeek(-1.0, tr("Rewind"));
             else
                 ChangeFFRew(-1);
-            break;
         }
-        case Key_PageUp:
-        {
+        else if (action == "JUMPRWND")
             DoSeek(-jumptime * 60, tr("Jump Back"));
-            break;
-        }
-        case Key_PageDown:
-        {
+        else if (action == "JUMPFFWD")
             DoSeek(jumptime * 60, tr("Jump Ahead"));
-            break;
-        }
-        case Key_Escape:
+        else if (action == "ESCAPE")
         {
             StopFFRew();
 
-            if (osd && osd->Visible())
+            if (osd)
             {
-                ChannelClear();
-                osd->HideAll();
-                return;
+                QStringList osetname;
+                osetname << "program_info" << "channel_number" << "status";
+                if (osd->HideSets(osetname))
+                {
+                    ChannelClear();
+                    return;
+                }
             }
-            else if (StateIsPlaying(internalState) &&
+
+            if (StateIsPlaying(internalState) &&
                 gContext->GetNumSetting("PlaybackExitPrompt") == 1) 
             {
                 nvp->Pause();
@@ -1067,107 +1224,134 @@ void TV::ProcessKeypress(int keypressed)
                     nvp->SetBookmark();
                 exitPlayer = true;
                 wantsToQuit = true;
-                break;
             }
             break;
         }
-        case Key_BracketLeft: case Key_F10: ChangeVolume(false); break;
-        case Key_BracketRight: case Key_F11: ChangeVolume(true); break;
-        case Key_Bar: case Key_F9: ToggleMute(); break;
-        case Key_W: ToggleLetterbox(); break;
+        else if (action == "VOLUMEDOWN")
+            ChangeVolume(false);
+        else if (action == "VOLUMEUP")
+            ChangeVolume(true);
+        else if (action == "MUTE")
+            ToggleMute();
+        else if (action == "TOGGLEASPECT")
+            ToggleLetterbox();
+        else
+            handled = false;
+    }
 
-        default: 
+    if (!handled)
+    {
+        if (doing_ff_rew)
         {
-            if (doing_ff_rew)
+            for (unsigned int i = 0; i < actions.size(); i++)
             {
-                switch (keypressed)
-                {
-                    case Key_0: ff_rew_index = SSPEED_NORMAL_WITH_DISPLAY; break;
-                    case Key_1: ff_rew_index = SSPEED_SLOW_1; break;
-                    case Key_2: ff_rew_index = SSPEED_SLOW_2; break;
-                    case Key_3: ff_rew_index = SSPEED_NORMAL; break;
-                    case Key_4: ff_rew_index = SSPEED_FAST_1; break;
-                    case Key_5: ff_rew_index = SSPEED_FAST_2; break;
-                    case Key_6: ff_rew_index = SSPEED_FAST_3; break;
-                    case Key_7: ff_rew_index = SSPEED_FAST_4; break;
-                    case Key_8: ff_rew_index = SSPEED_FAST_5; break;
-                    case Key_9: ff_rew_index = SSPEED_FAST_6; break;
+                action = actions[0];
+                bool ok = false;
+                int val = action.toInt(&ok);
 
-                    default:
-                       float time = StopFFRew();
-                       UpdatePosOSD(time, tr("Play"));
-                       was_doing_ff_rew = true;
-                       break;
+                if (ok && val < SSPEED_MAX)
+                {
+                    ff_rew_index = val;
+                    handled = true;
                 }
             }
-            if (speed_index)
+
+            if (!handled)
             {
-                NormalSpeed();
-                UpdatePosOSD(0.0, tr("Play"));
+                float time = StopFFRew();
+                UpdatePosOSD(time, tr("Play"));
                 was_doing_ff_rew = true;
             }
-            break;
+        }
+
+        if (speed_index)
+        {
+            NormalSpeed();
+            UpdatePosOSD(0.0, tr("Play"));
+            was_doing_ff_rew = true;
         }
     }
 
     if (internalState == kState_WatchingLiveTV)
     {
-        switch (keypressed)
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
         {
-            case Key_I: ToggleOSD(); break;
+            action = actions[i];
+            handled = true;
 
-            case Key_Up:
-                     if (persistentbrowsemode)
-                         BrowseDispInfo(BROWSE_UP);
-                     else
-                         ChangeChannel(CHANNEL_DIRECTION_UP);
-                     break;
-            case Key_Down:
-                     if (persistentbrowsemode)
-                         BrowseDispInfo(BROWSE_DOWN);
-                     else
-                         ChangeChannel(CHANNEL_DIRECTION_DOWN);
-                     break;
-            case Key_Slash: ChangeChannel(CHANNEL_DIRECTION_FAVORITE); break;
-
-            case Key_Question: ToggleChannelFavorite(); break;
-
-            case Key_C: ToggleInputs(); break;
-
-            case Key_0: case Key_1: case Key_2: case Key_3: case Key_4:
-            case Key_5: case Key_6: case Key_7: case Key_8: case Key_9:
-                     ChannelKey(keypressed); break;
-
-            case Key_Space: case Key_Enter: case Key_Return: 
-                     ChannelCommit(); break;
-
-            case Key_M: LoadMenu(); break;
-
-            case Key_V: TogglePIPView(); break;
-            case Key_B: ToggleActiveWindow(); break;
-            case Key_N: SwapPIP(); break;
-
-            case Key_F1: ChangeContrast(false, true); break;
-            case Key_F2: ChangeContrast(true, true); break;
-            case Key_F3: ChangeBrightness(false, true); break;
-            case Key_F4: ChangeBrightness(true, true); break;
-            case Key_F5: ChangeColour(false, true); break;
-            case Key_F6: ChangeColour(true, true); break;
-            case Key_F7: ChangeHue(false, true); break;
-            case Key_F8: ChangeHue(true, true); break;
-
-            case Key_O: BrowseStart(); break;
-            case Key_H: PreviousChannel(); break;
-
-            default: break;
+            if (action == "INFO")
+                ToggleOSD();
+            else if (action == "CHANNELUP")
+            {
+                if (persistentbrowsemode)
+                    BrowseDispInfo(BROWSE_UP);
+                else
+                    ChangeChannel(CHANNEL_DIRECTION_UP);
+            }
+            else if (action == "CHANNELDOWN")
+            {
+                if (persistentbrowsemode)
+                    BrowseDispInfo(BROWSE_DOWN);
+                else
+                    ChangeChannel(CHANNEL_DIRECTION_DOWN);
+            }
+            else if (action == "NEXTFAV")
+                ChangeChannel(CHANNEL_DIRECTION_FAVORITE);
+            else if (action == "TOGGLEFAV")
+                ToggleChannelFavorite();
+            else if (action == "TOGGLEINPUTS")
+                ToggleInputs();
+            else if (action == "0" || action == "1" || action == "2" ||
+                     action == "3" || action == "4" || action == "5" ||
+                     action == "6" || action == "7" || action == "8" ||
+                     action == "9")
+            {
+                ChannelKey(action.toInt());
+            }
+            else if (action == "SELECT")
+                ChannelCommit();
+            else if (action == "MENU")
+                LoadMenu();
+            else if (action == "TOGGLEPIPMODE")
+                TogglePIPView();
+            else if (action == "TOGGLEPIPWINDOW")
+                ToggleActiveWindow();
+            else if (action == "SWAPPIP")
+                SwapPIP();
+            else if (action == "CONTRASTDOWN")
+                ChangeContrast(false, true);
+            else if (action == "CONTRASTUP")
+                ChangeContrast(true, true);
+            else if (action == "BRIGHTDOWN")
+                ChangeBrightness(false, true);
+            else if (action == "BRIGHTUP")
+                ChangeBrightness(true, true);
+            else if (action == "COLORDOWN")
+                ChangeColour(false, true);
+            else if (action == "COLORUP")
+                ChangeColour(true, true);
+            else if (action == "HUEDOWN")
+                ChangeHue(false, true);
+            else if (action == "HUEUP")
+                ChangeHue(true, true);
+            else if (action == "TOGGLEBROWSE")
+                BrowseStart();
+            else if (action == "PREVCHAN")
+                PreviousChannel();
+            else
+                handled = false;
         }
     }
     else if (StateIsPlaying(internalState))
     {
-        switch (keypressed)
+        for (unsigned int i = 0; i < actions.size() && !handled; i++)
         {
-            case Key_I: DoInfo(); break;
-            case Key_Space: case Key_Enter: case Key_Return: 
+            action = actions[i];
+            handled = true;
+
+            if (action == "INFO")
+                DoInfo();
+            else if (action == "SELECT")
             {
                 if (!was_doing_ff_rew)
                 {
@@ -1177,39 +1361,39 @@ void TV::ProcessKeypress(int keypressed)
                     else
                         nvp->SetBookmark(); 
                 }
-                break;
+                else
+                    handled = false;
             }
-            case Key_E: case Key_M: 
+            else if (action == "MENU" || action == "TOGGLEEDIT")
             {
-               if (playbackinfo->IsEditing(m_db))
-               {
-                   nvp->Pause();
+                if (playbackinfo->IsEditing(m_db))
+                {
+                    nvp->Pause();
 
-                   dialogname = "alreadybeingedited";
+                    dialogname = "alreadybeingedited";
 
-                   QString message = tr("This program is currently being edited");
+                    QString message = tr("This program is currently being "
+                                         "edited");
 
-                   QStringList options;
-                   options += tr("Continue Editing");
-                   options += tr("Do not edit");
+                    QStringList options;
+                    options += tr("Continue Editing");
+                    options += tr("Do not edit");
 
-                   osd->NewDialogBox(dialogname, message, options, 0); 
-                   break;
-               }
-            editmode = nvp->EnableEdit();
-            break;        
+                    osd->NewDialogBox(dialogname, message, options, 0); 
+                    return;
+                }
+                editmode = nvp->EnableEdit();
+                if (editmode)
+                    nvp->SetPlaySpeed(1.0, false);
             }
-            case Key_Up:
-            {
+            else if (action == "TOGGLEBROWSE")
+                DoProgramMenu();
+            else if (action == "CHANNELUP")
                 DoSeek(-jumptime * 60, tr("Jump Back"));
-                break;
-            }
-            case Key_Down:
-            {
+            else if (action == "CHANNELDOWN")
                 DoSeek(jumptime * 60, tr("Jump Ahead"));
-                break;
-            }
-            default: break;
+            else
+                handled = false;
         }
     }
 }
@@ -1424,7 +1608,7 @@ void TV::NormalSpeed(void)
         return;
 
     speed_index = 0;
-    activenvp->SetPlaySpeed(1.0);
+    activenvp->SetPlaySpeed(1.0, true);
 }
 
 void TV::ChangeSpeed(int direction)
@@ -1453,7 +1637,7 @@ void TV::ChangeSpeed(int direction)
         default: speed_index = old_speed; return; break;
     }
 
-    activenvp->SetPlaySpeed(speed);
+    activenvp->SetPlaySpeed(speed, (speed == 1.0));
     UpdatePosOSD(time, mesg);
 
     if (paused)
@@ -1478,6 +1662,8 @@ float TV::StopFFRew(void)
     doing_ff_rew = 0;
     ff_rew_index = SSPEED_NORMAL;
 
+    activenvp->SetPlaySpeed(1.0, true);
+
     return time;
 }
 
@@ -1485,6 +1671,16 @@ void TV::ChangeFFRew(int direction)
 {
     if (doing_ff_rew == direction)
         ff_rew_index = (++ff_rew_index % SSPEED_MAX);
+    else if (!ff_rew_reverse && doing_ff_rew == -direction)
+    {
+        if (ff_rew_index > SSPEED_NORMAL)
+            ff_rew_index = (--ff_rew_index % SSPEED_MAX);
+        else
+        {
+            float time = StopFFRew();
+            UpdatePosOSD(time, tr("Play"));
+        }
+    }
     else
     {
         NormalSpeed();
@@ -1494,6 +1690,8 @@ void TV::ChangeFFRew(int direction)
 
         if (paused)
             paused = activenvp->TogglePause();
+
+        activenvp->SetPlaySpeed(1.0, false);
     }
 }
 
@@ -1679,10 +1877,7 @@ void TV::ChannelClear(void)
 
 void TV::ChannelKey(int key)
 {
-    char thekey = key;
-
-    if (key > 256)
-        thekey = key - 256 - 0xb0 + '0';
+    char thekey = key + '0';
 
     if (channelkeysstored == 4)
     {
@@ -1698,6 +1893,41 @@ void TV::ChannelKey(int key)
     }
     channelKeys[4] = 0;
 
+    channelqueued = true;
+
+    bool unique = false;
+
+    /* 
+     * Always use smartChannelChange when channel numbers are entered in
+     * browse mode because in browse mode space/enter exit browse mode and
+     * change to the currently browsed channel. This makes smartChannelChange
+     * the only way to enter a channel number to browse without waiting for the
+     * OSD to fadeout after entering numbers.
+     */
+    if (smartChannelChange || browsemode)
+    {
+        char *chan_no_leading_zero = NULL;
+        for (int i = 0; i < channelkeysstored; i++)
+        {
+            if (channelKeys[i] != '0') 
+            {
+                chan_no_leading_zero = &channelKeys[i];
+                break;
+            }
+        }
+
+        if (chan_no_leading_zero)
+        {
+            QString chan = QString(chan_no_leading_zero).stripWhiteSpace();
+            if (!activerecorder->CheckChannelPrefix(chan, unique))
+            {
+                channelKeys[0] = thekey;
+                channelKeys[1] = channelKeys[2] = channelKeys[3] = ' ';
+                channelkeysstored = 1;
+            }
+        }
+    }
+
     if (activenvp == nvp && osd)
     {
         QMap<QString, QString> regexpMap;
@@ -1708,7 +1938,8 @@ void TV::ChannelKey(int key)
         osd->SetTextByRegexp("channel_number", regexpMap, 2);
     }
 
-    channelqueued = true;
+    if (unique)
+        ChannelCommit();
 }
 
 void TV::ChannelCommit(void)
@@ -1725,7 +1956,15 @@ void TV::ChannelCommit(void)
     }
 
     QString chan = QString(channelKeys).stripWhiteSpace();
-    ChangeChannelByString(chan);
+
+    if (browsemode)
+    {
+        BrowseChannel(chan);
+        if (activenvp == nvp && osd)
+            osd->HideSet("channel_number");
+    }
+    else
+        ChangeChannelByString(chan);
 
     ChannelClear();
 }
@@ -1859,7 +2098,8 @@ void TV::SetPreviousChannel()
 
 void TV::ToggleOSD(void)
 {
-    if (osd->Visible())
+    OSDSet *oset = osd->GetSet("program_info");
+    if (osd && (oset) && oset->Displaying())
     {
         osd->HideSet("program_info");
         osd->HideSet("channel_number");
@@ -2229,6 +2469,7 @@ void TV::ToggleLetterbox(void)
 
     switch (letterbox)
     {
+        case 3: text = tr("16:9 Zoom"); break;
         case 2: text = tr("4:3 Zoom"); break;
         case 1: text = tr("16:9"); break;
         default: text = tr("4:3"); break;
@@ -2311,6 +2552,11 @@ void TV::customEvent(QCustomEvent *e)
                 exitPlayer = true;
             }
         }
+        else if (message.left(12) == "EXIT_TO_MENU")
+        {
+            wantsToQuit = true;
+            exitPlayer = true;
+        }
     }
 }
 
@@ -2387,10 +2633,7 @@ void TV::BrowseDispInfo(int direction)
     regexpMap["dbstarttime"] = browsestarttime;
     regexpMap["chanid"] = browsechanid;
 
-    if (direction != BROWSE_SAME)
-        GetNextProgram(activerecorder, direction, regexpMap);
-    else
-        GetChannelInfo(activerecorder, regexpMap);
+    GetNextProgram(activerecorder, direction, regexpMap);
 
     browsechannum = regexpMap["channum"];
     browsechanid = regexpMap["chanid"];
@@ -2430,6 +2673,15 @@ void TV::BrowseToggleRecord(void)
     delete program_info;
 }
 
+void TV::BrowseChannel(QString &chan)
+{
+    if (!activerecorder->CheckChannel(chan))
+        return;
+
+    browsechannum = chan;
+    BrowseDispInfo(BROWSE_SAME);
+}
+
 void TV::HandleOSDClosed(int osdType)
 {
     switch (osdType)
@@ -2510,3 +2762,95 @@ void TV::DoChangePictureAttribute(bool up)
             break;
     }
 }
+
+OSD *TV::GetOSD(void)
+{
+    return nvp->GetOSD();
+}
+
+void TV::DoProgramMenu(void)
+{
+    if (GetState() == kState_WatchingLiveTV)
+       return;
+
+    if (!osd)
+        return;
+
+    NormalSpeed();
+
+    osd->HideAll();
+
+    dialogname = "programmenubox";
+
+    QString message = tr("Program Menu");
+
+    QStringList options;
+
+    if (autoCommercialSkip == 1)
+        options += tr("Set Commercial Auto-Skip OFF");
+    else if (autoCommercialSkip == 2)
+        options += tr("Set Commercial Auto-Skip ON");
+    else
+        options += tr("Set Commercial Auto-Skip to Notify");
+
+    if (playbackinfo->GetAutoExpireFromRecorded(m_db))
+        options += tr("Don't Auto Expire");
+    else
+        options += tr("Auto Expire");
+
+    options += tr("Cancel");
+
+    osd->NewDialogBox(dialogname, message, options, 10); 
+}
+
+void TV::ProgramMenuAction(int result)
+{
+    QString desc = "";
+
+    while (osd->Visible())
+        usleep(50);
+
+    switch(result)
+    {
+        case 1:
+            if (autoCommercialSkip == 1)
+            {
+                autoCommercialSkip = 0;
+                desc = tr("Auto-Skip OFF");
+            }
+            else if (autoCommercialSkip == 2)
+            {
+                autoCommercialSkip = 1;
+                desc = tr("Auto-Skip ON");
+            }
+            else
+            {
+                autoCommercialSkip = 2;
+                desc = tr("Auto-Skip Notify");
+            }
+
+            nvp->SetAutoCommercialSkip(autoCommercialSkip);
+            break;
+
+        case 2:
+            if (playbackinfo->GetAutoExpireFromRecorded(m_db))
+            {
+                playbackinfo->SetAutoExpire(false, m_db);
+                desc = "Auto-Expire OFF";
+            }
+            else
+            {
+                playbackinfo->SetAutoExpire(true, m_db);
+                desc = "Auto-Expire ON";
+            }
+            break;
+    }
+
+    if (activenvp == nvp && desc != "" )
+    {
+        QString curTime = "";
+        int pos = nvp->calcSliderPos(0, curTime);
+        osd->StartPause(pos, false, desc, curTime, 1);
+        update_osd_pos = false;
+    }
+}
