@@ -6,7 +6,7 @@
 #include <qdatetime.h>
 #include <pthread.h>
 #include <qvaluevector.h>
-#include <qvaluelist.h>
+#include <qptrlist.h>
 #include <qmutex.h>
 
 #include "tv.h"
@@ -22,6 +22,7 @@ class NuppelVideoPlayer;
 class RingBuffer;
 class ProgramInfo;
 class MythDialog;
+class UDPNotify;
 
 class TV : public QObject
 {
@@ -30,6 +31,8 @@ class TV : public QObject
     TV(QSqlDatabase *db);
    ~TV(void);
 
+    static void InitKeys(void);
+
     void Init(bool createWindow = true);
 
     int LiveTV(bool showDialogs = true);
@@ -74,12 +77,14 @@ class TV : public QObject
     bool getRequestDelete(void) { return requestDelete; }
     bool getEndOfRecording(void) { return endOfRecording; }
 
-    void ProcessKeypress(int keypressed);
+    void ProcessKeypress(QKeyEvent *e);
     void customEvent(QCustomEvent *e);
 
     void AddPreviousChannel(void);
     void PreviousChannel(void);
 
+    OSD *GetOSD(void);
+
   public slots:
     void HandleOSDClosed(int osdType);
 
@@ -161,15 +166,20 @@ class TV : public QObject
     void BrowseEnd(bool change);
     void BrowseDispInfo(int direction);
     void BrowseToggleRecord(void);
+    void BrowseChannel(QString &chan);
 
     void DoTogglePictureAttribute(void);
     void DoChangePictureAttribute(bool up);
 
+    void DoProgramMenu(void);
+    void ProgramMenuAction(int result);
+
     int osd_display_time;
 
     bool channelqueued;
     char channelKeys[5];
     int channelkeysstored;
+    bool smartChannelChange;
 
     bool menurunning;
 
@@ -179,6 +189,8 @@ class TV : public QObject
     bool exitPlayer;
     bool paused;
 
+    int autoCommercialSkip;
+
     float frameRate;
 
     pthread_t event, decode, pipdecode;
@@ -193,6 +205,7 @@ class TV : public QObject
     int rewtime;
     int stickykeys;
     int ff_rew_repos;
+    bool ff_rew_reverse;
     int doing_ff_rew;
     int ff_rew_index;
     int speed_index;
@@ -243,7 +256,7 @@ class TV : public QObject
 
     MythDialog *myWindow;
 
-    QValueList<int> keyList;
+    QPtrList<QKeyEvent> keyList;
     QMutex keyListLock;
 
     bool wantsToQuit;
@@ -259,6 +272,8 @@ class TV : public QObject
 
     bool smartForward;
     bool doSmartForward;
+
+    UDPNotify *udpnotify;
 };
 
 #endif
