@@ -22,12 +22,15 @@ using namespace std;
 #include "NuppelVideoRecorder.h"
 #include "mpegrecorder.h"
 #include "hdtvrecorder.h"
-#include "dvbrecorder.h"
 #include "NuppelVideoPlayer.h"
 #include "channel.h"
-#include "dvbchannel.h"
 #include "commercial_skip.h"
 
+#ifdef USING_DVB
+#include "dvbchannel.h"
+#include "dvbrecorder.h"
+#endif
+
 void *SpawnEncode(void *param)
 {
     RecorderBase *nvr = (RecorderBase *)param;
@@ -60,21 +63,28 @@ TVRec::TVRec(int capturecardnum)
     audiosamplerate = -1;
 
     QString inputname, startchannel;
-    int use_ts = 0;
-    char dvb_type = '\0';
 
     GetDevices(capturecardnum, videodev, vbidev, audiodev, audiosamplerate,
-               inputname, startchannel, cardtype, use_ts, dvb_type);
+               inputname, startchannel, cardtype, dvb_swfilter, dvb_recordts);
 
     if (cardtype == "DVB")
     {
-        channel = new DVBChannel(this, videodev.toInt(), use_ts == 1, dvb_type);
+#ifdef USING_DVB
+        channel = new DVBChannel(videodev.toInt(), this);
+        channel->Open();
         if (inputname.isEmpty())
             channel->SetChannelByString(startchannel);
         else
             channel->SwitchToInput(inputname, startchannel);
         channel->SetChannelOrdering(chanorder);
         // don't close this channel, otherwise we cannot read data
+#else
+        VERBOSE(VB_IMPORTANT, "ERROR: DVB Card configured, "
+                              "but no DVB support compiled in!");
+        VERBOSE(VB_IMPORTANT, "Remove the card from configuration, "
+                              "or recompile MythTV.");
+        exit(-1);
+#endif
     }
     else // "V4L" or "MPEG", ie, analog TV, or "HDTV"
     {
@@ -200,7 +210,7 @@ int TVRec::StartRecording(ProgramInfo *rcinfo)
         MythEvent me(message);
         gContext->dispatch(me);
 
-        timeout = QDateTime::currentDateTime().addSecs(3);
+        timeout = QDateTime::currentDateTime().addSecs(10);
 
         while (internalState != kState_None &&
                QDateTime::currentDateTime().secsTo(timeout) > 0)
@@ -210,7 +220,7 @@ int TVRec::StartRecording(ProgramInfo *rcinfo)
         {
             gContext->dispatch(me);
 
-            timeout = QDateTime::currentDateTime().addSecs(3);
+            timeout = QDateTime::currentDateTime().addSecs(10);
 
             while (internalState != kState_None &&
                    QDateTime::currentDateTime().secsTo(timeout) > 0)
@@ -230,7 +240,7 @@ int TVRec::StartRecording(ProgramInfo *rcinfo)
     if (internalState == kState_None)
     {
         outputFilename = rcinfo->GetRecordFilename(recprefix);
-        recordEndTime = rcinfo->endts;
+        recordEndTime = rcinfo->recendts;
         curRecording = new ProgramInfo(*rcinfo);
 
         nextState = kState_RecordingOnly;
@@ -422,14 +432,13 @@ void TVRec::HandleStateChange(void)
 
     if (!changed)
     {
-        printf("Unknown state transition: %s to %s\n", origname.ascii(),
-                                                       statename.ascii());
+        VERBOSE(VB_IMPORTANT, QString("Unknown state transition: %1 to %2")
+                .arg(origname).arg(statename));
     }
     else
     {
-        QString trans = QString("Changing from %1 to %2")
-                               .arg(origname).arg(statename);
-        VERBOSE(VB_GENERAL, trans);
+        VERBOSE(VB_GENERAL, QString("Changing from %1 to %2")
+                .arg(origname).arg(statename));
     }
  
     if (startRecorder)
@@ -473,7 +482,10 @@ void TVRec::HandleStateChange(void)
         SetupRecorder(profile);
         nvr->SetRecording(curRecording);
         nvr->SetDB(db_conn, &db_lock);
+        if (channel != NULL)
+            nvr->ChannelNameChanged(channel->GetCurrentName());
 
+        SetVideoFiltersForChannel(channel, channel->GetCurrentName());
         pthread_create(&encode, NULL, SpawnEncode, nvr);
 
         while (!nvr->IsRecording())
@@ -481,7 +493,6 @@ void TVRec::HandleStateChange(void)
 
         // evil.
         channel->SetFd(nvr->GetVideoFd());
-        SetVideoFiltersForChannel(channel, channel->GetCurrentName());
 
         frameRate = nvr->GetFrameRate();
     }
@@ -551,10 +562,14 @@ void TVRec::SetupRecorder(RecordingProfile &profile)
     }
     else if (cardtype == "DVB")
     {
+#ifdef USING_DVB
         nvr = new DVBRecorder(dynamic_cast<DVBChannel*>(channel));
         nvr->SetRingBuffer(rbuffer);
         nvr->SetOption("cardnum", videodev.toInt());
+        nvr->SetOption("swfilter", dvb_swfilter);
+        nvr->SetOption("recordts", dvb_recordts);
         nvr->Initialize();
+#endif
         return;
     }
 
@@ -718,7 +733,7 @@ void TVRec::TeardownRecorder(bool killFile)
             {
                 QString message = QString("LOCAL_TRANSCODE %1 %2 %3")
                            .arg(prevRecording->chanid)
-                           .arg(prevRecording->startts.toString(Qt::ISODate))
+                           .arg(prevRecording->recstartts.toString(Qt::ISODate))
                            .arg(oldProfileName);
                 MythEvent me(message);
                 gContext->dispatch(me);
@@ -906,16 +921,16 @@ void TVRec::GetChannelInfo(ChannelBase *chan, QString &title, QString &subtitle,
                            QString &callsign, QString &iconpath, 
                            QString &channelname, QString &chanid)
 {
-    title = " ";
-    subtitle = " ";
-    desc = " ";
-    category = " ";
-    starttime = " ";
-    endtime = " ";
-    callsign = " ";
-    iconpath = " ";
-    channelname = " ";
-    chanid = " ";
+    title = "";
+    subtitle = "";
+    desc = "";
+    category = "";
+    starttime = "";
+    endtime = "";
+    callsign = "";
+    iconpath = "";
+    channelname = "";
+    chanid = "";
 
     if (!db_conn)
         return;
@@ -1056,8 +1071,8 @@ void TVRec::DisconnectDB(void)
 
 void TVRec::GetDevices(int cardnum, QString &video, QString &vbi, 
                        QString &audio, int &rate, QString &defaultinput,
-                       QString &startchan, QString &type, int &use_ts,
-                       char &dvb_type)
+                       QString &startchan, QString &type, int &dvb_swfilter,
+                       int &dvb_recordts)
 {
     video = "";
     vbi = "";
@@ -1071,8 +1086,8 @@ void TVRec::GetDevices(int cardnum, QString &video, QString &vbi,
     MythContext::KickDatabase(db_conn);
 
     QString thequery = QString("SELECT videodevice,vbidevice,audiodevice,"
-                               "audioratelimit,defaultinput,cardtype, "
-                               "use_ts,dvb_type "
+                               "audioratelimit,defaultinput,cardtype,"
+                               "dvb_swfilter,dvb_recordts "
                                "FROM capturecard WHERE cardid = %1;")
                               .arg(cardnum);
 
@@ -1103,10 +1118,8 @@ void TVRec::GetDevices(int cardnum, QString &video, QString &vbi,
         test = query.value(5).toString();
         if (test != QString::null)
             type = QString::fromUtf8(test);
-        use_ts = query.value(6).toInt();
-        test = query.value(7).toString();
-        if (test != QString::null)
-            dvb_type = test[0].latin1();
+        dvb_swfilter = query.value(6).toInt();
+        dvb_recordts = query.value(7).toInt();
 
         if (testnum > 0)
             rate = testnum;
@@ -1192,6 +1205,70 @@ bool TVRec::CheckChannel(ChannelBase *chan, const QString &channum,
     return ret;
 }
 
+/*
+ * Returns true if name is either a valid channel name or a valid channel
+ * prefix.  If name is a valid channel name and not a valid channel prefix
+ * unique is set to true.
+ * For example, if name == "36" and "36", "360", "361", "362", and "363" are
+ * valid channel names, this function would return true but set *unique to
+ * false.  However if name == "361" it would both return true and set *unique
+ * to true.
+ */
+bool TVRec::CheckChannelPrefix(QString name, bool &unique)
+{
+    if (!db_conn)
+        return true;
+
+    pthread_mutex_lock(&db_lock);
+    MythContext::KickDatabase(db_conn);
+
+    bool ret = false;
+    unique = false;
+
+    QString channelinput = channel->GetCurrentInput();
+
+    QString thequery = QString("SELECT channel.chanid FROM "
+                               "channel,capturecard,cardinput "
+                               "WHERE channel.channum LIKE \"%1%%\" AND "
+                               "channel.sourceid = cardinput.sourceid AND "
+                               "cardinput.inputname = \"%2\" AND "
+                               "cardinput.cardid = capturecard.cardid AND "
+                               "capturecard.cardid = \"%3\" AND "
+                               "capturecard.hostname = \"%4\";")
+                               .arg(name).arg(channelinput)
+                               .arg(m_capturecardnum)
+                               .arg(gContext->GetHostName());
+
+    QSqlQuery query = db_conn->exec(thequery);
+
+    if (!query.isActive())
+        MythContext::DBError("checkchannel", query);
+    else if (query.numRowsAffected() > 0)
+    {
+        pthread_mutex_unlock(&db_lock);
+
+        if (query.numRowsAffected() == 1)
+        {
+            unique = CheckChannel(name);
+        }
+
+        return true;
+    }
+
+    thequery = "SELECT NULL FROM channel;";
+    query = db_conn->exec(thequery);
+
+    if (query.numRowsAffected() == 0) 
+    {
+        unique = true;
+        ret = true;
+    }
+
+    pthread_mutex_unlock(&db_lock);
+
+    return ret;
+}
+
 bool TVRec::SetVideoFiltersForChannel(ChannelBase *chan, const QString &channum)
 {
 
@@ -1668,6 +1745,7 @@ void TVRec::ChangeChannel(int channeldirection)
     else
         channel->ChannelDown();
 
+    nvr->ChannelNameChanged(channel->GetCurrentName());
     nvr->Reset();
     nvr->Unpause();
 
@@ -1787,6 +1865,7 @@ void TVRec::SetChannel(QString name)
     if (!channel->SetChannelByString(chan))
         channel->SetChannelByString(prevchan);
 
+    nvr->ChannelNameChanged(channel->GetCurrentName());
     nvr->Reset();
     nvr->Unpause();
 
@@ -1815,8 +1894,8 @@ void TVRec::GetNextProgram(int direction,
         case BROWSE_SAME:
                 chanid = GetNextRelativeChanID(channelname,
                                                CHANNEL_DIRECTION_SAME);
-                compare = "=";
-                sortorder = "asc";
+                compare = "<=";
+                sortorder = "desc";
                 break;
         case BROWSE_UP:
                 chanid = GetNextRelativeChanID(channelname,
@@ -1838,6 +1917,12 @@ void TVRec::GetNextProgram(int direction,
                 compare = ">";
                 sortorder = "asc";
                 break;
+        case BROWSE_FAVORITE:
+                chanid = GetNextRelativeChanID(channelname,
+                                               CHANNEL_DIRECTION_FAVORITE);
+                compare = "<=";
+                sortorder = "desc";
+                break;
     }
 
     querystr += QString( "and channel.chanid = '%1' "
@@ -1973,7 +2058,9 @@ void TVRec::SetReadThreadSock(QSocket *sock)
 
 void TVRec::RequestRingBufferBlock(int size)
 {
-    if (!readthreadlive)
+    readthreadLock.lock();
+
+    if (!readthreadlive || !rbuffer)
         return;
 
     char buffer[256001];
@@ -1981,8 +2068,6 @@ void TVRec::RequestRingBufferBlock(int size)
     if (size > 256000)
         size = 256000;
 
-    readthreadLock.lock();
-
     while (size > 0 && !rbuffer->GetStopReads() && readthreadlive)
     {
         int ret = rbuffer->Read(buffer, size);
@@ -2137,7 +2222,7 @@ bool TVRec::isParsingCommercials(ProgramInfo *pginfo)
     pthread_mutex_lock(&commLock);
     for (pinfo = commercialFlag.first(); pinfo; pinfo = commercialFlag.next())
     {
-        if(pginfo->chanid == pinfo->chanid || pginfo->startts == pinfo->startts)
+        if(pginfo->chanid == pinfo->chanid || pginfo->recstartts == pinfo->recstartts)
         {
             pthread_mutex_unlock(&commLock);
             return true;
