@@ -26,7 +26,8 @@ typedef enum
     BROWSE_UP,
     BROWSE_DOWN,
     BROWSE_LEFT,
-    BROWSE_RIGHT
+    BROWSE_RIGHT,
+    BROWSE_FAVORITE
 } BrowseDirections;
 
 
@@ -102,6 +103,7 @@ class TVRec
     int ChangeBrightness(bool direction);
     int ChangeHue(bool direction);
     bool CheckChannel(QString name);
+    bool CheckChannelPrefix(QString name, bool &unique);
     void GetNextProgram(int direction,
                         QString &title, QString &subtitle, QString &desc,
                         QString &category, QString &starttime, 
@@ -141,7 +143,7 @@ class TVRec
 
     void GetDevices(int cardnum, QString &video, QString &vbi, QString &audio,
                     int &rate, QString &defaultinput, QString &startchannel,
-                    QString &type, int &use_ts, char &dvb_type);
+                    QString &type, int &dvb_swfilter, int &dvb_recordts);
 
     void ConnectDB(int cardnum);
     void DisconnectDB(void);
@@ -219,6 +221,9 @@ class TVRec
 
     QString profileName;
     int autoTranscode;
+
+    int dvb_swfilter;
+    int dvb_recordts;
 };
 
 #endif
