@@ -32,7 +32,7 @@ class VideoOutputVIA : public VideoOutput
 
     void UpdatePauseFrame(void);
     void ProcessFrame(VideoFrame *frame, OSD *osd,
-                      vector<VideoFilter *> &filterList,
+                      FilterChain *filterList,
                       NuppelVideoPlayer *pipPlayer);
 
   private:
