@@ -20,6 +20,7 @@ using namespace std;
 #include "osdsurface.h"
 #include "../libmyth/util.h"
 #include "mythcontext.h"
+#include "filtermanager.h"
 
 extern "C" {
 #include "../libavcodec/avcodec.h"
@@ -56,6 +57,7 @@ struct XvData
     GC XJ_gc;
     Screen *XJ_screen;
     Display *XJ_disp;
+    float display_aspect;
     XShmSegmentInfo *XJ_SHMInfo;
 
     map<unsigned char *, XvImage *> buffers;
@@ -81,6 +83,7 @@ VideoOutputXv::VideoOutputXv(void)
     scratchspace = NULL; 
 
     pauseFrame.buf = NULL;
+    pauseFrame.qscale_table = NULL;
 
     data = new XvData();
 }
@@ -90,6 +93,12 @@ VideoOutputXv::~VideoOutputXv()
     if (pauseFrame.buf)
         delete [] pauseFrame.buf;
 
+    if (pauseFrame.qscale_table)
+    {
+        delete [] pauseFrame.qscale_table;
+        pauseFrame.qscale_table = NULL;
+    }
+
     Exit();
     delete data;
 }
@@ -139,6 +148,8 @@ void VideoOutputXv::InputChanged(int width, int height, float aspect)
     pauseFrame.bpp = scratchFrame->bpp;
     pauseFrame.size = scratchFrame->size;
     pauseFrame.buf = new unsigned char[pauseFrame.size];
+    pauseFrame.qscale_table = scratchFrame->qscale_table = NULL;
+    pauseFrame.qstride = scratchFrame->qstride = 0;
 
     pthread_mutex_unlock(&lock);
 }
@@ -176,6 +187,7 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
     unsigned int p_version, p_release, p_request_base, p_event_base, 
                  p_error_base;
     int p_num_adaptors;
+    int w_mm, h_mm;
 
     XvAdaptorInfo *ai;
 
@@ -194,6 +206,13 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
     data->XJ_screen = DefaultScreenOfDisplay(data->XJ_disp);
     XJ_screen_num = DefaultScreen(data->XJ_disp);
 
+    w_mm = DisplayWidthMM(data->XJ_disp, XJ_screen_num);
+    h_mm = DisplayHeightMM(data->XJ_disp, XJ_screen_num);
+    if (w_mm == 0 || h_mm == 0)
+        data->display_aspect = XJ_aspect;
+    else
+        data->display_aspect = (float)w_mm/h_mm;
+
     XJ_white = XWhitePixel(data->XJ_disp, XJ_screen_num);
     XJ_black = XBlackPixel(data->XJ_disp, XJ_screen_num);
   
@@ -322,7 +341,7 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
         if (fo)
             XFree(fo);
 
-        printf("Using XV port %d\n", xv_port);
+        VERBOSE(VB_GENERAL, QString("Using XV port %1").arg(xv_port));
         XvGrabPort(data->XJ_disp, xv_port, CurrentTime);
     }
 
@@ -359,6 +378,8 @@ bool VideoOutputXv::Init(int width, int height, float aspect,
     pauseFrame.bpp = scratchFrame->bpp;
     pauseFrame.size = scratchFrame->size;
     pauseFrame.buf = new unsigned char[pauseFrame.size];
+    pauseFrame.qscale_table = NULL;
+    pauseFrame.qstride = 0;
 
     MoveResize();
  
@@ -411,6 +432,8 @@ bool VideoOutputXv::CreateXvBuffers(void)
         vbuffers[i].bpp = 12;
         vbuffers[i].size = XJ_height * XJ_width * 3 / 2;
         vbuffers[i].codec = FMT_YV12;
+        vbuffers[i].qscale_table = NULL;
+        vbuffers[i].qstride = 0;
     }
 
     XSync(data->XJ_disp, 0);
@@ -466,6 +489,8 @@ bool VideoOutputXv::CreateShmBuffers(void)
         vbuffers[i].size = XJ_height * XJ_width * 3 / 2;
         vbuffers[i].codec = FMT_YV12;
         vbuffers[i].buf = new unsigned char[vbuffers[i].size];
+        vbuffers[i].qscale_table = NULL;
+        vbuffers[i].qstride = 0;
     }
 
     XSync(data->XJ_disp, 0);
@@ -492,6 +517,8 @@ bool VideoOutputXv::CreateXBuffers(void)
         vbuffers[i].size = XJ_height * XJ_width * 3 / 2;
         vbuffers[i].codec = FMT_YV12;
         vbuffers[i].buf = new unsigned char[vbuffers[i].size];
+        vbuffers[i].qscale_table = NULL;
+        vbuffers[i].qstride = 0;
     }
 
     XSync(data->XJ_disp, 0);
@@ -533,6 +560,15 @@ void VideoOutputXv::DeleteXvBuffers()
         XFree(iter->second);
     }
 
+    for (int i = 0; i < numbuffers + 1; i++)
+    {
+        if (vbuffers[i].qscale_table)
+        {
+            delete [] vbuffers[i].qscale_table;
+            vbuffers[i].qscale_table = NULL;
+        }
+    }
+
     delete [] (data->XJ_SHMInfo);
 
     if (scratchspace)
@@ -557,6 +593,12 @@ void VideoOutputXv::DeleteShmBuffers()
     {
         delete [] vbuffers[i].buf;
         vbuffers[i].buf = NULL;
+
+        if (vbuffers[i].qscale_table)
+        {
+            delete [] vbuffers[i].qscale_table;
+            vbuffers[i].qscale_table = NULL;
+        }
     }
 }
 
@@ -568,6 +610,12 @@ void VideoOutputXv::DeleteXBuffers()
     {
         delete [] vbuffers[i].buf;
         vbuffers[i].buf = NULL;
+
+        if (vbuffers[i].qscale_table)
+        {
+            delete [] vbuffers[i].qscale_table;
+            vbuffers[i].qscale_table = NULL;
+        }
     }
 }
 
@@ -730,12 +778,29 @@ void VideoOutputXv::Show()
 
 void VideoOutputXv::DrawUnusedRects(void)
 {
+    // Draw black in masked areas
     XSetForeground(data->XJ_disp, data->XJ_gc, XJ_black);
-  
-    XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, dispx, dispy, 
-                   dispw, dispyoff);
-    XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, dispx, 
-                   dispyoff + disphoff, dispw, dispyoff);
+
+    if (dispxoff > dispx) // left
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispx, dispy, dispxoff-dispx, disph);
+    if (dispxoff+dispwoff < dispx+dispw) // right
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispxoff+dispwoff, dispy, 
+                       (dispx+dispw)-(dispxoff+dispwoff), disph);
+    if (dispyoff > dispy) // bottom
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispx, dispy, dispw, dispyoff-dispy);
+    if (dispyoff+disphoff < dispy+disph) // top
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispx, dispyoff+disphoff, 
+                       dispw, (dispy+disph)-(dispyoff+disphoff));
+    XSync(data->XJ_disp, false);
+}
+
+float VideoOutputXv::GetDisplayAspect(void)
+{
+    return data->display_aspect;
 }
 
 void VideoOutputXv::UpdatePauseFrame(void)
@@ -745,13 +810,13 @@ void VideoOutputXv::UpdatePauseFrame(void)
     VideoFrame *pauseb = scratchFrame;
     if (usedVideoBuffers.count() > 0)
         pauseb = usedVideoBuffers.head();
-    memcpy(pauseFrame.buf, pauseb->buf, pauseb->size);
+    CopyFrame(&pauseFrame, pauseb);
 
     pthread_mutex_unlock(&lock);
 }
 
 void VideoOutputXv::ProcessFrame(VideoFrame *frame, OSD *osd,
-                                 vector<VideoFilter *> &filterList,
+                                 FilterChain *filterList,
                                  NuppelVideoPlayer *pipPlayer)
 {
     pthread_mutex_lock(&lock);
@@ -759,10 +824,11 @@ void VideoOutputXv::ProcessFrame(VideoFrame *frame, OSD *osd,
     if (!frame)
     {
         frame = scratchFrame;
-        memcpy(scratchFrame->buf, pauseFrame.buf, pauseFrame.size);
+        CopyFrame(scratchFrame, &pauseFrame);
     }
 
-    process_video_filters(frame, &filterList[0], filterList.size());
+    if (filterList)
+        filterList->ProcessFrame(frame);
 
     ShowPip(frame, pipPlayer);
     DisplayOSD(frame, osd);
