@@ -61,6 +61,7 @@ struct XvMCData
     Screen *XJ_screen;
     Display *XJ_disp;
     XShmSegmentInfo *XJ_SHMInfo;
+    float display_aspect;
 
     XvMCSurfaceInfo surface_info;
     XvMCContext ctx;
@@ -168,7 +169,7 @@ bool VideoOutputXvMC::Init(int width, int height, float aspect,
   
     unsigned int p_version, p_release, p_request_base, p_event_base, 
                  p_error_base;
-    int p_num_adaptors;
+    int p_num_adaptors, w_mm, h_mm;
 
     XvAdaptorInfo *ai;
 
@@ -187,6 +188,13 @@ bool VideoOutputXvMC::Init(int width, int height, float aspect,
     data->XJ_screen = DefaultScreenOfDisplay(data->XJ_disp);
     XJ_screen_num = DefaultScreen(data->XJ_disp);
 
+    w_mm = DisplayWidthMM(data->XJ_disp, XJ_screen_num);
+    h_mm = DisplayHeightMM(data->XJ_disp, XJ_screen_num);
+    if (w_mm == 0 || h_mm == 0)
+        data->display_aspect = XJ_aspect;
+    else
+        data->display_aspect = (float)w_mm/h_mm;
+
     XJ_white = XWhitePixel(data->XJ_disp, XJ_screen_num);
     XJ_black = XBlackPixel(data->XJ_disp, XJ_screen_num);
   
@@ -295,11 +303,13 @@ bool VideoOutputXvMC::Init(int width, int height, float aspect,
     old_handler = XSetErrorHandler(XJ_error_catcher);
     XSync(data->XJ_disp, 0);
 
-    printf("Using XV port %d\n", xv_port);
+    VERBOSE(VB_GENERAL, QString("Using XV port %1").arg(xv_port));
     XvGrabPort(data->XJ_disp, xv_port, CurrentTime);
 
     data->XJ_gc = XCreateGC(data->XJ_disp, data->XJ_win, 0, 0);
     XJ_depth = DefaultDepthOfScreen(data->XJ_screen);
+    XFlush(data->XJ_disp);
+    XSync(data->XJ_disp, false);
 
     XvImageFormatValues *xvfmv;
     int num_subpic;
@@ -404,7 +414,16 @@ bool VideoOutputXvMC::CreateXvMCBuffers(void)
 
     if (ret != Success)
     {
-        cerr << "Unable to create XvMC Context\n";
+        cerr << "Unable to create XvMC Context return status:" << ret ;
+        switch (ret)
+        {
+            case XvBadPort: cerr << " XvBadPort"; break;
+            case BadValue:  cerr << " BadValue" ; break;
+            case BadMatch:  cerr << " BadMatch" ; break;
+            case BadAlloc:  cerr << " BadAlloc" ; break;
+            default:        cerr << " unrecognized return value"; break;
+        }
+        cerr << endl;
         return false;
     }
 
@@ -428,7 +447,9 @@ bool VideoOutputXvMC::CreateXvMCBuffers(void)
         if (ret != Success)
         {
             cerr << "Unable to create XvMC Macro Blocks\n";
+            XvMCDestroyBlocks(data->XJ_disp,&(data->data_blocks[i]));
             XvMCDestroyContext(data->XJ_disp, &data->ctx);
+            return false;
         }
     }
 
@@ -478,6 +499,7 @@ bool VideoOutputXvMC::CreateXvMCBuffers(void)
 
     if (rez == Success)
     {
+        data->subpicture_alloc = true;
         XvMCClearSubpicture(data->XJ_disp, &data->subpicture, 0, 0, XJ_width,
                             XJ_height, data->subpicture_clear_color);
 
@@ -492,10 +514,10 @@ bool VideoOutputXvMC::CreateXvMCBuffers(void)
 
         data->xvimage->data = data->shminfo.shmaddr;
 
-        shmctl(data->shminfo.shmid, IPC_RMID, 0);
-
         XShmAttach(data->XJ_disp, &data->shminfo);
 
+        shmctl(data->shminfo.shmid, IPC_RMID, 0);
+
         if (data->subpicture.num_palette_entries > 0)
         {
             int snum = data->subpicture.num_palette_entries;
@@ -525,7 +547,10 @@ bool VideoOutputXvMC::CreateXvMCBuffers(void)
         }
     }
     else
+    {
         data->subpicture_mode = NO_SUBPICTURE;
+        data->subpicture_alloc = false;
+    }
 
     XSync(data->XJ_disp, 0);
 
@@ -550,7 +575,7 @@ void VideoOutputXvMC::Exit(void)
 
 void VideoOutputXvMC::DeleteXvMCBuffers()
 {
-    for (int i = 0; i < numbuffers; i++)
+    for (int i = 0; i < 8; i++)
     {
         XvMCDestroyMacroBlocks(data->XJ_disp, &data->mv_blocks[i]);
         XvMCDestroyBlocks(data->XJ_disp, &data->data_blocks[i]);
@@ -580,6 +605,9 @@ void VideoOutputXvMC::DeleteXvMCBuffers()
 
         data->subpicture_alloc = false;
         XFree(data->xvimage);
+        XFlush(data->XJ_disp);
+        XSync(data->XJ_disp, false);
+
 
         if (data->palette)
             delete [] data->palette;
@@ -760,20 +788,34 @@ void VideoOutputXvMC::DrawUnusedRects(void)
                    dispw, disph);
 
     XSetForeground(data->XJ_disp, data->XJ_gc, XJ_black);
-    XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, dispx, dispy, 
-                   dispw, dispyoff);
-    XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, dispx,
-                   dispyoff + disphoff, dispw, dispyoff);
-
+    if (dispxoff > dispx) // left
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispx, dispy, dispxoff-dispx, disph);
+    if (dispxoff+dispwoff < dispx+dispw) // right
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispxoff+dispwoff, dispy, 
+                       (dispx+dispw)-(dispxoff+dispwoff), disph);
+    if (dispyoff > dispy) // bottom
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispx, dispy, dispw, dispyoff-dispy);
+    if (dispyoff+disphoff < dispy+disph) // top
+        XFillRectangle(data->XJ_disp, data->XJ_curwin, data->XJ_gc, 
+                       dispx, dispyoff+disphoff, 
+                       dispw, (dispy+disph)-(dispyoff+disphoff));
     XSync(data->XJ_disp, false);
 }
 
+float VideoOutputXvMC::GetDisplayAspect(void)
+{
+    return data->display_aspect;
+}
+
 void VideoOutputXvMC::UpdatePauseFrame(void)
 {
 }
 
 void VideoOutputXvMC::ProcessFrame(VideoFrame *frame, OSD *osd,
-                                   vector<VideoFilter *> &filterList,
+                                   FilterChain *filterList,
                                    NuppelVideoPlayer *pipPlayer)
 {
     (void)filterList;
