@@ -28,9 +28,11 @@ class VideoOutputXvMC : public VideoOutput
 
     void DrawUnusedRects(void);
 
+    float GetDisplayAspect(void);
+
     void UpdatePauseFrame(void);
     void ProcessFrame(VideoFrame *frame, OSD *osd,
-                      vector<VideoFilter *> &filterList,
+                      FilterChain *filterList,
                       NuppelVideoPlayer *pipPlayer);
 
     int ChangePictureAttribute(int attributeType, int newValue);
