@@ -90,6 +90,9 @@ TVState EncoderLink::GetState(void)
 {
     TVState retval = kState_Error;
 
+    if (!isConnected())
+        return retval;
+
     if (local)
         retval = tv->GetState();
     else if (sock)
@@ -104,7 +107,7 @@ bool EncoderLink::isRecording(ProgramInfo *rec)
 {
     bool retval = false;
 
-    if (rec->chanid == chanid && rec->startts == startRecordingTime)
+    if (rec->chanid == chanid && rec->recstartts == startRecordingTime)
         retval = true;
 
     return retval;
@@ -126,8 +129,8 @@ bool EncoderLink::MatchesRecording(ProgramInfo *rec)
         if (tvrec)
         {
             if (tvrec->chanid == rec->chanid && 
-                tvrec->startts == rec->startts &&
-                tvrec->endts == rec->endts)
+                tvrec->recstartts == rec->recstartts &&
+                tvrec->recendts == rec->recendts)
             {
                 retval = true;
             }
@@ -157,7 +160,7 @@ bool EncoderLink::WouldConflict(ProgramInfo *rec)
     if (!isConnected())
         return true;
 
-    if (rec->startts < endRecordingTime)
+    if (rec->recstartts < endRecordingTime)
         return true;
 
     return false;
@@ -237,8 +240,8 @@ int EncoderLink::StartRecording(ProgramInfo *rec)
 {
     int retval = 0;
 
-    endRecordingTime = rec->endts;
-    startRecordingTime = rec->startts;
+    endRecordingTime = rec->recendts;
+    startRecordingTime = rec->recstartts;
     chanid = rec->chanid;
 
     if (local)
@@ -524,6 +527,16 @@ bool EncoderLink::CheckChannel(QString name)
     return false;
 }
 
+bool EncoderLink::CheckChannelPrefix(QString name, bool &unique)
+{
+    if (local)
+        return tv->CheckChannelPrefix(name, unique);
+
+    cerr << "Should be local only query: CheckChannelPrefix\n";
+    unique = false;
+    return false;
+}
+
 void EncoderLink::GetNextProgram(int direction,
                                  QString &title, QString &subtitle, 
                                  QString &desc, QString &category, 
