@@ -6,6 +6,7 @@
 #include <qurl.h>
 #include <qthread.h>
 #include <qwaitcondition.h>
+#include <qregexp.h>
 
 #include <unistd.h>
 #include <stdlib.h>
@@ -76,9 +77,10 @@ class ProcessRequestThread : public QThread
 
 MainServer::MainServer(bool master, int port, int statusport, 
                        QMap<int, EncoderLink *> *tvList,
-                       QSqlDatabase *db)
+                       QSqlDatabase *db, Scheduler *sched)
 {
     m_db = db;
+    m_sched = sched;
 
     ismaster = master;
     masterServer = NULL;
@@ -113,6 +115,9 @@ MainServer::MainServer(bool master, int port, int statusport,
                 SLOT(reconnectTimeout()));
         masterServerReconnect->start(1000, true);
     }
+
+    if (sched)
+        sched->SetMainServer(this);
 }
 
 MainServer::~MainServer()
@@ -234,10 +239,18 @@ void MainServer::ProcessRequest(QSocket *sock)
     {
         HandleStopRecording(listline, pbs);
     }
+    else if (command == "CHECK_RECORDING")
+    {
+        HandleCheckRecordingActive(listline, pbs);
+    }
     else if (command == "DELETE_RECORDING")
     {
         HandleDeleteRecording(listline, pbs);
     }
+    else if (command == "FORGET_RECORDING")
+    {
+        HandleForgetRecording(listline, pbs);
+    }
     else if (command == "QUERY_GETALLPENDING")
     {
         HandleGetPendingRecordings(pbs);
@@ -318,6 +331,27 @@ void MainServer::ProcessRequest(QSocket *sock)
         else
             HandleFreeTuner(tokens[1].toInt(), pbs);
     }
+    else if (command == "QUERY_IS_ACTIVE_BACKEND")
+    {
+        if (tokens.size() != 1)
+            cerr << QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss")
+                 << " Bad QUERY_IS_ACTIVE_BACKEND" << endl;
+        else
+            HandleIsActiveBackendQuery(listline, pbs);
+        
+    }
+    else if (command == "SHUTDOWN_NOW")
+    {
+        if (tokens.size() != 1)
+            cerr << QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss")
+                 << " Bad SHUTDOWN_NOW request" << endl;
+        else if (!ismaster)
+        {
+            VERBOSE(VB_ALL, "Going down now as of Mainserver request!");
+            QString halt_cmd = listline[1];
+            system(halt_cmd.ascii());
+        }
+    }
     else if (command == "BACKEND_MESSAGE")
     {
         QString message = listline[1];
@@ -491,7 +525,7 @@ void MainServer::HandleAnnounce(QStringList &slist, QStringList commands,
                                  << " WARNING:  Capture device " << audiodevice 
                                  << " is not reporting full duplex "
                                  << "capability.\nSee docs/mythtv-HOWTO, "
-                                 << "section 18 for more information." << endl;
+                                 << "section 20.13 for more information." << endl;
                     }
                     else 
                         cerr << QDateTime::currentDateTime().toString("yyyy-MM-dd hh:mm:ss")
@@ -587,6 +621,8 @@ void MainServer::HandleQueryRecordings(QString type, PlaybackSock *pbs)
                                                       Qt::ISODate);
             proginfo->endts = QDateTime::fromString(query.value(2).toString(),
                                                     Qt::ISODate);
+            proginfo->recstartts = proginfo->startts;
+            proginfo->recendts = proginfo->endts;
             proginfo->title = QString::fromUtf8(query.value(3).toString());
             proginfo->subtitle = QString::fromUtf8(query.value(4).toString());
             proginfo->description = QString::fromUtf8(query.value(5).toString());
@@ -729,7 +765,7 @@ void MainServer::HandleQueueTranscode(QStringList &slist, PlaybackSock *pbs,
     QString message = QString("%1 %2 %3")
                             .arg(cmd)
                             .arg(pginfo->chanid)
-                            .arg(pginfo->startts.toString(Qt::ISODate));
+                            .arg(pginfo->recstartts.toString(Qt::ISODate));
     MythEvent me(message);
     gContext->dispatch(me);
 
@@ -772,6 +808,45 @@ static void *SpawnDelete(void *param)
     return NULL;
 }
 
+void MainServer::HandleCheckRecordingActive(QStringList &slist, 
+                                            PlaybackSock *pbs)
+{
+    QSocket *pbssock = NULL;
+    if (pbs)
+        pbssock = pbs->getSocket();
+
+    ProgramInfo *pginfo = new ProgramInfo();
+    pginfo->FromStringList(slist, 1);
+
+    int result = 0;
+
+    if (ismaster && pginfo->hostname != gContext->GetHostName())
+    {
+        PlaybackSock *slave = getSlaveByHostname(pginfo->hostname);
+
+        if (slave)
+            result = slave->CheckRecordingActive(pginfo);
+    }
+    else
+    {
+        QMap<int, EncoderLink *>::Iterator iter = encoderList->begin();
+        for (; iter != encoderList->end(); ++iter)
+        {
+            EncoderLink *elink = iter.data();
+
+            if (elink->isLocal() && elink->MatchesRecording(pginfo))
+                result = iter.key();
+        }
+    }
+
+    QStringList outputlist = QString::number(result);
+    if (pbssock)
+        SendResponse(pbssock, outputlist);
+
+    delete pginfo;
+    return;
+}
+
 void MainServer::HandleStopRecording(QStringList &slist, PlaybackSock *pbs)
 {
     ProgramInfo *pginfo = new ProgramInfo();
@@ -831,6 +906,17 @@ void MainServer::DoHandleStopRecording(ProgramInfo *pginfo, PlaybackSock *pbs)
         }
     }
 
+    if (QDateTime::currentDateTime() > pginfo->recendts)
+    { //don't update filename if in overrecord
+        if (pbssock)
+        {
+            QStringList outputlist = QString::number(recnum);
+            SendResponse(pbssock, outputlist);
+        }
+        delete pginfo;
+        return;
+    }
+
     QString thequery;
     QSqlQuery query;
 
@@ -838,7 +924,7 @@ void MainServer::DoHandleStopRecording(ProgramInfo *pginfo, PlaybackSock *pbs)
 
     MythContext::KickDatabase(m_db);
 
-    QString startts = pginfo->startts.toString("yyyyMMddhhmm");
+    QString startts = pginfo->recstartts.toString("yyyyMMddhhmm");
     startts += "00";
     QString endts = pginfo->endts.toString("yyyyMMddhhmm");
     endts += "00";
@@ -867,7 +953,7 @@ void MainServer::DoHandleStopRecording(ProgramInfo *pginfo, PlaybackSock *pbs)
     // If we change the recording times we must also adjust the .nuv file's name
     QString fileprefix = gContext->GetFilePrefix();
     QString oldfilename = pginfo->GetRecordFilename(fileprefix);
-    pginfo->endts = now;
+    pginfo->recendts = now;
     QString newfilename = pginfo->GetRecordFilename(fileprefix);
     QFile checkFile(oldfilename);
 
@@ -966,9 +1052,9 @@ void MainServer::DoHandleDeleteRecording(ProgramInfo *pginfo, PlaybackSock *pbs)
 
     QString thequery;
 
-    QString startts = pginfo->startts.toString("yyyyMMddhhmm");
+    QString startts = pginfo->recstartts.toString("yyyyMMddhhmm");
     startts += "00";
-    QString endts = pginfo->endts.toString("yyyyMMddhhmm");
+    QString endts = pginfo->recendts.toString("yyyyMMddhhmm");
     endts += "00";
 
     dblock.lock();
@@ -1048,6 +1134,27 @@ void MainServer::DoHandleDeleteRecording(ProgramInfo *pginfo, PlaybackSock *pbs)
     delete pginfo;
 }
 
+void MainServer::HandleForgetRecording(QStringList &slist, PlaybackSock *pbs)
+{
+    ProgramInfo *pginfo = new ProgramInfo();
+    pginfo->FromStringList(slist, 1);
+
+    QSocket *pbssock = NULL;
+    if (pbs)
+        pbssock = pbs->getSocket();
+
+    pginfo->DeleteHistory(m_db);
+
+    if (pbssock)
+    {
+        QStringList outputlist = QString::number(0);
+        SendResponse(pbssock, outputlist);
+    }
+
+    delete pginfo;
+
+}
+
 void MainServer::getFreeSpace(int &totalspace, int &usedspace)
 {
     struct statfs statbuf;
@@ -1144,52 +1251,22 @@ void MainServer::HandleGetPendingRecordings(PlaybackSock *pbs)
 {
     QSocket *pbssock = pbs->getSocket();
 
-    dblock.lock();
+    QStringList strList;
 
-    MythContext::KickDatabase(m_db);
+    m_sched->getAllPending(&strList);
 
-    Scheduler *sched = new Scheduler(false, encoderList, m_db);
-
-    bool conflicts = sched->FillRecordLists(false);
-    list<ProgramInfo *> *recordinglist = sched->getAllPending();
-
-    dblock.unlock();
-
-    QStringList strlist;
-
-    strlist << QString::number(conflicts);
-    strlist << QString::number(recordinglist->size());
-
-    list<ProgramInfo *>::iterator iter = recordinglist->begin();
-    for (; iter != recordinglist->end(); iter++)
-        (*iter)->ToStringList(strlist);
-
-    SendResponse(pbssock, strlist);
-
-    delete sched;
+    SendResponse(pbssock, strList);
 }
 
 void MainServer::HandleGetScheduledRecordings(PlaybackSock *pbs)
 {
     QSocket *pbssock = pbs->getSocket();
 
-    dblock.lock();
-    MythContext::KickDatabase(m_db);
-    Scheduler *sched = new Scheduler(false, encoderList, m_db);
-    list<ProgramInfo *> *recordinglist = sched->getAllScheduled();
-    dblock.unlock();
+    QStringList strList;
 
-    QStringList strlist;
+    m_sched->getAllScheduled(&strList);
 
-    strlist << QString::number(recordinglist->size());
-
-    list<ProgramInfo *>::iterator iter = recordinglist->begin();
-    for (; iter != recordinglist->end(); iter++)
-        (*iter)->ToStringList(strlist);
-
-    SendResponse(pbssock, strlist);
-
-    delete sched;
+    SendResponse(pbssock, strList);
 }
 
 void MainServer::HandleGetConflictingRecordings(QStringList &slist,
@@ -1198,31 +1275,17 @@ void MainServer::HandleGetConflictingRecordings(QStringList &slist,
 {
     QSocket *pbssock = pbs->getSocket();
 
-    dblock.lock();
-    MythContext::KickDatabase(m_db);
-    Scheduler *sched = new Scheduler(false, encoderList, m_db);
-
     bool removenonplaying = purge.toInt();
 
     ProgramInfo *pginfo = new ProgramInfo();
     pginfo->FromStringList(slist, 1);
 
-    sched->FillRecordLists(false);
+    QStringList strlist;
 
-    list<ProgramInfo *> *conflictlist = sched->getConflicting(pginfo, 
-                                                              removenonplaying);
-
-    dblock.unlock();
-
-    QStringList strlist = QString::number(conflictlist->size());
-
-    list<ProgramInfo *>::iterator iter = conflictlist->begin();
-    for (; iter != conflictlist->end(); iter++)
-        (*iter)->ToStringList(strlist); 
+    m_sched->getConflicting(pginfo, removenonplaying, &strlist);
 
     SendResponse(pbssock, strlist);
 
-    delete sched;
     delete pginfo;
 }
 
@@ -1589,6 +1652,14 @@ void MainServer::HandleRecorderQuery(QStringList &slist, QStringList &commands,
         QString name = slist[2];
         retlist << QString::number((int)(enc->CheckChannel(name)));
     }
+    else if (command == "CHECK_CHANNEL_PREFIX")
+    {
+        bool unique;
+        QString name = slist[2];
+        retlist << QString::number((int)(enc->CheckChannelPrefix(name, 
+                                                                 unique)));
+        retlist << QString::number((int)unique);
+    }
     else if (command == "GET_NEXT_PROGRAM_INFO")
     {
         QString channelname = slist[2];
@@ -1779,6 +1850,25 @@ void MainServer::HandleRemoteEncoder(QStringList &slist, QStringList &commands,
     SendResponse(pbssock, retlist);
 }
 
+void MainServer::HandleIsActiveBackendQuery(QStringList &slist,
+                                            PlaybackSock *pbs)
+{
+    QStringList retlist;
+    QString queryhostname = slist[1];
+    
+    if (gContext->GetHostName() != queryhostname)
+    {
+        if (getSlaveByHostname(queryhostname) != NULL)
+            retlist << "TRUE";
+        else
+            retlist << "FALSE";
+    }
+    else
+        retlist << "TRUE";
+    
+    SendResponse(pbs->getSocket(), retlist);
+} 
+
 void MainServer::HandleFileTransferQuery(QStringList &slist, 
                                          QStringList &commands,
                                          PlaybackSock *pbs)
@@ -2294,6 +2384,46 @@ void MainServer::reconnectTimeout(void)
     playbackList.push_back(masterServer);
 }
 
+// returns true, if a client (slavebackends are not counted!)
+// is connected by checking the lists.
+bool MainServer::isClientConnected()
+{
+    bool foundClient = false;
+
+    foundClient |= (ringBufList.size() > 0);
+    foundClient |= (fileTransferList.size() > 0);
+
+    if ((playbackList.size() > 0) && !foundClient)
+    {
+        vector<PlaybackSock *>::iterator it = playbackList.begin();
+        for (; !foundClient && (it != playbackList.end()); ++it)
+        {
+            // we simply ignore slaveBackends!
+            if (!(*it)->isSlaveBackend())
+                foundClient = true;
+        }
+    }
+    
+    return (foundClient);
+}
+
+// sends the Slavebackends the request to shut down using haltcmd
+void MainServer::ShutSlaveBackendsDown(QString &haltcmd)
+{
+    QStringList bcast = "SHUTDOWN_NOW";
+    bcast << haltcmd;
+    
+    if (playbackList.size() > 0)
+    {
+        vector<PlaybackSock *>::iterator it = playbackList.begin();
+        for (; it != playbackList.end(); ++it)
+        {
+            if ((*it)->isSlaveBackend())
+                WriteStringList((*it)->getSocket(),bcast); 
+        }
+    }
+}
+
 void MainServer::PrintStatus(QSocket *socket)
 {
     QTextStream os(socket);
@@ -2305,16 +2435,105 @@ void MainServer::PrintStatus(QSocket *socket)
     QDateTime qdtNow = QDateTime::currentDateTime();
 
     os << "HTTP/1.0 200 Ok\r\n"
-       << "Content-Type: text/html; charset=\"utf-8\"\r\n"
+       << "Content-Type: text/html; charset=\"UTF-8\"\r\n"
        << "\r\n";
 
-    os << "<HTTP>\r\n"
-       << "<HEAD>\r\n"
-       << "  <TITLE>MythTV Status - " 
+    os << "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" "
+       << "\"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\r\n"
+       << "<html xmlns=\"http://www.w3.org/1999/xhtml\""
+       << " xml:lang=\"en\" lang=\"en\">\r\n"
+       << "<head>\r\n"
+       << "  <meta http-equiv=\"Content-Type\""
+       << "content=\"text/html; charset=UTF-8\" />\r\n"
+       << "  <style type=\"text/css\" title=\"Default\" media=\"all\">\r\n"
+       << "  <!--\r\n"
+       << "  body {\r\n"
+       << "    background-color:#fff;\r\n"
+       << "    font:11px verdana, arial, helvetica, sans-serif;\r\n"
+       << "    margin:20px;\r\n"
+       << "  }\r\n"
+       << "  h1 {\r\n"
+       << "    font-size:28px;\r\n"
+       << "    font-weight:900;\r\n"
+       << "    color:#ccc;\r\n"
+       << "    letter-spacing:0.5em;\r\n"
+       << "    margin-bottom:30px;\r\n"
+       << "    width:650px;\r\n"
+       << "    text-align:center;\r\n"
+       << "  }\r\n"
+       << "  h2 {\r\n"
+       << "    font-size:18px;\r\n"
+       << "    font-weight:800;\r\n"
+       << "    color:#360;\r\n"
+       << "    border:none;\r\n"
+       << "    letter-spacing:0.3em;\r\n"
+       << "    padding:0px;\r\n"
+       << "    margin-bottom:10px;\r\n"
+       << "    margin-top:0px;\r\n"
+       << "  }\r\n"
+       << "  hr {\r\n"
+       << "    display:none;\r\n"
+       << "  }\r\n"
+       << "  div.content {\r\n"
+       << "    width:650px;\r\n"
+       << "    border-top:1px solid #000;\r\n"
+       << "    border-right:1px solid #000;\r\n"
+       << "    border-bottom:1px solid #000;\r\n"
+       << "    border-left:10px solid #000;\r\n"
+       << "    padding:10px;\r\n"
+       << "    margin-bottom:30px;\r\n"
+       << "    -moz-border-radius:8px 0px 0px 8px;\r\n"
+       << "  }\r\n"
+       << "  div#schedule a {\r\n"
+       << "    display:block;\r\n"
+       << "    color:#000;\r\n"
+       << "    text-decoration:none;\r\n"
+       << "    padding:.2em .8em;\r\n"
+       << "    border:thin solid #fff;\r\n"
+       << "    width:350px;\r\n"
+       << "  }\r\n"
+       << "  div#schedule a span {\r\n"
+       << "    display:none;\r\n"
+       << "  }\r\n"
+       << "  div#schedule a:hover {\r\n"
+       << "    background-color:#F4F4F4;\r\n"
+       << "    border-top:thin solid #000;\r\n"
+       << "    border-bottom:thin solid #000;\r\n"
+       << "    border-left:thin solid #000;\r\n"
+       << "    cursor:default;\r\n"
+       << "  }\r\n"
+       << "  div#schedule a:hover span {\r\n"
+       << "    display:block;\r\n"
+       << "    position:absolute;\r\n"
+       << "    background-color:#F4F4F4;\r\n"
+       << "    color:#000;\r\n"
+       << "    left:400px;\r\n"
+       << "    margin-top:-20px;\r\n"
+       << "    width:280px;\r\n"
+       << "    padding:5px;\r\n"
+       << "    border:thin dashed #000;\r\n"
+       << "  }\r\n"
+       << "  div.diskstatus {\r\n"
+       << "    width:325px;\r\n"
+       << "    height:7em;\r\n"
+       << "    float:left;\r\n"
+       << "  }\r\n"
+       << "  div.loadstatus {\r\n"
+       << "    width:325px;\r\n"
+       << "    height:7em;\r\n"
+       << "    float:right;\r\n"
+       << "  }\r\n"
+       << "  -->\r\n"
+       << "  </style>\r\n"
+       << "  <title>MythTV Status - " 
        << qdtNow.toString(shortdateformat) 
-       << " " << qdtNow.toString(timeformat) << "</TITLE>\r\n"
-       << "</HEAD>\r\n"
-       << "<BODY>\r\n";
+       << " " << qdtNow.toString(timeformat) << " - "
+       << MYTH_BINARY_VERSION << "</title>\r\n"
+       << "</head>\r\n"
+       << "<body>\r\n\r\n"
+       << "  <h1>MythTV Status</h1>\r\n"
+       << "  <div class=\"content\">\r\n"
+       << "    <h2>Encoder status</h2>\r\n";
 
     // encoder information ---------------------
     QMap<int, EncoderLink *>::Iterator iter = encoderList->begin();
@@ -2326,97 +2545,160 @@ void MainServer::PrintStatus(QSocket *socket)
 
         if (bIsLocal)
         {
-            os << "Encoder: " << elink->getCardId() << " is local ";
+            os << "    Encoder " << elink->getCardId() << " is local on "
+               << gContext->GetHostName();
         }
         else
         {
-            os << "Encoder: " << elink->getCardId() << " is remote ";
-            if (elink->isConnected())
-                os << "(currently connected) ";
-            else
-                os << "(currently not connected) ";
+            os << "    Encoder " << elink->getCardId() << " is remote on "
+               << elink->getHostname();
+            if (!elink->isConnected())
+            {
+                os << " (currently not connected).<br />";
+                continue;
+            }
         }
 
         TVState encstate = elink->GetState();
 
         if (encstate == kState_WatchingLiveTV)
         {
-            os << "and is watching Live TV.\r\n";
+            os << " and is watching Live TV";
+            if (bIsLocal)
+            {
+                QString title, callsign, dummy;
+                elink->GetChannelInfo(title, dummy, dummy, dummy, dummy, dummy,
+                                      callsign, dummy, dummy, dummy);
+                os << ": '" << title << "' on "  << callsign;
+            }
+            os << ".";
         }
         else if (encstate == kState_RecordingOnly || 
                  encstate == kState_WatchingRecording)
         {
-            os << "and is recording";
+            os << " and is recording";
             if (bIsLocal)
             {
                 ProgramInfo *pi = elink->GetRecording();
                 if (pi)
                 {
-                    os << " '" << pi->title << "'.  This recording will end "
-                       << "at " << (pi->endts).toString(timeformat);
+                    os << " '" << pi->title << "'. This recording will end "
+                       << "at " << (pi->recendts).toString(timeformat);
                     delete pi;
                 }
             }
-            os << ".\r\n";
+            os << ".";
         }
         else
-            os << "and is not recording.\r\n";
+            os << " and is not recording.";
 
-        os << "<br>\r\n";
+        if (elink->isLowOnFreeSpace())
+            os << " <strong>WARNING</strong>:"
+               << " This backend is low on free disk space!";
+
+        os << "<br />\r\n";
     }
 
+    os << "  </div>\r\n\r\n"
+       << "  <div class=\"content\">\r\n"
+       << "    <h2>Schedule</h2>\r\n";
+
     // upcoming shows ---------------------
-    dblock.lock();
-    MythContext::KickDatabase(m_db);
-    Scheduler *sched = new Scheduler(false, encoderList, m_db);
-    sched->FillRecordLists(false);
-    list<ProgramInfo *> *recordinglist = sched->getAllPending();
-    dblock.unlock();
+    list<ProgramInfo *> recordingList;
+    m_sched->getAllPending(&recordingList);
 
-    unsigned int iNum = 5;
-    if (recordinglist->size() < iNum) 
-    {
-        iNum = recordinglist->size();
-    }
+    unsigned int iNum = 10;
+    if (recordingList.size() < iNum) 
+        iNum = recordingList.size();
 
     if (iNum == 0)
-    {
-        os << "<P>There are no shows scheduled for recording.\r\n";
-    }
+        os << "    There are no shows scheduled for recording.\r\n";
     else
     {
-       os << "<P>The next " << iNum << " show" << (iNum == 1 ? "" : "s" )
+       os << "    The next " << iNum << " show" << (iNum == 1 ? "" : "s" )
           << " that " << (iNum == 1 ? "is" : "are") 
-          << " scheduled for recording:<BR>\r\n";
+          << " scheduled for recording:\r\n";
 
-       os << "<TABLE BORDER WIDTH=80%>\r\n"; 
-       os << "<TR><TH>Start Time</TH><TH>Show</TH><TH>Encoder</TH></TR>\r\n";
-       list<ProgramInfo *>::iterator iter = recordinglist->begin();
-       for (unsigned int i = 0; (iter != recordinglist->end()) && i < iNum; 
+       os << "    <div id=\"schedule\">\r\n";
+       list<ProgramInfo *>::iterator iter = recordingList.begin();
+       for (unsigned int i = 0; (iter != recordingList.end()) && i < iNum; 
             iter++, i++)
        {
            if (!(*iter)->recording ||     // bad entry, don't show as upcoming
-               ((*iter)->startts) < QDateTime::currentDateTime()) // recording
+               ((*iter)->recstartts) < QDateTime::currentDateTime()) // rec
            {                       
                i--;
            }
            else
            {
-               os << "<TR " << ((i % 2 == 0) ? "BGCOLOR=EEEEEE" : "") << ">" 
-                  << "<TD>" << ((*iter)->startts).toString(shortdateformat) 
-                  << " " << ((*iter)->startts).toString(timeformat) << "</TD>" 
-                  << "<TD>" << (*iter)->title << "</TD>"
-                  << "<TD>" << (*iter)->cardid << "</TD></TR>\r\n";
+               QString qstrTitle = ((*iter)->title).replace(QRegExp("\""), 
+                                                            "&quot;");
+               QString qstrDescription = ((*iter)->description).replace(
+                                                     QRegExp("\""), "&quot;");
+               QString qstrSubtitle = ((*iter)->subtitle).replace(
+                                                     QRegExp("\""), "&quot;");
+               QString timeToRecstart = "in";
+               int totalSecsToRecstart = qdtNow.secsTo((*iter)->recstartts);
+               int preRollSeconds = gContext->GetNumSetting("RecordPreRoll", 0);
+               totalSecsToRecstart -= preRollSeconds;
+               totalSecsToRecstart -= 60; //since we're not displaying seconds
+               int totalDaysToRecstart = totalSecsToRecstart / 86400;
+               int hoursToRecstart = (totalSecsToRecstart / 3600)
+                                     - (totalDaysToRecstart * 24);
+               int minutesToRecstart = (totalSecsToRecstart / 60) % 60;
+
+               if (totalDaysToRecstart > 1)
+                   timeToRecstart += QString(" %1 days,")
+                                             .arg(totalDaysToRecstart);
+               else if (totalDaysToRecstart == 1)
+                   timeToRecstart += (" 1 day,");
+
+               if (hoursToRecstart != 1)
+                   timeToRecstart += QString(" %1 hours and")
+                                             .arg(hoursToRecstart);
+               else if (hoursToRecstart == 1)
+                   timeToRecstart += " 1 hour and";
+ 
+               if (minutesToRecstart != 1)
+                   timeToRecstart += QString(" %1 minutes")
+                                             .arg(minutesToRecstart);
+               else
+                   timeToRecstart += " 1 minute";
+
+               if (hoursToRecstart == 0 && minutesToRecstart == 0)
+                   timeToRecstart = "within one minute";
+
+               if (totalSecsToRecstart < 0)
+                   timeToRecstart = "soon";
+
+               os << "      <a href=\"#\">"
+                  << ((*iter)->recstartts).addSecs(-preRollSeconds)
+                                          .toString("ddd") << " "
+                  << ((*iter)->recstartts).addSecs(-preRollSeconds)
+                                          .toString(shortdateformat) << " "
+                  << ((*iter)->recstartts).addSecs(-preRollSeconds)
+                                          .toString(timeformat) << " - "
+                  << (*iter)->channame << " - " << qstrTitle << "<br />"
+                  << "<span><strong>" << qstrTitle << "</strong> ("
+                  << (*iter)->startts.toString(timeformat) << "-"
+                  << (*iter)->endts.toString(timeformat) << ")<br />"
+                  << (qstrSubtitle == "" ? QString("") : "<em>" + qstrSubtitle
+                                                          + "</em><br /><br />")
+                  << qstrDescription << "<br /><br />"
+                  << "This recording will start "  << timeToRecstart
+                  << " using encoder " << (*iter)->cardid << " with the '";
+               dblock.lock();
+               os << (*iter)->GetProgramRecordingProfile(m_db);
+               dblock.unlock();
+               os << "' profile.</span></a><hr />\r\n";
            }
        }
-       os << "</TABLE>";
-    }
+       os  << "    </div>\r\n";
+   }
 
-    delete sched;
-
-    os << "<P>Machine Information:\r\n";
-    os << "<TABLE WIDTH =100% BGCOLOR=EEEEEE>";
-    os << "<TR><TD>";
+    os << "  </div>\r\n\r\n  <div class=\"content\">\r\n"
+       << "    <h2>Machine information</h2>\r\n"
+       << "    <div class=\"diskstatus\">\r\n";
 
     // drive space   ---------------------
     int iTotal = -1, iUsed = -1;
@@ -2424,36 +2706,95 @@ void MainServer::PrintStatus(QSocket *socket)
 
     getFreeSpace(iTotal, iUsed);
 
-    os << "Disk Usage:\r\n";
-
-    os << "<UL><LI>Total Space: ";
+    os << "      Disk Usage:\r\n      <ul>\r\n        <li>Total Space: ";
     rep.sprintf(tr("%d,%03d MB "), (iTotal) / 1000, (iTotal) % 1000);
-    os << rep << "\r\n";
+    os << rep << "</li>\r\n";
 
-    os << "<LI>Space Used: ";
+    os << "        <li>Space Used: ";
     rep.sprintf(tr("%d,%03d MB "), (iUsed) / 1000, (iUsed) % 1000);
-    os << rep << "\r\n";
+    os << rep << "</li>\r\n";
 
-    os << "<LI>Space Free: ";
+    os << "        <li>Space Free: ";
     rep.sprintf(tr("%d,%03d MB "), (iTotal - iUsed) / 1000,
                 (iTotal - iUsed) % 1000);
-    os << rep << "</UL>\r\n";
+    os << rep << "</li>\r\n      </ul>\r\n    </div>\r\n\r\n";
 
-    os << "</TD><TD>";
-    
     // load average ---------------------
+    os << "    <div class=\"loadstatus\">\r\n";
     double rgdAverages[3];
     if (getloadavg(rgdAverages, 3) != -1)
     {
-        os << "This machine's load average:";
-        os << "<UL><LI>1 Minute: " << rgdAverages[0] << "\r\n";
-        os << "<LI>5 Minute: " << rgdAverages[1] << "\r\n";
-        os << "<LI>15 Minute: " << rgdAverages[2] << "\r\n</UL>";
+        os << "      This machine's load average:"
+           << "\r\n      <ul>\r\n        <li>"
+           << "1 Minute: " << rgdAverages[0] << "</li>\r\n"
+           << "        <li>5 Minutes: " << rgdAverages[1] << "</li>\r\n"
+           << "        <li>15 Minutes: " << rgdAverages[2]
+           << "</li>\r\n      </ul>\r\n";
     }
 
-    os << "</TD></TR></TABLE>";    // end the machine information table
+    os << "    </div>\r\n";    // end of disk status and load average
 
-    os << "</BODY>\r\n"
-       << "</HTTP>\r\n";
+    dblock.lock();
+
+    QString querytext;
+    int DaysOfData;
+    QDateTime GuideDataThrough;
+
+    querytext = QString("SELECT max(endtime) FROM program;");
+
+    QSqlQuery query = m_db->exec(querytext);
+
+    if (query.isActive() && query.numRowsAffected())
+    {
+        query.next();
+        if (query.isValid())
+            GuideDataThrough = QDateTime::fromString(query.value(0).toString(),
+                                                     Qt::ISODate);
+    }
+    dblock.unlock();
+
+    QString mfdLastRunStart, mfdLastRunEnd, mfdLastRunStatus;
+
+    mfdLastRunStart = gContext->GetSetting("mythfilldatabaseLastRunStart");
+    mfdLastRunEnd = gContext->GetSetting("mythfilldatabaseLastRunEnd");
+    mfdLastRunStatus = gContext->GetNumSetting("mythfilldatabaseLastRunStatus");
+
+    os << "    Last mythfilldatabase run started on " << mfdLastRunStart
+       << " and ended on " << mfdLastRunEnd << ". ";
+
+    if(!mfdLastRunStatus)
+       os << "<br /><strong>WARNING</strong>: "
+          << "There was an error during the last run.<br />\r\n";
+    else
+       os << "Last run was successful.<br />\r\n";
+
+    if (!GuideDataThrough.isNull())
+    {
+        os << "    There's guide data until "
+           << QDateTime(GuideDataThrough).toString("yyyy-MM-dd hh:mm");
+
+        DaysOfData = qdtNow.daysTo(GuideDataThrough);
+
+        if (DaysOfData > 0)
+            os << " (" << DaysOfData << " day"
+               << (DaysOfData == 1 ? "" : "s" ) << ").";
+        else
+           os << ".";
+
+        if (DaysOfData <= 3)
+            os << " <strong>WARNING</strong>: is mythfilldatabase running?";
+    }
+    else
+        os << "    There's <strong>no guide data</strong> availible! "
+           << "You need to run mythfilldatabase!";
+
+    os << "\r\n  </div>\r\n\r\n</body>\r\n</html>\r\n";
+
+    while (recordingList.size() > 0)
+    {
+        ProgramInfo *pginfo = recordingList.back();
+        delete pginfo;
+        recordingList.pop_back();
+    }
 }
 
