@@ -14,6 +14,7 @@ using namespace std;
 #include "playbacksock.h"
 #include "encoderlink.h"
 #include "filetransfer.h"
+#include "scheduler.h"
 
 class QSqlDatabase;
 class HttpStatus;
@@ -24,13 +25,17 @@ class MainServer : public QObject
     Q_OBJECT
   public:
     MainServer(bool master, int port, int statusport, 
-               QMap<int, EncoderLink *> *tvList, QSqlDatabase *db);
+               QMap<int, EncoderLink *> *tvList, QSqlDatabase *db,
+               Scheduler *sched);
 
    ~MainServer();
 
     void customEvent(QCustomEvent *e);
     void PrintStatus(QSocket *socket);
 
+    bool isClientConnected();
+    void ShutSlaveBackendsDown(QString &haltcmd);
+
     void ProcessRequest(QSocket *sock); 
     void MarkUnused(ProcessRequestThread *prt);
 
@@ -48,12 +53,13 @@ class MainServer : public QObject
                         QSocket *socket);
     void HandleDone(QSocket *socket);
 
-    // playback
+    void HandleIsActiveBackendQuery(QStringList &slist, PlaybackSock *pbs);
     void HandleQueryRecordings(QString type, PlaybackSock *pbs);
     void HandleStopRecording(QStringList &slist, PlaybackSock *pbs);
     void DoHandleStopRecording(ProgramInfo *pginfo, PlaybackSock *pbs);
     void HandleDeleteRecording(QStringList &slist, PlaybackSock *pbs);
     void DoHandleDeleteRecording(ProgramInfo *pginfo, PlaybackSock *pbs);
+    void HandleForgetRecording(QStringList &slist, PlaybackSock *pbs);
     void HandleQueryFreeSpace(PlaybackSock *pbs);
     void HandleQueryCheckFile(QStringList &slist, PlaybackSock *pbs);
     void HandleGetPendingRecordings(PlaybackSock *pbs);
@@ -70,6 +76,7 @@ class MainServer : public QObject
     void HandleMessage(QStringList &slist, PlaybackSock *pbs);
     void HandleGenPreviewPixmap(QStringList &slist, PlaybackSock *pbs);
     void HandleIsRecording(QStringList &slist, PlaybackSock *pbs);
+    void HandleCheckRecordingActive(QStringList &slist, PlaybackSock *pbs);
     void HandleFillProgramInfo(QStringList &slist, PlaybackSock *pbs);
     void HandleQueueTranscode(QStringList &slist, PlaybackSock *pbs,
                               int state);
@@ -115,6 +122,7 @@ class MainServer : public QObject
     bool masterBackendOverride;
 
     QSqlDatabase *m_db;
+    Scheduler *m_sched;
 
     QMutex readReadyLock;
 };
