@@ -18,19 +18,29 @@ using namespace std;
 #include "libmythtv/scheduledrecording.h"
 #include "encoderlink.h"
 #include "libmyth/mythcontext.h"
+#include "mainserver.h"
 #include "remoteutil.h"
 
 Scheduler::Scheduler(bool runthread, QMap<int, EncoderLink *> *tvList, 
-                     QSqlDatabase *ldb)
+                     QSqlDatabase *ldb, bool noAutoShutdown)
 {
     hasconflicts = false;
     db = ldb;
     m_tvList = tvList;
 
+    m_mainServer = NULL;
+    m_noAutoShutdown = noAutoShutdown;
+    // we block the shutdown until a backend connected, if no recording
+    // starts within the next period of time (calculated in the while() loop)
+    m_blockShutdown = true;
+
     setupCards();
 
     threadrunning = runthread;
 
+    recordingList_lock = new QMutex(true);
+    scheduledList_lock = new QMutex(true);
+
     if (runthread)
     {
         pthread_t scthread;
@@ -48,6 +58,11 @@ Scheduler::~Scheduler()
     }
 }
 
+void Scheduler::SetMainServer(MainServer *ms)
+{
+    m_mainServer = ms;
+}
+
 void Scheduler::setupCards(void)
 {
     QString thequery;
@@ -140,7 +155,7 @@ class comp_proginfo
   public:
     bool operator()(ProgramInfo *a, ProgramInfo *b)
     {
-        return (a->startts < b->startts);
+        return (a->recstartts < b->recstartts);
     }
 };
 
@@ -156,15 +171,17 @@ void Scheduler::FillEncoderFreeSpaceCache()
 
 bool Scheduler::FillRecordLists(bool doautoconflicts)
 {
-    doRank = (bool)gContext->GetNumSetting("RankingActive");
-    doRankFirst = (bool)gContext->GetNumSetting("RankingOrder");
+    doRecPriority = (bool)gContext->GetNumSetting("RecPriorityActive");
+    doRecPriorityFirst = (bool)gContext->GetNumSetting("RecPriorityOrder");
 
-    if (rankMap.size() > 0)
-        rankMap.clear();
-    if (channelRankMap.size() > 0)
-        channelRankMap.clear();
-    if (recTypeRankMap.size() > 0)
-        recTypeRankMap.clear();
+    if (recpriorityMap.size() > 0)
+        recpriorityMap.clear();
+    if (channelRecPriorityMap.size() > 0)
+        channelRecPriorityMap.clear();
+    if (recTypeRecPriorityMap.size() > 0)
+        recTypeRecPriorityMap.clear();
+
+    QMutexLocker lockit(recordingList_lock);
 
     while (recordingList.size() > 0)
     {
@@ -192,6 +209,7 @@ bool Scheduler::FillRecordLists(bool doautoconflicts)
     {
         recordingList.sort(comp_proginfo());
         MarkKnownInputs();
+        PruneOverlaps();
         MarkConflicts();
         PruneList();
         MarkConflicts();
@@ -226,6 +244,8 @@ void Scheduler::FillRecordListFromMaster(void)
 
     vector<ProgramInfo *>::iterator pgiter = reclist.begin();
 
+    QMutexLocker lockit(recordingList_lock);
+
     for (; pgiter != reclist.end(); pgiter++)
     {
         ProgramInfo *pginfo = (*pgiter);
@@ -237,27 +257,27 @@ void Scheduler::FillRecordListFromMaster(void)
 
 void Scheduler::PrintList(void)
 {
-    QString totrank;
+    QString totrecpriority;
 
     cout << "--- print list start ---\n";
     list<ProgramInfo *>::iterator i = recordingList.begin();
     cout << "Title                 Chan  ChID  StartTime       S I C "
-            "-- C R D S Rank Total" << endl;
+            " C R O N Priority Total" << endl;
     for (; i != recordingList.end(); i++)
     {
         ProgramInfo *first = (*i);
 
-        totrank = QString::number(totalRank(first));
+        totrecpriority = QString::number(totalRecPriority(first));
 
         cout << first->title.leftJustify(22, ' ', true)
              << first->chanstr.rightJustify(4, ' ') << "  " << first->chanid 
-             << first->startts.toString("  MMM dd hh:mmap  ")
+             << first->recstartts.toString("  MMM dd hh:mmap  ")
              << first->sourceid 
-             << " " << first->inputid << " " << first->cardid << " -- "  
+             << " " << first->inputid << " " << first->cardid << "  "  
              << first->conflicting << " " << first->recording << " "
-             << first->duplicate << " " << first->suppressed << " "
-             << first->rank.rightJustify(4, ' ') << " "
-             << totrank.rightJustify(4, ' ')
+             << first->override << " " << first->NoRecordChar() << " "
+             << first->recpriority.rightJustify(8, ' ') << " "
+             << totrecpriority.rightJustify(4, ' ')
              << endl;
     }
 
@@ -300,6 +320,8 @@ void Scheduler::RemoveRecording(ProgramInfo *pginfo)
 {
     recPendingList.remove(pginfo->schedulerid);
 
+    QMutexLocker lockit(recordingList_lock);
+
     list<ProgramInfo *>::iterator i = recordingList.begin();
     for (; i != recordingList.end(); i++)
     {
@@ -320,12 +342,7 @@ bool Scheduler::Conflict(ProgramInfo *a, ProgramInfo *b)
             return false;
     }
 
-    if ((a->startts <= b->startts && b->startts < a->endts) ||
-        (a->startts <  b->endts   && b->endts   < a->endts) ||
-        (b->startts <= a->startts && a->startts < b->endts) ||
-        (b->startts <  a->endts   && a->endts   < b->endts))
-        return true;
-    return false;
+    return (a->recstartts < b->recendts && a->recendts > b->recstartts);
 }
 
 void Scheduler::MarkKnownInputs(void)
@@ -380,10 +397,47 @@ void Scheduler::MarkConflicts(list<ProgramInfo *> *uselist)
     }
 }
 
+void Scheduler::PruneOverlaps(void)
+{
+    list<ProgramInfo *>::iterator i;
+    for (i = recordingList.begin(); i != recordingList.end(); i++)
+    {
+        ProgramInfo *first = (*i);
+        if (first->norecord == nrOverlap)
+            continue;
+
+        list<ProgramInfo *>::iterator j = i;
+        for (j++; j != recordingList.end(); j++)
+        {
+            ProgramInfo *second = (*j);
+            if (second->norecord == nrOverlap)
+                continue;
+
+            if (first->IsSameTimeslot(*second))
+            {
+                int pfirst = RecTypePriority(first->rectype);
+                int psecond = RecTypePriority(second->rectype);
+                if (pfirst < psecond || 
+                    (pfirst == psecond && first->recordid < second->recordid))
+                {
+                    second->recording = false;
+                    second->norecord = nrOverlap;
+                }
+                else
+                {
+                    first->recording = false;
+                    first->norecord = nrOverlap;
+                    break;
+                }
+            }
+        }
+    }    
+}
+
 void Scheduler::PruneList(void)
 {
     list<ProgramInfo *>::reverse_iterator i;
-    list<ProgramInfo *>::iterator deliter, q;
+    list<ProgramInfo *>::iterator q;
 
     QDateTime now = QDateTime::currentDateTime();
 
@@ -394,10 +448,8 @@ void Scheduler::PruneList(void)
 
         if (!rec->AllowRecordingNewEpisodes(db))
         {
-            rec->suppressed = true;
             rec->recording = false;
-            rec->reasonsuppressed = tr("the maximum number of episodes have "
-                                       "already been recorded.");
+            rec->norecord = nrTooManyRecordings;
         }
 
         q++;
@@ -408,7 +460,7 @@ void Scheduler::PruneList(void)
     {
         ProgramInfo *rec = (*q);
 
-        if (rec->startts > now)
+        if (rec->recstartts > now)
         {
             break;
         }
@@ -424,6 +476,7 @@ void Scheduler::PruneList(void)
             if ((*dreciter).IsSameProgramTimeslot(*rec))
             {
                 rec->recording = false;
+                rec->norecord = nrDontRecordList;
             }
         }
 
@@ -445,63 +498,75 @@ void Scheduler::PruneList(void)
             q++;
     }
 
-    i = recordingList.rbegin();
-    while (i != recordingList.rend())
+    for (i = recordingList.rbegin(); i != recordingList.rend(); i++)
     {
-        list<ProgramInfo *>::reverse_iterator j = i;
-        j++;
-
         ProgramInfo *first = (*i);
 
-        if (first->GetProgramRecordingStatus(db) > kSingleRecord &&
-            (first->subtitle.length() > 2 && first->description.length() > 2))
+        if (!first->recording || first->rectype == kSingleRecord ||
+            first->subtitle.length() <= 2 && first->description.length() <= 2)
+            continue;
+
+        list<ProgramInfo *>::reverse_iterator j = i;
+
+        for (j++; j != recordingList.rend(); j++)
         {
-            if (first->duplicate)
+            ProgramInfo *second = (*j);
+
+            if (!second->recording)
+                continue;
+
+            if (first->IsSameProgram(*second))
             {
-                first->recording = false;
-            }
-            else
-            {
-                while (j != recordingList.rend())
+                if (((second->conflicting && !first->conflicting) ||
+                     second->recstartts < now.addSecs(-15) || first->override == 1) 
+                    && second->override != 1 
+                    && second->recdups != kRecordDupsAlways)
                 {
-                    ProgramInfo *second = (*j);
-                    if (first->IsSameTimeslot(*second)) 
-                    {
-                        delete second;
-                        deliter = j.base();
-                        deliter--;
-                        recordingList.erase(deliter);
-                    }
-                    else if (first->IsSameProgram(*second))
-                    {
-                        if ((second->conflicting && !first->conflicting) ||
-                            second->startts < now.addSecs(-15))
-                        {
-                            delete second;
-                            deliter = j.base();
-                            deliter--;
-                            recordingList.erase(deliter);
-                        }
-                        else
-                        {
-                            delete first;
-                            deliter = i.base();
-                            deliter--;
-                            recordingList.erase(deliter);
-                            break;
-                        }
-                    }
-                    else
-                    {
-                        j++;
-                    }
+                    second->recording = false;
+                    second->norecord = nrOtherShowing;
+                }
+                else if (first->override != 1
+                         && first->recdups != kRecordDupsAlways)
+                {
+                    first->recording = false;
+                    first->norecord = nrOtherShowing;
                 }
             }
         }
-        i++;
     }    
 }
 
+void Scheduler::getAllPending(list<ProgramInfo *> *retList)
+{
+    QMutexLocker lockit(recordingList_lock);
+
+    while (retList->size() > 0)
+    {
+        ProgramInfo *pginfo = retList->back();
+        delete pginfo;
+        retList->pop_back();
+    }
+
+    list<ProgramInfo *>::iterator i = recordingList.begin();
+    for (; i != recordingList.end(); i++)
+    {
+        ProgramInfo *newInfo = new ProgramInfo(*(*i));
+        retList->push_back(newInfo);
+    }
+}
+
+void Scheduler::getAllPending(QStringList *strList)
+{
+    QMutexLocker lockit(recordingList_lock);
+
+    (*strList) << QString::number(hasconflicts);
+    (*strList) << QString::number(recordingList.size());
+
+    list<ProgramInfo *>::iterator i = recordingList.begin();
+    for (; i != recordingList.end(); i++)
+        (*i)->ToStringList(*strList);
+}
+
 list<ProgramInfo *> *Scheduler::getAllScheduled(void)
 {
     while (scheduledList.size() > 0)
@@ -516,10 +581,42 @@ list<ProgramInfo *> *Scheduler::getAllScheduled(void)
     return &scheduledList;
 }
 
+void Scheduler::getAllScheduled(QStringList *strList)
+{
+    QMutexLocker lockit(scheduledList_lock);
+
+    getAllScheduled();
+
+    (*strList) << QString::number(scheduledList.size());
+
+    list<ProgramInfo *>::iterator i = scheduledList.begin();
+    for (; i != scheduledList.end(); i++)
+        (*i)->ToStringList(*strList);
+}
+
+void Scheduler::getConflicting(ProgramInfo *pginfo,
+                               bool removenonplaying,
+                               QStringList *strlist)
+{
+    QMutexLocker lockit(recordingList_lock);
+
+    list<ProgramInfo *> *curList = getConflicting(pginfo, removenonplaying);
+
+    (*strlist) << QString::number(curList->size());
+
+    list<ProgramInfo *>::iterator i = curList->begin();
+    for (; i != curList->end(); i++)
+        (*i)->ToStringList(*strlist);
+
+    delete curList;
+}
+
 list<ProgramInfo *> *Scheduler::getConflicting(ProgramInfo *pginfo,
                                                bool removenonplaying,
                                                list<ProgramInfo *> *uselist)
 {
+    QMutexLocker lockit(recordingList_lock);
+
     if (!pginfo->conflicting && removenonplaying)
         return NULL;
 
@@ -548,49 +645,55 @@ list<ProgramInfo *> *Scheduler::getConflicting(ProgramInfo *pginfo,
     return retlist;
 }
 
-int Scheduler::totalRank(ProgramInfo *info)
+int Scheduler::totalRecPriority(ProgramInfo *info)
 {
-    int rank = 0;
+    int recpriority = 0;
     RecordingType rectype;
 
-    if (rankMap.contains(info->schedulerid))
-        return rankMap[info->schedulerid];
-
-    if (!channelRankMap.contains(info->chanid))
-        channelRankMap[info->chanid] = info->GetChannelRank(db, info->chanid);
+    if (recpriorityMap.contains(info->schedulerid))
+        return recpriorityMap[info->schedulerid];
 
+    if (!channelRecPriorityMap.contains(info->chanid))
+    {
+        channelRecPriorityMap[info->chanid] = 
+                                 info->GetChannelRecPriority(db, info->chanid);
+    }
     rectype = info->GetProgramRecordingStatus(db);
-    if (!recTypeRankMap.contains(rectype))
-        recTypeRankMap[rectype] = info->GetRecordingTypeRank(rectype);
+    if (!recTypeRecPriorityMap.contains(rectype))
+    {
+        recTypeRecPriorityMap[rectype] = 
+                                    info->GetRecordingTypeRecPriority(rectype);
+    }
 
-    rank = info->rank.toInt();
-    rank += channelRankMap[info->chanid];
-    rank += recTypeRankMap[rectype];
-    rankMap[info->schedulerid] = rank;
+    recpriority = info->recpriority.toInt();
+    recpriority += channelRecPriorityMap[info->chanid];
+    recpriority += recTypeRecPriorityMap[rectype];
+    recpriorityMap[info->schedulerid] = recpriority;
 
-    return rank;
+    return recpriority;
 }
 
-void Scheduler::CheckRank(ProgramInfo *info,
+void Scheduler::CheckRecPriority(ProgramInfo *info,
                           list<ProgramInfo *> *conflictList)
 {
-    int rank, srank, resolved = 0;
+    int recpriority, srecpriority, resolved = 0;
 
-    rank = totalRank(info);
+    recpriority = totalRecPriority(info);
 
     list<ProgramInfo *>::iterator i = conflictList->begin();
     for (; i != conflictList->end(); i++)
     {
         ProgramInfo *second = (*i);
 
-        srank = totalRank(second);
+        srecpriority = totalRecPriority(second);
 
-        if (rank == srank)
+        if (recpriority == srecpriority)
             continue;
 
-        if (rank > srank)
+        if (recpriority > srecpriority)
         {
             second->recording = false;
+            second->norecord = nrLowerRecPriority;
             resolved++;
         }
     }
@@ -626,6 +729,7 @@ void Scheduler::CheckOverride(ProgramInfo *info,
             ProgramInfo *del = (*i);
 
             del->recording = false;
+            del->norecord = nrManualConflict;
         }
         info->conflicting = false;
     }
@@ -669,6 +773,7 @@ void Scheduler::MarkSingleConflict(ProgramInfo *info,
                     test->endts == badend)
                 {
                     test->recording = false;
+                    test->norecord = nrManualConflict;
                 }
             }
         }
@@ -707,6 +812,7 @@ void Scheduler::MarkSingleConflict(ProgramInfo *info,
                 if (test->title == badtitle)
                 {
                     test->recording = false;
+                    test->norecord = nrManualConflict;
                 }
             }
         }
@@ -731,7 +837,7 @@ void Scheduler::MarkConflictsToRemove(void)
 {
     list<ProgramInfo *>::iterator i;
 
-    if (doRank && doRankFirst) 
+    if (doRecPriority && doRecPriorityFirst) 
     {
         i = recordingList.begin();
         for (; i != recordingList.end(); i++)
@@ -741,7 +847,7 @@ void Scheduler::MarkConflictsToRemove(void)
             if (first->conflicting && first->recording)
             {
                 list<ProgramInfo *> *conflictList = getConflicting(first);
-                CheckRank(first, conflictList);
+                CheckRecPriority(first, conflictList);
                 delete conflictList;
             }
         }
@@ -775,7 +881,7 @@ void Scheduler::MarkConflictsToRemove(void)
             first->conflicting = false;
     }
 
-    if (doRank && !doRankFirst) 
+    if (doRecPriority && !doRecPriorityFirst) 
     {
         i = recordingList.begin();
         for (; i != recordingList.end(); i++)
@@ -785,7 +891,7 @@ void Scheduler::MarkConflictsToRemove(void)
             if (first->conflicting && first->recording)
             {
                 list<ProgramInfo *> *conflictList = getConflicting(first);
-                CheckRank(first, conflictList);
+                CheckRecPriority(first, conflictList);
                 delete conflictList;
             }
         }
@@ -830,13 +936,13 @@ ProgramInfo *Scheduler::GetBest(ProgramInfo *info,
         }
         else if (testtype == type)
         {
-            if (test->startts < info->startts)
+            if (test->recstartts < info->recstartts)
             {
                 best = test;
                 break;
             }
-            if (test->startts.secsTo(test->endts) >
-                info->startts.secsTo(info->endts))
+            if (test->recstartts.secsTo(test->recendts) >
+                info->recstartts.secsTo(info->recendts))
             {
                 best = test;
                 break;
@@ -872,12 +978,14 @@ void Scheduler::GuessSingle(ProgramInfo *info,
         {
             ProgramInfo *pginfo = (*i);
             pginfo->recording = false;
+            pginfo->norecord = nrAutoConflict;
         }
         best->conflicting = false;
     }
     else
     {
         info->recording = false;
+        info->norecord = nrAutoConflict;
     } 
 }
 
@@ -940,12 +1048,30 @@ list<ProgramInfo *> *Scheduler::CopyList(list<ProgramInfo *> *sourcelist)
 
             if (!placed)
             {
-                second->inputid = sourceToInput[first->sourceid][0];
-                second->cardid = inputToCard[second->inputid];
+                if (numinputs > 0)
+                {
+                    second->inputid = sourceToInput[first->sourceid][0];
+                    second->cardid = inputToCard[second->inputid];
+                }
+                else
+                {
+                    cerr << "Source: " << first->sourceid << " is not attached"
+                         << " to an input on a capture card.\n";
+                    cerr << "Unable to schedule:\n";
+                    cerr << first->title.leftJustify(22, ' ', true)
+                         << first->chanstr.rightJustify(4, ' ') << "  " 
+                         << first->chanid 
+                         << first->recstartts.toString("  MMM dd hh:mmap  ")
+                         << endl;
+                    cerr << " for recording.  It will be removed.";
+                    delete second;
+                    second = NULL;
+                }
             }
         }
 
-        retlist->push_back(second);
+        if (second)
+            retlist->push_back(second);
     }
 
     return retlist;
@@ -1003,7 +1129,8 @@ void Scheduler::DoMultiCard(void)
             if (second->conflictfixed)
                 secondmove = false;
 
-            if (doRank && totalRank(second) > totalRank(first))
+            if (doRecPriority && 
+                totalRecPriority(second) > totalRecPriority(first))
             {
                 highermove = secondmove;
                 higher = second;
@@ -1175,6 +1302,11 @@ void Scheduler::RunScheduler(void)
 
     list<ProgramInfo *>::iterator recIter;
 
+    QDateTime idleSince = QDateTime();
+    int idleTimeoutSecs = 0;
+    int idleWaitForRecordingTime = 0;
+    bool doneWakeupCheck = false;
+
     // wait for slaves to connect
     sleep(2);
 
@@ -1196,6 +1328,27 @@ void Scheduler::RunScheduler(void)
             // Determine if the user wants us to start recording early
             // and by how many seconds
             prerollseconds = gContext->GetNumSetting("RecordPreRoll");
+
+            idleTimeoutSecs = gContext->GetNumSetting("idleTimeoutSecs", 0);
+            idleWaitForRecordingTime =
+                       gContext->GetNumSetting("idleWaitForRecordingTime", 15);
+
+            // check once on startup, if a recording starts within the
+            // idleWaitForRecordingTime. If no, block the shutdown,
+            // because system seems to be waken up by the user and not by a
+            // wakeup call
+            if (!doneWakeupCheck)
+            {
+                if ((recIter = recordingList.begin()) != recordingList.end())
+                {
+                    if (curtime.secsTo((*recIter)->startts) - prerollseconds
+                        < idleWaitForRecordingTime * 60)
+                    {
+                        m_blockShutdown = false;
+                    }
+                }
+                doneWakeupCheck = true;
+            }
         }
 
         recIter = recordingList.begin();
@@ -1214,7 +1367,7 @@ void Scheduler::RunScheduler(void)
 
             bool recording = nextRecording->recording;
 
-            nextrectime = nextRecording->startts;
+            nextrectime = nextRecording->recstartts;
             secsleft = curtime.secsTo(nextrectime);
 
             if (secsleft - prerollseconds > 35)
@@ -1290,6 +1443,13 @@ void Scheduler::RunScheduler(void)
             if (recording && secsleft <= -2)
             {
                 QString msg;
+
+                nextRecording->recstartts = 
+                    QDateTime::currentDateTime().addSecs(30);
+                nextRecording->recstartts.setTime(QTime(
+                                   nextRecording->recstartts.time().hour(),
+                                   nextRecording->recstartts.time().minute()));
+
                 if (nexttv->StartRecording(nextRecording))
                     msg = "Started recording";
                 else
@@ -1325,10 +1485,125 @@ void Scheduler::RunScheduler(void)
                 recIter++;
         }
 
+        // if idletimeout is 0, the user disabled the auto-shutdown feature
+        if ((idleTimeoutSecs > 0) && (m_mainServer != NULL) && 
+            !m_noAutoShutdown)
+        {
+            // we release the block when a client connects
+            if (m_blockShutdown)
+                m_blockShutdown &= !m_mainServer->isClientConnected();
+            else
+            {
+                // find out, if we are currently recording (or LiveTV)
+                bool recording = false;
+                QMap<int, EncoderLink *>::Iterator it;
+                for (it = m_tvList->begin(); (it != m_tvList->end()) && 
+                     !recording; ++it)
+                {
+                    if (it.data()->IsBusy())
+                        recording = true;
+                }
+                
+                if (!(m_mainServer->isClientConnected()) && !recording)
+                {
+                    if (!idleSince.isValid())
+                    {
+                        if ((recIter = recordingList.begin()) != 
+                            recordingList.end())
+                        {
+                            if (curtime.secsTo((*recIter)->startts) - 
+                                prerollseconds > idleWaitForRecordingTime * 60)
+                            {
+                                idleSince = curtime;
+                            }
+                        }
+                        else
+                            idleSince = curtime;
+                    } 
+                    else 
+                    {
+                        // is the machine already ideling the timeout time?
+                        if (idleSince.addSecs(idleTimeoutSecs) < curtime)
+                        {
+                            ShutdownServer(prerollseconds);
+                        }
+                        else
+                        {
+                            int itime = idleSince.secsTo(curtime);
+                            QString msg;
+                            if (itime == 1)
+                            {
+                                msg = QString("I\'m idle now... shutdown will "
+                                              "occur in %1 seconds.")
+                                             .arg(idleTimeoutSecs);
+                                VERBOSE(VB_ALL, msg);
+                            }
+                            else if (itime % 10 == 0)
+                            {
+                                msg = QString("%1 secs left to system "
+                                              "shutdown!")
+                                             .arg(idleTimeoutSecs - itime);
+                                VERBOSE(VB_ALL, msg);
+                            }
+                        }
+                    }
+                }
+                else
+                    // not idle, make the time invalid
+                    idleSince = QDateTime();
+            }
+        }
+
         sleep(1);
     }
 } 
 
+void Scheduler::ShutdownServer(int prerollseconds)
+{    
+    list<ProgramInfo *>::iterator recIter = recordingList.begin();
+
+    // set the wakeuptime if needed
+    if (recIter != recordingList.end())
+    {
+        ProgramInfo *nextRecording = (*recIter);
+        QDateTime restarttime = nextRecording->startts.addSecs((-1) * 
+                                                               prerollseconds);
+
+        int add = gContext->GetNumSetting("StartupSecsBeforeRecording", 240);
+        if (add)
+            restarttime = restarttime.addSecs((-1) * add);
+
+        QString wakeup_timeformat = gContext->GetSetting("WakeupTimeFormat",
+                                                         "hh:mm yyyy-MM-dd");
+        QString setwakeup_cmd = gContext->GetSetting("SetWakeuptimeCommand",
+                                                     "echo \'Wakeuptime would "
+                                                     "be $time if command "
+                                                     "set.\'");
+
+        if (wakeup_timeformat == "time_t")
+        {
+            QString time_ts;
+            setwakeup_cmd.replace("$time", 
+                                  time_ts.setNum(restarttime.toTime_t()));
+        }
+        else
+            setwakeup_cmd.replace("$time", 
+                                  restarttime.toString(wakeup_timeformat));
+
+        // now run the command to set the wakeup time
+        system(setwakeup_cmd.ascii());
+    }
+
+    QString halt_cmd = gContext->GetSetting("ServerHaltCommand",
+                                            "sudo /sbin/halt -p");
+
+    // now we shut the slave backends down...
+    m_mainServer->ShutSlaveBackendsDown(halt_cmd);
+
+    //and now shutdown myself
+    system(halt_cmd.ascii());
+}
+
 void *Scheduler::SchedulerThread(void *param)
 {
     Scheduler *sched = (Scheduler *)param;
