@@ -4,7 +4,9 @@
 class ProgramInfo;
 class QSqlDatabase;
 class EncoderLink;
+class MainServer;
 
+#include <qmutex.h>
 #include <qmap.h> 
 #include <list>
 #include <vector>
@@ -18,7 +20,7 @@ class Scheduler : public QObject
 {
   public:
     Scheduler(bool runthread, QMap<int, EncoderLink *> *tvList, 
-              QSqlDatabase *ldb);
+              QSqlDatabase *ldb, bool noAutoShutdown = false);
    ~Scheduler();
 
     bool CheckForChanges(void);
@@ -30,14 +32,25 @@ class Scheduler : public QObject
     void RemoveRecording(ProgramInfo *pginfo);
 
     list<ProgramInfo *> *getAllPending(void) { return &recordingList; }
-    list<ProgramInfo *> *getAllScheduled(void);
+    void getAllPending(list<ProgramInfo *> *retList);
+    void getAllPending(QStringList *strList);
 
+    list<ProgramInfo *> *getAllScheduled(void);
+    void getAllScheduled(QStringList *strList);
+
+    void getConflicting(ProgramInfo *pginfo,
+                        bool removenonplaying,
+                        QStringList *strlist);
     list<ProgramInfo *> *getConflicting(ProgramInfo *pginfo,
                                         bool removenonplaying = true,
                                         list<ProgramInfo *> *uselist = NULL);
 
     void PrintList(void);
 
+    bool HasConflicts(void) { return hasconflicts; }
+
+    void SetMainServer(MainServer *ms);
+
   protected:
     void RunScheduler(void);
     static void *SchedulerThread(void *param);
@@ -47,14 +60,15 @@ class Scheduler : public QObject
 
     void MarkKnownInputs(void);
     void MarkConflicts(list<ProgramInfo *> *uselist = NULL);
+    void PruneOverlaps(void);
     void PruneList(void);
 
     void MarkConflictsToRemove(void);
     void MarkSingleConflict(ProgramInfo *info,
                             list<ProgramInfo *> *conflictList);
 
-    int totalRank(ProgramInfo *info);
-    void CheckRank(ProgramInfo *info, list<ProgramInfo *> *conflictList);
+    int totalRecPriority(ProgramInfo *info);
+    void CheckRecPriority(ProgramInfo *info, list<ProgramInfo *> *conflictList);
     void CheckOverride(ProgramInfo *info, list<ProgramInfo *> *conflictList);
     void RemoveConflicts(void);
     void GuessSingle(ProgramInfo *info, list<ProgramInfo *> *conflictList);
@@ -68,6 +82,8 @@ class Scheduler : public QObject
                          list<ProgramInfo *> *conflictList);
     void DoMultiCard();
 
+    void ShutdownServer(int prerollseconds);
+
     list<ProgramInfo *> *CopyList(list<ProgramInfo *> *sourcelist);
 
     QSqlDatabase *db;
@@ -75,12 +91,15 @@ class Scheduler : public QObject
     list<ProgramInfo *> recordingList;
     list<ProgramInfo *> scheduledList;
 
-    bool doRank;
-    bool doRankFirst;
+    QMutex *recordingList_lock;
+    QMutex *scheduledList_lock;
 
-    QMap<QString, int> rankMap;
-    QMap<QString, int> channelRankMap;
-    QMap<RecordingType, int> recTypeRankMap;
+    bool doRecPriority;
+    bool doRecPriorityFirst;
+
+    QMap<QString, int> recpriorityMap;
+    QMap<QString, int> channelRecPriorityMap;
+    QMap<RecordingType, int> recTypeRecPriorityMap;
 
     bool hasconflicts;
 
@@ -102,6 +121,10 @@ class Scheduler : public QObject
     void PruneDontRecords(void);
 
     QValueList<ProgramInfo> dontRecordList;
+
+    MainServer *m_mainServer;
+    bool m_blockShutdown;
+    bool m_noAutoShutdown;
 };
 
 #endif
