@@ -6,6 +6,7 @@
 #include "libmyth/settings.h"
 
 #include "libmythtv/guidegrid.h"
+#include "libmythtv/tv.h"
 
 MythContext *gContext;
 
@@ -36,7 +37,9 @@ int main(int argc, char **argv)
     MythMainWindow *mainWindow = new MythMainWindow();
     mainWindow->Show();
     gContext->SetMainWindow(mainWindow);
-    
+
+    TV::InitKeys();
+
     QString chanstr = RunProgramGuide(startchannel);
 
     int chan = 0;
