@@ -57,6 +57,7 @@ class ChanInfo
     QString name;
     QString freqid;
     QString finetune;
+    QString tvformat;
 };
 
 struct ProgRating
@@ -215,6 +216,7 @@ ChanInfo *parseChannel(QDomElement &element, QUrl baseUrl)
     chaninfo->iconpath = "";
     chaninfo->name = "";
     chaninfo->finetune = "";
+    chaninfo->tvformat = "Default";
 
     for (QDomNode child = element.firstChild(); !child.isNull();
          child = child.nextSibling())
@@ -433,6 +435,12 @@ ProgInfo *parseProgram(QDomElement &element, int localTimezoneOffset)
                     if (pginfo->catType == "")
                         pginfo->catType = cat;
                 }
+
+                if (cat == "Film" && !isNorthAmerica)
+                {
+                    // Hack for tv_grab_uk_rt
+                    pginfo->catType = cat;
+                }
             }
             else if (info.tagName() == "date" && pginfo->airdate == "")
             {
@@ -716,6 +724,10 @@ unsigned int promptForChannelUpdates(QValueList<ChanInfo>::iterator chaninfo,
     (*chaninfo).finetune = getResponse("Choose a channel fine tune offset (just"
                                        " like xawtv) ",(*chaninfo).finetune);
 
+    (*chaninfo).tvformat = getResponse("Choose a TV format "
+                                       "(PAL/SECAM/NTSC/ATSC/Default) ",
+                                       (*chaninfo).tvformat);
+
     (*chaninfo).iconpath = getResponse("Choose a channel icon image (any path "
                                        "name) ",(*chaninfo).iconpath);
 
@@ -783,8 +795,9 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
         }
 
         querystr.sprintf("SELECT chanid,name,callsign,channum,finetune,"
-                         "icon,freqid FROM channel WHERE xmltvid = \"%s\" AND "
-                         "sourceid = %d;", (*i).xmltvid.ascii(), id); 
+                         "icon,freqid,tvformat FROM channel WHERE "
+                         "xmltvid = \"%s\" AND sourceid = %d;", 
+                         (*i).xmltvid.ascii(), id); 
 
         query.exec(querystr);
         if (query.isActive() && query.numRowsAffected() > 0)
@@ -800,6 +813,7 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                 QString finetune = QString::fromUtf8(query.value(4).toString());
                 QString icon     = QString::fromUtf8(query.value(5).toString());
                 QString freqid   = QString::fromUtf8(query.value(6).toString());
+                QString tvformat = QString::fromUtf8(query.value(7).toString());
 
                 cout << "### " << endl;
                 cout << "### Existing channel found" << endl;
@@ -812,6 +826,7 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                 if (channel_preset)
                     cout << "### freqid   = " << freqid.ascii()   << endl;
                 cout << "### finetune = " << finetune.ascii()     << endl;
+                cout << "### tvformat = " << tvformat.ascii()     << endl;
                 cout << "### icon     = " << icon.ascii()         << endl;
                 cout << "### " << endl;
 
@@ -820,6 +835,7 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                 (*i).chanstr  = chanstr;
                 (*i).finetune = finetune;
                 (*i).freqid = freqid;
+                (*i).tvformat = tvformat;
 
                 promptForChannelUpdates(i, atoi(chanid.ascii()));
 
@@ -828,12 +844,14 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                     chanstr  != (*i).chanstr ||
                     finetune != (*i).finetune ||
                     freqid   != (*i).freqid ||
-                    icon     != localfile)
+                    icon     != localfile ||
+                    tvformat != (*i).tvformat)
                 {
                     querystr.sprintf("UPDATE channel SET chanid = %s, "
                                      "name = \"%s\", callsign = \"%s\", "
                                      "channum = \"%s\", finetune = %d, "
-                                     "icon = \"%s\", freqid = \"%s\" "
+                                     "icon = \"%s\", freqid = \"%s\", "
+                                     "tvformat = \"%s\", "
                                      " WHERE xmltvid = \"%s\" "
                                      "AND sourceid = %d;",
                                      chanid.ascii(),
@@ -843,6 +861,7 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                                      atoi((*i).finetune.ascii()),
                                      localfile.ascii(),
                                      (*i).freqid.ascii(),
+                                     (*i).tvformat.ascii(),
                                      (*i).xmltvid.ascii(),
                                      id);
 
@@ -896,6 +915,7 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                 if (channel_preset)
                     cout << "### freqid   = " << (*i).freqid.ascii()   << endl;
                 cout << "### finetune = " << (*i).finetune.ascii()     << endl;
+                cout << "### tvformat = " << (*i).tvformat.ascii()     << endl;
                 cout << "### icon     = " << localfile.ascii()         << endl;
                 cout << "### " << endl;
 
@@ -905,9 +925,9 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                 {
                     querystr.sprintf("INSERT INTO channel (chanid,name,"
                                      "callsign,channum,finetune,icon,"
-                                     "xmltvid,sourceid,freqid) "
+                                     "xmltvid,sourceid,freqid,tvformat) "
                                      "VALUES(%d,\"%s\",\"%s\",\"%s\",%d,"
-                                     "\"%s\",\"%s\",%d,\"%s\");", 
+                                     "\"%s\",\"%s\",%d,\"%s\",\"%s\");", 
                                      chanid,
                                      (*i).name.ascii(),
                                      (*i).callsign.ascii(),
@@ -915,7 +935,8 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                                      atoi((*i).finetune.ascii()),
                                      localfile.ascii(),
                                      (*i).xmltvid.ascii(),
-                                     id, (*i).freqid.ascii());
+                                     id, (*i).freqid.ascii(),
+                                     (*i).tvformat.ascii());
 
                     if (!query.exec(querystr))
                     {
@@ -960,9 +981,10 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                 }
 
                 querystr.sprintf("INSERT INTO channel (chanid,name,callsign,"
-                                 "channum,finetune,icon,xmltvid,sourceid,freqid) "
+                                 "channum,finetune,icon,xmltvid,sourceid,"
+                                 "freqid,tvformat) "
                                  "VALUES(%d,\"%s\",\"%s\",\"%s\",%d,\"%s\","
-                                 "\"%s\",%d,\"%s\");", 
+                                 "\"%s\",%d,\"%s\",\"%s\");", 
                                  chanid,
                                  (*i).name.ascii(),
                                  (*i).callsign.ascii(),
@@ -970,7 +992,8 @@ void handleChannels(int id, QValueList<ChanInfo> *chanlist)
                                  atoi((*i).finetune.ascii()),
                                  localfile.ascii(),
                                  (*i).xmltvid.ascii(),
-                                 id, (*i).freqid.ascii());
+                                 id, (*i).freqid.ascii(),
+                                 (*i).tvformat.ascii());
 
                 if (!query.exec(querystr))
                     MythContext::DBError("channel insert", query);
@@ -1341,6 +1364,11 @@ bool grabData(Source source, int offset, QDate *qCurrentDate = 0)
         command.sprintf("nice %s --days 14 --config-file '%s' --output %s",
                         xmltv_grabber.ascii(), configfile.ascii(),
                         filename.ascii());
+    else if (xmltv_grabber == "tv_grab_dk")
+        // Use fixed interval of 7 days for Danish grabber
+        command.sprintf("nice %s --days 7 --config-file '%s' --output %s",
+                        xmltv_grabber.ascii(), configfile.ascii(),
+                        filename.ascii());
     else
     {
         isNorthAmerica = true;
@@ -1356,6 +1384,7 @@ bool grabData(Source source, int offset, QDate *qCurrentDate = 0)
          xmltv_grabber == "tv_grab_es" ||
          xmltv_grabber == "tv_grab_nz" ||
          xmltv_grabber == "tv_grab_sn" ||
+         xmltv_grabber == "tv_grab_dk" ||
          xmltv_grabber == "tv_grab_uk" ||
          xmltv_grabber == "tv_grab_uk_rt" ||
          xmltv_grabber == "tv_grab_nl" ||
@@ -1366,7 +1395,22 @@ bool grabData(Source source, int offset, QDate *qCurrentDate = 0)
     if (!quiet)
          cout << "----------------- Start of XMLTV output -----------------" << endl;
 
+    QDateTime qdtNow = QDateTime::currentDateTime();
+    QSqlQuery query;
+    query.exec(QString("UPDATE settings SET data ='%1' "
+                       "WHERE value='mythfilldatabaseLastRunStart'")
+                       .arg(qdtNow.toString("yyyy-MM-dd hh:mm")));
+
     int status = system(command.ascii());
+
+    query.exec(QString("UPDATE settings SET data ='%1' "
+                       "WHERE value='mythfilldatabaseLastRunStatus'")
+                       .arg(status));
+
+    qdtNow = QDateTime::currentDateTime();
+    query.exec(QString("UPDATE settings SET data ='%1' "
+                       "WHERE value='mythfilldatabaseLastRunEnd'")
+                       .arg(qdtNow.toString("yyyy-MM-dd hh:mm")));
  
     if (!quiet)
          cout << "------------------ End of XMLTV output ------------------" << endl;
@@ -1427,6 +1471,11 @@ bool fillData(QValueList<Source> &sourcelist)
             if (!grabData(*it, 0))
                 ++failures;
         }
+        else if (xmltv_grabber == "tv_grab_dk")
+        {
+            if (!grabData(*it, 0))
+                ++failures;
+        }
         else if (xmltv_grabber == "tv_grab_nz")
         {
             // tv_grab_nz only supports a 7-day "grab".
@@ -1463,7 +1512,7 @@ bool fillData(QValueList<Source> &sourcelist)
             }
         }
         else if (xmltv_grabber == "tv_grab_na" || 
-                     xmltv_grabber == "tv_grab_uk_rt")
+                 xmltv_grabber == "tv_grab_uk_rt")
         {
             QDate qCurrentDate = QDate::currentDate();
 
@@ -1488,13 +1537,17 @@ bool fillData(QValueList<Source> &sourcelist)
                     qCurrentDate = newDate;
                 }
 
+                // Check to see if we already downloaded data for this date
+                bool download_needed = false;
                 QString date(qCurrentDate.addDays(i).toString());
                 QString querystr;
+
                 querystr.sprintf("SELECT COUNT(*) as 'hits' "
                                  "FROM channel LEFT JOIN program USING (chanid) "
                                  "WHERE sourceid = %d AND starttime >= "
-                                 "DATE_ADD(CURRENT_DATE(), INTERVAL %d DAY) "
-                                 "AND starttime < DATE_ADD(CURRENT_DATE(), "
+                                 "DATE_ADD(CURRENT_DATE(), INTERVAL '%d 12' "
+                                 "DAY_HOUR) AND "
+                                 "starttime < DATE_ADD(CURRENT_DATE(), "
                                  "INTERVAL 1+%d DAY) "
                                  "GROUP BY channel.chanid "
                                  "ORDER BY hits DESC LIMIT 1",
@@ -1507,21 +1560,55 @@ bool fillData(QValueList<Source> &sourcelist)
                     if (!query.numRowsAffected() ||
                         (query.next() && query.value(0).toInt() <= 1)) 
                     {
-                        if (!quiet)
-                            cout << "Fetching data for " << date << endl;
-                        if (!grabData(*it, i, &qCurrentDate))
-                            ++failures;
-                    }
-                    else
-                    {
-                        if (!quiet)
-                            cout << "Data is already present for " << date
-                                 << ", skipping\n";
+                        download_needed = true;
                     }
                 } 
                 else
                     MythContext::DBError("checking existing program data", 
                                          query);
+
+                // Now look for programs marked as "To Be Announced"
+                if (!download_needed && xmltv_grabber == "tv_grab_uk_rt") 
+                {
+                    querystr.sprintf("SELECT COUNT(*) as 'hits' "
+                                     "FROM channel LEFT JOIN program USING (chanid) "
+                                     "WHERE sourceid = %d AND starttime >= "
+                                     "DATE_ADD(CURRENT_DATE(), INTERVAL '%d 12' DAY_HOUR) "
+                                     "AND starttime < DATE_ADD(CURRENT_DATE(), "
+                                     "INTERVAL 1+%d DAY) "
+                                     "AND category = 'TBA' "
+                                     "GROUP BY channel.chanid "
+                                     "ORDER BY hits DESC LIMIT 1",
+                                      (*it).id, i, i);
+                    QSqlQuery query;
+                    query.exec(querystr);
+
+                    if (query.isActive()) 
+                    {
+                        if (query.numRowsAffected() || 
+                            (query.next() && query.value(0).toInt() >= 1)) 
+                        {
+                            download_needed = true;
+                        }
+                    } 
+                    else
+                        MythContext::DBError("checking existing program data", 
+                                             query);
+                }
+
+                if (download_needed)
+                {
+                    if (!quiet)
+                        cout << "Fetching data for " << date << endl;
+                    if (!grabData(*it, i, &qCurrentDate))
+                        ++failures;
+                }
+                else
+                {
+                    if (!quiet)
+                        cout << "Data is already present for " << date
+                             << ", skipping\n";
+                }
             }
         }
         else
@@ -1790,11 +1877,12 @@ int main(int argc, char *argv[])
             cout << "   Read channels as defined in xawtvrc file given\n";
             cout << "   <sourceid>    = cardinput\n";
             cout << "   <xawtvrcfile> = file to read\n";
+            cout << "\n";
             cout << "--help\n";
             cout << "   This text\n";
             cout << "\n";
             cout << "\n";
-            cout << "  --manual and --update can not be used together\n";
+            cout << "  --manual and --update can not be used together.\n";
             cout << "\n";
             return -1;
         }
@@ -1864,6 +1952,7 @@ int main(int argc, char *argv[])
         }
     
         bool ret = fillData(sourcelist);
+
         if (!ret)
         {
              cerr << "Failed to fetch some program info\n";
