@@ -115,6 +115,19 @@ public:
         };
 };
 
+class AC3PassThrough: public CheckBoxSetting, public GlobalSetting {
+public:
+    AC3PassThrough():
+        GlobalSetting("AC3PassThru") {
+        setLabel(QObject::tr("Enable AC3 to SPDIF passthrough"));
+        setValue(false);
+        setHelpText(QObject::tr("Enable sending AC3 sound directly to your "
+                    "sound card's SPDIF output, on sources which contain "
+                    "AC3 soundtracks (usually digital TV).  Requires that "
+                    "the audio output device be set to something suitable."));
+    };
+};
+
 class Deinterlace: public CheckBoxSetting, public GlobalSetting {
 public:
     Deinterlace():
@@ -129,6 +142,17 @@ public:
     };
 };
 
+class CustomFilters: public LineEditSetting, public GlobalSetting {
+public:
+    CustomFilters():
+        GlobalSetting("CustomFilters") {
+        setLabel(QObject::tr("Custom Filters"));
+        setValue("");
+        setHelpText(QObject::tr("Advanced Filter configuration, format:\n"
+                                "[[<filter>=<options>,]...]"));
+    };
+};
+
 class DecodeExtraAudio: public CheckBoxSetting, public GlobalSetting {
 public:
     DecodeExtraAudio():
@@ -141,10 +165,23 @@ public:
     };
 };
 
+class PIPLocation: public ComboBoxSetting, public GlobalSetting {
+public:
+    PIPLocation():
+        GlobalSetting("PIPLocation") {
+        setLabel(QObject::tr("PIP Video Location"));
+        addSelection(QObject::tr("Top Left"), "0");
+        addSelection(QObject::tr("Bottom Left"), "1");
+        addSelection(QObject::tr("Top Right"), "2");
+        addSelection(QObject::tr("Bottom Right"), "3");
+        setHelpText(QObject::tr("Location of PIP Video window."));
+    };
+};
+
 class JumpAmount: public SpinBoxSetting, public GlobalSetting {
 public:
     JumpAmount():
-        SpinBoxSetting(1, 30, 1),
+        SpinBoxSetting(1, 30, 5, true),
         GlobalSetting("JumpAmount") {
         setLabel(QObject::tr("Jump amount (in minutes)"));
         setValue(10);
@@ -156,7 +193,7 @@ public:
 class FastForwardAmount: public SpinBoxSetting, public GlobalSetting {
 public:
     FastForwardAmount():
-        SpinBoxSetting(1, 600, 1),
+        SpinBoxSetting(1, 600, 5, true),
         GlobalSetting("FastForwardAmount") {
         setLabel(QObject::tr("Fast forward amount (in seconds)"));
         setValue(30);
@@ -168,7 +205,7 @@ public:
 class RewindAmount: public SpinBoxSetting, public GlobalSetting {
 public:
     RewindAmount():
-        SpinBoxSetting(1, 600, 1),
+        SpinBoxSetting(1, 600, 5, true),
         GlobalSetting("RewindAmount") {
         setLabel(QObject::tr("Rewind amount (in seconds)"));
         setValue(5);
@@ -216,15 +253,18 @@ public:
     };
 };
 
-class AutoCommercialSkip: public CheckBoxSetting, public GlobalSetting {
+class AutoCommercialSkip: public ComboBoxSetting, public GlobalSetting {
 public:
     AutoCommercialSkip():
         GlobalSetting("AutoCommercialSkip") {
         setLabel(QObject::tr("Automatically Skip Commercials"));
-        setValue(false);
+        addSelection(QObject::tr("Off"), "0");
+        addSelection(QObject::tr("Notify, but do not skip"), "2");
+        addSelection(QObject::tr("Automatically Skip"), "1");
         setHelpText(QObject::tr("Automatically skip commercial breaks that "
                     "have been flagged during Automatic Commercial Flagging "
-                    "or by the mythcommflag program."));
+                    "or by the mythcommflag program, or just notify that a "
+                    "commercial has been detected."));
     };
 };
 
@@ -251,6 +291,18 @@ public:
     };
 };
 
+class CommSkipAllBlanks: public CheckBoxSetting, public BackendSetting {
+public:
+    CommSkipAllBlanks():
+        BackendSetting("CommSkipAllBlanks") {
+        setLabel(QObject::tr("Skip blank frames after commercials"));
+        setValue(true);
+        setHelpText(QObject::tr("When using Blank Frame Detection and "
+                    "Auto-Flagging, flag blank frames following commercial "
+                    "breaks as part of the the commercial break."));
+    };
+};
+
 class AutoExpireDiskThreshold: public SpinBoxSetting, public BackendSetting {
 public:
     AutoExpireDiskThreshold():
@@ -268,7 +320,7 @@ public:
 class AutoExpireFrequency: public SpinBoxSetting, public BackendSetting {
 public:
     AutoExpireFrequency():
-        SpinBoxSetting(1, 60, 1),
+        SpinBoxSetting(1, 60, 10, true),
         BackendSetting("AutoExpireFrequency") {
         setLabel(QObject::tr("Auto Expire Frequency (in minutes)"));
         setHelpText(QObject::tr("Number of minutes the AutoExpire process "
@@ -318,7 +370,7 @@ public:
 class RecordPreRoll: public SpinBoxSetting, public BackendSetting {
 public:
     RecordPreRoll():
-        SpinBoxSetting(0, 600, 1),
+        SpinBoxSetting(0, 600, 60, true),
         BackendSetting("RecordPreRoll") {
         setLabel(QObject::tr("Time to record before start of show "
                  "(in seconds)"));
@@ -329,7 +381,7 @@ public:
 class RecordOverTime: public SpinBoxSetting, public BackendSetting {
 public:
     RecordOverTime():
-        SpinBoxSetting(0, 600, 1),
+        SpinBoxSetting(0, 600, 60, true),
         BackendSetting("RecordOverTime") {
         setLabel(QObject::tr("Time to record past end of show (in seconds)"));
         setValue(0);
@@ -377,6 +429,20 @@ public:
     };
 };
 
+class FFRewReverse: public CheckBoxSetting, public GlobalSetting {
+public:
+    FFRewReverse():
+        GlobalSetting("FFRewReverse") {
+        setLabel(QObject::tr("Reverse direction in fast forward/rewind"));
+        setValue(true);
+        setHelpText(QObject::tr("If set, pressing the sticky rewind key "
+                    "in fast forward mode will switch to rewind mode, and "
+                    "vice versa.  If not set, doing so will decrease the "
+                    "speed in the current direction or switch to play mode if "
+                    "the speed can't be decreased further.."));
+    };
+};
+
 class OSDDisplayTime: public SpinBoxSetting, public GlobalSetting {
 public:
     OSDDisplayTime():
@@ -422,8 +488,8 @@ public:
         GlobalSetting("OSDFont") {
 
         setLabel(QObject::tr("OSD font"));
-        addSelection("FreeSans.ttf");
-        addSelection("FreeMono.ttf");
+        QDir ttf(PREFIX"/share/mythtv", "*ttf");
+        fillSelectionsFromDir(ttf, false);
     };
 };
 
@@ -433,8 +499,20 @@ public:
         GlobalSetting("OSDCCFont") {
 
         setLabel(QObject::tr("Closed Caption font"));
-        addSelection("FreeMono.ttf");
-        addSelection("FreeSans.ttf");
+        QDir ttf(PREFIX"/share/mythtv", "*ttf");
+        fillSelectionsFromDir(ttf, false);
+    };
+};
+
+class OSDThemeFontSizeType: public ComboBoxSetting, public GlobalSetting {
+public:
+    OSDThemeFontSizeType():
+        GlobalSetting("OSDThemeFontSizeType") {
+        setLabel(QObject::tr("Font size"));
+        addSelection(QObject::tr("default"), "default");
+        addSelection(QObject::tr("small"), "small");
+        addSelection(QObject::tr("big"), "big");
+        setHelpText(QObject::tr("default: TV, small: monitor, big:"));
     };
 };
 
@@ -596,6 +674,19 @@ public:
     };
 };
 
+class UDPNotifyPort: public LineEditSetting, public GlobalSetting {
+public:
+    UDPNotifyPort():
+        GlobalSetting("UDPNotifyPort") {
+        setLabel(QObject::tr("UDP Notify Port"));
+        setValue("6948");
+        setHelpText(QObject::tr("If this is set to a port number, MythTV will "
+                    "listen during playback for connections from the "
+                    "'mythtvosd' or 'mythudprelay' for events.  See the "
+                    "README in contrib/mythnotify/ for more details."));
+    };
+};
+
 class PlaybackExitPrompt: public ComboBoxSetting, public GlobalSetting {
 public:
     PlaybackExitPrompt():
@@ -873,6 +964,19 @@ public:
     };
 };
 
+class ThemeFontSizeType: public ComboBoxSetting, public GlobalSetting {
+public:
+    ThemeFontSizeType():
+        GlobalSetting("ThemeFontSizeType") {
+        setLabel(QObject::tr("Font size"));
+        addSelection(QObject::tr("default"), "default");
+        addSelection(QObject::tr("small"), "small");
+        addSelection(QObject::tr("big"), "big");
+        setHelpText(QObject::tr("default: TV, small: monitor, big:"));
+    };
+};
+
+
 ThemeSelector::ThemeSelector():
     GlobalSetting("Theme") {
 
@@ -919,6 +1023,18 @@ public:
     };
 };
 
+class SmartChannelChange: public CheckBoxSetting, public GlobalSetting {
+public:
+    SmartChannelChange():
+        GlobalSetting("SmartChannelChange") {
+        setLabel(QObject::tr("Change channels immediately without select"));
+        setValue(false);
+        setHelpText(QObject::tr("When a complete channel number is entered "
+                    "MythTV will switch to that channel immediately without "
+                    "requiring you to hit the select button."));
+    };
+};
+
 class QtFontBig: public SpinBoxSetting, public GlobalSetting {
 public:
     QtFontBig():
@@ -1000,80 +1116,81 @@ public:
     };
 };
 
-// General Ranking settings
+// General RecPriorities settings
 
-class GRUseRanking: public CheckBoxSetting, public BackendSetting {
+class GRUseRecPriorities: public CheckBoxSetting, public BackendSetting {
 public:
-    GRUseRanking():
-        BackendSetting("RankingActive") {
-        setLabel(QObject::tr("Use Rankings"));
-        setHelpText(QObject::tr("Use program rankings to resolve conflicts."));
+    GRUseRecPriorities():
+        BackendSetting("RecPriorityActive") {
+        setLabel(QObject::tr("Use Recording Priorities"));
+        setHelpText(QObject::tr("Use program recording priorities to resolve "
+                    "conflicts."));
         setValue(false);
     };
 };
 
-class GRRankingFirst: public CheckBoxSetting, public BackendSetting {
+class GRRecPrioritiesFirst: public CheckBoxSetting, public BackendSetting {
 public:
-    GRRankingFirst():
-        BackendSetting("RankingOrder") {
-        setLabel(QObject::tr("Rankings First."));
-        setHelpText(QObject::tr("Use rankings to resolve conflicts before "
-                    "using traditional conflict resolution."));
+    GRRecPrioritiesFirst():
+        BackendSetting("RecPriorityOrder") {
+        setLabel(QObject::tr("Recording Priorities First."));
+        setHelpText(QObject::tr("Use recording priorities to resolve conflicts "
+                    "before using traditional conflict resolution."));
         setValue(true);
     };
 };
 
-class GRSingleRecordRank: public SpinBoxSetting, public BackendSetting {
+class GRSingleRecordRecPriority: public SpinBoxSetting, public BackendSetting {
 public:
-    GRSingleRecordRank():
-        SpinBoxSetting(-99, 99, 1), BackendSetting("SingleRecordRank") {
-        setLabel(QObject::tr("Single Recordings Rank"));
+    GRSingleRecordRecPriority():
+        SpinBoxSetting(-99, 99, 1), BackendSetting("SingleRecordRecPriority") {
+        setLabel(QObject::tr("Single Recordings Priority"));
         setHelpText(QObject::tr("Single Recordings will receive this "
-                    "additional ranking value."));
+                    "additional recording priority value."));
         setValue(0);
     };
 };
 
-class GRWeekslotRecordRank: public SpinBoxSetting, public BackendSetting {
+class GRWeekslotRecordRecPriority: public SpinBoxSetting, public BackendSetting {
 public:
-    GRWeekslotRecordRank():
-        SpinBoxSetting(-99, 99, 1), BackendSetting("WeekslotRecordRank") {
-        setLabel(QObject::tr("Weekslot Recordings Rank"));
+    GRWeekslotRecordRecPriority():
+        SpinBoxSetting(-99, 99, 1), BackendSetting("WeekslotRecordRecPriority") {
+        setLabel(QObject::tr("Weekslot Recordings Priority"));
         setHelpText(QObject::tr("Weekslot Recordings will receive this "
-                    "additional ranking value."));
+                    "additional recording priority value."));
         setValue(0);
     };
 };
 
-class GRTimeslotRecordRank: public SpinBoxSetting, public BackendSetting {
+class GRTimeslotRecordRecPriority: public SpinBoxSetting, public BackendSetting {
 public:
-    GRTimeslotRecordRank():
-        SpinBoxSetting(-99, 99, 1), BackendSetting("TimeslotRecordRank") {
-        setLabel(QObject::tr("Timeslot Recordings Rank"));
+    GRTimeslotRecordRecPriority():
+        SpinBoxSetting(-99, 99, 1), BackendSetting("TimeslotRecordRecPriority") {
+        setLabel(QObject::tr("Timeslot Recordings Priority"));
         setHelpText(QObject::tr("Timeslot Recordings will receive this "
-                    "additional ranking value."));
+                    "additional recording priority value."));
         setValue(0);
     };
 };
 
-class GRChannelRecordRank: public SpinBoxSetting, public BackendSetting {
+class GRChannelRecordRecPriority: public SpinBoxSetting, public BackendSetting {
 public:
-    GRChannelRecordRank():
-        SpinBoxSetting(-99, 99, 1), BackendSetting("ChannelRecordRank") {
-        setLabel(QObject::tr("Channel Recordings Rank"));
+    GRChannelRecordRecPriority():
+        SpinBoxSetting(-99, 99, 1), BackendSetting("ChannelRecordRecPriority") {
+        setLabel(QObject::tr("Channel Recordings Priority"));
         setHelpText(QObject::tr("Channel Recordings will receive this "
-                    "additional ranking value."));
+                    "additional recording priority value."));
         setValue(0);
     };
 };
 
-class GRAllRecordRank: public SpinBoxSetting, public BackendSetting {
+class GRAllRecordRecPriority: public SpinBoxSetting, public BackendSetting {
 public:
-    GRAllRecordRank():
-        SpinBoxSetting(-99, 99, 1), BackendSetting("AllRecordRank") {
-        setLabel(QObject::tr("All Recordings Rank"));
+    GRAllRecordRecPriority():
+        SpinBoxSetting(-99, 99, 1), BackendSetting("AllRecordRecPriority") {
+        setLabel(QObject::tr("All Recordings Priority"));
         setHelpText(QObject::tr("All Recording types will receive this "
-                    "additional ranking value."));
+                    "additional recording priority value."));
         setValue(0);
     };
 };
@@ -1117,6 +1234,7 @@ public:
          setUseLabel(false);
 
          addChild(new AudioOutputDevice());
+         addChild(new AC3PassThrough());
          addChild(new AggressiveBuffer());
 
          Setting* volumeControl = new MythControlsVolume();
@@ -1282,16 +1400,23 @@ PlaybackSettings::PlaybackSettings()
     VerticalConfigurationGroup* general = new VerticalConfigurationGroup(false);
     general->setLabel(QObject::tr("General playback"));
     general->addChild(new Deinterlace());
+    general->addChild(new CustomFilters());
     general->addChild(new ReduceJitter());
     general->addChild(new ExperimentalSync());
     general->addChild(new DecodeExtraAudio());
-    general->addChild(new PlaybackExitPrompt());
-    general->addChild(new EndOfRecordingExitPrompt());
-    general->addChild(new ClearSavedPosition());
-    general->addChild(new AltClearSavedPosition());
-    general->addChild(new UsePicControls());
+    general->addChild(new PIPLocation());
     addChild(general);
 
+    VerticalConfigurationGroup* gen2 = new VerticalConfigurationGroup(false);
+    gen2->setLabel(QObject::tr("General playback (part 2)"));
+    gen2->addChild(new PlaybackExitPrompt());
+    gen2->addChild(new EndOfRecordingExitPrompt());
+    gen2->addChild(new ClearSavedPosition());
+    gen2->addChild(new AltClearSavedPosition());
+    gen2->addChild(new UsePicControls());
+    gen2->addChild(new UDPNotifyPort());
+    addChild(gen2);
+
     addChild(new PVR350Settings());
 
     VerticalConfigurationGroup* seek = new VerticalConfigurationGroup(false);
@@ -1301,6 +1426,7 @@ PlaybackSettings::PlaybackSettings()
     seek->addChild(new SmartForward());
     seek->addChild(new StickyKeys());
     seek->addChild(new FFRewRepos());
+    seek->addChild(new FFRewReverse());
     seek->addChild(new ExactSeeking());
     seek->addChild(new JumpAmount());
     addChild(seek);
@@ -1310,6 +1436,7 @@ PlaybackSettings::PlaybackSettings()
     comms->addChild(new AutoCommercialFlag());
     comms->addChild(new CommercialSkipMethod());
     comms->addChild(new AggressiveCommDetect());
+    comms->addChild(new CommSkipAllBlanks());
     comms->addChild(new AutoCommercialSkip());
     addChild(comms);
 
@@ -1327,6 +1454,7 @@ PlaybackSettings::PlaybackSettings()
     osd->addChild(new OSDDisplayTime());
     osd->addChild(new OSDFont());
     osd->addChild(new OSDCCFont());
+    osd->addChild(new OSDThemeFontSizeType());
     osd->addChild(new DefaultCCMode());
     osd->addChild(new PersistentBrowseMode());
     addChild(osd);
@@ -1341,6 +1469,7 @@ GeneralSettings::GeneralSettings()
     general->addChild(new PlayBoxOrdering());
     general->addChild(new ChannelOrdering());
     general->addChild(new DisplayChanNum());
+    general->addChild(new SmartChannelChange());
     general->addChild(new GeneratePreviewPixmaps());
     general->addChild(new PlaybackPreview());
     general->addChild(new AdvancedRecord());
@@ -1376,18 +1505,18 @@ EPGSettings::EPGSettings()
     addChild(gen);
 }
 
-GeneralRankingSettings::GeneralRankingSettings()
+GeneralRecPrioritiesSettings::GeneralRecPrioritiesSettings()
 {
     VerticalConfigurationGroup* gr = new VerticalConfigurationGroup(false);
-    gr->setLabel(QObject::tr("General Ranking Settings"));
+    gr->setLabel(QObject::tr("General Recording Priorities Settings"));
 
-    gr->addChild(new GRUseRanking());
-    gr->addChild(new GRRankingFirst());
-    gr->addChild(new GRSingleRecordRank());
-    gr->addChild(new GRWeekslotRecordRank());
-    gr->addChild(new GRTimeslotRecordRank());
-    gr->addChild(new GRChannelRecordRank());
-    gr->addChild(new GRAllRecordRank());
+    gr->addChild(new GRUseRecPriorities());
+    gr->addChild(new GRRecPrioritiesFirst());
+    gr->addChild(new GRSingleRecordRecPriority());
+    gr->addChild(new GRWeekslotRecordRecPriority());
+    gr->addChild(new GRTimeslotRecordRecPriority());
+    gr->addChild(new GRChannelRecordRecPriority());
+    gr->addChild(new GRAllRecordRecPriority());
     addChild(gr);
 }
 
@@ -1397,6 +1526,7 @@ AppearanceSettings::AppearanceSettings()
     theme->setLabel(QObject::tr("Theme"));
 
     theme->addChild(new ThemeSelector());
+    theme->addChild(new ThemeFontSizeType());
     theme->addChild(new RandomTheme());
     addChild(theme);
 
