@@ -17,8 +17,8 @@ using namespace std;
 #include "manualschedule.h"
 #include "playbackbox.h"
 #include "viewscheduled.h"
-#include "rankprograms.h"
-#include "rankchannels.h"
+#include "programrecpriority.h"
+#include "channelrecpriority.h"
 #include "globalsettings.h"
 #include "profilegroup.h"
 
@@ -33,23 +33,27 @@ using namespace std;
 #include "dbcheck.h"
 
 #define QUIT     1
-#define HALTWKUP 2
-#define HALT     3
+#define HALT     2
 
 ThemedMenu *menu;
 MythContext *gContext;
 XBox *xbox = NULL;
 
-QString startGuide(void)
+void startGuide(void)
 {
     QString startchannel = gContext->GetSetting("DefaultTVChannel");
     if (startchannel == "")
         startchannel = "3";
 
-    return RunProgramGuide(startchannel);
+    RunProgramGuide(startchannel);
 }
 
-int startManaged(void)
+void startFinder(void)
+{
+    RunProgramFind();
+}
+
+void startManaged(void)
 {
     QSqlDatabase *db = QSqlDatabase::database();
     ViewScheduled vsb(db, gContext->GetMainWindow(), "view scheduled");
@@ -57,77 +61,64 @@ int startManaged(void)
     qApp->unlock();
     vsb.exec();
     qApp->lock();
-
-    return 0;
 }
 
-int startProgramRankings(void)
+void startProgramRecPriorities(void)
 {
     QSqlDatabase *db = QSqlDatabase::database();
-    RankPrograms rsb(db, gContext->GetMainWindow(), "rank scheduled");
+    ProgramRecPriority rsb(db, gContext->GetMainWindow(), "recpri scheduled");
 
     qApp->unlock();
     rsb.exec();
     qApp->lock();
-
-    return 0;
 }
 
-int startChannelRankings(void)
+void startChannelRecPriorities(void)
 {
     QSqlDatabase *db = QSqlDatabase::database();
-    RankChannels rch(db, gContext->GetMainWindow(), "rank channels");
+    ChannelRecPriority rch(db, gContext->GetMainWindow(), "recpri channels");
 
     qApp->unlock();
     rch.exec();
     qApp->lock();
-
-    return 0;
 }
 
-int startPlayback(void)
+void startPlayback(void)
 {
-    PlaybackBox pbb(PlaybackBox::Play, gContext->GetMainWindow(), "play");
+    PlaybackBox pbb(PlaybackBox::Play, gContext->GetMainWindow(), 
+                    "tvplayselect");
 
     qApp->unlock();
     pbb.exec();
     qApp->lock();
-
-    return 0;
 }
 
-int startDelete(void)
+void startDelete(void)
 {
     PlaybackBox delbox(PlaybackBox::Delete, gContext->GetMainWindow(), 
-                       "delete");
+                       "tvplayselect");
    
     qApp->unlock();
     delbox.exec();
     qApp->lock();
-
-    return 0;
 }
 
-int startManual(void)
+void startManual(void)
 {
     ManualBox manbox(gContext->GetMainWindow(), "manual box");
 
     qApp->unlock();
     manbox.exec();
     qApp->lock();
-
-    return 0;
 }
 
-int startManualSchedule(void)
+void startManualSchedule(void)
 {
     ManualSchedule mansched(gContext->GetMainWindow(), "manual schedule");
 
     qApp->unlock();
     mansched.exec();
     qApp->lock();
-
-    return 0;
 }
 
 void startTV(void)
@@ -212,6 +203,73 @@ void startTV(void)
     delete tv;
 }
 
+void showStatus(void)
+{
+    QString mfdLastRunStart, mfdLastRunEnd, mfdLastRunStatus, Status;
+    QString querytext;
+    int DaysOfData;
+    QDateTime qdtNow, GuideDataThrough;
+    QSqlDatabase *db = QSqlDatabase::database();
+
+    qdtNow = QDateTime::currentDateTime();
+    querytext = QString("SELECT max(endtime) FROM program;");
+
+    QSqlQuery query = db->exec(querytext);
+
+    if (query.isActive() && query.numRowsAffected())
+    {
+        query.next();
+        GuideDataThrough = QDateTime::fromString(query.value(0).toString(),
+                                                 Qt::ISODate);
+    }
+
+    mfdLastRunStart = gContext->GetSetting("mythfilldatabaseLastRunStart");
+    mfdLastRunEnd = gContext->GetSetting("mythfilldatabaseLastRunEnd");
+    mfdLastRunStatus = gContext->GetNumSetting("mythfilldatabaseLastRunStatus");
+
+    Status = "Last mythfilldatabase guide update:";
+    Status += "\n   Started:   ";
+    Status += mfdLastRunStart;
+    Status += "\n   Finished: ";
+    Status += mfdLastRunEnd;
+
+    Status += "\n   Result: ";
+
+    if(!mfdLastRunStatus)
+       Status += "FAILED";
+    else
+       Status += "Successful";
+
+    Status += "\n\nThere is guide data until ";
+    Status += QDateTime(GuideDataThrough).toString("yyyy-MM-dd hh:mm");
+
+    DaysOfData = qdtNow.daysTo(GuideDataThrough);
+
+    Status += "\nThere ";
+
+    if (DaysOfData == 1) 
+       Status += "is ";
+    else 
+       Status += "are ";
+
+    Status += QString::number(DaysOfData);
+    Status += " day";
+
+    if (DaysOfData != 1)
+       Status += "s";
+
+    Status += " of guide data remaining in the database.\n";
+
+    if (DaysOfData <= 3)
+       Status += "\nWARNING: is mythfilldatabase running?";
+
+    DialogBox *status_dialog = new DialogBox(gContext->GetMainWindow(), Status);
+    status_dialog->AddButton(QObject::tr("OK"));
+    status_dialog->exec();
+
+    delete status_dialog;
+}
+
 void TVMenuCallback(void *data, QString &selection)
 {
     (void)data;
@@ -231,10 +289,10 @@ void TVMenuCallback(void *data, QString &selection)
         startManualSchedule();
     else if (sel == "tv_fix_conflicts")
         startManaged();
-    else if (sel == "tv_set_rankings")
-        startProgramRankings();
+    else if (sel == "tv_set_recpriorities")
+        startProgramRecPriorities();
     else if (sel == "tv_progfind")
-        RunProgramFind();
+        startFinder();
     else if (sel == "settings appearance") 
     {
         AppearanceSettings settings;
@@ -270,15 +328,15 @@ void TVMenuCallback(void *data, QString &selection)
         EPGSettings settings;
         settings.exec(QSqlDatabase::database());
     } 
-    else if (sel == "settings generalranking") 
+    else if (sel == "settings generalrecpriorities") 
     {
-        GeneralRankingSettings settings;
+        GeneralRecPrioritiesSettings settings;
         settings.exec(QSqlDatabase::database());
         ScheduledRecording::signalChange(QSqlDatabase::database());
     } 
-    else if (sel == "settings channelranking") 
+    else if (sel == "settings channelrecpriorities") 
     {
-        startChannelRankings();
+        startChannelRecPriorities();
     }
     else if (xbox && sel == "settings xboxsettings")
     {
@@ -287,45 +345,50 @@ void TVMenuCallback(void *data, QString &selection)
 
         xbox->GetSettings();
     }
+    else if (sel == "tv_status")
+        showStatus();
 }
 
 int handleExit(void)
 {
+    // first of all find out, if a backend runs on this host...
+    bool backendOnLocalhost = false;
+
+    QStringList strlist = "";
+    strlist << "QUERY_IS_ACTIVE_BACKEND";
+    strlist << gContext->GetHostName();
+                
+    gContext->SendReceiveStringList(strlist);
+
+    if (QString(strlist[0]) == "FALSE")
+        backendOnLocalhost = false;
+    else //if (QString(strlist[0]) == "TRUE")
+        backendOnLocalhost = true;
+
     QString title = QObject::tr("Do you really want to exit MythTV?");
 
     DialogBox diag(gContext->GetMainWindow(), title);
     diag.AddButton(QObject::tr("No"));
     diag.AddButton(QObject::tr("Yes, Exit now"));
-    diag.AddButton(QObject::tr("Yes, Exit and shutdown the computer"));
-//    bool haltNwakeup = context->GetNumSetting("UseHaltWakeup");
-//    if (haltNwakeup)
-//        diag.AddButton("Yes, Shutdown and set wakeup time");
+    if (!backendOnLocalhost)
+        diag.AddButton(QObject::tr("Yes, Exit and Shutdown"));
 
     int result = diag.exec();
     switch (result)
     {
         case 2: return QUIT;
         case 3: return HALT;
-//        case 4: return HALTWKUP;
         default: return 0;
     }
 
     return 0;
 }
 
-void haltnow(int how)
+void haltnow()
 {
-    QString halt_cmd = gContext->GetSetting("HaltCommand", "halt");
-    QString haltwkup_cmd = gContext->GetSetting("HaltCommandWhenWakeup",
-                                                "echo 'would halt now, and set "
-                                                "wakeup time to %1 (secs since "
-                                                "1970) if command was set'");
-
-    if (how == HALTWKUP)
-    {
-    }
-    else if (how == HALT)
-        system(halt_cmd.ascii());
+    QString halt_cmd = gContext->GetSetting("HaltCommand", 
+                                            "sudo /sbin/halt -p");
+    system(halt_cmd.ascii());
 }
 
 int RunMenu(QString themedir)
@@ -350,9 +413,10 @@ int RunMenu(QString themedir)
     return exitstatus;
 }   
 
-void WriteDefaults(QSqlDatabase* db) {
-    // If any settings are missing from the database, this will write
-    // the default values
+// If any settings are missing from the database, this will write
+// the default values
+void WriteDefaults(QSqlDatabase* db) 
+{
     PlaybackSettings ps;
     ps.load(db);
     ps.save(db);
@@ -368,7 +432,7 @@ void WriteDefaults(QSqlDatabase* db) {
     MainGeneralSettings mgs;
     mgs.load(db);
     mgs.save(db);
-    GeneralRankingSettings grs;
+    GeneralRecPrioritiesSettings grs;
     grs.load(db);
     grs.save(db);
 }
@@ -412,6 +476,21 @@ QString RandTheme(QString &themename, QSqlDatabase *db)
     return themename;
 }
 
+void InitJumpPoints(void)
+{
+    REG_JUMP("Program Guide", "", "", startGuide);
+    REG_JUMP("Program Finder", "", "", startFinder);
+    REG_JUMP("Manage Recordings / Fix Conflicts", "", "", startManaged);
+    REG_JUMP("Program Recording Priorities", "", "", startProgramRecPriorities);
+    REG_JUMP("Channel Recording Priorities", "", "", startChannelRecPriorities);
+    REG_JUMP("TV Recording Playback", "", "", startPlayback);
+    REG_JUMP("TV Recording Deletion", "", "", startDelete);
+    REG_JUMP("Live TV", "", "", startTV);
+    REG_JUMP("Manual Record Scheduling", "", "", startManual);
+
+    TV::InitKeys();
+}
+
 int main(int argc, char **argv)
 {
     QString lcd_host;
@@ -528,11 +607,17 @@ int main(int argc, char **argv)
                 cerr << "Missing argument to -v/--verbose option\n";
                 return -1;
             }
-        } else if ((argpos + 1 == a.argc()) &&
+        }
+        else if (!strcmp(a.argv()[argpos],"--version"))
+        {
+            cout << MYTH_BINARY_VERSION << endl;
+            exit(0);
+        }
+        else if ((argpos + 1 == a.argc()) &&
                     !QString(a.argv()[argpos]).startsWith("-"))
         {
             pluginname = a.argv()[argpos];
-        } 
+        }
         else
         {
             if (!(!strcmp(a.argv()[argpos],"-h") ||
@@ -544,6 +629,7 @@ int main(int argc, char **argv)
                     "                               Accepts any combination (separated by comma)" << endl << 
                     "                               of all,none,quiet,record,playback," << endl <<
                     "                               channel,osd,file,schedule,network" << endl <<
+                    "--version                      Version information" << endl <<
                     "<plugin>                       Initialize and run this plugin" << endl;
             return -1;
         }
@@ -591,8 +677,6 @@ int main(int argc, char **argv)
 
     VERBOSE(VB_ALL, QString("Enabled verbose msgs :%1").arg(verboseString));
 
-    MythPluginManager::init();
-
     translator.load(PREFIX + QString("/share/mythtv/i18n/mythfrontend_") + 
                     QString(gContext->GetSetting("Language").lower()) + 
                     QString(".qm"), ".");
@@ -620,10 +704,14 @@ int main(int argc, char **argv)
     mainWindow->Init();
     gContext->SetMainWindow(mainWindow);
 
+    InitJumpPoints();
+
+    MythPluginManager::init();
+
     gContext->UpdateImageCache();
 
-    lcd_host = gContext->GetSetting("LCDHost");
-    lcd_port = gContext->GetNumSetting("LCDPort");
+    lcd_host = gContext->GetSetting("LCDHost", "localhost");
+    lcd_port = gContext->GetNumSetting("LCDPort", 13666);
 
     if (lcd_host.length() > 0 && lcd_port > 1024 && gContext->GetLCDDevice())
     {
@@ -639,21 +727,20 @@ int main(int argc, char **argv)
     else
         xbox = NULL;
 
+    // this direct connect is only necessary, if the user wants to use the
+    // auto shutdown/wakeup feature
+    if (gContext->GetNumSetting("idleTimeoutSecs",0) > 0)
+        gContext->ConnectToMasterServer();
+
     if (pluginname != "")
     {
-        if (MythPluginManager::init_plugin(pluginname))
-        {
-            MythPluginManager::run_plugin(pluginname);
+        if (MythPluginManager::run_plugin(pluginname))
             return 0;
-        }
         else
         {
             pluginname = "myth" + pluginname;
-            if (MythPluginManager::init_plugin(pluginname))
-            {
-                MythPluginManager::run_plugin(pluginname);
+            if (MythPluginManager::run_plugin(pluginname))
                 return 0;
-            }
         }
     }            
 
@@ -662,7 +749,8 @@ int main(int argc, char **argv)
 
     int exitstatus = RunMenu(themedir);
 
-    haltnow(exitstatus);
+    if (exitstatus == HALT)
+        haltnow();
 
     delete gContext;
     return exitstatus;
