@@ -14,6 +14,7 @@
 #include <qheader.h>
 #include <qfile.h>
 #include <qsqldatabase.h>
+#include <qmap.h>
 
 #include <unistd.h>
 
@@ -68,8 +69,6 @@ PlaybackBox::PlaybackBox(BoxType ltype, MythMainWindow *parent,
     usageRect = QRect(0, 0, 0, 0);
     videoRect = QRect(0, 0, 0, 0);
 
-    connect(this, SIGNAL(killTheApp()), this, SLOT(accept()));
-
     noUpdate = false;
 
     showDateFormat = gContext->GetSetting("ShortDateFormat", "M/d");
@@ -99,7 +98,7 @@ PlaybackBox::PlaybackBox(BoxType ltype, MythMainWindow *parent,
         exit(0);
     }
 
-    connected = FillList(); 
+    firstrun = true;
 
     curTitle = 0;
 
@@ -118,7 +117,7 @@ PlaybackBox::PlaybackBox(BoxType ltype, MythMainWindow *parent,
 
     connect(timer, SIGNAL(timeout()), this, SLOT(timeout()));
 
-    timer->start(1000 / 30);
+    timer->start(500);
     gContext->addListener(this);
 }
 
@@ -238,7 +237,7 @@ void PlaybackBox::exitWin()
     timer->stop();
     killPlayer();
 
-    emit killTheApp();
+    accept();
 }
 
 void PlaybackBox::updateBackground(void)
@@ -317,6 +316,7 @@ void PlaybackBox::updateInfo(QPainter *p)
     if (noUpdate == true)
         return;
 
+    QMap<QString, QString> regexpMap;
     QRect pr = infoRect;
     QPixmap pix(pr.size());
     pix.fill(this, pr.topLeft());
@@ -330,22 +330,7 @@ void PlaybackBox::updateInfo(QPainter *p)
         if (playingVideo == true)
             killPlayer();
 
-        QDateTime startts = curitem->startts;
-        QDateTime endts = curitem->endts;
-
-        QString timedate = startts.date().toString(dateformat) + ", " +
-                           startts.time().toString(timeformat) + " - " +
-                           endts.time().toString(timeformat);
-
-        QString chantext = "";
-        if (displayChanNum)
-            chantext = curitem->channame + " [" + curitem->chansign + "]";
-        else
-            chantext = curitem->chanstr;
-
-        QString subtitle = curitem->subtitle;
-        if (subtitle.length() > 1)
-            subtitle = "\"" + curitem->subtitle + "\"";
+        curitem->ToMap(m_db, regexpMap);
 
         LayerSet *container = NULL;
         if (type != Delete)
@@ -354,25 +339,12 @@ void PlaybackBox::updateInfo(QPainter *p)
             container = theme->GetSet("program_info_del");
         if (container)
         {
-            UITextType *type = (UITextType *)container->GetType("title");
-            if (type)
-                type->SetText(curitem->title);
+            if ((playbackPreview == 0) &&
+                (generatePreviewPixmap == 0))
+                container->UseAlternateArea(true);
 
-            type = (UITextType *)container->GetType("subtitle");
-            if (type)
-                type->SetText(subtitle);
-    
-            type = (UITextType *)container->GetType("timedate");
-            if (type)
-                type->SetText(timedate);
-
-            type = (UITextType *)container->GetType("description");
-            if (type)
-                type->SetText(curitem->description);
-
-            type = (UITextType *)container->GetType("channel");
-            if (type)
-                type->SetText(chantext);
+            container->ClearAllText();
+            container->SetTextByRegexp(regexpMap);
 
             UIImageType *itype;
             itype = (UIImageType *)container->GetType("commflagged");
@@ -441,9 +413,9 @@ void PlaybackBox::updateInfo(QPainter *p)
 
         ignoreevents = false;
 
-        timer->start(1000 / 30);
+        timer->start(500);
     }
-    else
+    else if (!firstrun)
     {
         LayerSet *norec = theme->GetSet("norecordings_info");
         if (type != Delete && norec)
@@ -461,7 +433,7 @@ void PlaybackBox::updateVideo(QPainter *p)
     if (noUpdate == true)
         return;
 
-    if (playbackPreview == 0 && curitem)
+    if (((playbackPreview == 0) || !playingVideo) && curitem)
     {
         QPixmap temp = getPixmap(curitem);
         if (temp.width() > 0)
@@ -582,7 +554,7 @@ void PlaybackBox::updateShowTitles(QPainter *p)
     QString tempDate;
     QString tempTime;
     QString tempSize;
-    bool tempCurrent;
+    int tempCurrent = 0;
 
     QString match;
     QRect pr = listRect;
@@ -597,12 +569,10 @@ void PlaybackBox::updateShowTitles(QPainter *p)
     typedef QMap<QString, ProgramInfo> ShowData;
     ProgramInfo *tempInfo;
 
-    QDateTime curtime = QDateTime::currentDateTime();
-
     ShowData::Iterator it;
     ShowData::Iterator start;
     ShowData::Iterator end;
-    if (titleData[curTitle] != tr("All Programs"))
+    if (titleData && titleData[curTitle] != tr("All Programs"))
     {
         start = showData.begin();
         end = showData.end();
@@ -613,7 +583,10 @@ void PlaybackBox::updateShowTitles(QPainter *p)
         end = showDateData.end();
     }
 
-    if (container)
+    int overrectime = gContext->GetNumSetting("RecordOverTime", 0);
+    int underrectime = gContext->GetNumSetting("RecordPreRoll", 0);
+
+    if (container && titleData)
     {
         int itemCnt = 0;
         UIListType *ltype = (UIListType *)container->GetType("toptitles");
@@ -682,10 +655,9 @@ void PlaybackBox::updateShowTitles(QPainter *p)
                      {
                          tempInfo = &(it.data());
 
-                         if (curtime < tempInfo->endts)
-                             tempCurrent = true;
-                         else
-                             tempCurrent = false;
+                         tempCurrent = RemoteGetRecordingStatus(tempInfo,
+                                                                overrectime,
+                                                                underrectime);
 
                          if (titleData[curTitle] == tr("All Programs"))
                              tempSubTitle = tempInfo->title; 
@@ -719,10 +691,12 @@ void PlaybackBox::updateShowTitles(QPainter *p)
                          ltype->SetItemText(cnt, 2, tempDate);
                          ltype->SetItemText(cnt, 3, tempTime);
                          ltype->SetItemText(cnt, 4, tempSize);
-                         if (tempCurrent == true)
+                         if (tempCurrent == 1)
                              ltype->EnableForcedFont(cnt, "recording");
+                         else if (tempCurrent > 1)
+                             ltype->EnableForcedFont(cnt, "recording"); // FIXME: change to overunderrecording, fall back to recording. 
 
-                            cnt++;
+                         cnt++;
                      }
                      pastSkip--;
                      titleitems++;
@@ -787,7 +761,7 @@ void PlaybackBox::updateShowTitles(QPainter *p)
 
     leftRight = false;
 
-    if (showData.count() == 0)
+    if (showData.count() == 0 && !firstrun)
     {
         LayerSet *norec = theme->GetSet("norecordings_list");
         if (type != Delete && norec)
@@ -1320,7 +1294,7 @@ void PlaybackBox::play(ProgramInfo *rec)
 
     ignoreevents = false;
 
-    timer->start(1000 / 30);
+    timer->start(500);
 }
 
 void PlaybackBox::stop(ProgramInfo *rec)
@@ -1333,13 +1307,13 @@ void PlaybackBox::stop(ProgramInfo *rec)
     noUpdate = false;
 }
 
-void PlaybackBox::doRemove(ProgramInfo *rec)
+void PlaybackBox::doRemove(ProgramInfo *rec, bool forgetHistory)
 {
     if (noUpdate)
         return;
 
     noUpdate = true;
-    RemoteDeleteRecording(rec);
+    RemoteDeleteRecording(rec, forgetHistory);
     noUpdate = false;
 
     if (titleitems == 1)
@@ -1470,6 +1444,15 @@ void PlaybackBox::showDeletePopup(ProgramInfo *program, int types)
     QString tmpmessage;
     const char *tmpslot;
 
+    if ((types == 1 || types == 2) &&
+        (program->subtitle != "" || program->description != ""))
+    {
+
+        tmpmessage = tr("Yes; allow re-recording"); 
+        tmpslot = SLOT(doDeleteForgetHistory());
+        popup->addButton(tmpmessage, this, tmpslot);
+    }
+
     switch (types)
     {
         case 1: case 2: tmpmessage = tr("Yes, get rid of it"); 
@@ -1538,11 +1521,13 @@ void PlaybackBox::showActionPopup(ProgramInfo *program)
     initPopup(popup, program, " ", tr("Select action:"));
 
     QSqlDatabase *db = QSqlDatabase::database();
-    QDateTime curtime = QDateTime::currentDateTime();
 
     QButton *playButton = popup->addButton(tr("Play"), this, SLOT(doPlay()));
 
-    if ((curtime >= program->startts) && (curtime < program->endts))
+    int overrectime = gContext->GetNumSetting("RecordOverTime", 0);
+    int underrectime = gContext->GetNumSetting("RecordPreRoll", 0);
+
+    if (RemoteGetRecordingStatus(program, overrectime, underrectime) > 0)
         popup->addButton(tr("Stop Recording"), this, SLOT(askStop()));
 
     if (delitem->GetAutoExpireFromRecorded(db))
@@ -1650,7 +1635,7 @@ void PlaybackBox::noStop(void)
     delete delitem;
     delitem = NULL;
 
-    timer->start(1000 / 30);
+    timer->start(500);
 }
 
 void PlaybackBox::doStop(void)
@@ -1665,7 +1650,7 @@ void PlaybackBox::doStop(void)
     delete delitem;
     delitem = NULL;
 
-    timer->start(1000 / 30);
+    timer->start(500);
 }
 
 void PlaybackBox::askDelete(void)
@@ -1688,7 +1673,7 @@ void PlaybackBox::noDelete(void)
     delete delitem;
     delitem = NULL;
 
-    timer->start(1000 / 30);
+    timer->start(500);
 }
 
 void PlaybackBox::doDelete(void)
@@ -1698,12 +1683,27 @@ void PlaybackBox::doDelete(void)
 
     cancelPopup();
 
-    doRemove(delitem);
+    doRemove(delitem, false);
 
     delete delitem;
     delitem = NULL;
 
-    timer->start(1000 / 30);
+    timer->start(500);
+}
+
+void PlaybackBox::doDeleteForgetHistory(void)
+{
+    if (!expectingPopup)
+        return;
+
+    cancelPopup();
+
+    doRemove(delitem, true);
+
+    delete delitem;
+    delitem = NULL;
+
+    timer->start(500);
 }
 
 void PlaybackBox::noAutoExpire(void)
@@ -1775,6 +1775,15 @@ void PlaybackBox::timeout(void)
         return;
     if (noUpdate)
         return;
+
+    if (firstrun)
+    {
+        firstrun = false;
+        connected = FillList();
+        skipUpdate = false;
+        repaint(fullRect);
+    }
+
     if (showData.count() == 0)
         return;
 
@@ -1804,6 +1813,8 @@ void PlaybackBox::timeout(void)
 
     if (playbackPreview == 0)
         timer->stop();
+    else
+        timer->start(1000 / 30);
 }
 
 void PlaybackBox::keyPressEvent(QKeyEvent *e)
@@ -1813,43 +1824,49 @@ void PlaybackBox::keyPressEvent(QKeyEvent *e)
 
     bool handled = false;
 
-    if (showData.count() > 0)
+    QStringList actions;
+    gContext->GetMainWindow()->TranslateKeyPress("TV Frontend", e, actions);
+
+    for (unsigned int i = 0; i < actions.size() && !handled; i++)
     {
+        QString action = actions[i];
         handled = true;
-        switch (e->key())
+
+        if (action == "ESCAPE")
         {
-            case Key_D: 
-                deleteSelected(); 
-                break;
-            case Key_I: 
-                showActionsSelected(); 
-                break;
-            case Key_P: 
-                playSelected(); 
-                break;
-            case Key_Space:
-            case Key_Enter:
-            case Key_Return:
-                selected();
-                break;
-            default:  handled = false; break;
+            exitWin();
         }
+        else if (showData.count() > 0)
+        {
+            if (action == "DELETE")
+                deleteSelected();
+            else if (action == "PLAYBACK")
+                playSelected();
+            else if (action == "MENU" || action == "INFO")
+                showActionsSelected();
+            else if (action == "SELECT")
+                selected();
+            else if (action == "UP")
+                cursorUp();
+            else if (action == "DOWN")
+                cursorDown();
+            else if (action == "LEFT")
+                cursorLeft();
+            else if (action == "RIGHT")
+                cursorRight();
+            else if (action == "PAGEUP")
+                pageUp();
+            else if (action == "PAGEDOWN")
+                pageDown();
+            else
+                handled = false;
+        }
+        else
+            handled = false;
     }
 
-    if (handled)
-        return;
-
-    switch (e->key())
-    {
-        case Key_Left: cursorLeft(); break;
-        case Key_Right: cursorRight(); break;
-        case Key_Down: cursorDown(); break;
-        case Key_Up: cursorUp(); break;
-        case Key_3: case Key_PageUp: pageUp(); break;
-        case Key_9: case Key_PageDown: pageDown(); break;
-        case Key_Escape: exitWin(); break;
-        default: MythDialog::keyPressEvent(e); break;
-    }   
+    if (!handled)
+        MythDialog::keyPressEvent(e);
 }
 
 void PlaybackBox::customEvent(QCustomEvent *e)
