@@ -31,9 +31,6 @@ class PlaybackBox : public MythDialog
    
     void customEvent(QCustomEvent *e);
   
-  signals:
-    void killTheApp();
- 
   protected slots:
     void timeout(void);
 
@@ -58,6 +55,7 @@ class PlaybackBox : public MythDialog
 
     void askDelete();
     void doDelete();
+    void doDeleteForgetHistory();
     void noDelete();
 
     void doAutoExpire();
@@ -116,7 +114,7 @@ class PlaybackBox : public MythDialog
     void killPlayer(void);
     void startPlayer(ProgramInfo *rec);
 
-    void doRemove(ProgramInfo *);
+    void doRemove(ProgramInfo *, bool forgetHistory);
     void promptEndOfRecording(ProgramInfo *);
     void showDeletePopup(ProgramInfo *, int);
     void showActionPopup(ProgramInfo *program);
@@ -172,6 +170,8 @@ class PlaybackBox : public MythDialog
     QColor popupHighlight;
 
     bool expectingPopup;
+
+    bool firstrun;
 };
 
 #endif
