@@ -53,6 +53,8 @@ int main(int argc, char *argv[])
     mainWindow->Show();
     gContext->SetMainWindow(mainWindow);
 
+    TV::InitKeys();
+
     TV *tv = new TV(db);
     tv->Init();
 
@@ -61,6 +63,7 @@ int main(int argc, char *argv[])
         QString filename = a.argv()[1];
 
         ProgramInfo *pginfo = new ProgramInfo();
+        pginfo->endts = QDateTime::currentDateTime().addSecs(-180);
         pginfo->pathname = filename;
     
         tv->Playback(pginfo);
